*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   24.06.2006                                 *
*  top quark decay widths via FCNC channels                                  *
*----------------------------------------------------------------------------*
      subroutine FCNC_INI(tw) 
*     -------------------                                                    *
*                                                                            *
* anomalous couplings, see 'Top quark physics", hep-ph/0003033, M.Beneke     *
* parameters for each type (i.e. F + H gamma_5)                              *
* parameterization assumed  Ubar(t) ... ( F + H gamma_5) u(q)                *
* return the top decay width (in GeV)                                        *
*............................................................................*

      implicit none
      include "txpar.inc" 
      double precision mq,       mq2
      common  /massql/ mq(0:20), mq2(0:20)
      double precision als
      double precision tw(0:6) 
      integer I, JJ, KZ
      double complex   FL,     FR,      HL,    HR,
     &                 XL,     XR,      YL,    YR
      common /ANOMCPL/FL(20), FR(20), HL(20), HR(20), 
     &                XL(20), XR(20), YL(20), YR(20) 
      double precision rl1, rl2, rl3, xz
*............................................................................*
*..Rpar(30)     : width of t-> d  W decay at tree level (SM case)            *
*..Rpar(31)     : width of t-> s  W decay at tree level (SM case)            *
*..Rpar(32)     : width of t-> b  W decay at tree level (SM case)            *
*..Rpar(33)     : width of t-> b4 W decay at tree level (SM case)            *
*..Rpar(34)     : total t-quark decay width                                  *
*..Rpar(50)     : New Physics scale (1 TeV), FCNC                            *
*... FCNC          t GLUON q                                                 *
*............................................................................*
*
* setting KF codes for final particles in top FCNC decay
      
      FID(1,11,1) = 2   ! Up
      FID(1,11,2) = 21  ! gluon 
      FID(1,12,1) = 4   ! C 
      FID(1,12,2) = 21  ! gluon 

      FID(1,13,1) = 2   ! Up
      FID(1,13,2) = 22  ! photon 
      FID(1,14,1) = 4   ! C 
      FID(1,14,2) = 22  ! photon

      FID(1,15,1) = 2   ! Up
      FID(1,15,2) = 23  ! Z-boson 
      FID(1,16,1) = 4   ! C 
      FID(1,16,2) = 23  ! Z-boson
      FID(1,18,2) = 23  ! Z-boson
*
      if(MID(15, 1).ge.1.or.MID(16, 1).ge.1) then
      if(mid(7,  4).ge.1) mid(7,  4) = 0  ! supress b4 
      if(mid(8,  4).ge.1) mid(8,  4) = 0  ! supress t4
      if(mid(15, 4).ge.1) mid(15, 4) = 0  ! supress L4
      if(mid(16, 4).ge.1) mid(16, 4) = 0  ! supress nu_L4
       endif
                      
      if(  MID(11, 1).eq.-1.and.MID(12, 1).eq.-1
     &.and.MID(13, 1).eq.-1.and.MID(14, 1).eq.-1
     &.and.MID(15, 1).eq.-1.and.MID(16, 1).eq.-1) then
*      write(*, 175) 
 175  format(/,3x,'TopReX : no FCNC interactions',/,
     &         3x,'-----------------------------',/)
      return
      endif
*
      als = 0.1     ! we set alpha_s = 0.1
       do I = 1,6
        tw(I) = 0.d0
       enddo      
* t -> gluon U 
       JJ = 11
      if(mid(jj,1).ge.0) then
       tw(1) = 
     & 16.d0*(HR(jj)*conjg(HR(jj)) + HL(jj)*conjg(HL(jj)))
     & + mq2(6)*(XR(jj)*conjg(XR(jj)) + XL(jj)*conjg(XL(jj)))
     & -4.d0*mq(6)*
     &       (HR(jj)*conjg(XR(jj)) + XR(jj)*conjg(HR(jj))
     &      + HL(jj)*conjg(XL(jj)) + XL(jj)*conjg(HL(jj)))
       TW(1) = tw(1) * als * mq(6)**3 / 12.d0
      else
       tw(1) = 0.d0
      endif 
* t -> gluon C
       JJ = 12
      if(mid(jj,1).ge.0) then
       tw(2) = 
     & 16.d0*(HR(jj)*conjg(HR(jj)) + HL(jj)*conjg(HL(jj)))
     & + mq2(6)*(XR(jj)*conjg(XR(jj)) + XL(jj)*conjg(XL(jj)))
     & -4.d0*mq(6)*
     &       (HR(jj)*conjg(XR(jj)) + XR(jj)*conjg(HR(jj))
     &      + HL(jj)*conjg(XL(jj)) + XL(jj)*conjg(HL(jj)))
       TW(2) = tw(2) * als * mq(6)**3 / 12.d0
      else
       tw(2) = 0.d0
      endif 
* t -> gamma U 
       JJ = 13
      if(mid(jj,1).ge.0) then
       tw(3) = 
     & 16.d0*(HR(jj)*conjg(HR(jj)) + HL(jj)*conjg(HL(jj)))
     & + mq2(6)*(XR(jj)*conjg(XR(jj)) + XL(jj)*conjg(XL(jj)))
     & -4.d0*mq(6)*
     &       (HR(jj)*conjg(XR(jj)) + XR(jj)*conjg(HR(jj))
     &      + HL(jj)*conjg(XL(jj)) + XL(jj)*conjg(HL(jj)))
       TW(3) = tw(3) * rpar(11) * mq(6)**3 / 16.d0
      else
       tw(3) = 0.d0
      endif 
* t -> gamma C 
       JJ = 14
      if(mid(jj,1).ge.0) then
       tw(4) = 
     & 16.d0*(HR(jj)*conjg(HR(jj)) + HL(jj)*conjg(HL(jj)))
     & +      XR(jj)*conjg(XR(jj)) + XL(jj)*conjg(XL(jj))
     & -4.d0*(HR(jj)*conjg(XR(jj)) + XR(jj)*conjg(HR(jj))
     &      + HL(jj)*conjg(XL(jj)) + XL(jj)*conjg(HL(jj)))
       TW(4) = tw(4) * rpar(11) * mq(6)**3 / 16.d0
      else
       tw(4) = 0.d0
      endif 
* t -> Z U 
      xz = Rpar(46)/mq2(6)
      TW(5) = (rpar(11) * mq(6)**3/4.d0/Rpar(46)/Rpar(25)**2) 
     & * (1.d0 - xz)**2
      KZ = 15
      RL1=FL(kz)*conjg(FL(kz)) + FR(kz)*conjg(FR(kz))
      RL2=HR(kz)*conjg(HR(kz)) + HL(kz)*conjg(HL(kz))
      RL3=FR(kz)*conjg(HR(kz)) + FL(kz)*conjg(HL(kz))
     &   +HR(kz)*conjg(FR(kz)) + HL(kz)*conjg(FL(kz))
      TW(5) = TW(5) *
     &(  RL1 * (1.d0 + 2.d0*xz) 
     & + RL2 * 4.d0 * mq2(6) * xz * (2.d0 + xz)
     & - RL3 * 6.d0 * mq(6) * xz )
* t -> Z C,   gamma-coupling
      xz = Rpar(46)/mq2(6)
      TW(6) = (rpar(11) * mq(6)**3/4.d0/Rpar(46)/Rpar(25)**2) 
     & * (1.d0 - xz)**2
      KZ = 16
      RL1=FL(kz)*conjg(FL(kz)) + FR(kz)*conjg(FR(kz))
      RL2=HR(kz)*conjg(HR(kz)) + HL(kz)*conjg(HL(kz))
      RL3=FR(kz)*conjg(HR(kz)) + FL(kz)*conjg(HL(kz))
     &   +HR(kz)*conjg(FR(kz)) + HL(kz)*conjg(FL(kz))
      TW(6) = TW(6) *
     &(  RL1 * (1.d0 + 2.d0*xz) 
     & + RL2 * 4.d0 * mq2(6) * xz * (2.d0 + xz)
     & - RL3 * 6.d0 * mq(6) * xz )
**
      TW(0) = 0.d0
      do i = 1,6
       if(mid((I+10), 1).lt.0) tw(i) = 0.d0
        tw(0) = tw(0) + tw(i)
      enddo  
      write(*, 75) Rpar(50)
 75   format(/,3x,'TopReX :  FCNC couplings and  widths',/,
     &         3x,'------------------------------------',/,
     &3x,'New Physics scale  Lambda = ',f8.2,' GeV') 
      
      if(mid(11,1).ge.0.OR.mid(12,1).ge.0) then
       write(*,*) '  FCNC:  q GLUON T '
       write(*,74) tw(1),tw(2) 
      endif
      if(mid(13,1).ge.0.OR.mid(14,1).ge.0) then
       write(*,*) '  FCNC:  q PHOTON T '
       write(*,74) tw(3),tw(4)
      endif 
      if(mid(15,1).ge.0.OR.mid(16,1).ge.0) then
       write(*,*) '  FCNC:  q Z T '
       write(*,74) tw(5),tw(6)
      endif
       write(*,79)  tw(0)
 74   format('   Width U ',d9.3,1x,'Width C ',d9.3)
 79   format(
     &3x,'total t-quark FCNC decay width = ',d10.3,' GeV')

      return
      end
