*----------------------------------------------------------------------------*
*.. author:   Serge Slabospitsky   10.03.2002                                *
*............................................................................*
      subroutine HC_dec_ini
*     --------------------                                                   *
*                                                                            *
* return charged Higgs decay width (in GeV)                                  *
* decay channels of H+- are considered, H+- ->                               *
* 1 : U Dbar,  2 : C Dbar,  3 : T Dbar,    4 : t4 Dbar                       *
* 5 : U Sbar,  6 : C Sbar,  7 : T Sbar,    8 : t4 Sbar                       *
* 9 : U Bbar,  10: C Bbar,  11: T Bbar,    12: t4 Bbar                       *
* 13: U brbar, 14: C b4bar, 15: T b4bar,   16: t4 b4bar                      *
* 17: nue   e, 18: numu mu, 19: nutau tau, 20: nuL L                         *
* 21: t*(W b) bbar -> W B Bbar, 22:29 reserved for future                    *
* 30: t -> B H                                                               *
*                                                                            *
*............................................................................*

      implicit none
      include "txpar.inc" 
      double precision mql,       mql2
      common  /massql/ mql(0:20), mql2(0:20)
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6

      double precision mh, tb, ctb, a, b, del !, rt !, rw, tww21
      double precision VCKM2
      common  /CKMD/ VCKM2(-6:6,-6:6)

* first parameter in MID, BRF, FID, and BRS has the meaning as follows
      integer IT        
*     It = 1 : top quark,  It = 2 : W-boson, 
*     It = 3 : H+- boson,  It = 4 : Z-boson 
*...........
      integer i,j,iu,id, nnn
      double precision  widnew   ! width to new decay channels
*............................................................................*
*..Rpar(51)     : Charged Higgs Mass                                         *
*..Rpar(53)     : total charged Higgs decay width                            *
*..Rpar(55)     : MSSM's tan(beta)                                           *

      double precision HCPL,       HCPL2   
      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)

*..HCPL(1)  = (m(D)/M_W) * tan(beta)     HCPL(2) = (m(U)/M_W) * cot(beta)    *
*..HCPL(3)  = (m(S)/M_W) * tan(beta)     HCPL(4) = (m(C)/M_W) * cot(beta)    *
*..HCPL(5)  = (m(B)/M_W) * tan(beta)     HCPL(6) = (m(T)/M_W) * cot(beta)    *
*..HCPL(11) = (m(e)/M_W)   *tan(beta) HCPL(12) = (m(nu_e)/M_W) * cot(beta)   *
*..HCPL(13) = (m(mu)/M_W)  *tan(beta) HCPL(14) = (m(nu_mu)/M_W) * cot(beta)  *
*..HCPL(15) = (m(tau)/M_W) *tan(beta) HCPL(16) = (m(nu_tau)/M_W) * cot(beta) *
*............................................................................*
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
*...............................    
      if(.NOT.first) return 
      first=.FALSE.
*
      Rpar(52) = Rpar(51)**2 
      Rpar(56) = 1.d0 / Rpar(55)

      It = 3          ! H+- 
      widnew = 0.d0   !  no uncalculated channels are considered
* always supress decays:  H+ -> T Dbar and H+ -> T Sbar
      mid(3, it) = -1
      mid(7, it) = -1
*
      tb  = Rpar(55)
      ctb = Rpar(56) 
      mh  = Rpar(51)
* always supress decays into NEW 4-generation quarks and leptons
      mid( 4, it)  = -1    
      mid( 8, it)  = -1
      mid(12, it) = -1
      mid(13, it) = -1
      mid(14, it) = -1
      mid(15, it) = -1
      mid(16, it) = -1
      mid(20, it) = -1
*   H+-  -> q qbar'
      nnn = 0 
      do j = 1,4
      do i = 1,4
       nnn = nnn + 1
       iu = 2*I
       id = 2*J - 1 
        Fid(it,nnn,1) = +iu
        Fid(it,nnn,2) = -id
       if(mid(nnn, it).eq.-1)        goto 229
        if(abs(iu).eq.6)            goto 229  ! supress t -> b H+
        if((mql(iu)+mql(id)).ge.MH) goto 229 
         a = (mql(id) / mh)**2
         b = (mql(iu) / mh)**2
         del = sqrt(1. + a**2 + b**2 - 2.*(a + b + a*b))
       wid(nnn,IT) = del*(3.* Rpar(26)**2 / (32. *pi * mh))
     &*( (mh**2 - mql2(iu)-mql2(id))*(hcpl2(iu)+hcpl2(id))
     & - 4.d0*hcpl(iu)*hcpl(id)*mql(iu)*mql(id))
       wid(nnn,IT) = WID(nnn,IT) * Vckm2(id,iu)
       goto 230 
 229   wid(nnn,IT) = 0.d0
 230  continue 
      enddo      
      enddo      

*   H+-  -> e nu_e, mu nu_mu, tau nu_tau 
      wid(17,it) = rpar(26)**2 * mh * hcpl2(11) / (32.d0 *pi) 
        Fid(it,17,1) =  12 
        Fid(it,17,2) = -11 
      wid(18,it) = rpar(26)**2 * mh * hcpl2(13) / (32.d0 *pi) 
        Fid(it,18,1) =  14 
        Fid(it,18,2) = -13 
      wid(19,it) = rpar(26)**2 * mh * hcpl2(15) / (32.d0 *pi)
        Fid(it,19,1) =  16 
        Fid(it,19,2) = -15 
*
      wid(0,it) = widnew   ! uncalculated width  
      do I = 1, 21
       if(mid(I, it).ne.-1)  wid(0,it) = wid(0,it) + wid(I,it)
      enddo
      RETURN
      END
