
*----------------------------------------------------------------------------*
*----------------------------------------------------------------------------*
*...Author : Serge Slabospitsky                                              *
*...                                                                         *
      subroutine LIPS2(Q, p1, p2, Wt)
*     -------------------------------                                        *
*...                                                                         *
*...calculate 2-body Lorentz Invariant Phase Space                           *
*    Q --> p1 p2                                                             *
*...input  : Q is 5-vector of initial system                                 *
*...output : p1 and p2 are 5-momenta of final particles                      *
*   the LIPS2 return WT, which is the weight                                 *
*       WT = 4*pi* / p-vect/ (4 sqrt(s)) / (2*pi)**6                         *
* ...(5) are masses of the momenta                                           *
*............................................................................*

      implicit None
      double precision Q(5), p1(5), p2(5), pp(5)
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision PYR
      double precision Wt, delta, rp, cte, ste, fi
      Integer l
*
      Wt = 0.d0
      DELTA = Q(5)**4 + p1(5)**4 + p2(5)**4 
     &-2.d0*((Q(5)*p1(5))**2+(Q(5)*p2(5))**2+(p1(5)*p2(5))**2)
       if(delta.ge.0.0d0) then
        delta = dsqrt(delta)
       else
        delta = 0.d0
       endif
      rp = delta / (2.d0 * Q(5)) 
c  calculation of p1 and p2  in the rest frame of pin
      cte = 1.d0 - 2.d0*PYR(0) 
      ste = DSQRT(1.d0 - cte*cte)
      fi = 2.d0*pi*PYR(0) 
      pp(4) = (Q(5)**2 + p1(5)**2 - p2(5)**2) / (2.d0 * Q(5)) 
      pp(3) = rp*cte
      pp(2) = rp*ste*DSIN(fi)
      pp(1) = rp*ste*DCOS(fi)
      pp(5) = p1(5)
       if(pp(5).GT.pp(4)) return
* now PP is momentum of 1-particle in the rest frame of Q 
      call lorenb_s(Q, pp, p1) ! Lorentz transformation into initial frame
        if(p1(5).gt.p1(4)) return
       do l = 1,4
        p2(l) = Q(l) - p1(l)
       end do
        if(p2(5).gt.p2(4)) return
      Wt = pi * rp / (Q(5) * pi2_6 )
      return
      end
