*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   15.11.99                                   *
*....                                                                        *
      subroutine LIPS_QG(Q, b, PS, P0, Ves)      
*     -------------------------------------                                  *
*                                                                            *
* calculation of the LIPS with ONE system and one on-shell particle          *
* in the final state with inclusion of denominator from system               *
* the denominator corresponds to B-exchane in the t-channel                  *
*   R -> P1 (-> X1)  PS                                                      *
*                                                                            *
*    4 * R2(R -> b Ps)                                                       *
*    -----------------                                                       *
*    [(m(b)**2 - t)                                                          *
*                                                                            *
*... input :                                                                 *
*  Q   is  5-momentum of initial system                                      *
*  P0  is min. invariant mass of the system (PS)                             *
*  P0 is positive(negative) for q along-side(counter-side) Z-axis            *
*                                                                            *
*    q ------O------ b                                                       *
*            |          t = (q - b)**2                                       *
*            |                                                               *
*    --------O====== Ps                                                      *
*                                                                            *
*... output :                                                                *
*  B  is 5-momentum of the on-shell particle                                 *
*  PS is 5-momentum of the system                                            *
*  ves is the weight                                                         * 
*............................................................................*

      implicit none
      double precision PYR, aran
      double precision Q(5), B(5), PS(5), P0, bv, p2, al 
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision fi, del, cte, ste
      double precision ves
      integer j
c  calculation of Ps**2 and ps in the rest frame of pin
      del = (Q(5) - b(5))**2 - p0**2
      p2  = p0**2 + del*PYR(0)
*      ps(5) = p2
      b(4) = (q(5)**2 + b(5)**2 - p2) / 2.d0 / q(5)
      bv = dsqrt(b(4)**2 - b(5)**2)
      aran = pyr(0)
      al = b(4) / bv
       cte = al - (al-1.d0)*((al+1.d0)/(al-1.d0))**(pyr(0))
       if(p0.lt.0.d0) cte = - cte
       ste = dsqrt(1. - cte*cte)
       fi = pi2 * PYR(0) 
      b(3) = bv * cte
      b(2) = bv * ste * dsin(fi)
      b(1) = bv * ste * dcos(fi)
* now B is momentum of 1-particle in the rest frame of Q
      call lorenb_s(q, b, Ps)     ! Lorentz trasformation into
                                  ! initial frame
       ps(5) = dsqrt(p2)
      do j = 1,4
       b(j) = ps(j)
       PS(j) = Q(j) - B(j)
      end do
      ves = del * dlog((b(4)+bv)/b(5)) / (4.d0 * pi**2 * Q(5)**2)
      return
      end
