*----------------------------------------------------------------------------*
*  matrix element for the W Q Qbar process                                   *
*.. author: Serge Slabospitsky                                               *
*.. 21/06/2000                                                               *
*                                                                            *
      subroutine MwQQ(k1,k2, q1, q2, PL, PN, ves)
*     ---------------------------------------------------                    *
*   U    Dbar --> W+ (-> e+(l1) nu(l2)) Q  Qbar                              *
*   k1   k2              PL     PN      q1 q2                                *
*   W-boson decay is included and W-boson is OFF-SHELL                       * 
*   denominators from gluon and W-boson propagators are removed and          *
*   calculated in LIPS (see RLIP43 routine)                                  *
*   amq is mass of q1 (or q2)                                                *
*............................................................................*
      Implicit none
      include "txpar.inc" 
      double precision amq, amq2
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision k1(5), k2(5), q1(5), q2(5), PL(5), pn(5)
      double precision q(5), r(5), x1(5), x2(5)
      double precision SCALP, t1, t2, t3 
      double precision qq2, s, t, U, R2, rk1, rk2, rl1, rl2
      double precision qk1, qk2, ql1, ql2, k1l1, k1l2, k2l1,k2l2, all
      double precision coef, ves 
      integer i

      LOGICAL first
      DATA first /.TRUE./
      SAVE first, Coef
*......
      if(first) THEN
      coef = 1024.*2.*rpar(10)*((4.*pi)**2)*(rpar(26)/2./dsqrt(2.d0))**4 
      coef = coef / (3. * 3. * 2. * 2.)  ! colors & spins
      coef = coef * 9.   !"*9" due to normalization to Br(W -> e+ nu) = 1
      first=.FALSE.
      ENDIF
* running
      amq = q1(5)
      amq2 = amq**2
      do i=1,4
       q(i) = q1(i) + q2(i)
       r(i) = q1(i) - q2(i)
       x1(i) = q(i) - k2(i)
       x2(i) = k1(i) - q(i)
      enddo

      qq2 = SCALP(q, q)
      t   = SCALP(x1, x1)
      U   = SCALP(x2, x2)
      S   = 2. * SCALP(k1, k2)
      R2  = SCALP(r, r)
      rk1 = SCALP(r, k1)
      rl1 = SCALP(r, pl)
      rk2 = SCALP(r, k2)
      rl2 = SCALP(r, pn)
      qk1 = SCALP(q, k1)
      ql1 = SCALP(q, PL)
      qk2 = SCALP(q, k2)
      ql2 = SCALP(q, pn)
      k1l1 = SCALP(k1, PL)
      k1l2 = SCALP(k1, pn)
      k2l1 = SCALP(k2, PL)
      k2l2 = SCALP(k2, pn)
      all   = SCALP(PL, pn)

      t1 = qq2*(- qk2*ql2 + 2.*qk2*k2l2 - rk2*rl2 + 2.*amq2*k2l2)
     & +qk2*(- 4.*ql2*amq2 + 2*rk2*rl2 - 2*qk2*k2l2) - 2*ql2*rk2**2
     &+ 2*rk2**2*k2l2

      t2 = qq2*(- qk1*ql1 + 2*qk1*k1l1 - rk1*rl1 + 2*amq2*k1l1)
     & - 4*qk1*ql1*amq2 + 2*qk1*rk1*rl1 - 2*qk1**2*k1l1 - 2*ql1*rk1**2
     &+ 2*rk1**2*k1l1

      t3 = s*qq2*(- 0.5*ql1*ql2 + ql1*k2l2 + ql2*k1l1 + 0.5*rl1*rl2
     &- 2*amq2*all - 2*k1l1*k2l2) + 2*s*ql1*ql2*amq2 - qq2*qk1*qk2*all
     &+ qq2*qk1*ql2*k2l1 - 2*qq2*qk1*k2l1*k2l2 + qq2*qk2*ql1*k1l2
     &- 2*qq2*qk2*k1l1*k1l2 + qq2*rk1*rk2*all - qq2*rk1*rl2*k2l1
     &- qq2*rk2*rl1*k1l2 + 4*qq2*amq2*k1l2*k2l1 - 2*qk1*qk2*rl1*rl2
     &+ 4*qk1*qk2*amq2*all + 4*qk1*qk2*k1l1*k2l2 + 2*qk1*ql2*rk2*rl1
     &- 4*qk1*ql2*amq2*k2l1 - 2*qk1*rk2*rl1*k2l2 + 2*qk2*ql1*rk1*rl2
     &- 4*qk2*ql1*amq2*k1l2 - 2*qk2*rk1*rl2*k1l1 - 2*ql1*ql2*rk1*rk2
     &+2*ql1*rk1*rk2*k2l2+2*ql2*rk1*rk2*k1l1 -4*rk1*rk2*k1l1*k2l2


      t1 = k1l1 * t1
      t2 = k2l2 * t2

      t1 = t1 / t**2
      t2 = t2 / u**2
      t3 = t3 / (t*u)

      ves = -(t1 + t2 + t3) * coef * rpar(15)**2
      ves = ves / qq2
      end
