*----------------------------------------------------------------------------*
*...Author : Serge Slabospitsky                                              *
      subroutine TX_Dec_Table 
*     -----------------------
*. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . *
* set decay tables for top, W+-, H+-, Z                                      *
* copy of W and Z boson decay parameters from PYTHIA to TopReX               *
*............................................................................*

      implicit none
      include "pydat_62.inc"
      include "txpar.inc" 
c      parameter (ndch=50)
      integer dectop(ndch), dechpm(ndch) 
      common /TXdecRE/dectop, dechpm 
      integer IT, I, J, i5,i6,i11 
* first parameter in MID, BRF, FID, and BRS has the meaning as follows
*     IT = 1 : top quark,  IT = 2 : W-boson, 
*     IT = 3 : H+- boson,  IT = 4 : Z-boson 
*  BRS(1, it) is the TOTAL Branching ratio for      particle
*  BRS(2, it) is the TOTAL Branching ratio for ANTI-particle
      do j = 1,ndch
         mid(j,1) = dectop(j) 
         mid(j,3) = dechpm(j) 
       do i = 1,4
        wid(0,i) = 0.d0 
        wid(j,i) = 0.d0 
        brf(j,i) = 0.d0    
       enddo
      enddo

*......................................
      IT = 1                ! top-quark
      Mid(0, it) = 16       ! number of top decay channels    
      if(mid(1,it).eq.-1) mid(1,it) = 0  ! SM always contributes to t width
      if(mid(2,it).eq.-1) mid(2,it) = 0  ! SM always contributes to t width
      if(mid(3,it).eq.-1) mid(3,it) = 0  ! SM always contributes to t width
*............................................................................*
*  copy of W-boson decay parameters from PYTHIA to TopReX                    *
*  WARNING !!! For W-boson case                                              *
*  First and second fermion flavors are opposite to PYTHIA,                  *
*  i.e. FDW(...,1) = KFDP(...,2) and FDW(...,2) = KFDP(...,1)                *
       IT = 2              ! W-boson  
        MID(0,IT) = 20     ! NWmax
         do I = 1, mid(0,it)
          J = 189 + I      ! J = 190 to 209  for PYTHIA
          MID(I,it)  = MDME(J,1)
          BRF(I,it)  = BRAT(J)
          FID(it,I,1) = KFDP(J,2)   ! interchange the order of final fermions
          FID(it,I,2) = KFDP(J,1)   ! for W-boson
         enddo
*................................................................
*  set decay table for H+- boson (very different from PYTHIA table)
* H+- decay channels: 
*  1  2  3   4    5  6  7  8    9  10 11 12 ...  17   18     19
*  dU dC dT  dt'  sU sC sT st'  bU bC bT bt'    e&nu mu&nu tau&nu 
*...........................................................
      IT = 3               ! H+- 
      mid(0,it) = 19       ! max. num. of H+- decay channels
      mid(3,it) = -1       ! always supress H+ -> T Dbar decay
      mid(7,it) = -1       ! always spores H+ -> T Sbar decay
* 
* check the consistence of t -> b H+, t -> H+*(->t*), and H+ -> t b~ 
* if at least one value ge.0 all other -1 values replaced to 0 value

      i5 = mid(5,1)
      i6 = mid(6,1)
      i11 = mid(11,3) 
      if(mid(5,1). eq.-1.AND.(mid(6,1).ge.0.OR.mid(11,3).ge.0)) 
     &   mid(5,1) = 0
      if(mid(6,1). eq.-1.AND.(mid(5,1).ge.0.OR.mid(11,3).ge.0)) 
     &   mid(6,1) = 0
      if(mid(11,3).eq.-1.AND.(mid(5,1).ge.0.OR.mid(6,1). ge.0)) 
     &   mid(11,3) = 0

       if(mid(5,1).ne.i5) write(*,5) 
 5    format(/,'  MID(5,1) = -1 is changed to zero-value')
       if(mid(6,1).ne.i6) write(*,6) 
 6    format(/,'  MID(6,1) = -1 is changed to zero-value')
       if(mid(11,3).ne.i11) write(*,11) 
 11   format(/,'  MID(11,3) = -1 is changed to zero-value')

*  Z-boson 
*  copy of Z-boson decay parameters from PYTHIA to TopReX                    *
      IT = 4              !  Z-boson
      MID(0,IT) = 16      !  max. num. of Z-boson decay channels
        do I = 1, mid(0,IT)
         J = 173 + I      ! J = 174 to 188
         MID(I,it)   = MDME(J,1)
         BRF(I,it)   = BRAT(J)
         FID(it,I,1) = KFDP(J,1) 
         FID(it,I,2) = KFDP(J,2)
        enddo
*.....
*
      call HIGCPL        ! H+- Yukawa couplings with running quark masses 
      call TXDEC_INI
*
      return
      end
