******************************************************************************
*                                                                            *
*          T o p R e X : 4.23                                                *
*          Date:  10.12.2006                                                 *
*----------------------------------------------------------------------------*
*                                                                            *
*... author : Serge Slabospitsky                                             *
*                                                                            *
      subroutine TopReX(FRAME,BEAM,TARGET, Ecm)
*     -----------------------------------------------                        *
*. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . *
*  setting user's parameters and  initializations of user's routines         *
*  for PYTHIA >= 6.226                                                       *
*............................................................................*
*                                                                            *
*............................................................................*
* Txsel = -1 : PYTHIA process                                                *
* Txsel = 1 : txpro(1) + txpro(2), doubling counting is removed              *
* Txsel = 2 : txpro(30+31+32+33),  doubling counting is removed              *
* Txpro( 1) :  EW top : W g(2->2)                                            *
* Txpro( 2) :  EW top : W g(2->3)                                            *
* Txpro( 3) :  EW top : t W                                                  *
* Txpro( 4) :  EW top : W* -> t bbar                                         *
* Txpro( 5) :  W Q Qbar                                                      *
* Txpro( 6) :  W+-  -> tau nu                                                *
* Txpro( 7) :  W+- (-> tau nu) JET                                           *
* Txpro( 8) :  H+-  -> t bbar                                                *
* Txpro( 9) :  H+-  -> tau nu                                                *
* Txpro(10) :  H+- (-> tau nu) JET                                           *
* Txpro(20) :  gg+qq~ -> tt~,  'on-shell ',  S. Slabospitsky                 *
* Txpro(23) :  Z Q Qbar                                                      *
* Txpro(24) : g g -> Z Z    with   Z -> f fbar                               *
* Txpro(25) : q q~ -> t tbar gamma                                           *
* Txpro(30) :  FCNC top : g u -> top                                         *
* Txpro(31) :  FCNC top : q q~ -> top u(c)                                   *
* Txpro(32) :  FCNC top : g g  -> top u(c)                                   *
* Txpro(33) :  FCNC top : g q  -> top g                                      *
* Txpro(61) :  q q~   -> H+ H-                                               *
*                                                                            *
* Txpro(99) :  testing and development                                       *
*............................................................................*
*..... GLOBAL     TopReX    parameters                                       *
*. . . . . .  INTEGER parameters . . . . . . . . . . . . . . . . . .. . . .  *
*..Ipar(1)      ! current TopReX process's code                              *
*  Ipar(2)      : current event                                              *
*..Ipar(3)      : evolution scale type for PDF                               *
*..Ipar(4)      : evolution scale type for alpha_S                           *
*  Ipar(5)      : 0(1) quark masses are taken from PYTHIA(PDG)               *
*  Ipar(6)      : 0(1) s,c,b,t mass value are QCD-evaluated(fixed)           *
*               : Ipar(6) is used only for evaluation of H+- couplings       *
*..Ipar(7)      : KF code of Q-quark for WQQbar                              *
*..Ipar(8)      : INIT flag                                                  *
*..Ipar(9)     : continuation flag                                           *
*..Ipar(10)     : 1(0) (no)print  sigma for each q, qbar contribution        *
*..Ipar(11)     : 0/1 to NOT/print output from single top production         *
*..Ipar(12)     : 0/1 print information about hard process                   *
*. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . *
*..Ipar(16)     : flag for first/second order in alpha-s evaluation (PYTHIA) *
*..Ipar(17)     : check max. diff. X-section, during run                     *
*..Ipar(18)     : 1/0 evaluate PDF uncertainty                               *
*..Ipar(19)     : = MSTP(52) from PYTHIA                                     *
*..Ipar(21)     : W-exchange: > 0 tb, <0 tau nu, 1 W, 2 H, 3 (W+H+Int)       *
*..Ipar(22)     : 0: gg + qqbar, 1: gg,   2: qqbar                           *
*..Ipar(23)     : Zqq, 0: gam* + Z,   1: gam*, 2: Z                          *
*..Ipar(24)     : gg->ZZ, 0: SM box, 1: box + Higgs, 2: Higgs                *
*..Ipar(25)     : free
*..Ipar(26)     : bW 0 SM + FCNC, 1 - SM, 2 - FCNC                           *
*  Ipar(31)     : 1(0) running (fixed) top-mass according top width          *
*..Ipar(32)     : 1/0 finite/zero width of the W-boson in decay chain        *
*  ipar(33)     : 1(0) take (not) into account spin of produced top quarks   *
*..Ipar(41)     : number of the particles in the hard process                *
*..Ipar(42)     : sig*10**(Ipar(42))                                         *
*  ipar(50)     : number of current color                                    *
*..Ipar(51)     : num. of events used for estimation of SigMax               *
*..ipar(52)     : num. of events used for estimation of M**2                 *
*..Ipar(53)     : num. of MC entries  for estimates  of H+- and T decays     *
*..Ipar(100)    : current process number = Ipar(1)                           *
*..Ipar(101)    : current process position in /HEPRUP/ list, i.e. 1,2,3..NPRUP
*..Ipar(120)    : final leptons for ADD:                                     *
*. . . . . . . . . . . . . .  . . . . . . . . . . . . . . . . . . . . . . .  *
*. . . . . .  DOUBLE PRECISION parameters . . . . . . . . . . . . . . . . .  *
*..Rpar(1)      : Ecm                                                        *
*..Rpar(2)      : S = Ecm**2                                                 *
*..Rpar(3)      : Evolution scale for PDF                                    *
*..Rpar(4)      : Evolution scale for alpha_s                                *
*..Rpar(5)      : parameter for Q-scale evaluation for PDF                   *
*..Rpar(6)      : parameter for Q-scale evaluation for alpha_s               *
*..Rpar(7)      : x1 the momentum fraction x taken by the parton from a beam *
*..Rpar(8)      : x2 the momentum fraction x taken by the parton from a target
*
*.............. couplings ...................................................*
*..Rpar(10)     : 0.38939d0     transformation 1/GeV**2 to mb                *
*..Rpar(11)     : alpha_QED = (1/128) is electromagnetic coupling            *
*..Rpar(12)     : 4.*pi*rpar(11)  = (electric charge)**2                     *
*..Rpar(13)     : sqrt(4.*pi*rpar(11)) is electric charge                    *
*..Rpar(14)     : G_Fermi                                                    *
*..Rpar(15)     : alpha_QCD = QCD coupling used for event                    *
*..Rpar(16)     : 4*pi * Rpar(15) = (QCD charge)**2 = (g_s)**2               *
*..Rpar(17)     : sqrt(4*pi * Rpar(15)) = QCD charge                         *
*..Rpar(18)     : 10**(9 - ipar(42))
*.......
*..Rpar(21)     : sin(theta_W)                                               *
*..Rpar(22)     : cos(theta_W)                                               *
*..Rpar(23)     : sin(theta_W)**2                                            *
*..Rpar(24)     : cos(theta_W)**2                                            *
*..Rpar(25)     : sin(2*theta_W) = 2 * sin(theta_W) * cos(theta_W)           *
*..Rpar(26)     : g = g_weak  = e / sin(theta_W)                             *
*..Rpar(27)     : g_z         = e / sin(2*theta_W)                           *
*..Rpar(28)     : v vacuum expectation value * 246/sqrtr(2) GeV              *
*
*.............. top quark parameters ........................................*
*..Rpar(30)     : width of t-> d  W decay at tree level (SM case)            *
*..Rpar(31)     : width of t-> s  W decay at tree level (SM case)            *
*..Rpar(32)     : width of t-> b  W decay at tree level (SM case)            *
*..Rpar(33)     : width of t-> b4 W decay at tree level (SM case)            *
*..Rpar(34)     : total t-quark decay width                                  *
*..Rpar(35)     : width of t -> b H+- decay channel                          *
*..Rpar(36)     : M(top) * width(total top)                                  *
*..Rpar(37)     : current value of M(top) generated with B.W.                *
*.............. W-boson and Z-boson parameters  .............................*
*..Rpar(41)     : W-boson mass                                               *
*..Rpar(42)     : Rpar(41)**2                                                *
*..Rpar(43)     : W-boson width                                              *
*..Rpar(44)     : M(W) * Width(W)                                            *
*...                                                                         *
*..Rpar(45)     : Z-boson mass                                               *
*..Rpar(46)     : Rpar(45)**2                                                *
*..Rpar(47)     : Z-boson width                                              *
*..Rpar(48)     : M(Z) * Width(Z)                                            *
*............................................................................*
*..Rpar(50)     : New Physics scale (1 TeV), FCNC                            *
*.............. charged Higgs parameters  ...................................*
*..Rpar(51)     : charged Higgs mass                                         *
*..Rpar(52)     : Rpar(51)**2                                                *
*..Rpar(53)     : total charged Higgs decay width                            *
*..Rpar(54)     : M(H+-) * Width(H+-)                                        *
*..Rpar(55)     : tan(beta)                                                  *
*..Rpar(56)     : (1/tan(beta))                                              *
*............................................................................*
*..Rpar(57)     : neutral Higgs (SM) mass                                    *
*..Rpar(58)     : total Higgs decay width                                    *
*..Rpar(59)     : M(H) * Width(H)                                            *
*............................................................................*
*..Rpar(61:63) are for processes Ipar(1) = 50, 51, 52 only                   *
*..Rpar(61)    : gVV, relative coupling of Higgs boson(H0) to W and Z bosons *
*..Rpar(62)    : a, scalar Yukawa coupling of Higgs boson(H0) to top quarks  *
*..Rpar(63)    : a~, pseudoscalar Yukawa coupling of H0 boson to top quarks  *
*............................................................................* 
*..Rpar(64)    : total X-section for the process, evaluated for each event   *
*..Rpar(65)    : differential cross section (in PB) for current event        *
*..Rpar(67)    : 2.d0,  PTmin(Z), IPAR(1) = 34, ZZ-production                *
*..Rpar(68)    : 20.d0, PTmin(q)    ==> Rpar(81), IPAR(1) = 11, T-channel    *
*..Rpar(69)    : 10.d0, PTmin(Bbar) ==> Rpar(82), IPAR(1) = 11, T-channel    *
*..Rpar(70)    : MW/Z_min  for virtual W/Z in heavy particle decay           *
*..... kinematic ............................................................*
*..Rpar(71)    : Shat       for hard process                                 *
*..Rpar(72)    : That       for hard process                                 *
*..Rpar(73)    : Uhat       for hard process                                 *
*..Rpar(74)    : sqrt(Shat) for hard process                                 *
*..Rpar(75)    : PThat      for hard process                                 *
*..Rpar(76)    : PThat**2   for hard process                                 *
*..Rpar(77)    : M(QQbar)_MIN  for W/Z Q Qbar production                     *
*..Rpar(78)    : M(QQbar)_MAX  for W/Z Q Qbar production                     *
*..Rpar(79)    : M(ffbar)_MIN  for gamma* or Z*                              *
*..Rpar(80)    : M(ffbar)_MAX  for gamma* or Z*                              *
*..Rpar(81)    : kinematic cut,  >=3 final state, PTmin(q) for Ipar(11)      *
*..Rpar(82)    : kinematic cut,  >=3 final state, PTmin(Bbar) for Ipar(11)   *
*..Rpar(83:99) : kinematic cuts, >=3 final state                             *
*............................................................................* 
*..Rpar(101)   : CKIN(1) = sqrt(Shat_MIN) for hard process                   *
*..Rpar(102)   : CKIN(2) = sqrt(Shat_MAX) for hard process                   *
*..Rpar(103)   : CKIN(3) = PThat_MIN                                         *
*..Rpar(104)   : CKIN(4) = PThat_MAX                                         *
*............................................................................*
*...........  Graviton* production,  ADD scenario                            *
*..Rpar(121)     : M_exdim,                         ADD scenario             *
*..Rpar(122)     : n_exdim,  Graviton* production,  ADD scenario             *
*..Rpar(123)     : mKK mass of KK-excitation,       ADD scenario             *
*..Rpar(124)     : recommended PThat_MIN            ADD scenario             *
*..Rpar(125)     : factor_ADD                                                *
*............................................................................*
*...........  Black Hole (BH) production                                     *
*  Rpar(131)     : Planck scale, GeV                                         *
*  Rpar(132)     : n extra dimensions                                        *
*  Rpar(133)     : BR(BH -> q qbar X)                                        *
*  Rpar(134)     : BR(BH -> g g    X) / 2                                    *
*  Rpar(135)     : BR(BH -> l l'   X)                                        *
*  Rpar(136)     : BR(BH -> gamma,W,Z X) + BR(BH -> Higgs  X)                *
*  Rpar(137)     : BR(BH -> Higgs  X)                                        *
*............................................................................*

      implicit none
*
* PYTHIA common
      include "txpar.inc" 
      include "pydat_62.inc"
      integer MINT
      double precision VINT
      COMMON/PYINT1/MINT(400),VINT(400)
      integer         MSEL,MSELPD,MSUB,     KFIN
      double precision                                     CKIN
      COMMON /PYSUBS/ MSEL,MSELPD,MSUB(500),KFIN(2,-40:40),CKIN(200)
*
      CHARACTER*(*) FRAME,BEAM,TARGET
      character*12 XFRAME, XBEAM, XTARGET
      common /TXFBT/XFRAME, XBEAM, XTARGET
      CHARACTER CHFRAM*12,CHBEAM*12,CHTARG*12
      INTEGER MAXPUP
      PARAMETER (MAXPUP=100)
      INTEGER IDBMUP,PDFGUP,PDFSUP,IDWTUP,NPRUP,LPRUP
      double precision EBMUP,XSECUP,XERRUP,XMAXUP
      COMMON/HEPRUP/IDBMUP(2),EBMUP(2),PDFGUP(2),PDFSUP(2),
     &IDWTUP,NPRUP,XSECUP(MAXPUP),XERRUP(MAXPUP),XMAXUP(MAXPUP),
     &LPRUP(MAXPUP)
      SAVE /HEPRUP/
*
      double precision Ecm 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer IBEAM, ITARGET
*............................................................................*
      CHFRAM=FRAME//' '
      CHBEAM=BEAM//' '
      CHTARG=TARGET//' '
*
      call TX_TIT                    ! print TopReX title
*
      Rpar(1) = Ecm               ! ECM energy
      Rpar(2) = Rpar(1) * Rpar(1) ! S = Ecm**2 
*
      XFRAME  = FRAME 
      XBEAM   = BEAM
      XTARGET = TARGET
*
      call tx_mult
      call Rep_PDF               ! print information about PDF set
*
      MSEL = 0   ! return full user control to TopReX
*
      Ipar(19) = mstp(52)
*      

      call IBMTG(chBEAM,chTARG,  IBEAM, ITARGET)
       IDBMUP(1) = IBEAM 
       IDBMUP(2) = ITARGET 
       EBMUP(1)  = rpar(1) / 2.d0
       EBMUP(2)  = rpar(1) / 2.d0
       IDWTUP    = 1

       if(Ipar(16).eq.2)  then
        if(MSTP(51).eq.7) mstp(2) = 1  ! first  order in alpha_s 
        if(MSTP(51).eq.8) mstp(2) = 2  ! second order in alpha_s 
       endif

       MSTU(12)= 0  ! switch off print PYTHIA logo 
       MSTP(122)=0  ! switch off X section print out     
      call PYINIT(chFRAM,chBEAM,chTARG, Ecm)
       MSTP(122)=1  ! switch on X section print out
* 
* start to evaluation of Toprex parameters
*........integer parameters

      call TXWEAK                 ! set TopReX additional parameters
      call TX_DEC_TABLE           ! set decay table for top, W+-, H+-, Z 
*  set kinematics
        rpar(101) = CKIN(1)         ! sqrt(Shat) MIN
        rpar(102) = CKIN(2)         ! sqrt(Shat) MAX
        Rpar(103) = CKIN(3)         ! PThat      MIN
*..................................................................
      call UPEVNT   ! first call - initialization and evaluation of Sigmax
      return
      end

c----------------------------------------------------------------------------c
C PYTHIA ROUTINE should be putted explicitly
      SUBROUTINE UPINIT
 
C...Double precision and integer declarations.
      IMPLICIT double precision(A-H, O-Z)
      IMPLICIT INTEGER(I-N)
 
C...User process initialization commonblock.
      INTEGER MAXPUP
      PARAMETER (MAXPUP=100)
      INTEGER IDBMUP,PDFGUP,PDFSUP,IDWTUP,NPRUP,LPRUP
      double precision EBMUP,XSECUP,XERRUP,XMAXUP
      COMMON/HEPRUP/IDBMUP(2),EBMUP(2),PDFGUP(2),PDFSUP(2),
     &IDWTUP,NPRUP,XSECUP(MAXPUP),XERRUP(MAXPUP),XMAXUP(MAXPUP),
     &LPRUP(MAXPUP)
      SAVE /HEPRUP/
 
      RETURN
      END
*----------------------------------------------------------------------------*
*...UPEVNT PYTHIA                                                            * 
*............................................................................*

      subroutine UPEVNT
      implicit none
       call TX_UPEVNT
      return
      end
*----------------------------------------------------------------------------*
c PYTHIA
 
      SUBROUTINE UPVETO(IVETO)
      implicit none
      integer IVETO 
       call TX_UPVETO(IVETO)
      return
      end


*----------------------------------------------------------------------------*
*---  modified by Serge Slabospitsky 13.12.2004  ------------------------
*---  could be used with TopReX version >= 4.09  ------------------------
*------------------------------------------------------------------------ 
C...All partons at the end of the shower phase are stored in the
C...HEPEVT commonblock. The interesting information is
C...NHEP = the number of such partons, in entries 1 <= i <= NHEP,
C...IDHEP(I) = the particle ID code according to PDG conventions,
C...PHEP(J,I) = the (p_x, p_y, p_z, E, m) of the particle.
C...All ISTHEP entries are 1, while the rest is zeroed.
 
C...The user decision is to be conveyed by the IVETO value.
C...IVETO = 0 : retain current event and generate in full;
C...      = 1 : abort generation of current event and move to next.
 
      SUBROUTINE TX_UPVETO(IVETO)
      implicit none
      include "txpar.inc" 
      include "txpro.inc" 
      include "hepevt.inc" 
      integer IVETO
C...HEPEVT commonblock.
*      PARAMETER (NMXHEP=4000)
*      COMMON/HEPEVT/NEVHEP,NHEP,ISTHEP(NMXHEP),IDHEP(NMXHEP),
*     &JMOHEP(2,NMXHEP),JDAHEP(2,NMXHEP),PHEP(5,NMXHEP),VHEP(4,NMXHEP)
*      DOUBLE PRECISION PHEP,VHEP
*      SAVE /HEPEVT/
 
C...Next few lines allow you to see what info PYVETO extracted from
C...the full event record for the first two events.
C...Delete if you don't want it.
c      INTEGER NLIST/0/
c      SAVE NLIST
c      goto 999
c      IF(NLIST.LE.2) THEN
c        WRITE(*,*) ' Full event record at time of UPVETO call:'
c        CALL PYLIST(1)
c        WRITE(*,*) ' Part of event record made available to UPVETO:'
c        CALL PYLIST(5)
c        NLIST=NLIST+1
c      ENDIF
 
C...Make decision here.
      IVETO = 0
      if(txsel.eq.1.OR.txsel.eq.2) then ! for TopReX matching
       call txmatching(IVETO)             ! for   
       NHEP = 0 
      endif
      RETURN
      END

*----------------------------------------------------------------------------*
      subroutine TX_UPEVNT 
      implicit none 
      include "hepeup.inc"
      include "txpar.inc" 
      include "txpro.inc" 
      include "pydat_62.inc"
      integer Nproc
C...User process event common block 
      INTEGER MAXPUP
      PARAMETER (MAXPUP=100)
      INTEGER IDBMUP,PDFGUP,PDFSUP,IDWTUP,NPRUP,LPRUP
      double precision EBMUP,XSECUP,XERRUP,XMAXUP
      COMMON/HEPRUP/IDBMUP(2),EBMUP(2),PDFGUP(2),PDFSUP(2),
     &IDWTUP,NPRUP,XSECUP(MAXPUP),XERRUP(MAXPUP),XMAXUP(MAXPUP),
     &LPRUP(MAXPUP)
      logical first
      data first /.TRUE./
      save first
*........................................      
      IF(MSTI(52).GE.1 .AND. MSTI(52).LE.5) RETURN
* 
      IF(first) then
        first=.FALSE.
       print*,'                                     '
       print*,' ************************************'
       print*,' *                                  *'
       print*,' *  UPEVNT initial call for TopReX  *'
       print*,' *                                  *'
       print*,' ************************************'
*
      call TX_EST_INI
* start through all switched-ON rpocesses

       If(txmup.ge.1) THEN
         do Nproc = 1, maxpro
           if(txpro(Nproc).eq.1) then
             ipar(1) = Nproc 
             Ipar(101) = txext(Nproc) 
             call TX_EST
           endif
         enddo
       EndIf
      ELSE
*...  start normal running
        call TX_GEN
      ENDIF
      return
      end
*----------------------------------------------------------------------------*
*
      subroutine TX_EST_INI
      implicit none 
      include "txpar.inc" 
      include "txpro.inc" 
* rxsig(I,1) : sum of differential X-section   
* rxsig(I,2) : total X-section value
* rxsig(I,3) : max of differential X-section 
* rxsig(I,4) : sum of differential X-section squared
      integer I 
         do I = 1,maxpro
          NXev(I)    = 0
          RXsig(I,1) = 0.d0 
          RXsig(I,2) = 0.d0 
          RXsig(I,3) = 0.d0 
          RXsig(I,4) = 0.d0 
         enddo
      return
      end
*----------------------------------------------------------------------------*
* author: Serge Slabospitsky,  08.06.2006                                    *
* evaluate X-sections values, max(diff. X-section)                           *
* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .*
      subroutine TX_EST
*     ----------------------
      implicit none 
      include "txpar.inc" 
      include "txpro.inc" 
      include "pydat_62.inc"
C...User process event common block 
      INTEGER MAXPUP
      PARAMETER (MAXPUP=100)
      INTEGER IDBMUP,PDFGUP,PDFSUP,IDWTUP,NPRUP,LPRUP
      double precision EBMUP,XSECUP,XERRUP,XMAXUP
      COMMON/HEPRUP/IDBMUP(2),EBMUP(2),PDFGUP(2),PDFSUP(2),
     &IDWTUP,NPRUP,XSECUP(MAXPUP),XERRUP(MAXPUP),XMAXUP(MAXPUP),
     &LPRUP(MAXPUP)
*
* rxsig(I,1) : sum of differential X-section   
* rxsig(I,2) : total X-section value
* rxsig(I,3) : max of differential X-section 
* rxsig(I,4) : sum of differential X-section squared
      double precision sigpb, xcspb(-6:6,-6:6)
      common/xsecpb/   sigpb, xcspb
      double precision deltasig, delpdf 
      integer Ncall, Nups, Icur, J   
      double precision nsng1, nsng2
      common /xmatch/nsng1(2), nsng2(2)
*........................................      
*
       Ipar(8) = -1  ! init flag
*       Sigev  = 0.d0

* start through all switched-ON rpocesses
        Ncall = 0
         Ipar(100) = Ipar(1)
         Icur = Ipar(100)
*         if(Ipar(18).eq.1) call PDFEST(-1, delpdf)
 1000   NXev(icur) = NXev(icur) + 1
        Ncall = Ncall + 1
        if(Ncall.gt.Ipar(51)) goto 1001
         call TX_GEJZER(NUPS)   

       if(sigpb.gt.RXsig(icur,3)) then
         RXsig(Icur,3) = sigpb
       endif      
*
          RXsig(Icur, 1) = RXsig(Icur, 1) + sigpb
          RXsig(Icur, 4) = RXsig(Icur, 4) + sigpb**2
         goto 1000 
 1001  continue
        NXev(icur) = NXev(icur) - 1
         RXsig(icur,2) = RXsig(icur,1) / NXev(icur)
*** TopReX matching
        if    (txsel.eq.1) then 
          RXsig(1,2) = RXsig(1,1) / NXev(1) 
          RXsig(2,2) = RXsig(2,1) / NXev(2) 
        elseif(txsel.eq.2) then 
          do j = 30,33
            RXsig(J,2) = RXsig(J,1) / NXev(J) 
          enddo
        endif
***
        RXsig(icur, 4) = RXsig(icur,4) /  NXev(icur) 
        deltasig = 
     &dsqrt((RXsig(icur,4) - RXsig(icur,2)**2)/NXev(icur)) 
*          if(Ipar(18).eq.1.and.Ipar(19).eq.2) call PDFEST(1, deltasig) 
        write(*,4117)
 4117   format(/,50('*'),/,'*')
        call tx_nam(1)
        if(ipar(18).eq.1) then
         write(*,4112) NXev(Ipar(1)),RXsig(icur,2), deltasig, delpdf 
 4112   format('* TopReX: Nev = ',i10,/,
     & '* sigma(pb)   = ',1p,d11.4,' +- ',1p,d11.4,' +- ',
     &  1p,d11.4,' (PDF)')
         else
        write(*,4116) NXev(Ipar(1)),RXsig(Ipar(1),2), deltasig
 4116   format('* TopReX: Nev = ',i10,/,
     & '* sigma(pb) = ',1p,d11.4,' +- ',1p,d11.4)
        endif
        write(*,4115)
 4115   format('*',/,50('*'))
        

      if(RXsig(icur,2).le.0.d0) then
        write(*,4555) 
 4555 format(/,2x,'TopReX : zero or negative cross section. Stop')
           STOP
      endif        
*        sigev = xsec2     ! sig_max = sigma_tot !
        xsecup(Ipar(101)) = RXsig(icur,2) ! 
        xmaxup(Ipar(101)) = RXsig(icur,2)  ! sigmx !* 10.**9
* TopReX matching
       if    (txsel.eq.1) then 
          do j = 1,2
            xsecup(j) =  RXsig(j,2) 
            xmaxup(j) = xsecup(j) 
          enddo
       elseif(txsel.eq.2) then 
          do j = 30,33
            xsecup(j) =  RXsig(j,2) 
            xmaxup(j) = xsecup(j) 
          enddo
       endif
      RETURN
      END
*----------------------------------------------------------------------------*
* author : Serge Slabospitsky  08.06.2006                                    *
* normal run
*............................................................................*
      subroutine TX_GEN
      implicit none
      include "hepeup.inc"
      include "txpar.inc" 
      include "txpro.inc" 
*...Standard PYTHIA 6.2 event data common.
      include "pydat_62.inc"
C...User process event common block 
      INTEGER MAXPUP
      PARAMETER (MAXPUP=100)
      INTEGER IDBMUP,PDFGUP,PDFSUP,IDWTUP,NPRUP,LPRUP
      double precision EBMUP,XSECUP,XERRUP,XMAXUP
      COMMON/HEPRUP/IDBMUP(2),EBMUP(2),PDFGUP(2),PDFSUP(2),
     &IDWTUP,NPRUP,XSECUP(MAXPUP),XERRUP(MAXPUP),XMAXUP(MAXPUP),
     &LPRUP(MAXPUP)
* PYTHIA6.2 common block for external user's process 
      double precision sigpb, xcspb(-6:6,-6:6)
      common/xsecpb/   sigpb, xcspb
      double precision xst, wrk
* rxsig(I,1) : sum of differential X-section   
* rxsig(I,2) : total X-section value
* rxsig(I,3) : max of differential X-section 
* rxsig(I,4) : sum of differential X-section squared
      integer ip1, ip2
      integer I, J, jk1,jk2   
      double precision PYR, ARAN 
*      double precision mbpb
*      data mbpb /1.d09/
      double precision nsng1, nsng2
      common /xmatch/nsng1(2), nsng2(2)
*
      double precision Pus        ! 4-momenta of user's particles
      common /user_mom/ Pus(20,5)
      integer Icur, Nups
*........................................      

      Ipar(100) = IDPRUP 
      Ipar(1) = Ipar(100)
      Icur = Ipar(1)
      Ipar(8) = 1     ! running 
 998  continue
      NXev(ipar(1)) = NXev(ipar(1)) + 1
       call TX_GEJZER(NUPS)   
      if(sigpb.le.0.d0) goto 998

* two options for SIGPB and SIGMX
* sigPB < sigMX or sigPB = sigMX : sigPB is added to Xsig, then compared sigMX
* sigPB > sigMX 
* Ipar(17) =  0: normal case, event is always (!) accepted, sigPB => + Xsig
* Ipar(17) = +1: if sigPB > sigMX events is NOT accepted 
*                and  sigPB is NOT added to Xsig

      if(txsel.eq.1.or.txsel.eq.2) goto 901 
      If(sigpb.le.RXsig(icur,3) ) then
          RXsig(icur,1) = RXsig(icur,1) + sigpb        
          RXsig(icur,2) = RXsig(icur,1) / NXev(icur)
          aran  = pyr(0) * RXsig(icur,3) ! sigmx 
          if(sigpb.lt.aran) goto 998
      ElseIf(sigpb.gt.RXsig(icur,3) ) then
        if(Ipar(17).eq.0) then
          RXsig(icur,1) = RXsig(icur,1) + sigpb        
          RXsig(icur,2) = RXsig(icur,1) / NXev(icur)
          RXsig(icur,3) = sigpb
        elseif(Ipar(17).eq.1) then
          goto 998    ! event is not accepted
        else
          print*,' Ipar(17) = ',Ipar(17),' not allowed. stop' 
          STOP
        endIf
      EndIf
 901  continue
* TopReX matching 
       If(txsel.eq.1.or.txsel.eq.2) then 
          RXsig(Ipar(100),1) = RXsig(Ipar(100),1) + sigpb
          RXsig(ipar(100),2) = RXsig(Ipar(100),1) / NXev(ipar(100)) 
        if(sigpb.gt.RXsig(Ipar(100),3)) RXsig(Ipar(100),3) = sigpb
          aran  = pyr(0) * RXsig(Ipar(100),3) 
          if(sigpb.lt.aran) goto 998
       endif 
 996  xst=sigpb * PYR(0) 
      do i=-5,5
        do j=-5,5
          wrk=xcspb(i,j)
          if(wrk.gt.0.d0)then
            if(xst.lt.wrk)then
              ip1=i             ! parton type from hadron_1
              ip2=j             ! parton type from hadron_2 
              goto 601
            else
              xst=xst - wrk 
            endif
          endif
        enddo
      enddo
      goto 998                  ! bad rndm for initial process
 601  continue
*     
       xwgtup = RXsig(ipar(100), 2)
       Rpar(64) = RXsig(ipar(100), 2) 
* TopReX matching
      IF(txsel.eq.1.or.txsel.eq.2) THEN
       xwgtup = rpar(18) * RXsig(ipar(100),1) / NXev(ipar(100)) 
       if(txsel.eq.1) then
         Rpar(64) =
     &   (RXsig(1,1)/NXev(1)) * nsng1(1) / (nsng1(1) + nsng1(2))
     & + (Rxsig(2,1)/NXev(2)) * nsng2(2) / (nsng2(1) + nsng2(2))
       elseif(txsel.eq.2) then
         Rpar(64) =
     &   (RXsig(30,1)/NXev(30)) * nsng1(1) / (nsng1(1) + nsng1(2))
     & + ( Rxsig(31,1)/NXev(31) + Rxsig(32,1)/NXev(32) 
     & +   Rxsig(33,1)/NXev(33))* nsng2(2)/(nsng2(1) + nsng2(2))
       endif
      ENDIF 


      scalup = rpar(3)
      NUP  = nups 
       do jk1 = 1,maxnup
        idup(jk1) = 0
        istup(jk1) = 0
        mothup(1,jk1) = 0
        mothup(2,jk1) = 0
        icolup(1,jk1) = 0
        icolup(2,jk1) = 0
         do jk2 = 1,5
          pup(jk2, jk1) = 0.d0
         enddo
       enddo

* fill momenta for PYTHIA
      do j = 1, NUP
        do i=1,5
          pup(i,j) = pus(j,i)
        enddo
      enddo

         AQEDUP = rpar(11) 
         AQCDUP = rpar(15)
*  common settings for hard process: parton_1 + parton_2  
        istup(1) = -1     ! first parton 
        mothup(1,1)=0    
        mothup(2,1)=0    
        idup(1) = ip1
         istup(2) = -1    ! second parton
         mothup(1,2)=0   
         mothup(2,2)=0
         idup(2)=ip2
      
*
      if    (Ipar(1).eq.1)  then
        call ColorF_01(ip1,ip2)      !  W-gluon process
      elseif(Ipar(1).eq.2)  then
        call ColorF_02(ip1, ip2)     !  W-gluon process   2 -> 3
      elseif(Ipar(1).eq.3)  then
        call ColorF_03(ip1, ip2)     !  t W  process
      elseif(Ipar(1).eq.4.or.Ipar(1).eq.8.        ! (W* H*) -> T Bbar 
     &    or.Ipar(1).eq.6.or.Ipar(1).eq.9) then   ! (W* + H*) -> tau nu
        call ColorF_04(ip1, ip2)    
      elseif(Ipar(1).eq.20) then
        call ColorF_20(ip1, ip2)     !  t t~    process (SM)
      elseif(Ipar(1).eq.5) then 
        call ColorF_05(ip1, ip2)     !  WQQbar  process
      elseif(Ipar(1).eq.23)   then 
        call ColorF_23(ip1,ip2)      !  Z Q Qbar
      elseif(Ipar(1).eq.24)   then 
        call ColorF_24(ip1,ip2)      !   g g -> Z Z    with   Z -> f fbar 
      elseif(Ipar(1).eq.25)   then 
        call ColorF_25(ip1,ip2)      !  t tbar gamma 
      elseif(Ipar(1).eq.7.or.Ipar(1).eq.10) then 
        call ColorF_07(ip1,ip2)      !  JET + (W* H*) 
      elseif(Ipar(1).eq.61)   then 
        call ColorF_61(ip1,ip2)      !  H+ H- 
      elseif(Ipar(1).eq.29)  then
        call ColorF_29(ip1,ip2)      !  FCNC -> t
      elseif(Ipar(1).eq.30)  then
        call ColorF_30(ip1,ip2)      !  FCNC -> t
      elseif(Ipar(1).eq.31)  then
        call ColorF_31(ip1,ip2)      !  FCNC -> T q
      elseif(Ipar(1).eq.32)  then
        call ColorF_32(ip1,ip2)      !  FCNC -> T q
      elseif(Ipar(1).eq.33)  then
        call ColorF_33(ip1,ip2)      !  FCNC -> T g
      elseif(Ipar(1).eq.34)  then
        call ColorF_34(ip1,ip2)      !  FCNC -> T g
*
      else 
         write(*,4114) Ipar(1)
 4114    format(3x,'TopReX : HEPEUP',/,
     &          3x,'---------------',/,
     &          3x,'TopReX can not run process ',i4,'  with PYTHIA',/
     &          3x,'stop TopReX run')
        STOP
      ENDIF
 8888 continue
      if(ipar(12).eq.1) call TX_HRD_OUT 
      RETURN
      END
*----------------------------------------------------------------------------*
*...Author : Serge Slabospitsky 20.05.2006                                   *
      subroutine TX_HRD_OUT
*     ---------------------
      implicit none
      include "txpar.inc" 
      include "hepeup.inc"
      integer I,J
*
      print*,'***************  Event = ',ipar(2)
      print*,'  KF  status  mother 1   mother 2  col 1  col 2'
      do I = 1,nup
       write(*,1) I, idup(i),istup(i),mothup(1,i),mothup(2,i),
     &  icolup(1,i),icolup(2,i)
 1     format('n ',i2,' ! ',6(i5,1x))
       write(*,2) (pup(j,i),j=1,5)
 2     format('  x y z E m ',5(e10.4,1x))
      enddo
      return
      end
*----------------------------------------------------------------------------*
*...Author : Serge Slabospitsky                                              *
      subroutine TX_Dec_Table 
*     -----------------------
*. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . *
* set decay tables for top, W+-, H+-, Z                                      *
* copy of W and Z boson decay parameters from PYTHIA to TopReX               *
*............................................................................*

      implicit none
      include "pydat_62.inc"
      include "txpar.inc" 
c      parameter (ndch=50)
      integer dectop(ndch), dechpm(ndch) 
      common /TXdecRE/dectop, dechpm 
      integer IT, I, J, i5,i6,i11 
* first parameter in MID, BRF, FID, and BRS has the meaning as follows
*     IT = 1 : top quark,  IT = 2 : W-boson, 
*     IT = 3 : H+- boson,  IT = 4 : Z-boson 
*  BRS(1, it) is the TOTAL Branching ratio for      particle
*  BRS(2, it) is the TOTAL Branching ratio for ANTI-particle
      do j = 1,ndch
         mid(j,1) = dectop(j) 
         mid(j,3) = dechpm(j) 
       do i = 1,4
        wid(0,i) = 0.d0 
        wid(j,i) = 0.d0 
        brf(j,i) = 0.d0    
       enddo
      enddo

*......................................
      IT = 1                ! top-quark
      Mid(0, it) = 16       ! number of top decay channels    
      if(mid(1,it).eq.-1) mid(1,it) = 0  ! SM always contributes to t width
      if(mid(2,it).eq.-1) mid(2,it) = 0  ! SM always contributes to t width
      if(mid(3,it).eq.-1) mid(3,it) = 0  ! SM always contributes to t width
*............................................................................*
*  copy of W-boson decay parameters from PYTHIA to TopReX                    *
*  WARNING !!! For W-boson case                                              *
*  First and second fermion flavors are opposite to PYTHIA,                  *
*  i.e. FDW(...,1) = KFDP(...,2) and FDW(...,2) = KFDP(...,1)                *
       IT = 2              ! W-boson  
        MID(0,IT) = 20     ! NWmax
         do I = 1, mid(0,it)
          J = 189 + I      ! J = 190 to 209  for PYTHIA
          MID(I,it)  = MDME(J,1)
          BRF(I,it)  = BRAT(J)
          FID(it,I,1) = KFDP(J,2)   ! interchange the order of final fermions
          FID(it,I,2) = KFDP(J,1)   ! for W-boson
         enddo
*................................................................
*  set decay table for H+- boson (very different from PYTHIA table)
* H+- decay channels: 
*  1  2  3   4    5  6  7  8    9  10 11 12 ...  17   18     19
*  dU dC dT  dt'  sU sC sT st'  bU bC bT bt'    e&nu mu&nu tau&nu 
*...........................................................
      IT = 3               ! H+- 
      mid(0,it) = 19       ! max. num. of H+- decay channels
      mid(3,it) = -1       ! always supress H+ -> T Dbar decay
      mid(7,it) = -1       ! always spores H+ -> T Sbar decay
* 
* check the consistence of t -> b H+, t -> H+*(->t*), and H+ -> t b~ 
* if at least one value ge.0 all other -1 values replaced to 0 value

      i5 = mid(5,1)
      i6 = mid(6,1)
      i11 = mid(11,3) 
      if(mid(5,1). eq.-1.AND.(mid(6,1).ge.0.OR.mid(11,3).ge.0)) 
     &   mid(5,1) = 0
      if(mid(6,1). eq.-1.AND.(mid(5,1).ge.0.OR.mid(11,3).ge.0)) 
     &   mid(6,1) = 0
      if(mid(11,3).eq.-1.AND.(mid(5,1).ge.0.OR.mid(6,1). ge.0)) 
     &   mid(11,3) = 0

       if(mid(5,1).ne.i5) write(*,5) 
 5    format(/,'  MID(5,1) = -1 is changed to zero-value')
       if(mid(6,1).ne.i6) write(*,6) 
 6    format(/,'  MID(6,1) = -1 is changed to zero-value')
       if(mid(11,3).ne.i11) write(*,11) 
 11   format(/,'  MID(11,3) = -1 is changed to zero-value')

*  Z-boson 
*  copy of Z-boson decay parameters from PYTHIA to TopReX                    *
      IT = 4              !  Z-boson
      MID(0,IT) = 16      !  max. num. of Z-boson decay channels
        do I = 1, mid(0,IT)
         J = 173 + I      ! J = 174 to 188
         MID(I,it)   = MDME(J,1)
         BRF(I,it)   = BRAT(J)
         FID(it,I,1) = KFDP(J,1) 
         FID(it,I,2) = KFDP(J,2)
        enddo
*.....
*
      call HIGCPL        ! H+- Yukawa couplings with running quark masses 
      call TXDEC_INI
*
      return
      end
*----------------------------------------------------------------------------*
c...subroutine W treatment
      SUBROUTINE Weight(BrPerm, BrWplus, BrWminus)

      IMPLICIT NONE

c     decay table for W's
      include "pydat_62.inc"

      double precision BrPerm, BrWplus, BrWminus
      INTEGER I

      BrPerm=2.d0
      BrWplus=0.d0
      BrWminus=0.d0
      DO I=190,209
        IF (MDME(I,1).EQ.1) THEN
          BrWplus=BrWplus+BRAT(I)
          BrWminus=BrWminus+BRAT(I)
          BrPerm=1.d0
        ELSEIF (MDME(I,1).EQ.2) THEN
          BrWplus=BrWplus+BRAT(I)
        ELSEIF (MDME(I,1).EQ.3) THEN
          BrWminus=BrWminus+BRAT(I)
        ENDIF
      ENDDO
      
      RETURN
      END
c...~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

*----------------------------------------------------------------------------*
*  routines COLORF_...                                                       *
*   color flow and showering description for PYTHIA                          *
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  05.09.2002                                  *
* Single top: t-channel : 2 -> 2                                             *
*   TopReX code = 1                                                          *
*   color flow and showering description for PYTHIA                          *
      subroutine COLORF_01(ip1, ip2)
*     ------------------------------                                         *
*............................................................................*
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer I, ip1, ip2, iqp, aip1, aip2, ntop, kpp(2), kftop(2) 
*.................  W g  :   2 -> 2 .........................................*
*     q(b)[1] ---------O----------  q`[4]                                    *
*                      <                                                     *
*                      >  W* (t-channel)  : not stored in list               *
*                      <                                                     * 
*     b(q)[2] ---------O==========  T [3]                                    *
*............................................................................*

* HEPEUP :        1     2       3     4 
*       nup = 4 ! q(b)  b(q) -> t(t~) q' 
* how PYTHIA will be treated
        istup(3) =  2 ! final top 
        istup(4) =  1 ! final q'
* parent's lines
          mothup(1,3)=1  ! final top
          mothup(2,3)=2  !
           mothup(1,4)=1  ! final q'
           mothup(2,4)=2  !
* KF code
* colors flow
        ipar(50) = 300
        aip1 = abs(ip1)
        aip2 = abs(ip2)
        icolup(1,1) = (ipar(50)+1)*(aip1+ip1)/2/aip1 ! color 
        icolup(2,1) = (ipar(50)+1)*(aip1-ip1)/2/aip1 ! anticolor 
        icolup(1,2) = (ipar(50)+2)*(aip2+ip2)/2/aip2 ! color 
        icolup(2,2) = (ipar(50)+2)*(aip2-ip2)/2/aip2 ! anticolor 
      if(abs(ip1).eq.5) then  
* B[1] Q[2]
        idup(3) = 6 * ip1 / aip1
        call qflqw(ip2, iqp)
        idup(4) = iqp
* color flow
         icolup(1,3) =  icolup(1,1)  ! b    => t
         icolup(2,3) =  icolup(2,1)  ! bbar => tbar
         icolup(1,4) =  icolup(1,2)  ! q    => q'
         icolup(2,4) =  icolup(2,2)  ! qbar => q'bar
      else 
* q[1] b[2]
        idup(3) = 6 * ip2 / aip2
        call qflqw(ip1, iqp)
        idup(4) = iqp
* color flow
         icolup(1,3) =  icolup(1,2)  ! b    => t
         icolup(2,3) =  icolup(2,2)  ! bbar => tbar
         icolup(1,4) =  icolup(1,1)  ! q    => q'
         icolup(2,4) =  icolup(2,1)  ! qbar => q'bar
      endif  
      pup(5,4) = mq(abs(iqp))
*
      ntop = 0
      do I = 3, Nup
       if(abs(idup(I)).eq.6) then
        ntop = ntop + 1
        kpp(ntop) = I
        kftop(ntop) = idup(i)
       endif 
      enddo
       if(ntop.ge.1) then
        call top_decay(ntop, kpp, kftop) 
       else 
        STOP ! no top quark
       endif
      return
      end
c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky  06.09.2002                                  *
* Single top: t-channel : 2 -> 3                                             *
*   TopReX code = 2                                                          *
*   color flow and showering description for PYTHIA                          *
      subroutine COLORF_02(ip1, ip2)
*     ------------------------------                                         *
*............................................................................*
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
*..................TopReX commons and internal variables
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      Integer I, Iglu, iqrk, ip1, ip2, iwkf, iqp
      integer ntop, kpp(2), kftop(2) 
*............................................................................*
*....  particles description                                                 *
*...                                                                         *
*     g(q)[1] ---------O------------- q`[3]                                  *
*                      <                                                     *
*                      >  W* (t-channel)                                     *
*                      <                                                     *
*                      O============= t[5]                                   *
*                      |                                                     *
*                      |                                                     *
*                      |                                                     *
*     q(g)[2] ~~~~~~~~~O------------- Bbar[4]                                *
*............................................................................*

* HEPEUP          1     2       3   4     5     
*       nup = 5 ! g(q)  q(g) -> q'  Bbar  t(t~) 
* how PYTHIA will be treated
        istup(3) =  1 ! final q'
        istup(4) =  1 ! final Bbar from initial gluon splitting
        istup(5) =  2 ! top, not to be treated by PYTHIA
* parent's lines
          mothup(1,3)=1  ! final q' 
          mothup(2,3)=2  !
           mothup(1,4)=1  ! final bbar 
           mothup(2,4)=2  !
            mothup(1,5)=1  ! final top 
            mothup(2,5)=2  !
* KF code
* Iglu is No of lines of initial gluon 
        if(ip1.eq.0) then
* GLUON and quark initial state
         Iglu = 1
         iqrk = 2
         idup(1) = 21  
         idup(2) = ip2
         iwkf = ip2
        else
* QUARK and gluon initial state
         Iglu = 2
         iqrk = 1
         idup(1) = ip1  
         idup(2) = 21
         iwkf = ip1
        endif
         call qflqw(iwkf, iqp)
* now IWKF is W-boson PYTIA code, +24/-24 = W+/W- = top/top_bar production
        idup(3) = iqp
        pup(5,3)  = mq(abs(iqp))
       
* KF codes and COLOR FLOW for final B1[4] 
        ipar(50) = 300
         if(iqp.gt.0) then  ! initial quark
           icolup(1,iqrk) = ipar(50)+1       
           icolup(1,3)    = icolup(1,iqrk)
         else               ! initial  
           icolup(2,iqrk) = ipar(50)+1       
           icolup(2,3)    = icolup(2,iqrk)
         endif
        ipar(50) = ipar(50) + 100
          icolup(1,iglu) = ipar(50) + 1
          icolup(2,iglu) = ipar(50) + 2

        if(Iwkf.eq.+24) then    
* top     decay: t[5] and bbar[4]
         idup(5) =  6         ! top 
         idup(4) = -5         ! B_bar
          icolup(1,5) = icolup(1,iglu)
          icolup(2,4) = icolup(2,iglu)
        else
* top_bar decay: tbar[5] and b[4] 
         idup(5) = -6         ! top_bar
         idup(4) =  5         ! B
          icolup(2,5) = icolup(2,iglu)
          icolup(1,4) = icolup(1,iglu)
        endif
* 
      ntop = 0
      do I = 3, Nup
       if(abs(idup(I)).eq.6) then
        ntop = ntop + 1
        kpp(ntop) = I
        kftop(ntop) = idup(i)
       endif 
      enddo
       if(ntop.ge.1) then
        call top_decay(ntop, kpp, kftop) 
       endif
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  01.03.2004                                  *
*   FCNC top production : 2 -> 1  including SM contribution  gu(c)->bW       *
*   TopReX code = 12                                                         *
*   color flow and showering description for PYTHIA                          *
      subroutine COLORF_29(ip1, ip2)
*     ------------------------------                                         *
*............................................................................*
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer ip1, ip2, KT, KW, Ires, IR, kff1, kff2
*      integer I
*.................  FCNC :   2 -> 1 .........................................*
*     g(U)[1] \            /   b[3]                                          *
*              \          /                                                  *
*               == T[.]==/                                                   *
*              /         >                                                   * 
*     U(g)[2] /           <                                                  *
*..........................>  W[4] -> L+-[5] NU[6] ..........................*

* HEPEUP :        1     2       3     4 
*       nup = 6 ! 
* how PYTHIA will be treated
        istup(3) =  1 ! final b
        istup(4) =  2 ! final W+-
        istup(5) =  1 ! final NU  (or Dbar)
        istup(6) =  1 ! final L+- (or U)
* parent's lines
        mothup(1,3)=1  ! final b
        mothup(2,3)=2  
         mothup(1,4)=1  ! final W
         mothup(2,4)=2  !
          mothup(1,5)=4  ! final L+- (U)
          mothup(2,5)=4  !
           mothup(1,6)=4  ! final NU  (Dbar)
           mothup(2,6)=4  !
* KF code
        if(idup(1).eq.0) idup(1) = 21
        if(idup(2).eq.0) idup(2) = 21
         KT = +1   ! top
         if(ip1.lt.0.OR.ip2.lt.0) KT = -1 ! antitop
        idup(3) = KT*5
        idup(4) = KT*24
        KW = idup(4)
* colors flow
        ipar(50) = 300
      if(ip1.eq.0)  then   !  GLUON Q      
       icolup(1,1) = ipar(50)      ! color
       icolup(2,1) = ipar(50) + 1  ! anticolor
         if(kt.eq.1) then
          icolup(1,2) = ipar(50) + 1
          icolup(2,2) = 0
          icolup(1,3) = ipar(50)
          icolup(2,3) = 0
         else
          icolup(1,2) = 0
          icolup(2,2) = ipar(50)
          icolup(1,3) = 0
          icolup(2,3) = ipar(50) + 1
         endif
      elseif(ip2.eq.0)  then   !  GLUON Q      
       icolup(1,2) = ipar(50)      ! color
       icolup(2,2) = ipar(50) + 1  ! anticolor
        if(kt.eq.1) then
         icolup(1,1) = ipar(50) + 1
         icolup(2,1) = 0
         icolup(1,3) = ipar(50)
         icolup(2,3) = 0
        else
         icolup(1,1) = 0
         icolup(2,1) = ipar(50)
         icolup(1,3) = 0
         icolup(2,3) = ipar(50) + 1
        endif
       endif
*  fill information about fermions from W
      Ires = 2  ! W-boson
      call Res_branch(2, kw, Ir)
      kw = kw / abs(kw)         ! +1(-1) for W+(W-)
      kff1 = kw * FID(Ires,Ir,1)   ! KF code of first  fermion 
      kff2 = kw * FID(Ires,Ir,2)   ! KF code of second fermion 
      call colorf_bff(4, 5, kff1,  6, kff2) 

      return
      end
c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky  03.07.2006                                  *
*   FCNC top production : 2 -> 1  including SM contribution  gu(c)->bW       *
*   TopReX code = 30                                                         *
*   color flow and showering description for PYTHIA                          *
      subroutine COLORF_30(ip1, ip2)
*     ------------------------------                                         *
*............................................................................*
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer ip1, ip2, j, ntop, kpp(2), kftop(2) 
      double precision hrgu   ,hrug   , hrgc   , hrcg   
      common /fcncpol/ hrgu(4),hrug(4), hrgc(4), hrcg(4)
      double precision hv
      common /topol1/  hV(4)    ! TOP polarisation vector
*.................  FCNC :            .......................................*
*     g(U)[1] \                                                              *
*              \                                                             *
*               == T[3]                                                      *
*              /                                                             * 
*     U(g)[2] /                                                              *
*.........................                            .......................*

* HEPEUP :        1     2       3     4 
*       nup = 6 ! 
* how PYTHIA will be treated
        if(idup(1).eq.0) idup(1) = 21
        if(idup(2).eq.0) idup(2) = 21
        istup(3) =  2 ! final top
* parent's lines
        mothup(1,3)=1 
        mothup(2,3)=2  
* KF code
         idup(3) = 6 
         if(ip1.lt.0.OR.ip2.lt.0) idup(3) = -6 !  antitop
* colors flow
        ipar(50) = 300
      if(ip1.eq.0)  then   !  GLUON Q      
       icolup(1,1) = ipar(50)      ! color
       icolup(2,1) = ipar(50) + 1  ! anticolor
         if(idup(3).eq.6) then
          icolup(1,2) = ipar(50) + 1
          icolup(2,2) = 0
          icolup(1,3) = ipar(50)
          icolup(2,3) = 0
         else
          icolup(1,2) = 0
          icolup(2,2) = ipar(50)
          icolup(1,3) = 0
          icolup(2,3) = ipar(50) + 1
         endif
      elseif(ip2.eq.0)  then   !  GLUON Q      
       icolup(1,2) = ipar(50)      ! color
       icolup(2,2) = ipar(50) + 1  ! anticolor
        if(idup(3).eq.6) then
         icolup(1,1) = ipar(50) + 1
         icolup(2,1) = 0
         icolup(1,3) = ipar(50)
         icolup(2,3) = 0
        else
         icolup(1,1) = 0
         icolup(2,1) = ipar(50)
         icolup(1,3) = 0
         icolup(2,3) = ipar(50) + 1
        endif
       endif
*
         do j = 1,4
          hv(j) = 0.d0
         enddo
      If(ip1.eq.0) then
        if(abs(ip2).eq.2) then
         do j = 1,4
          hv(j) = hrgu(j)
         enddo
        elseif(abs(ip2).eq.4) then
         do j = 1,4
          hv(j) = hrgc(j)
         enddo
        endif
      ElseIf(ip2.eq.0) then
        if(abs(ip1).eq.2) then
         do j = 1,4
          hv(j) = hrug(j)
         enddo
        elseif(abs(ip1).eq.4) then
         do j = 1,4
          hv(j) = hrcg(j)
         enddo
        endif
      EndIf

      ntop = 1
         kpp(ntop) = 3
         kftop(ntop) = idup(3)
       if(ntop.ge.1) call top_decay(ntop, kpp, kftop) 
      return
      end
c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky  09.09.2002                                  *
*   t W production                                                           *
*   TopReX code = 3                                                          *
*   color flow and showering description for PYTHIA                          *
*............................................................................*
      subroutine COLORF_03(ip1, ip2)
*     ------------------------------                                         *
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer ip1, ip2, I, iglu, iqrk, kfw, IR, kff1, kff2
      Integer ntop, kpp(2), kftop(2)
* first parameter in MID, BRF, FID, and BRS has the meaning as follows
*     IRES = 1 : top quark,  IRES = 2 : W-boson, 
*     IRES = 3 : H+- boson,  IRES = 4 : Z-boson 
      integer Ires
*.................  tW process   ............................................*
*                                      / [5] nu(U~)                          *
*                                     /                                      *
*     g(b)[1] ---------O/\/\ W*[4]/\/0                                       *
*                      |              \                                      *
*                      |               \ [6] L(D)                            *
*                      |                                                     *
*     b(g)[2] ---------O============ T [3]                                   *
*............................................................................*
*
*                 1     2        3   4   5   6 
*      nup = 6  ! g(b)  g(b~) -> T   W*  N1  L1 
* how PYTHIA will be treated
        istup(3) = 2   ! final top 
        istup(4) = 2   ! virtual W* 
        istup(5) = 1   ! final NU(U~) from W[3] 
        istup(6) = 1   ! final L(D)   from W[3] 

        pup(5,4) = dsqrt(pup(4,4)**2-pup(1,4)**2
     &                 - pup(2,4)**2-pup(3,4)**2)
* parent's lines of final nu(U) L(D) 
        mothup(1,3)=1  ! final top 
        mothup(2,3)=2  !
         mothup(1,4)=1  ! final W 
         mothup(2,4)=2  !
* KF code and color flow
         if(idup(1).eq.0) then
          iglu = 1
          iqrk = 2
         else
          iglu = 2
          iqrk = 1
         endif
         idup(iglu) = 21  
        if(idup(iqrk).gt.0) then
          idup(4) = -24   ! W-
          idup(3) = +6    ! Top 
        else   
          idup(4) = +24   ! W+
          idup(3) = -6    ! Tbar 
        endif 
        ipar(50) = 300
        icolup(1,iglu) = ipar(50) + 1
        icolup(2,iglu) = ipar(50) + 2
      if(idup(3).eq.6) then 
        icolup(1,3)    = icolup(1,iglu)
        icolup(1,iqrk) = icolup(2,iglu)
      else
        icolup(2,3)    = icolup(2,iglu)
        icolup(2,iqrk) = icolup(1,iglu)
      endif
* showering

* fill HEPEUP for W-boson and its decays products 
      
      kfw = idup(4)          ! KF code of second W
      ires = 2
      call Res_branch(ires, kfw, Ir)
* fill masses and HEPEUP information for the fermions from second W-boson
      kfw = kfw / abs(kfw)         ! +1(-1) for W+(W-)
      kff1 = kfw * FID(Ires,Ir,1)   ! KF code of first  fermion 
      kff2 = kfw * FID(Ires,Ir,2)   ! KF code of second fermion 
      call colorf_bff(4, 5, kff1,  6, kff2) 
* parameters for top decay
*      return
      ntop = 0
      do I = 3, Nup
       if(abs(idup(I)).eq.6) then
         ntop = ntop + 1
         kpp(ntop) = I
         kftop(ntop) = idup(i)
       endif 
      enddo
       if(ntop.ge.1) call top_decay(ntop, kpp, kftop) 
      return
      end

*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky,     09.09.2002                              *
*   W* and H* production                                                     *
*   TopReX code = 4      ==> top b   final state                             *
*   TopReX code = 7      ==> nu  tau final state                             *
*   color flow and showering description for PYTHIA                          *
*............................................................................*
      subroutine COLORF_04(i1, i2)
*     ----------------------------                                           *
*............................................................................*
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
*..................TopReX commons and internal variables
      integer I, i1, i2, izn, kf1, kf2, kpp(2), ntop, kftop(2) 
*............. W* + H* process   ............................................*
*                            Ipar(1) =  4        8                           *
*     q(q~)[1]\                       / T [4]    NU[4]                       *
*              \                     /                                       *
*               \                   /                                        *
*                O/\ W* + H*[3] \/\O                                         *
*               /                   \                                        *
*              /                     \                                       *
*     q~(q)[2]/                       \ B [5]    TAU[5]                      *
*............................................................................*
*
*                  1      2       3          4       5  
*      nup=5    ! q(q~)  q~(q) -> (W* H*) -> T (NU)  Bbar (TAU) 
* how PYTHIA will be treated
        istup(3) = 2   ! virtual boson 
        istup(4) = 1   ! final NU(top) 
        istup(5) = 1   ! final B
* parent's lines of final nu(U) L(D) 
        mothup(1,3)=1  
        mothup(2,3)=2  
         mothup(1,4)=3 
         mothup(2,4)=3 
          mothup(1,5)=3 
          mothup(2,5)=3 
* KF code and color flow
       if    (abs(ipar(21)).eq.1) then
          idup(3) = -24
       elseif(abs(ipar(21)).eq.2) then
          idup(3) = -37
       else
          idup(3) = 94
       endif

      if(i1.eq.2.OR.i1.eq.4.OR.i2.eq.2.OR.i2.eq.4) then
       idup(3)=-idup(3)   ! T Bbar  or NU TAU+ 
       izn =  1    
      else
       izn = -1
      endif      

       if(Ipar(1).eq.4.or.Ipar(1).eq.8) then
        kf1 = izn * 6
        kf2 = -izn * 5
        istup(4) = 2  ! final top
      else
        kf1 =  izn*16
        kf2 = -izn*15
      endif 
* color flow for initial quarks
      ipar(50) = 300
        if(i1.gt.0) then
         icolup(1,1) = ipar(50) + 1 
         icolup(2,2) = ipar(50) + 1 
        else
         icolup(2,1) = ipar(50) + 1 
         icolup(1,2) = ipar(50) + 1 
        endif
* colorf flow for final fermions
      idup(4) = kf1 
      idup(5) = kf2 
      ipar(50) = 300 + 100
        if(idup(4).eq.6) then
         icolup(1,4) = ipar(50) + 1 
         icolup(2,5) = ipar(50) + 1 
       elseif(idup(4).eq.-6) then
         icolup(2,4) = ipar(50) + 1 
         icolup(1,5) = ipar(50) + 1 
       endif

      ntop = 0
      do I = 3, Nup
       if(abs(idup(I)).eq.6) then
         ntop = ntop + 1
         kpp(ntop) = I
         kftop(ntop) = idup(I)
       endif 
      enddo
      if(ntop.ge.1)  call top_decay(ntop, kpp, kftop) 
      RETURN
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  09.09.2002                                  *
*   color flow and showering description for PYTHIA                          *
*   t tbar  production (SM)                                                  *
*   TopReX code = 20                                                         *
      subroutine COLORF_20(ip1, ip2)
*     -------------------------------                                        *
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
*..................TopReX commons and internal variables
      Integer I, ip1, ip2,  ntop, kpp(2), kftop(2) 
      double precision zn1, zn2
      COMMON /colden/ zn1, zn2
*...END VARIABLE'S DEFINITION

*............................................................................*
*     q([1] ---------O=======> top     [3]                                   *
*                    <                                                       *
*                    >                                                       *
*                    <                                                       *
*     q_[2] ---------O=======> top_bar [4]                                   *
*............................................................................*

* PYUPR :        1   2     3   4  
*
*      nup = 4 ! q   q~ -> t   t~ 
* how PYTHIA will be treated
        istup(3) = 2  ! final top 
        istup(4) = 2  ! final topbar
* parent's lines 
          mothup(1,3)=1  
          mothup(2,3)=2  
            mothup(1,4)=1 
            mothup(2,4)=2 
* KF code
      idup(3) =  6
      idup(4) = -6
*
      idup(1) = ip1 
       if(idup(1).eq.0) idup(1) = 21
      idup(2) = ip2
       if(idup(2).eq.0) idup(2) = 21
*  color flow 
       ipar(50) = 300
       icolup(1,3) = ipar(50) + 1
       icolup(2,4) = ipar(50) + 2

        if(idup(1).eq.21) then         ! gluon gluon
         if(abs(zn1).le.abs(zn2)) then  ! t-channel
* color flow :   t-channel
*       color(g1) -> T[3]   anti-color(g1) -> g2
*       color(g2) -> g1     anti-color(g2) -> T~[4]
          icolup(1,1) = icolup(1,3)  
          icolup(2,1) = ipar(50) + 3 
          icolup(1,2) = icolup(2,1)  
          icolup(2,2) = icolup(2,4)
          else
* color flow : u-channel
*       color(g1) -> g2   anti-color(g1) -> T~[4]
*       color(g2) -> T[3] anti-color(g2) -> g1
          icolup(1,1) = ipar(50) + 3 
          icolup(2,1) = icolup(2,4) 
          icolup(1,2) = icolup(1,3)  
          icolup(2,2) = icolup(1,1)
         endif  ! finish gluon gluon color prescription 
        elseif(ip1.gt.0) then  ! quark
          icolup(1,1) = icolup(1,3)          
          icolup(2,2) = icolup(2,4)          
        elseif(ip1.lt.0) then
          icolup(2,1) = icolup(2,4)          
          icolup(1,2) = icolup(1,3)          
        endif
* top decays 

      ntop = 0
      do I = 3, Nup
       if(abs(idup(I)).eq.6) then
         ntop = ntop + 1
         kpp(ntop) = I
         kftop(ntop) = idup(i)
       endif
      enddo
       if(ntop.ge.1) then
        call top_decay(ntop, kpp, kftop) 
       endif
*
*      call hardinfo
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  09.09.2002                                  *
*   color flow and showering description for PYTHIA                          *
*   t tbar  production (SM)                                                  *
*   TopReX code = 20                                                         *
      subroutine COLORF_25(ip1, ip2)
*     -------------------------------                                        *
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
*..................TopReX commons and internal variables
      Integer I, ip1, ip2,  ntop, kpp(2), kftop(2) 
      double precision zn1, zn2
      COMMON /colden/ zn1, zn2
      double precision vh 
      common /topol2/  vh(2,3,3)
      double precision vtt3
      common /topol2gam/ vtt3(3,3,3)
      integer j1, j2
*...END VARIABLE'S DEFINITION

*............................................................................*
*     q([1] ---------O=======> top     [3]                                   *
*                    <                                                       *
*                    >                                                       *
*                    <                                                       *
*     q_[2] ---------O=======> top_bar [4]                                   *
*............................................................................*

* PYUPR :        1   2     3   4  
*
*      nup = 4 ! q   q~ -> t   t~ gamma 
* how PYTHIA will be treated
        istup(3) = 2  ! final top 
        istup(4) = 2  ! final topbar
        istup(5) = 1  ! final photon
* parent's lines 
          mothup(1,3)=1  
          mothup(2,3)=2  
            mothup(1,4)=1 
            mothup(2,4)=2 
             mothup(1,5)=1 
             mothup(2,5)=2 
* KF code
      idup(3) =  6
      idup(4) = -6
      idup(5) = 22 ! photon
*
      idup(1) = ip1 
       if(idup(1).eq.0) idup(1) = 21
      idup(2) = ip2
       if(idup(2).eq.0) idup(2) = 21
*  color flow 
       ipar(50) = 300
       icolup(1,3) = ipar(50) + 1
       icolup(2,4) = ipar(50) + 2

        if(idup(1).eq.21) then         ! gluon gluon
         if(abs(zn1).ge.abs(zn2)) then  ! t-channel
* color flow :   t-channel
*       color(g1) -> T[3]   anti-color(g1) -> g2
*       color(g2) -> g1     anti-color(g2) -> T~[4]
          icolup(1,1) = icolup(1,3)  
          icolup(2,1) = ipar(50) + 3 
          icolup(1,2) = icolup(2,1)  
          icolup(2,2) = icolup(2,4)
          else
* color flow : u-channel
*       color(g1) -> g2   anti-color(g1) -> T~[4]
*       color(g2) -> T[3] anti-color(g2) -> g1
          icolup(1,1) = ipar(50) + 3 
          icolup(2,1) = icolup(2,4) 
          icolup(1,2) = icolup(1,3)  
          icolup(2,2) = icolup(1,1)
         endif  ! finish gluon gluon color prescription 
        elseif(ip1.gt.0) then  ! quark
          icolup(1,1) = icolup(1,3)          
          icolup(2,2) = icolup(2,4)          
        elseif(ip1.lt.0) then
          icolup(2,1) = icolup(2,4)          
          icolup(1,2) = icolup(1,3)          
        endif
* top decays 
       do j1 = 1,3
        do j2 = 1,3
         vh(1, j1, j2) = vtt3(1, j1, j2) 
        if(abs(ip1).eq.1.OR.abs(ip1).eq.3.OR.
     &                       abs(ip1).eq.5) then
         vh(2, j1, j2) = vtt3(3, j1, j2) 
        elseif(abs(ip1).eq.2.OR.abs(ip1).eq.4) then
         vh(2, j1, j2) = vtt3(2, j1, j2) 
        endif
        enddo
       enddo
      ntop = 0
      do I = 3, Nup
       if(abs(idup(I)).eq.6) then
         ntop = ntop + 1
         kpp(ntop) = I
         kftop(ntop) = idup(i)
       endif
      enddo
       if(ntop.ge.1) then
        call top_decay(ntop, kpp, kftop) 
       endif

      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  26.01.2001                                  *
*   W Q Qbar production                                                      *
*   TopReX code = 5                                                          *
*   color flow and showering description for PYTHIA                          *
*............................................................................*
      subroutine COLORF_05(ip1, ip2)
*     ------------------------------                                         *
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
*..................TopReX commons and internal variables
      integer ip1, ip2
*   W-boson decay parameters
      integer kfw, IR, Ires 
* first parameter in MID, BRF, FID, and BRS has the meaning as follows
*     IRES = 1 : top quark,  IRES = 2 : W-boson, 
*     IRES = 3 : H+- boson,  IRES = 4 : Z-boson 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer kff1, kff2
*..
*................... WQQbar  process  .......................................*
*     g(q) [1]\                                                              *
*              \                 N1[4]                                       *
*               \              /                                             *
*                \  W*[3]     /                                              *
*                 O\/\/\/\/\/O                                               *
*                /            \                                              *
*               /              \ L1[5]     / Q[6]                            *
*              /    g*                    /                                  *
*             O~~~~~~~~~~~~~~~~~~~~~~~~~~O                                   *
*            /                            \                                  *
*   g(q~)[2]/                              \ Qbar[7]                         *
*............................................................................*
*

*                           4-vectors --> /HEPEUP/

*                1     2   3  4  5        6  7
*       nup=7 ! q(~)  q(~) W  Nu L+-  g*  Q  Qbar
* how PYTHIA will be treated
        istup(3) =  2 ! virtual W*,  mass preserved 
        istup(6) =  1 ! final Q 
        istup(7) =  1 ! final Qbar
* masses
        pup(5,3) = dsqrt(pup(4,3)**2-pup(1,3)**2
     &                 - pup(2,3)**2-pup(3,3)**2)
      if(ip1.eq.1.or.ip1.eq.3.or.ip2.eq.1.or.ip2.eq.3) then
       kfw = -24     ! W- production
      else
       kfw =  24     ! W+ production
      endif
* KF codes
        idup(3)=kfw
        idup(6)= Ipar(7)
        idup(7)=-Ipar(7)
* parent's lines
        mothup(1,1)=0   
        mothup(2,1)=0
         mothup(1,2)=0
         mothup(2,2)=0
          mothup(1,3)=1  ! final W 
          mothup(2,3)=2  !
        mothup(1,6)=1  ! final Q 
        mothup(2,6)=2  !
        mothup(1,7)=1  ! final Qbar 
        mothup(2,7)=2  !
*
* color flow
        ipar(50) = 600  ! new number of current color
        if(idup(1).gt.0) then    ! q1 q_bar2
         icolup(1,1)=ipar(50)+1  !      color  q1     -> Q[6]
         icolup(2,2)=ipar(50)+2  ! anti-color q_bar2 -> Qbar[7]
        else                     ! q_bar1   q2
         icolup(2,1)=ipar(50)+2  !     color  q1     -> Q[6]
         icolup(1,2)=ipar(50)+1  ! anti-color q_bar2 -> Qbar[7]
        endif
         icolup(1,6)=ipar(50)+1  !     color  Q[6]
         icolup(2,7)=ipar(50)+2  ! anti-color Qbar[7]
*
       ires = 2  !  W-boson decay
       call Res_branch(ires, kfw, IR)
* fill masses and HEPEUP information for the fermions from W-boson
        kfw = idup(3) / abs(idup(3))    ! +1(-1) for W+ (W-)
        kff1 = kfw *FID(Ires,IR,1)       ! KF code of first  fermion 
        kff2 = kfw *FID(Ires,IR,2)       ! KF code of second fermion
* color flow
      call colorf_bff(3, 4, kff1,  5, kff2) 
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  31.01.2001                                  *
*   H+- JET   production                                                     *
*   TopReX code = 7                                                          *
*   color flow and showering description for PYTHIA                          *
*............................................................................*
      subroutine COLORF_07(i1, i2)
*     --------------------------------                                       *
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
*..................TopReX commons and internal variables
      integer i1, i2, IKF, iglu, iqrk, ik
      common /hjetfl/ ik(3) 
*.............  H JET  process   .......................
*...
*                                                        
*     q(q~)[1]\ ~~~~~~~~~~~~~~~~~~~~~~~~  final q or G [3]
*              \                         
*               \                 /   NU [5]  
*                \               /      
*                 O/\  H [4]  /\O    
*                /               \
*               /                 \
*     q~(q)[2] /                   \ TAU [6]
*                                      
*...........................................................
*                 1      2        3   4        5    6
*      nup=6    ! q(q~)  q~(q) -> q   H(W) ->  NU  TAU   
* how PYTHIA will be treated
        istup(3) =  1 ! final parton 
        istup(4) =  2 ! virtual boson
        istup(5) =  1 ! final NU 
        istup(6) =  1 ! final TAU
* parent's lines
          mothup(1,3)=1  ! final Q
          mothup(2,3)=2  !
        mothup(1,4)=1  ! final W 
        mothup(2,4)=2  !
        mothup(1,5)=4  ! final NU 
        mothup(2,5)=4  !
        mothup(1,6)=4  ! final TAU 
        mothup(2,6)=4  !
* KF code
        if    (abs(ipar(21)).eq.1) then
          idup(4) = -24 
        elseif(abs(ipar(21)).eq.2) then
          idup(4) = -37
        else
          idup(4) = 94
        endif
       if(i1.eq.2.OR.i1.eq.4.OR.i1.eq.-1.OR.i1.eq.-3.OR.i1.eq.-5.
     & or.i2.eq.2.OR.i2.eq.4.OR.i2.eq.-1.OR.i2.eq.-3.OR.i2.eq.-5)
     & idup(4) = -idup(4) 
       if(idup(4).gt.0)    then
        idup(5) =  16   ! H+, W+
        idup(6) = -15
       else
        idup(5) = -16   ! H-, W-
        idup(6) =  15
       endif 
* color flow
       ipar(50) = 300
*       ikf = abs(ik(3))
      IF    (i1.EQ.0.OR.i2.EQ.0) THEN  ! gluon + quark 
        if(i1.eq.0) then
         iglu = 1
         iqrk = 2
         idup(2) = i2
         ikf = abs(ik(3))
         if(i2.lt.0) ikf = -ikf
        elseif(i2.eq.0) then
         iglu = 2
         iqrk = 1
         idup(1) = i1
         ikf = abs(ik(3))
         if(i1.lt.0) ikf = -ikf
        endif
         idup(iglu) = 21  ! initial gluon 
         idup(3) = ikf ! flavor of final quark
*  colors
          icolup(1,iglu) = ipar(50) + 1   ! gluon color
          icolup(2,iglu) = ipar(50) + 2   ! gluon anticolor
         if    (ikf.gt.0) then
          icolup(1,iqrk) = icolup(2,iglu)    ! from gluon
          icolup(1,3)    = icolup(1,iglu)    ! from gluon
         else 
          icolup(2,iqrk) = icolup(1,iglu)    ! from gluon
          icolup(2,3)    = icolup(2,iglu)    ! from gluon
         endif
      ELSEIF(i1.NE.0.and.i2.NE.0) then
* quark + antiquark in the initial state
        idup(1) = i1   ! initial quark 
        idup(2) = i2   ! initial quark
        idup(3) = 21   ! flavor of final gluon 
         icolup(1,3) = ipar(50) + 1
         icolup(2,3) = ipar(50) + 2
       if(i1.gt.0) then
         icolup(1,1) = icolup(1,3) 
         icolup(2,2) = icolup(2,3) 
       else 
         icolup(2,1) = icolup(2,3) 
         icolup(1,2) = icolup(1,3) 
       endif
      endif
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  10.09.2002                                  *
*   H+ H- production                                                         *
*   TopReX code = 31                                                         *
      subroutine COLORF_61(ip1, ip2)
*     -------------------------------                                        *
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
*..................TopReX commons and internal variables
      Integer I, ip1, ip2
*...END VARIABLE'S DEFINITION

*............................................................................*
*     q [1] ---------O=======> H+ [3]                                        *
*                    <                                                       *
*                    >                                                       *
*                    <                                                       *
*     q_[2] ---------O=======> H- [4]                                        *
*............................................................................*

* PYUPR :        1   2     3   4  
*
*      nup = 4 ! q   q~ -> H+  H- 
* how PYTHIA will be treated
        istup(3) = 2  ! final H+ 
        istup(4) = 2  ! final H- 
* parent's lines
          mothup(1,3)=1  ! final H+
          mothup(2,3)=2  !
          mothup(1,4)=1  ! final H-
          mothup(2,4)=2  ! final H-
* KF code
      idup(3) =  37 
      idup(4) = -37
*
      idup(1) = ip1 
      idup(2) = ip2
*  color flow 
        ipar(50) = 300
         if(idup(1).gt.0) then
            icolup(1,1) = ipar(50) + 1 
            icolup(2,2) = icolup(1,1)
         elseif(idup(1).lt.0) then
            icolup(2,1) = ipar(50) + 1 
            icolup(1,2) = icolup(2,1)
         endif
*  showering
       do i = 3, nup
        if(abs(idup(i)).eq.37) call HPM_decay(I, idup(I)) 
       enddo 
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky,     10.09.2002                              *
*  H+- -> bbar T (-> b W -> f1 f2)
*   color flow and showering description for PYTHIA                          *
*............................................................................*
      subroutine COLORF_HFF_11(kp) 
*     -------------------------------                                        *
*............................................................................*
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
      integer mxdc
      parameter (mxdc=20)   
      integer ndec, kdec
      double precision pdm, pdpl
      common /decmom/ pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)
      integer kp, izn, nbar1, nt, nw, nb1, nl1, nl2, fc1, fc2
*
       Nbar1 = NUP + 1
       NT    = NUP + 2
       NB1   = NUP + 3
       NW    = NUP + 4
       NL1   = NUP + 5                       ! U(nu) 
       NL2   = NUP + 6                       ! D(l+-)
       izn = idup(kp) / abs(idup(kp))        ! +1(-1) for H+ (H-)

        istup(nbar1) = 1           ! Bbar from H+- 
        idup(nbar1) = kdec(1,1) 
        mothup(1,nbar1) = kp 
        mothup(2,nbar1) = kp 
        ipar(50) = ipar(50) + 100
        icolup(1,nbar1) = (ipar(50) + 1) * (1 - izn)/2
        icolup(2,nbar1) = (ipar(50) + 1) * (1 + izn)/2
* 
        istup(nt) = 2           ! top from H+- 
        idup(nt) = kdec(2,1) 
        mothup(1,nt) = kp 
        mothup(2,nt) = kp 
        icolup(1,nt) = (ipar(50) + 1) * (1 + izn)/2
        icolup(2,nt) = (ipar(50) + 1) * (1 - izn)/2
* 
        istup(nb1) = 1           ! final b from top
        idup(nb1) = kdec(3,1) 
        mothup(1, nb1) = nt 
        mothup(2, nb1) = nt 
        icolup(1,nb1) = icolup(1, nt)
        icolup(2,nb1) = icolup(2, nt)
*
        istup(nw) = 2           ! final W from top
        idup(nw) = kdec(4,1)
        mothup(1,nw) = nt 
        mothup(2,nw) = nt 
*
       fc1 = kdec(5,1)                   ! KF code
       fc2 = kdec(6,1)                   ! KF code
       NUP = NUP + 6
       call colorf_BFF(NW, NL1, fc1, NL2, fc2)
*
       call DECHEP(KP, 1, nbar1) 
       call DECHEP(KP, 2, nt) 
       call DECHEP(KP, 3, nb1) 
       call DECHEP(KP, 4, nw) 
       call DECHEP(KP, 5, nl1) 
       call DECHEP(KP, 6, nl2) 

*      do I = 1,5
*       pup(i, nbar1) = pdm(1,I)      
*       pup(i, nt)    = pdm(2,I)      
*       pup(i, nb1)   = pdm(3,I)      
*       pup(i, nw)    = pdm(4,I)      
*       pup(i, nl1)   = pdm(5,I)      
*       pup(i, nl2)   = pdm(6,I)      
*      enddo
      RETURN
      END
c----------------------------------------------------------------------------c
*.. author : Serge Slabospitsky   03.02.2001                                 *
*....                                                                        *
      subroutine Top_Decay(Ntop, KPP, KFT) 
*     ------------------------------------                                   *
*  NTOP is number of t-quarks                                                *
*  KPP  are position of t-quarks in HEPEUP list                              *
*  KFT  are KF code of top quarks                                            *
*............................................................................*
      implicit none
      integer Ntop, IR, KPP(2) , kft(2) 
      integer id1, kp1, kft1 !, iqs1 
      integer id2, kp2, kft2 !, iqs2 
*.........

      if(ntop.eq.1) then 
       Ir  = 1       ! top
       kp1  = KPP(1)
       kft1 = kft(1) 
       call Res_branch (IR, kft1, Id1) 
       call top_rdec_1(id1, Kp1) 
      elseif(ntop.eq.2) then 
       IR  = 1       ! top 
       kp1  = KPP(1)
       kft1 = KFT(1) 
       call Res_branch (IR, kft1, Id1) 
       kp2  = KPP(2)
       kft2 = KFT(2) 
       call Res_branch (IR, kft2, Id2) 
       call top_rdec_2(id1, id2, kp1, kp2) 
      else
       write(*,10) Ntop 
 10    format('  wrong number of decaying top quarks',
     &3x,' stop TopReX running ')
          STOP
      endif
      return
      end
*----------------------------------------------------------------------------*
*..decays routines. for PYTHIA 6.2xx version                                 *
*.. author : Serge Slabospitsky   27.01.2001                                 *
*....                                                                        *
       subroutine top_rdec_1(id, KP)
*     ---------------------------------                                      *
*  ID is  top decay channel                                                  *
*  KP is the position of t-quark in HEPEUP list                              *
*  KFT is the KF code  of t-quark                                            *
*............................................................................*

      implicit none
* PYTHIA6.2 common block for external user's process 

      include "hepeup.inc"
      include "txpar.inc" 
      integer id, KP, KFT, Irs, I
      double precision vh, pyr, ves
      common /topol1/ vh(4)
      integer mxdc
      parameter (mxdc=20)   
      integer                                     ndec, kdec
      double precision pdm,       pdpl
      common /decmom/  pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)
      double precision mt
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision cos3, nv(3)
      common /nvv/nv
* first parameter in MID, BRF, FID, and BRS has the meaning as follows
*     IRS = 1 : top quark,  IRS = 2 : W-boson, 
*     IRS = 3 : H+- boson,  IRS = 4 : Z-boson 
*     IRS = 5 : t -> b H* -> T* 
*...........
      ndec = 0
      kft = IDup(kp)  ! top KF code of the top quark
      if(kft.lt.0) then
       do i = 1,3
        vh(i) = -vh(i)
       enddo
      endif 

      if( id.eq.1. OR.id.eq.2
     &.OR.id.eq.3)               irs = 2 ! W-boson
      if( id.eq.5)               irs = 3 ! H-boson
      if( id.eq.6)               irs = 5 ! t -> H+- T* 
      if (id.eq.11.or.id.eq.12
     &.or.id.eq.13.or.id.eq.14)  irs = 1 ! t -> q G (A) 
      if( id.eq.15.or.id.eq.16
     &.or.id.eq.17.or.id.eq.18)  irs = 4 ! t -> q Z 
      if(irs.eq.-1) STOP
*
      nv(1) = 0.d0
      nv(2) = 0.d0
      nv(3) = 0.d0
       cos3 = 
     & dsqrt(pup(1,kp)**2+pup(2,kp)**2+pup(3,kp)**2)
       if(cos3.ge.0.001d0) then
        nv(1) = pup(1,kp) / cos3
        nv(2) = pup(2,kp) / cos3
        nv(3) = pup(3,kp) / cos3
       endif 
 11   continue
      mt = pup(5,kp)

       if(irs.eq.1) call Top_dec_01(id, kft, MT) 
       if(irs.eq.2) call Top_dec_02(id, kft, MT) 
       if(irs.eq.3) call Top_dec_03(kft, MT) 
       if(irs.eq.4) call Top_dec_04(id, kft, MT) 
       if(irs.eq.5) call Top_dec_05(kft, MT) 

*      print*,(pup(ii,kp),ii=1,5)
      IF(ipar(33).eq.1) THEN ! take into account spin of produced tops
       ves = vh(1)*pdm(20,1)+vh(2)*pdm(20,2)+vh(3)*pdm(20,3) 
       ves = (1.d0 + ves) / 2.d0
       if(pyr(0).ge.ves) goto 11
      ENDIF

*  final f1 f2~ KF codes 
      if(irs.eq.1)                             then
        call colorf_t_qv(kp) 
      elseif(irs.eq.2.or.irs.eq.3.or.irs.eq.4) then
       call colorf_t_q2f(kp) 
      elseif(irs.eq.5)                         then
       call colorf_t_qht(kp) 
      endif

      return 
      end
c----------------------------------------------------------------------------c
*.. author : Serge Slabospitsky   06.09.2002                                 *
*....                                                                        *
       subroutine top_rdec_2(id1, id2, kp1, kp2) 
*     --------------------------------------------------                     *
*  ID1 and ID2 are numbers of first and second top-quark decay channels      *
*  KP1 and KP2 are the positions of t-quarks in KUP list                     *
*  KFT1 and KFT2 are the KF codes  of t1 and t2 quarks                       *
*............................................................................*

      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
      integer mxdc
      parameter (mxdc=20)   
      integer ndec, kdec
      double precision pdm, pdpl
      common /decmom/  pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)
      integer I, J, igq, irs1, irs2, id1, id2, KP1, kp2, kft1, kft2 
      double precision mt1, mt2 
      double precision vh 
      common /topol2/  vh(2,3,3)
      double precision pyr, ves
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
* first parameter in MID, BRF, FID, and BRS has the meaning as follows
*     IRES = 1 : top quark,  IRES = 2 : W-boson, 
*     IRES = 3 : H+- boson,  IRES = 4 : Z-boson 
*     IRS = 5 : t -> b H* -> T* 
      integer ndec1, kdec1(20,3), ndec2, kdec2(20,3)
      double precision pdm1(20,5),  pdm2(20,5)
      double precision cos3, nv(3), nv1(3), nv2(3)
      common /nvv/nv
*...
* start executing !
      irs1 = -1
      irs2 = -1
*
       kft1 = idup(kp1)  ! top KF code
       kft2 = idup(kp2)  ! top KF code

                           igq = 2   !  q qbar -> T Tbar
        if(idup(1).eq.21)  igq = 1   !  G G    -> T Tbar
*
      if( id1.eq.1.OR.id1.eq.2
     &.OR.id1.eq.3)               irs1 = 2 ! W-boson
      if( id1.eq.5)               irs1 = 3 ! H-boson
      if( id1.eq.6)               irs1 = 5 ! t -> H -> t* 
      if (id1.eq.11.or.id1.eq.12
     &.or.id1.eq.13.or.id1.eq.14) irs1 = 1 ! t -> q G (A) 
      if( id1.eq.15.or.id1.eq.16
     &.or.id1.eq.17.or.id1.eq.18) irs1 = 4 ! t -> q Z 
      if(irs1.eq.-1) STOP
*
* second top quark
      if( id2.eq.1.OR.id2.eq.2
     &.OR.id2.eq.3)               irs2 = 2 ! W-boson
      if( id2.eq.5)               irs2 = 3 ! H-boson
      if( id2.eq.6)               irs2 = 5 ! t -> H+- -> t*
      if (id2.eq.11.or.id2.eq.12
     &.or.id2.eq.13.or.id2.eq.14) irs2 = 1 ! t -> q G (A) 
      if( id2.eq.15.or.id2.eq.16
     &.or.id2.eq.17.or.id2.eq.18) irs2 = 4 ! t -> q Z 
      if(irs2.eq.-1) STOP
* 
*  top decay procedure
*
      nv1(1) = 0.d0
      nv1(2) = 0.d0
      nv1(3) = 0.d0
       cos3 = 
     & dsqrt(pup(1,kp1)**2+pup(2,kp1)**2+pup(3,kp1)**2)
       if(cos3.ge.0.001d0) then
        nv1(1) = pup(1,kp1) / cos3
        nv1(2) = pup(2,kp1) / cos3
        nv1(3) = pup(3,kp1) / cos3
       endif 

      nv2(1) = 0.d0
      nv2(2) = 0.d0
      nv2(3) = 0.d0
       cos3 = 
     & dsqrt(pup(1,kp2)**2+pup(2,kp2)**2+pup(3,kp2)**2)
       if(cos3.ge.0.001d0) then
        nv2(1) = pup(1,kp2) / cos3
        nv2(2) = pup(2,kp2) / cos3
        nv2(3) = pup(3,kp2) / cos3
       endif 


 11   continue

       nv(1) = nv1(1)
       nv(2) = nv1(2)
       nv(3) = nv1(3)
      mt1 = pup(5,kp1)
       if(irs1.eq.1) call Top_dec_01(id1, kft1, MT1) 
       if(irs1.eq.2) call Top_dec_02(id1, kft1, MT1) 
       if(irs1.eq.3) call Top_dec_03(kft1, MT1)
       if(irs1.eq.4) call Top_dec_04(id1, kft1, MT1)
       if(irs1.eq.5) call Top_dec_05(kft1, mt1)

       ndec1 = ndec
       do I = 1,20
         kdec1(I,1) = kdec(I,1) 
         kdec1(I,2) = kdec(I,2) 
         kdec1(I,3) = kdec(I,3) 
           do J = 1,5
            pdm1(I, J) = pdm(I, J) 
           enddo
       enddo

*
       nv(1) = nv2(1)
       nv(2) = nv2(2)
       nv(3) = nv2(3)
      mt2 = pup(5,kp2)
       if(irs2.eq.1) call Top_dec_01(id2, kft2, MT2) 
       if(irs2.eq.2) call Top_dec_02(id2, kft2, MT2)
       if(irs2.eq.3) call Top_dec_03(kft2, MT2)
       if(irs2.eq.4) call Top_dec_04(id2, kft2, MT2)
       if(irs2.eq.5) call Top_dec_05(kft2, mt2)
*
       ndec2 = ndec
       do I = 1,20
         kdec2(I,1) = kdec(I,1) 
         kdec2(I,2) = kdec(I,2) 
         kdec2(I,3) = kdec(I,3) 
           do J = 1,5
            pdm2(I, J) = pdm(I, J) 
           enddo
       enddo
* 
      IF(ipar(33).eq.1) THEN ! take into account spin of produced tops
       ves = 0.d0
        do i = 1,3
         do j = 1,3
           ves = ves + vh(igq, i, j) * pdm1(20,i) * pdm2(20,j)
         enddo
        enddo
       ves = (1.d0 + ves) / 4.d0
      if(pyr(0).ge.ves) goto 11
      ENDIF
* FIRST  top :  feel final f1 f2~ KF codes and color flow information
       ndec = ndec1
       do I = 1,20
         kdec(I,1) = kdec1(I,1) 
         kdec(I,2) = kdec1(I,2) 
        do J = 1,5
         pdm(I, J) = pdm1(I, J) 
        enddo
       enddo

      if(irs1.eq.1)                               then
        call colorf_t_qv (kp1) 
      elseif(irs1.eq.2.or.irs1.eq.3.or.irs1.eq.4) then
        call colorf_t_q2f(kp1) 
      elseif(irs1.eq.5)                           then
        call colorf_t_qht(kp1) 
      endif

* SECOND top    
       ndec = ndec2
       do I = 1,20
         kdec(I,1) = kdec2(I,1) 
         kdec(I,2) = kdec2(I,2) 
        do J = 1,5
         pdm(I, J) = pdm2(I, J) 
        enddo
       enddo
      if(irs2.eq.1)                               then
         call colorf_t_qv(kp2) 
      elseif(irs2.eq.2.or.irs2.eq.3.or.irs2.eq.4) then
        call colorf_t_q2f(kp2) 
      elseif(irs2.eq.5)                           then
        call colorf_t_qht(kp2) 
      endif

      RETURN 
      end
c----------------------------------------------------------------------------c
*.. author : Serge Slabospitsky   31.01.2002                                 *
*....                                                                        *
      subroutine HPM_Decay(KP, KFH) 
*     ------------------------------------                                   *
*  KP   are position of H-bosons in KUP list                                 *
*  KFH  are KF codes  of H-bosons                                            *
*............................................................................*
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
      integer kp, kfh, irh, idh, nl1,fc1, nl2,fc2 
      double precision mhs
* first parameter in MID, BRF, FID, and BRS has the meaning as follows
*     IRES = 1 : top quark,  IRES = 2 : W-boson, 
*     IRES = 3 : H+- boson,  IRES = 4 : Z-boson 
      integer mxdc
      parameter (mxdc=20)   
      integer ndec, kdec
      double precision pdm, pdpl
      common /decmom/  pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)
*...
*
       irh  = 3        ! H+- 
       call Res_branch (IRH, kfH, Idh) 
* start executing !
      MHS = pup(5,kp) 
      if(idh.eq.11) then
        call HPM_dec_11(KP, kfh)
      else
        call HPM_dec_01(idh, kfh, MHS) 
      endif
      if(idh.eq.11) then
        call COLORF_HFF_11(kp)  
      else
        NL1 = NUP + 1                       ! U(nu) 
        NL2 = NUP + 2                       ! D(l+-)
        fc1 = kdec(1,1)                    ! KF code
        fc2 = kdec(2,1)                    ! KF code
        NUP = NUP + 2
        call colorf_BFF(KP, NL1, FC1, NL2, FC2) 
        call DECHEP(KP, 1, NL1) 
        call DECHEP(KP, 2, NL2) 
      endif      

      return
      end
*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   10.09.2002                                 *
*.... H+- decay into t* (-> b W* => b f1 f2) + bbar                          *
      subroutine HPM_dec_11(ih, kfh) 
*     -----------------------------------------------                        *
*   H(ph) -> b(k1) t*(p) W*(q) nu(l1) l+-(l2) bbar(q1)                       *
*............................................................................*

      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/   mq(0:20), mq2(0:20)
      double precision CKM2
      common /CKMD/    CKM2(-6:6,-6:6)
      double precision HCPL,       HCPL2   
      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)

      double precision PH(5), L1(5), L2(5), K1(5), q1(5)
      double precision Ves 
      double precision PYR
*...........
      LOGICAL first
      SAVE first 
      DATA first /.TRUE./
      double precision VesMaX(30), aran, dh(3), coef 

      save VesMaX, coef 
      integer mxdc
      parameter (mxdc=20)   
      integer ndec, kdec
      double precision pdm, pdpl
      common /decmom/ pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)
      integer I, II, ih, kfh, irw, idw, iz, kv, il1, il2 
      double precision vh      
      common /topol1/ vh(4)
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
* 

       do I = 1,5
        ph(I) = pup(I, ih)
       enddo
      ndec = 6
      if(.NOT.first) goto 114 
        do I = 1,30
         vesmax(i) = 0.d0
        enddo
      coef = pi2_4 / 2.d0 
      do 225 i = 1, mid(0,2)
       if(mid(i,2).le.-1) goto 225
        do ii = 1, ipar(53)
         call HPM_ME_03(i, ph, k1, q1, l1, l2, dh, ves) 
         ves = ves * coef / ph(5)
         if(vesmax(i).le.ves) vesmax(i) = ves
        enddo 
 225  continue
      first = .false. 
 114  continue
       irw  = 2       ! W+-
       call Res_branch (IRW, kfh, idw) 
         call HPM_ME_03(idw, ph, k1, q1, l1, l2, dh, ves) 
         ves = ves * coef / ph(5)
         if(vesmax(i).le.ves) vesmax(i) = ves
         aran = VesMax(idw) * PYR(0) 
         if(Ves.lt.aran) goto 114 
* color flow
        iz =  kfh / abs(kfh)  ! +1(-1) for top (topbar) 
        kv  = iz * 37       ! KF code of H-boson from top 
        il1 = FID(2,idw,1) 
        il2 = FID(2,idw,2) 
      kdec(1,1) = -5 * iz   ! bbar
      kdec(2,1) =  6 * iz   ! t*
      kdec(3,1) =  5 * iz   ! b from t*
      kdec(4,1) = 24 * iz   ! W
      kdec(5,1) = il1 * iz 
      kdec(6,1) = il2 * iz

      do I = 1,5
       pdm(1,I) = q1(I)                 ! bbar
       pdm(2,i) = k1(I) + L1(I) + L2(I) ! t*
       pdm(3,I) = k1(I)                 ! b from t*
       pdm(4,I) = L1(I) + L2(I)         ! W
       pdm(5,I) = L1(I) 
       pdm(6,I) = L2(I) 
      enddo
       pdm(2,5) = dsqrt(pdm(2,4)**2 - pdm(2,1)**2
     &                 - pdm(2,2)**2 - pdm(2,3)**2)
       pdm(4,5) = dsqrt(pdm(4,4)**2 - pdm(4,1)**2
     &                 - pdm(4,2)**2 - pdm(4,3)**2)
      do I = 1,3
       pdm(20,I) = dh(I)
      enddo
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky    27.02.2004                                * 
      subroutine colorf_t_qV(it) 
*     -------------------------------------                                  *
*  fill information about color flow for two-body top decay                  *
*      t -> q V (gluon or photon)                                            * 
* positions in HEPEUP list are as follows:                                   *
*    (hard process) + q   V(G or A)                                          *
*  IT is position of parent top in HEPEUP list                               *
* internal :                                                                 *
*  IQ, IV are HEPEUP positions of q-quark and V-boson from top (t -> q V) dec*
*............................................................................*
      implicit none
*
      include "txpar.inc"     
      include "hepeup.inc" 
*
      integer mxdc
      parameter (mxdc=20)   
      integer ndec, kdec
      double precision pdm, pdpl
      common /decmom/ pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)
      integer  it 
      integer iQ, iV   ! positions of final q and V-boson from top decay
*.....
*
      iQ = NUP + 1   ! quark   position
      iV = NUP + 2   ! V-boson position
* HEPEUP positions for quark
      istup(IQ) = 1
      mothup(1,IQ) = IT          ! mother is top 
      mothup(2,IQ) = IT          ! mother is top 
      idup(iQ)     = kdec(2,1)  ! KF code of the final quark
* HEPEUP positions for gluon (photon)
      istup(IV) = 1
      mothup(1,IV) = IT          ! mother is top 
      mothup(2,IV) = IT          ! mother is top 
      idup(iV)     = kdec(1,1)  ! KF code of the final gluon or photon
* color flow information
      if(kdec(1,1).eq.21)    then            ! gluon
       ipar(50) = ipar(50) + 100      ! new current color
        if(idup(IQ).gt.0) then       !  final QUARK
         icolup(1,IQ) = ipar(50) + 1  !  q :  color comes from gluon
         icolup(2,IQ) = 0             ! 
         icolup(1,IV) = icolup(1,it)  !  g :  color comes from top 
         icolup(2,IV) = icolup(1,IQ)  !  g : Acolor comes from q
        else                          !  final ANTIQUARK
         icolup(1,IQ) = 0             ! 
         icolup(2,IQ) = ipar(50) + 1  !  q : Acolor comes from gluon
         icolup(1,IV) = icolup(2,IQ)  !  g :  color comes from q
         icolup(2,IV) = icolup(2,IT)  !  g : Acolor comes from topbar
        endif
      elseif(kdec(1,1).eq.22) then   ! photon, colors are identical to top 
        icolup(1,IQ) = icolup(1,IT)
        icolup(2,IQ) = icolup(2,IT)
       endif
* momenta 
      call DECHEP(IT, 1, IV) 
      call DECHEP(IT, 2, IQ) 
      NUP = NUP + 2
      return 
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky    06.09.2002                                * 
      subroutine colorf_t_q2f(it) 
*     ---------------------------                                            *
*  fill information about color flow for three-body top decay                *
*      t -> q W/H/Z (-> NU L+-, U D~, L- L+)                                 * 
* positions in HEPEUP list are as follows:                                   *
*    (hard process) V(W,H+-,Z) q f1 f2~                                      *
* input :                                                                    * 
*  IT is position of parent top in HEPEUP list                               *
*  fc(1) and fc(2) are KF codes of the first and second fermions from boson  *
* internal :                                                                 *
*  IQ, IV, IL1, IL2 are positions in HEPEUP list of the final particles:     *
*  q-quark, V-boson, and two final fermions from V-boson decay               *
*............................................................................*
      implicit none
*
      include "txpar.inc"     
      include "hepeup.inc" 
      integer mxdc
      parameter (mxdc=20)   
      integer ndec, kdec
      double precision pdm, pdpl
      common /decmom/ pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)
      integer it, IV, IQ, IL1, IL2, fc1, fc2  
*.....
      IV   = NUP + 2              ! V-boson position in HEPEUP list
      kdec(1,2) = IV              ! V-boson position in HEPEUP list
      istup(IV) = 2               ! will be not treated by PYTHIA
      mothup(1,IV) = IT           ! mother is top 
      mothup(2,IV) = IT           ! mother is top 
      idup(iV)     = kdec(1,1)    ! KF code of the V-boson
*... 
      IQ = NUP + 1                ! color flow (top => q)
      kdec(2,2) = IQ              ! Q position in HEPEUP list
      istup(IQ)    = 1
      mothup(1,IQ) = IT           ! mother is top 
      mothup(2,IQ) = IT           ! mother is top 
      idup(iQ)     = kdec(2,1)    ! KF code of the final quark
      icolup(1,IQ) = icolup(1,IT) ! color flow is identical
      icolup(2,IQ) = icolup(2,IT) ! to top quark
*....
       IL1 = NUP + 3                       ! U(nu) 
       IL2 = NUP + 4                       ! D(l+-)
       kdec(3,2) = IL1                     ! U(nu)  position in HEPEUP list
       kdec(4,2) = IL2                     ! D(L+-) position in HEPEUP list
       fc1 = kdec(3,1)                     ! KF code
       fc2 = kdec(4,1)                     ! KF code
       call colorf_BFF(IV, IL1, FC1, IL2, FC2) 

      call DECHEP(IT, 1, IV) 
      call DECHEP(IT, 2, IQ) 
      call DECHEP(IT, 3, IL1) 
      call DECHEP(IT, 4, IL2) 
        NUP = NUP + 4        
*
      return
      end
c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky    03.02.2001                                * 
      subroutine colorf_t_qht(it) 
*     --------------------------------------------------------               *
*  fill information about color flow for five-body top decay                 *
*      t -> B H* (Bbar T* (-> B W* (-> NU L+-, U D~)                         * 
* input :                                                                    * 
*  IT is position of parent top in HEPEUP list                               *
*............................................................................*
      implicit none
*
      include "txpar.inc"     
      include "hepeup.inc" 
      integer mxdc
      parameter (mxdc=20)   
      integer ndec, kdec
      double precision pdm, pdpl
      common /decmom/ pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)
      integer it, NL1, NL2, fc1, fc2, nb1, nb2, nh, nbar1, nw, iz  
*.....
* top[ipt] -> B2[nb2] + H+- 
*                     H+- -> Bbar1[Nbar1] t*
*                                         t* -> W[NW] B1[nb1] nu[NL1] L+[NL2]  
*
      Nb2   = NUP + 1  ! position of B2   from initial top
      NH    = NUP + 2  ! position of H+- 
      Nbar1 = NUP + 3  ! position of Bbar from H+- 
      NW    = NUP + 4  ! position of W    from top    
      Nb1   = NUP + 5  ! position of B1   from second (virtual) top    
      NL1   = NUP + 6  ! position of nu   from W 
      NL2   = NUP + 7  ! position of L+-  from W 
* B2 (from top) 
      istup(nb2)    = 1
      mothup(1,nb2) = IT           ! mother is top 
      mothup(2,nb2) = IT           ! mother is top 
      idup(nb2)     = kdec(1,1)    ! KF code of the final B2-quark
      icolup(1,nb2) = icolup(1,IT) ! color flow is identical
      icolup(2,nb2) = icolup(2,IT) ! to top quark
      iz = idup(it)/abs(idup(it))  ! +1 for top and H+, -1 for antipart.
* H+- 
      istup(NH)    = 2
      mothup(1,NH) = IT           ! mother is top 
      mothup(2,NH) = IT           ! mother is top 
      idup(NH)     = kdec(2,1)    ! KF code of the H+-
      icolup(1,NH) = 0
      icolup(2,NH) = 0
* for Bbar from H+-
      istup(Nbar1) = 1     
      mothup(1,Nbar1) = NH        ! mother is H+-
      mothup(2,Nbar1) = NH        ! mother is H+- 
      idup(nbar1)     = kdec(3,1) 
       IPAR(50) = IPAR(50) + 100  ! new current color
      icolup(1,nbar1) = (ipar(50)+1)*(1-iz)/2
      icolup(2,nbar1) = (ipar(50)+1)*(1+iz)/2
* for W from second top 
      istup(NW) = 2     
*      idup(NW) = 2      
      mothup(1,NW) = NH           ! mother is H+-
      mothup(2,NW) = NH           ! mother is H+- 
      idup(NW)     = kdec(5,1) 
* for B1 from second top 
      istup(Nb1) = 1     
      mothup(1,Nb1) = NH          ! mother is H+-
      mothup(2,Nb1) = NH          ! mother is H+- 
      idup(Nb1)     = kdec(6,1) 
      icolup(1,nb1) = (ipar(50)+1)*(1+iz)/2
      icolup(2,nb1) = (ipar(50)+1)*(1-iz)/2
*
      fc1 = kdec(7,1) 
      fc2 = kdec(8,1) 
      call colorf_BFF(nw, NL1, fc1, NL2, fc2) 
* boost to initial hadron ref. frame
      call DECHEP(IT, 1, nb2  ) ! B2 
      call DECHEP(IT, 2, NH   ) ! H+- 
      call DECHEP(IT, 3, NBar1) ! Bbar1 
      call DECHEP(IT, 5, NW   ) ! W 
      call DECHEP(IT, 6, NB1  ) ! B1
      call DECHEP(IT, 7, NL1  ) ! NU or U
      call DECHEP(IT, 8, NL2  ) ! L+- or Dbar
*  increase NUP
      NUP = NUP + 7        
*
      return
      end
c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky    06.09.2002                                * 
      subroutine DECHEP(KI, KD, KO) 
*     -----------------------------------------------                        *
*  special case !
*  KI is position in HEPEUP list of P, which define Lorentz boost            *
*  KD is position in decmom list of particle in KI rest frame                * 
*  KO is position in HEPEUP list of boosted P-particle                       *
*............................................................................*
      implicit none
*
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      integer mxdc
      parameter (mxdc=20)   
      integer ndec, kdec
      double precision pdm, pdpl
      common /decmom/ pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)
      integer ki, ko, kd 
      double precision pf4, fn
*.....
      if (pup(4,KI).eq.pup(5,KI)) go to 17
      pf4  = ( pdm(KD,4)*pup(4,KI) + pdm(KD,3)*pup(3,KI)
     &       + pdm(KD,2)*pup(2,KI) + pdm(KD,1)*pup(1,KI))
     &          / pup(5,KI)
      fn   = (pf4+pdm(KD,4)) / (pup(4,KI)+pup(5,KI))
      pup(1,KO)= pdm(KD,1) + fn*pup(1,KI)
      pup(2,KO)= pdm(KD,2) + fn*pup(2,KI)
      pup(3,KO)= pdm(KD,3) + fn*pup(3,KI)
      pup(4,KO)= pf4
      go to 18
c
   17 pup(1,KO) = pdm(KD,1)
      pup(2,KO) = pdm(KD,2)
      pup(3,KO) = pdm(KD,3)
      pup(4,KO) = pdm(KD,4)
c
   18 pup(5,KO) = pdm(KD,5)
      RETURN
      END
c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky    05.09.2002                                * 
      subroutine colorf_BFF(IV, I1, K1,  I2, K2)
*     -----------------------------------------------                        *
* fill position, mother, and color for NU(U) and L+(Dbar)                    *
* from neutral boson decay                                                   *
* IV       is the position in HEPEUP list of V-boson                         *
* I1, K1 are position in HEPEUP list and KF code or first (NU, U) fermion    *
* I2, K2 are position in HEPEUP list and KF code or second (L+, Dbar) ferm.  *
* it is assumed, that both final fermions will be treated by PYTHIA          *
*   I1 = 0 means, that the final fermions are not added yet in HEPEUP list   *
*   in this case NUP will be increased to NUP_new = NUP_old + 2              *
*............................................................................*
      implicit none
*
      include "hepeup.inc" 
      include "txpar.inc"     
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)

      integer  iv, i1, i2, k1, k2  
*.....
      if(i1.eq.0) then
       i1 = nup + 1   !  added to HEPEUP list
       i2 = nup + 2
       nup = nup + 2
      endif
* mother's position
         istup(i1) = 1
         mothup(1,i1) = iv  ! 1-fermion from V-boson 
         mothup(2,i1) = iv  !
          istup(i2) = 1
          mothup(1,i2)= iv  ! 2-fermion from V-boson
          mothup(2,i2)= iv  !
         idup(i1) = k1
         idup(i2) = k2
* color flow
       pup(5,i1) = mq(ABS(k1))
       pup(5,i2) = mq(ABS(k2)) 
      if (ABS(k1).LE.8) then !  final quarks
        ipar(50) = ipar(50) + 100  ! new current color number
        icolup(1,i1) = (ipar(50) + 1) * (abs(k1)+k1)/2/abs(k1)
        icolup(2,i1) = (ipar(50) + 1) * (abs(k1)-k1)/2/abs(k1)
        icolup(1,i2) = (ipar(50) + 1) * (abs(k2)+k2)/2/abs(k2)
        icolup(2,i2) = (ipar(50) + 1) * (abs(k2)-k2)/2/abs(k2)
      endif 
      RETURN
      END
c----------------------------------------------------------------------------c

      subroutine IBMTG(BM,TG,  IB, IT) 
      implicit none
      CHARACTER*12 BM,TG,  BM2, TG2 
      integer Ib, It 
      integer MAXnum
      PARAMETER (MAXNUM=33)
      character*12 CDHE(maxnum) 
      DATA CDHE/     'e-          ','e+          ','nu_e        ',
     &'nu_ebar     ','mu-         ','mu+         ','nu_mu       ',
     &'nu_mubar    ','tau-        ','tau+        ','nu_tau      ',
     &'nu_taubar   ','pi+         ','pi-         ','n0          ',
     &'nbar0       ','p+          ','pbar-       ','gamma       ',
     &'lambda0     ','sigma-      ','sigma0      ','sigma+      ',
     &'xi-         ','xi0         ','omega-      ','pi0         ',
     &'k+          ','k-          ','ks0         ','kl0         ',
     &'p           ','pbar        '/
      integer KCDE(maxnum) 
      DATA KCDE/      11,            -11,           12,
     & -12,           13,            -13,           14, 
     & -14,           15,            -15,           16,
     & -16,           211,           -211,          2112,
     & -2112,         2212,          -2212,         22,
     &  3122,         3112,           3212,         3222,
     &  3312,         3322,           3334,          111, 
     &  321,         -321,           310,             130,
     & 2212, - 2212/
      integer i 
* transform capital letters to small ones
       bm2 = '            '
       tg2 = '            '
       do i = 1,12 
       if(BM(i:i).ne.' ') then
         if(ichar(BM(i:i)).ge.65.AND.ichar(BM(i:i)).LE.90) then
           BM2(i:i) = char(ichar(BM(i:i))+32)
         else
           BM2(i:i) = BM(i:i)
         endif
       endif
       enddo
       do i = 1,12 
       if(TG(i:i).ne.' ') then
         if(ichar(TG(i:i)).ge.65.AND.ichar(TG(i:i)).LE.90) then
           TG2(i:i) = char(ichar(TG(i:i))+32)
         else
           TG2(i:i) = TG(i:i)
         endif
       endif
       enddo
      Ib = 0
      It = 0
      do I = 1, maxnum
        if(BM2.eq.CDHE(I)) Ib = KCDE(I)
        if(TG2.eq.CDHE(I)) It = KCDE(I)
      enddo
      if(Ib.ne.0.and.It.ne.0) then
        RETURN
      else   
       if(Ib.eq.0) write(*,11) BM
 11    format(//,3x,'TopReX : unknown BEAM = ',a12)
       if(It.eq.0) write(*,12) TG 
 12    format(//,3x,'TopReX : unknown TARGET = ',a12)
       write(*,14)
 14    format(/,3x,'stop run')
      STOP
      endif
      return
      end
c----------------------------------------------------------------------------c
* for multiple processes

      subroutine TX_MULT
      implicit none
      Integer           Ipar     ! global TopRex integer parameters  
      double precision  Rpar     ! global TopRex real    parameters
      common /TXPAR/Ipar(200), Rpar(200)
      save   /TXPAR/
      integer I 
      integer  maxpro 
      parameter (maxpro=500)
      integer         txmup, txsel, txpro,      txext
      common /trxpro/ txmup, txsel, txpro(maxpro), txext(maxpro)
      save   /trxpro/
C...User process event common block 
      INTEGER MAXPUP
      PARAMETER (MAXPUP=100)
      INTEGER IDBMUP,PDFGUP,PDFSUP,IDWTUP,NPRUP,LPRUP
      double precision EBMUP,XSECUP,XERRUP,XMAXUP
      COMMON/HEPRUP/IDBMUP(2),EBMUP(2),PDFGUP(2),PDFSUP(2),
     &IDWTUP,NPRUP,XSECUP(MAXPUP),XERRUP(MAXPUP),XMAXUP(MAXPUP),
     &LPRUP(MAXPUP)
      integer         MSTP,               MSTI 
      double precision          PARP,               PARI      
      COMMON /PYPARS/ MSTP(200),PARP(200),MSTI(200),PARI(200)
*
      If(txsel.eq.-1) return ! PYTHIA process 
      If(txsel.ge.1) then 
         do i = 1,maxpro
          txpro(i) = 0
         enddo 
       if(txsel.eq.1) then
        txpro(1) = 1
        txpro(2) = 1
       elseif(txsel.eq.2) then
        txpro(30) = 1
        txpro(31) = 1
        txpro(32) = 1
        txpro(33) = 1
       else
        print*,' TXSEL value ',txsel,' is not implemented. Stop'
        stop 
       endif
      Else ! txsel <= 0
       txmup = 0
       do I = 1, maxpro
        if(txpro(I).eq.1) txmup = txmup + 1
       enddo
        if(txmup.eq.0) then
        print*,' no TopReX process is switched-ON. Stop'
        stop 
        endif
       if(txpro(1).eq.1.and.txpro(2).eq.1) then
         if(txmup.ge.3) then
          print*,' No other process can be generated with '
         print*,' Single top (2->2) and (2->3) production. Stop'
         stop 
        endif
        txsel = 1
        TXpro(1) = 1
        TXpro(2) = 1
       endif  
      if( txpro(30).eq.1.and.txpro(31).eq.1.
     &and.txpro(32).eq.1.and.txpro(33).eq.1) then
         if(txmup.ge.5) then
          print*,' No other process can be generated with '
         print*,' FCNC (t-gluon-q) single top production. Stop'
         stop 
        endif
        txsel = 2
      endif 
      EndIf

****
       txmup = 0
       do I = 1, maxpro
        if(txpro(I).eq.1) then
         txmup = txmup + 1
         ipar(1) = I
         call TX_NAM(0) 
         nprup = txmup
         lprup(txmup) = ipar(1)
         txext(I) = txmup
        endif
       enddo
****
       if(txmup.eq.0) then
        print*,' no TopReX process is switched-ON. Stop'
        stop 
       endif
        if(txsel.ge.1) mstp(143) = 1
*
      return
      end
c----------------------------------------------------------------------------c
      subroutine spin_check
      implicit none
      include "txpar.inc"
      include "txpro.inc" 
      integer spinum
      common /maxspinum/ spinum

      if(ipar(33).ge.2) then 
       print*,' spin state IPAR(33) = ',ipar(33)
       print*,' can affect on t -> b W channel only'
      endif

      if(ipar(33).gt.spinum) then
        print*,' spin state IPAR(33) = ',ipar(33)
        print*,' is not allowed. Only 0 1 ... ',spinum,
     &' can be used. Stop'
        stop 
       endif

      If(ipar(33).eq.0.or.ipar(33).eq.1) then 
        return
      ElseIf(ipar(33).eq.2.or.ipar(33).eq.3) then
        if(txpro(20).eq.1) then
          print*,' spin states IPAR(33) = ',ipar(33)
          print*,' can NOT be used with t tbar production. Stop'
          stop 
        endif
      ElseIf(ipar(33).ge.4.AND.ipar(33).le.7) then 
        if(txpro(20).ne.1) then
          print*,' spin states IPAR(33) = ',ipar(33)
          print*,' can be used with t tbar production only. Stop'
          stop 
        endif
       EndIf 
      return 
      end
c----------------------------------------------------------------------------c
      subroutine TX_NAM(mode) 
      implicit none
      include "txpar.inc"
      include "txpro.inc" 
      character*12  FRAME, BEAM, TARGET
      common /TXFBT/FRAME, BEAM, TARGET
      character *40 np(0:200)     ! process's name 
      character *40 procnum            ! process's name 
      character *40 mtop(0:1)         ! t-mass generation
      integer spinum
      common /maxspinum/ spinum
      data spinum /7/
      save /maxspinum/
      character *40 spin(0:7)         ! spin correlations
      character *40 boxhig(0:2)         ! spin correlations
      character*20 whr0 
      data whr0 /'   TopReX process  '/ 
      integer ITZ, mode
      logical first
      data first /.TRUE./
      save first
*
*             123456789012345678901234567890
*             12345678901234567890123456789|1234567890
****
      if(first) THEN
      first=.FALSE.
      np(1) =' EW top : W g (2->2)                    '  ! Ipar(1) =  1
      np(2) =' EW top : W g (2->3)                    '  ! Ipar(1) =  2
      np(3) =' EW top : t W                           '  ! Ipar(1) =  3
      np(4) =' EW top : W* -> t b~                    '  ! Ipar(1) =  4
      np(5) =' W Q Qbar                               '  ! Ipar(1) =  5
      np(6) =' W+-  -> tau nu                         '  ! Ipar(1) =  6
      np(7) =' W+- (-> tau nu)  JET                   '  ! Ipar(1) =  7
      np(8) =' H+-  -> t  bbar                        '  ! Ipar(1) =  8
      np(9) =' H+-  -> tau nu                         '  ! Ipar(1) =  9
      np(10)=' H+- (-> tau nu)  JET                   '  ! Ipar(1) = 10
      np(11)=' EW top : W g (2-> 2 + 3)               '  ! Ipar(1) = 11
      np(20)=' gg+qq~ -> tt~ Breit-Wig                '  ! Ipar(1) = 20
      np(21)=' gg     -> tt~ Breit-Wig                '  ! Ipar(1) = 21
      np(22)=' qq~    -> tt~ Breit-Wig                '  ! Ipar(1) = 22
      np(23)=' Z Q Qbar                               '  ! Ipar(1) = 23
      np(24)=' g g -> Z Z    with   Z -> f fbar       '  ! Ipar(1) = 24
      np(25)=' gg+qq~ -> t t~ gamma                   '  ! Ipar(1) = 25

      np(30)=' FCNC   g u(c) -> t -> b W              '  ! Ipar(1) = 30
      np(31)=' FCNC:  q q~ -> t u(c)~                 '  ! Ipar(1) = 31
      np(32)=' FCNC:  g g  -> t u(c)~                 '  ! Ipar(1) = 32
      np(33)=' FCNC:  g u/c  -> t g                   '  ! Ipar(1) = 33
      np(34)=' FCNC:  g u/c  -> t gamma (FCNC-GLUON   '  ! Ipar(1) = 34
*
      np(61)=' qq~    -> H+ H-                        '  ! Ipar(1) = 61
*
      np(99)=' for testing and development            '  ! Ipar(1) = 52
*      
        mtop(0)=' m(top) - fixed                         '  ! Ipar(31) = 0
        mtop(1)=' m(top) - Breit_Wigner(Gamma_tot)       '  ! Ipar(31) = 1

       call spin_check
        spin(0)=' NO spin correlations                   '  ! ipar(33) = 0
        spin(1)=' spin correlations is included          '  ! ipar(33) = 1
        spin(2)=' spin LEFT-state                        '  ! ipar(33) = 2
        spin(3)=' spin RIGHT-state                       '  ! ipar(33) = 3
        spin(4)=' T Tbar :  Left  Left                   '  ! ipar(33) = 4
        spin(5)=' T Tbar :  Left  Right                  '  ! ipar(33) = 5
        spin(6)=' T Tbar :  Right Left                   '  ! ipar(33) = 6
        spin(7)=' T Tbar :  Right Right                  '  ! ipar(33) = 7


      boxhig(0)=' BOX only                               '  ! Ipar(24) = 0
      boxhig(1)=' BOX and Higgs                          '  ! Ipar(24) = 1
      boxhig(2)=' Higgs only                             '  ! Ipar(24) = 2
*
*
       write(*,888) 
 888  format(//,3x,76('*'),//,
     &4x,'TopReX start to generate',/,
     &4x,'------------------------',/)
       if(ipar(1).eq.20.and.txpro(20).eq.1) then
          procnum = np(20)
          if(ipar(22).eq.1) procnum = np(21)
          if(ipar(22).eq.2) procnum = np(22)
      else 
         procnum = np(ipar(1))
       endif
       write(*,889) beam,target,Rpar(1)
 889  format(4x,a6,1x,a6,' collision  with Ecm = ',f8.1,' GeV',/)
*
      ENDIF
      if(mode.eq.0.and.txsel.eq.1.and.ipar(1).eq.2) return

      if( txpro(1) .eq.1.or.txpro(2). eq.1.
     & or.txpro(3) .eq.1.or.txpro(4) .eq.1.
     & or.txpro(5) .eq.1.or.txpro(6). eq.1.
     & or.txpro(7) .eq.1.or.txpro(8). eq.1.
     & or.txpro(9) .eq.1.or.txpro(10).eq.1.
     & or.txpro(20).eq.1.or.txpro(25).eq.1.
     & or.txpro(23).eq.1.or.txpro(24).eq.1.
     & or.txpro(30).eq.1.or.txpro(31).eq.1.
     & or.txpro(32).eq.1.or.txpro(33).eq.1.
     & or.txpro(34).eq.1.or.txpro(61).eq.1.
     & or.txpro(99).eq.1)  then
       continue 
      else
       write(*,890) Ipar(1)  
 890   format(//,3x,76('*'),////,
     &4x,'non-existed TopReX process <',i4,' >  STOP running')
       STOP
      endif

       if(ipar(1).eq.20.and.txpro(20).eq.1) then
          procnum = np(20)
          if(ipar(22).eq.1) procnum = np(21)
          if(ipar(22).eq.2) procnum = np(22)
      else 
         procnum = np(ipar(1))
      endif
*
      if(ipar(1).eq.5) then 
        if(ipar(7).eq.5) then
          procnum = ' W  B Bbar                   '  ! Ipar(1) = 5
        elseif(ipar(7).eq.4) then
         procnum = ' W  C Cbar                    '  ! Ipar(1) =  5
        endif
      endif
      if(ipar(1).eq.23) then 
        if(ipar(7).eq.5) then
         procnum = ' Z  B Bbar                              '! Ipar(1) = 5
        elseif(ipar(7).eq.4) then
         procnum = ' Z  C Cbar                              '! Ipar(1) = 5
        endif
      endif

      if(mode.eq.0.and.txsel.eq.1) procnum = np(11)
 2000 continue
        ITZ = 0
      if(Ipar(1).eq.1. or.Ipar(1).eq.2. or.Ipar(1).eq.3.
     .or.Ipar(1).eq.4. or.Ipar(1).eq.11.or.Ipar(1).eq.20.
     .or.Ipar(1).eq.25.
     .or.Ipar(1).eq.8) then
        ITZ = 1
      elseif(Ipar(1).eq.24) then
        ITZ = 2
      endif
      If(ITZ.eq.1) then
       if(mode.eq.0.and.txsel.eq.1) then
        write(*,989) whr0, procnum,mtop(Ipar(31)),
     & spin(ipar(33)) 
 989   format(1x,a20,1x,3x,1x,':',a40,/,3x,a40,/,3x,a40,/)
       else
        write(*,991) whr0,Ipar(1),procnum,mtop(Ipar(31)),
     & spin(ipar(33)) 
 991   format(1x,a20,1x,i3,1x,':',a40,/,3x,a40,/,3x,a40,/)
       endif


      ElseIf(ITZ.eq.2) then
       write(*,992) whr0,Ipar(1),procnum,
     &  boxhig(Ipar(24)), spin(ipar(33))
 992  format(1x,a20,1x,i3,1x,':',a40,/,3x,a40,/,3x,a40,/)
      Else
       write(*,998) whr0,Ipar(1),procnum
      EndIf
 998  format(1x,a20,1x,i3,1x,':',a40,/)
* 
      If(Ipar(1).eq.25) then
       if(ipar(22).eq.0)     then
          write(*,923) 
       elseif(ipar(22).eq.1) then 
          write(*,924) 
       elseif(ipar(22).eq.2) then 
          write(*,925) 
       else
          write(*,*) 'wrong Ipar(22) = ',Ipar(22),'stop'
          STOP
       endif
       EndIf




      If(Ipar(1).eq.23) then
       if(ipar(22).eq.0)     then
          write(*,920) 
       elseif(ipar(22).eq.1) then 
          write(*,921) 
       elseif(ipar(22).eq.2) then 
          write(*,922) 
       else
          write(*,*) 'wrong Ipar(22) = ',Ipar(22),'stop'
          STOP
       endif

       if(ipar(23).eq.0)     then
          write(*,930) 
       elseif(ipar(23).eq.1) then 
          write(*,931) 
       elseif(ipar(23).eq.2) then 
          write(*,932) 
       else
          write(*,*) 'wrong Ipar(23) = ',ipar(23),'stop'
          STOP
       endif
      Endif

 920   format('   gluon gluon  + q qbar -> Z Q Qbar')
 921   format('   gluon gluon  -> Z Q Qbar')
 922   format('   q qbar -> Z Q Qbar')
 930   format('   Z Q Qbar:  gamma* + Z* -> f fbar')
 931   format('   Z Q Qbar:  gamma* -> f fbar')
 932   format('   Z Q Qbar:  Z* -> f fbar')
 923   format('   gluon gluon  + q qbar -> t tbar gamma ')
 924   format('   gluon gluon  -> t tbar gamma ')
 925   format('   q qbar -> t tbar gamma ')
      return
      end
*----------------------------------------------------------------------------*
*...author :    Serge Slabospitsky  01.03.2004                               *
*                                                                            *
      subroutine TX_GEJZER(NUPS)  
*     ------------------------                                               *
*............................................................................*
      implicit none
      include "txpar.inc" 
      integer    NUPS 
      double precision sigrx,xcs(-6:6,-6:6)
      common/xsecs/sigrx, xcs
      double precision sigpb,xcspb(-6:6,-6:6)
      common/xsecpb/sigpb, xcspb
      save  /xsecpb/
      integer i1,i2
**************
          if    (Ipar(1).eq.1) then
             call gejzer_01(NUPS) !  W-gluon process : 2 -> 2
          elseif(Ipar(1).eq.2) then
             call gejzer_02(nups) !  W-gluon process : 2 -> 3
          elseif(Ipar(1).eq.3) then
            call gejzer_03(nups) !  t W process 
          elseif(Ipar(1).eq.4) then
            call gejzer_04(nups) !  W* -> t bbar process
          elseif(Ipar(1).eq.20)  then 
            call gejzer_20(nups) !  gg (q q~) -> t t~ 
          elseif(Ipar(1).eq.5)  then
            call gejzer_05(nups) !  WQQ~  process
          elseif(Ipar(1).eq.23) then
            call gejzer_23(nups)   ! Z Q Qbar
          elseif(Ipar(1).eq.24) then
            call gejzer_24(nups)   ! gg -> ZZ
          elseif(Ipar(1).eq.25) then
            call gejzer_25(nups)   ! qq -> t tbar gamma
           elseif(Ipar(1).eq.6) then
            call gejzer_06(nups) !  W+  -> tau nu 
          elseif(Ipar(1).eq.7) then
            call gejzer_07(nups) !  JET + W+- ( -> tau nu) 
          elseif(Ipar(1).eq.8) then
            call gejzer_04(nups) !  H* -> t bbar process
          elseif(Ipar(1).eq.9) then
            call gejzer_06(nups) !  H+ -> tau nu 
          elseif(Ipar(1).eq.10) then
           call gejzer_07(nups) !  JET + H+- ( -> tau nu) 
* FCNC + SM
          elseif(Ipar(1).eq.29) then
           call gejzer_29(nups) !   FCNC top production: 2 -> 1
* FCNC process
          elseif(Ipar(1).eq.30) then
            call gejzer_30(nups) !   FCNC top production: 2 -> 1
          elseif(Ipar(1).eq.31) then
            call gejzer_31(nups) !   FCNC top production: q q -> t q
          elseif(Ipar(1).eq.32) then
            call gejzer_32(nups) !   FCNC top production: g g -> t qbar
          elseif(Ipar(1).eq.33) then
            call gejzer_33(nups) !   FCNC top production: g g -> t qbar
          elseif(Ipar(1).eq.34) then
            call gejzer_34(nups) !   FCNC top production: g g -> t qbar
          elseif(Ipar(1).eq.61) then
            call gejzer_61(nups)   ! qq~ -->  H+ H-  
*** for testing only
          elseif(Ipar(1).eq.99) then
            call gejzer_test(nups)   !test 
      else
         write(*,4114) Ipar(1)
 4114    format(3x,'TopReX : UPEVNT',/,
     &          3x,'---------------',/,
     &          3x,'UPEVNT  wrong No for TopReX ',i10,/
     &          3x,'stop TopReX run')
         STOP
      endif
      sigpb = 0.d0
       do i1  = -5,5
        do i2 = -5,5
           xcspb(i1,i2) = xcs(i1,i2) * rpar(18)
           sigpb = sigpb + xcspb(i1,i2)
        enddo
       enddo
       Rpar(65) = sigpb
       Ipar(41) = nups
      return
      end

*----------------------------------------------------------------------------*
*...Author :    Serge Slabospitsky  03/06/2002                               *
*                                                                            *
      subroutine TX_REP(mode)       
      implicit none
      double precision sigrx,xcs(-6:6,-6:6)
      common/xsecs/sigrx, xcs
      double precision xsum(-6:6,-6:6)
      include "txpar.inc" 
      integer mode, J, JJ
      double precision sigP, sigM

      if(mode.eq.-1)   then
          do  J = -6, 6
            do JJ = -6, 6
              xsum(j, jj) = 0.d0
            enddo
          enddo
      elseif(mode.eq.0) then
          do  J = -6, 6
            do JJ = -6, 6
              xsum(j, jj) = xsum(j, jj) + xcs(j, jj)  
            enddo
          enddo

      elseif(mode.eq.1) then
        do  J = -5, 5
          do JJ = -5, 5
            xsum(j, jj) = xsum(j, jj) / ipar(51) 
          enddo
        enddo
       sigP = xsum( 2,-1) + xsum( 2, 5) + xsum( 2,-3) 
     &      + xsum(-1, 2) + xsum( 5, 2) + xsum(-3, 2)
     &      + xsum( 4,-1) + xsum( 4,-3) 
     &      + xsum(-1, 4) + xsum(-3, 4)
       sigM = xsum(-2, 1) + xsum( 1,-5) + xsum(-2, 3)
     &      + xsum( 1,-2) + xsum(-5, 1) + xsum( 3,-2)
     &      + xsum(-4, 1) + xsum(-4, 3) 
     &      + xsum( 1,-4) + xsum( 3,-4)
*       print*,' sig+ sig- ',sigP, sigM
        if(ipar(10).eq.1) then
          write(*, 2371) (jj,jj=-5,0)
 2371     format(3x,7x,6(i4,7x))
          do J = -5,5
            write(*,2372) J, (xsum(J,jj),jj=-5,0)
 2372       format(1p,4x,i4,2x,6(d10.3,1x))
          enddo
          write(*, 2373) (jj,jj=1,5)
 2373     format(3x,7x,5(i4,7x))
          do J = -5,5
            write(*,2372) J, (xsum(J,jj),jj=1,5)
 2374       format(1p,4x,i4,2x,5(d10.3,1x))
          enddo
        endif
      ENDIF
      return
      end
*----------------------------------------------------------------------------*
*...Author :    Serge Slabospitsky  08.03.2005                               *
*  final report on parameters                                                *
      subroutine TXFINREP
      implicit none
      include "txpar.inc" 
      include "txpro.inc" 
      integer I
*
      if(ipar(1).le.0) return
      write(*,99) 
 99   format(/,'    final TopReX report ')
      if(txsel.eq.1) write(*,111) Rpar(81),rpar(82)
 111  format(/,'  T-channel 2->2 + 2->3: PTmin(q) = ',f10.3,
     &'  PTmin(Bbar) = ',f10.3)
      if(ipar(1).eq.24.or.txpro(24).eq.1) write(*,124) Rpar(67) 
 124  format(/,'  gg -> ZZ:  PTmin(Z) = ',f6.1,' GeV')
*
      do I = 1, maxpro
       if(txpro(I).eq.1) then
        write(*,100) I, Rxsig(I,2)
       endif
      enddo
 100  format('  TopReX proc. ',i3,' X-sec(tot) = ',1p,d11.4,' pb')
       if(txmup.eq.0) write(*,100) Ipar(1), Rxsig(Ipar(1),2)
      return
      end
*----------------------------------------------------------------------------*
*...Author :    Serge Slabospitsky                                           *
*                                                                            *
      Subroutine TX_TIT       
*     ---------------------                                                  *
*...print TopReX title                                                       *
*............................................................................*
      Implicit none
      character*1    NVER
      data NVER/'4'/
      character*2    NSUBV
      data NSUBV/'23'/                  ! date  10.12.2006
*
 8009 format(3x,76('*')) 
 8010 format(3x,76('*'),/,3x,76('*'))
 6022 format(3x,2('*'),4x,(' TTTTTTTT    OOOOOOO   PPPPPPPP '),2x,
     &('RRRRRRRR   EEEEEEEEE  XX     XX   '),2('*'))
 6023 format(3x,2('*'),4x,('    TT      OO     OO  PP     PP'),2x,
     &('RR     RR  EE          XX   XX    '),2('*'))
 6024 format(3x,2('*'),4x,('    TT      OO     OO  PP     PP'),2x,
     &('RR     RR  EE           XX XX     '),2('*'))
 6025 format(3x,2('*'),4x,('    TT      OO     OO  PPPPPPPP '),2x,
     &('RRRRRRRR   EEEEE         XXX      '),2('*'))
 6026 format(3x,2('*'),4x,('    TT      OO     OO  PP       '),2x,
     &('RR  RR     EE           XX XX     '),2('*'))
 6027 format(3x,2('*'),4x,('    TT      OO     OO  PP       '),2x,
     &('RR   RR    EE          XX   XX    '),2('*'))
 6028 format(3x,2('*'),4x,('    TT       OOOOOOO   PP       '),2x,
     &('RR    RR   EEEEEEEEE  XX     XX   '),2('*'))

      write(*, 8010)
 8011 format(3x,2('*'),72(' '),2('*'))
      write(*, 8011)

      write(*, 6022)
      write(*, 6023)
      write(*, 6024)
      write(*, 6025)
      write(*, 6026)
      write(*, 6027)
      write(*, 6028)
      write(*, 8011)
      write(*, 8009)
 8012 format(3x,1('*'),74(' '),1('*'))
 8013 format(3X,'*',21x,'V E R S I O N',3x,a1,'.',a2,33x,'*')
*     &3x,'*',26X,21('.'),27x,'*')
 8014 format(3X,'*',21x,'Event generator ',37x,'*')
 8015 FORMAT(3x,
     &'*',2X,'Author :',11x,'Sergey Slabospitsky',34x,'*')
*    &'*',2X,'with colaboration Slabospitsky',
*    &'  and  Lars Sonnenschein',18x,'*')
 7013 format(3x,1('*'),74(' '),1('*'))
 7014 format(3x,'*',20x,'PYTHIA internal process',31x,'*')

 8041 format(3x,'*',20x,'T O P R E X    process  ',30x,'*')
*.......  contributors
* 9081 FORMAT(3x,'*',1X,  ' Contributed code:    ',T79,'*') 
* 9082 FORMAT(3x,'*',1X,  
*     &          ' # Lars Sonnenschein     -->   ',T79,'*',/,
*     & 3x,'*',10X,' W decays and parton shower treatment ', T79,'*') 
* 9083 FORMAT(3x,'*',1X,  
*     &          ' # M. Foursa and D.Murashev -->',T79,'*',/,
*     & 3x,'*',10x,' charged Higgs contribution into tb    ', T79,'*') 
* 9084 FORMAT(3x,'*',1X,  
*     &          ' # F.del Aguila and J.A.Aguilar-Saavedra -->',T79,'*',/,
*     & 3x,'*',10X,' top production via FCNC               ', T79,'*') 

      write(*, 8012)
      write(*, 8013) Nver, Nsubv
      write(*, 8012)
      write(*, 8014)
      write(*, 8012)
      write(*, 8015)
*      write(*, 8012)
*      write(*, 9081)
*      write(*, 9082)
*      write(*, 9083)
*      write(*, 9084)
      write(*, 7013)
      write(*, 7013)
      write(*, 8009)
 9999 format(a80)
      return
      end
*----------------------------------------------------------------------------*
* routines GEJZER_... evaluate matrix elements squared, momenta of           *
* initial and final final particles and corresponding LIPS                   *
*............................................................................*
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  26.01.2001                                  *
*     Wg process : 2 -> 2                                                    *
*     TopReX code = 1                                                        *
*............................................................................*

      subroutine gejzer_01(NFP)
      implicit None
      include "txpar.inc" 
      include "txpro.inc" 

      integer NFP   ! number of particles in hard process 
      double precision Pus        ! 4-momenta of user's particles
      common /user_mom/ Pus(20,5)

      double precision Ves, qf(5), p1(5), q1(5), q2(5), qq(5) 
      double precision qff(5), pp1(5), qq1(5), qq2(5)

      double precision            sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)

      integer I, J, Bqdir, j1,j2
      double precision  x1, x2, sg, sgs
      double precision  pdfBT(-5:5, -5:5)
      double precision  Veslum, vesQB, vesBQ, ParL(3) ! , TopMV
* 
      logical first
      data first /.TRUE./
      save first
      double precision qpr(5), bpr(5), PYR 
      double precision fqwq
      common /sng1fc/ fqwq(4)   !  is factor for weight  
      integer imatch
      common /wmtch/imatch 
      integer         MSTP,               MSTI 
      double precision          PARP,               PARI      
      COMMON /PYPARS/ MSTP(200),PARP(200),MSTI(200),PARI(200)
*..............

      if(first) THEN
       If( Ipar(1).eq.1.or.txpro(1).eq.1)  then 
* EW top-quark production : t-channel (2->2),   Ipar(1) = 1
* EW top-quark production : s-channel,          Ipar(1) = 4
* EW top-quark production : t-channel (2->2+3), Ipar(1) = 11
        ipar(21) = 1
        if(txsel.eq.1) mstp(143) = 1
       EndIf
       I = 1
       J = 1
       call qflqw(I, J)
      first=.FALSE.
      ENDIF

      imatch = 1
      sigrx=0.d0
        do j1 = -6,6
        do j2 = -6,6
         xcs(j1,j2) = 0.d0
        enddo
        enddo
*
        do j1 = 1,5
         q1(j1) = 0.d0
         q2(j1) = 0.d0
        enddo

      p1(5) = mq(6)
      PARL(1) = p1(5) + 1.d0 ! min sqrt(S_hat) 
      PARL(2) = Rpar(1)      ! max sqrt(S_hat) 
      PARL(3) = Rpar(1)      ! sqrt(S) 

 199  call X1X2GEN(ParL, X1, X2, Veslum, qq1, qq2, QQ)
      
      if(qq1(4).lt.mq(5).or.qq2(4).lt.mq(5)) goto 199 
       if(PYR(0).le.0.5) then
        Bqdir = -1            !     Q B
       else
        Bqdir = +1            !     B Q
       endif
      call kinsng1(QQ, q1, q2, Bqdir)
      sg  = QQ(5)**2
      sgs = QQ(5)
      if(sgs.lt.Parl(1)) return
* new top mass generation
      qf(5) = mq(2)
      call LIPS2 (QQ,  P1, qf, Ves)

* setting Q-scale for PDF( Rpar(3)) and for alpha_s 
      call TXQscale     
      call pdf_BT(x1, x2, pdfBT) 

       veslum = 2.d0 * veslum * ves  * pi2_4 / (2.*sg)  ! 2 due to QB choice
*
      do j = 1,4
       qpr(j) = -qf(j)
      enddo
       qpr(5) =  qf(5)
      if(Bqdir.eq.-1) then     ! Q B
       do j = 1,4
        bpr(j) = -q2(j)
       enddo
        bpr(5) =  q2(5)
        call sng_01(q1, qpr, p1, bpr, vesQB)
        VesBQ = 0.d0
      else                     ! B Q
       do j = 1,4
        bpr(j) = -q1(j)
       enddo
        bpr(5) =  q1(5)
        call sng_01(q2, qpr, p1, bpr, vesBQ)
        VesQB = 0.d0
      endif

      VesQB = VesQB * Veslum 
      VesBQ = VesBQ * Veslum 

*  top production
      do I = 1,4
       J = I
       if(I.eq.1.or.I.eq.3) J = -I
       Xcs( J, 5) = VesQB * pdfBT( J, 5) * fqwq(I) * BRS(1,1)  ! T
       Xcs(-J,-5) = VesQB * pdfBT(-J,-5) * fqwq(I) * BRS(2,1)  ! Tbar 
       Xcs( 5, J) = VesBQ * pdfBT( 5, J) * fqwq(I) * BRS(1,1)  ! T 
       Xcs(-5,-J) = VesBQ * pdfBT(-5,-J) * fqwq(I) * BRS(2,1)  ! Tbar
      enddo

      sigrx=0.d0
      do i=-5,5
        do j=-5,5
          sigrx = sigrx + xcs(i,j)
        enddo
      enddo

* fill momenta array 
       nfp = 4
        call TXTQ1SMR(QQ, p1, qf, pp1, qff)
       do i = 1, 5
        pus(1,i) = qq1(i)
        pus(2,i) = qq2(i)
        pus(3,i) = pp1(i) ! final top 
        pus(4,i) = qff(i)
       enddo
      return
      end
c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky  24.12.2003                                  *
*     Wg process : 2 -> 2                                                    *
*     TopReX code = 1                                                        *
*............................................................................*

      subroutine kinsng1(Q, q1, q2, Bqdir) 
      implicit None
      double precision Q(5), q1(5), q2(5), gam, bet, kv
      integer bqdir, I 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
*
      gam = q(4) / q(5)
      bet = q(3) / q(4)
      kv = (q(5)**2 - mq2(5))/ 2.d0 / q(5)
      if(bqdir.eq.-1) then
       q1(1) = 0.d0
       q1(2) = 0.d0     
       q1(5) = 0.d0 
       q1(4) = gam*(1.d0+bet)*kv
       q1(3) = q1(4)
        q2(5) = mq(5)
        do I = 1,4
         q2(I) = Q(I) - q1(I)
        enddo
      elseif(bqdir.eq.1) then
       q2(1) = 0.d0
       q2(2) = 0.d0     
       q2(5) = 0.d0 
       q2(4) = gam*(1.d0 - bet)*kv
       q2(3) = -q2(4)
        q1(5) = mq(5)
        do I = 1,4
         q1(I) = Q(I) - q2(I)
        enddo
      endif
      RETURN 
      end     
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  09/01/2001                                  *
* Single top: t-channel : 2 -> 3                                             *
*   TopReX code = 2                                                          *
      subroutine gejzer_02(NFP)
*     --------------------                                                   *
*............................................................................*
      implicit None
      include "txpar.inc" 
      include "txpro.inc" 
      Integer NFP          ! number of particles in hard process 
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision  p1(5),  pq(5),  pb(5) 
      double precision  pp1(5), pq1(5), pb1(5) 
      double precision  q1(5), q2(5), qq(5)
      double precision            sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      Integer I, J, j1,j2
      double precision mq, mq2
      common /massql/  mq(0:20), mq2(0:20)
      double precision  x1, x2, sg, sgs
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision fqwq
      common  /sng1fc/ fqwq(4)   !  is factor for weigh  
      double precision  pdfBT(-5:5, -5:5)
      double precision  Veslum, VesGU, vesUG
      integer ich                        ! mark for W-boson exchange
      save ich
      double precision ParL(3) ! , TopMV
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
      double precision wgSUM(-5:5)
      save wgSUM 
      integer         MSTP,               MSTI 
      double precision          PARP,               PARI      
      COMMON /PYPARS/ MSTP(200),PARP(200),MSTI(200),PARI(200)
*.......
      double precision p0, ps(5), wtR, ves2, pyr, pt
      integer imatch
      common /wmtch/imatch 
*
      IF(first) THEN
       if(txsel.eq.1) mstp(143) = 1
*       if(txpro(1).eq.1.and.txpro(2).eq.1) mstp(143) = 1
       ich = +1          ! W-boson exchaneg in T-channel
      I = 1
      J = 1
      Call qflqw(I, J)
        wgSUM(2) = BRS(1,1) 
        wgsum(4) = wgSUM(2)
        wgSUM(1) = BRS(2,1) 
        wgsum(3) = wgSUM(1)
        wgsum(-1) = wgSUM(2)
        wgsum(-2) = wgSUM(1)
        wgsum(-3) = wgSUM(2)
        wgsum(-4) = wgSUM(1)
* 
*  special cuts for Ipar(1) = 11. 
*  Rpar(81) = minPT for light quark,     LHC: Rpar(81) = Rpar(68) = 20 GeV
*  Rpar(82) = minPT for additional Bbar, LHC: Rpar(82) = Rpar(69) = 10 GeV
*            Rpar(81) = Rpar(68) ! PTmin for q
*            Rpar(82) = Rpar(69) ! PTmin for bbar
*        EndIf 
        If(txsel.eq.1)  then
            Rpar(81) = Rpar(68) ! PTmin for q
            Rpar(82) = Rpar(69) ! PTmin for bbar
        EndIf 
       first=.FALSE.
      ENDIF

      sigrx=0.d0
      imatch = 2
        do j1 = -6,6
        do j2 = -6,6
         xcs(j1,j2) = 0.d0
        enddo
        enddo
*
        do j1 = 1,5
         q1(j1) = 0.d0
         q2(j1) = 0.d0
        enddo
* evaluate of the top on-shell mass
*      p1(5) = TopMV(Rpar(34), mq(6))
       p1(5) = mq(6)
       Parl(1) = p1(5) + mq(5) 
       ParL(2) = Rpar(1)
       ParL(3) = Rpar(1)
 919  call X1X2GEN( ParL, X1, X2, Veslum, q1, q2, QQ)

      call Mass2(q1, q2, sg, sgs)

      pq(5) = 0.d0
      pb(5) = mq(5)
      if(pyr(0).ge.0.5) then
       p0 = p1(5) 
       call LIPS_QG(QQ, pb, ps, p0, wtR) 
       call LIPS2(PS, pq, p1, ves2)
       call TXQscale     
       call sng_02(ich, q1, q2,  pq, p1, pb, vesGU)
       vesGU = VesGU * wtR * ves2 * Veslum * pi2_4 / (2.d0*sg)
       vesGU = 2.d0 * vesGU    ! due to two variants
       vesUG = 0.d0
      else
       p0 = -p1(5) 
       call LIPS_QG(QQ, pb, ps, p0, wtR)
       call LIPS2(PS, pq, p1, ves2)
       call TXQscale     
       call sng_02(ich, q2, q1,  pq, p1, pb, vesUG)
       vesUG = VesUG * wtR * ves2 * Veslum * pi2_4 / (2.d0*sg)
       vesUG = 2.d0 * vesUG    ! due to two variants
       vesGU = 0.d0
      endif
* fill momenta matrix  for PYTHIA treatment (HEPEUP)
* additional cut on pt(qprime)

       if(pt(pq).lt.Rpar(81).or.pt(pb).lt.Rpar(82)) then
          NXev(2) = NXev(2) + 1
          goto 919  !PT of final q-quark 
       endif

      call pdf_BT(x1, x2, pdfbt) 

      do I = 1,4
       J = -I
       xcs(0, I) = VesGU * pdfBT( 0, I) * fqwq(I) * wgSUM(I) 
       xcs(0, J) = VesGU * pdfBT( 0, J) * fqwq(I) * wgSUM(J) 
       xcs(I, 0) = vesUG * pdfBT( I, 0) * fqwq(I) * wgSUM(I) 
       xcs(J, 0) = vesUG * pdfBT( J, 0) * fqwq(I) * wgSUM(J)
      enddo
       
       sigrx=0.d0
       do i=-5,5
        do j=-5,5
         sigrx=sigrx+xcs(i,j)
        enddo
       enddo
* fill momenta array
        call TXTQ2SMR(QQ, p1, pb, pq, pp1, pb1, pq1)
       NFP = 5
       do i = 1, 5
        pus(1,i) = q1(i)
        pus(2,i) = q2(i)
        pus(3,i) = pq1(i)       ! final light quark
        pus(4,i) = pB1(i)       ! bbar 
        pus(5,i) = pp1(i)       ! top
       enddo
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  27.01.2001                                  *
*     tW process                                                             *
*     TopReX code = 3                                                        *
*                                                                            *
      subroutine gejzer_03(NFP)
*     --------------------                                                   *
*............................................................................*
      implicit None
      include "txpar.inc" 
      include "txpro.inc" 
      Integer NFP         ! number of particles in hard process 
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision            sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)

      double precision PYR 
      double precision  p1(5), pw(5), q1(5), q2(5), qq(5), pp1(5)
      double precision  pq(5), pb(5), PN(5), PL(5), pn1(5), pl1(5) 
      Integer I, Bqdir, j1,j2
      double precision  x1, x2, sg, sgs, Veslum, Ves, vesGU, vesUG
      double precision  pdfbt(-5:5, -5:5)
      double precision  parw(4)           ! parameters for LIPS
      integer ich                         ! mark for W-boson exchange
      save ich
      double precision Parl(3) ! , TopMV
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
*     IT = 1 : top quark,  IT = 2 : W-boson, 
*     IT = 3 : H+- boson,  IT = 4 : Z-boson 
*.......
*
      if(first) THEN
      ich = -1              ! W-boson exchaneg in S-channel
      first=.FALSE.
      ENDIF
 
      sigrx=0.d0
        do j1 = -6,6
        do j2 = -6,6
         xcs(j1,j2) = 0.d0
        enddo
        enddo
*
        do j1 = 1,5
         q1(j1) = 0.d0
         q2(j1) = 0.d0
        enddo
* evaluate of the top on-shell mass
      p1(5) = mq(6)
       PARL(1) = p1(5) + rpar(70)  ! min sqrt(S_hat) 
       PARL(2) = Rpar(1)          ! max sqrt(S_hat) 
       PARL(3) = Rpar(1)          ! sqrt(S) 
      call X1X2GEN( ParL, X1, X2, Veslum, q1, q2, QQ)

      if(q1(4).lt.mq(5).or.q2(4).lt.mq(5)) return
       if(PYR(0).le.0.5) then
       Bqdir = -1            !     G B
       q2(3) = -dsqrt(q2(4)**2 - mq2(5))
       q2(5) =  mq(5)
      else
       Bqdir = +1            !     B G
       q1(3) =  dsqrt(q1(4)**2 - mq2(5))
       q1(5) =  mq(5)
      endif

      call Mass2(q1, q2, sg, sgs)
      if(sgs.lt.Parl(1)) return
*
       qq(5) = sgs
       qq(4) = q1(4) + q2(4)       
       qq(3) = q1(3) + q2(3)       
       qq(2) = q1(2) + q2(2)       
       qq(1) = q1(1) + q2(1)       

      call TXQscale    ! setting Q-scale for PDF( Rpar(3)) and for alpha_s
      call pdf_BT(x1, x2, pdfbt) 

*..Rpar(41): W-boson mass,  Rpar(42) = Rpar(41)**2 
*..Rpar(43): W-boson width, Rpar(44) = M(W) * Width(W)
       ParW(1) = Rpar(41)  ! mass of the first resonance 
       ParW(2) = Rpar(44)  ! Width(W) * M(W) 
       ParW(3) = rpar(70)  ! minimal invariant mass of the final W-boson
       ParW(4) = QQ(5)     ! maximal invariant mass of the final W-boson

      Call LIPS_RES_ONE(QQ, ParW, PW, P1, Ves)
      veslum = veslum * ves * 2.d0  ! 2 due to two choices of b direction
       PN(5) = 0.d0  ! nu  or U-quark
       PL(5) = 0.d0  ! L+- or D-quark
      call LIPS2 (PW, PN, PL, Ves)
      veslum = veslum * ves * pi2_4 / (2.*sg)
      
      if(Bqdir.eq.-1) then     ! G B
        pq(5) = PN(5)
        PB(5) = q2(5)
         do I = 1,4
          pq(I) = -PN(I)
          pb(I) = -q2(I)
         enddo
       Call sng_02(ich, q1, Pq,  PL, p1, PB, vesGU)
       VesUG = 0d0
      else                     ! B G
        pq(5) = PN(5)
        PB(5) = q1(5)
         do I = 1,4
          pq(I) = -PN(I)
          pb(I) = -q1(I)
         enddo
       Call sng_02(ich, q2, Pq,  PL, p1, PB, vesUG)
       VesGU = 0d0
      endif

      vesGU = VesGU * Veslum 
      vesUG = VesUG * veslum 
*                  top      W-boson
      xcs( 0, 5) = BRS(1,1)*BRS(2,2) * vesGU * pdfBT( 0, 5) ! G  B , T  W-  
      xcs( 0,-5) = BRS(2,1)*BRS(1,2) * vesGU * pdfBT( 0,-5) ! G  B~, T~ W+ 
      xcs( 5, 0) = BRS(1,1)*BRS(2,2) * vesUG * pdfBT( 5, 0) ! B  G , T  W-
      xcs(-5, 0) = BRS(2,1)*BRS(1,2) * vesUG * pdfBT(-5, 0) ! B~ G , T~ W+
 
      sigrx = Xcs( 0, 5) + Xcs(0,-5) + Xcs(5,0) + Xcs(-5,0)
* fill momenta matrix
       NFP = 6
        call TXTQ2SMR(QQ, p1, pn, pl, pp1, pn1, pl1)
       do i = 1, 5
        pus(1,i) = q1(i)
        pus(2,i) = q2(i)
        pus(3,i) = pp1(i)           ! top
        pus(4,i) = pn1(i) + PL1(i)   ! final (virtual) W from b-quark 
        pus(5,i) = PN1(i)           ! final f1 f2_bar
        pus(6,i) = PL1(i)           ! from second W
       enddo
      return
      end
*----------------------------------------------------------------------------*
*... Authors  : Serge Slabospitsky                                           *
*... 25.01.2001                                                              *
*    q q~' -> W+- ( + H+- )  -> t bbar                                       *
*----------------------------------------------------------------------------*
      subroutine gejzer_04(NFP)
      implicit None
      include "txpar.inc" 
      include "txpro.inc" 
      Integer NFP         ! number of particles in hard process 
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision ptop(5),pb(5),q1(5),q2(5),qq(5),ptop1(5),pb1(5) 
      double precision  Ves2, vesm, veslum
      double precision            sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      Integer I, II, J, j1,j2
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision  x1, x2, sgs
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision pdfbt(-5:5, -5:5)
      double precision CKM2
      common /CKMD/ CKM2(-6:6,-6:6)
      double precision PYR, shat, ParL(3), WR(2) 
      integer ncomb 
      parameter (ncomb = 12)
      double precision XEST(0:ncomb), aran
      save  XEST
*
      integer        ju, jd, jt,jb 
      common /isng01/ju, jd, jt,jb 
      integer IB(12), IT(12), IQ 
       data ib/ 2, 2, 2,   4, 4, 4,  -1, -3, -5,  -1, -3, -5/ 
       data it/-1,-3,-5, - 1,-3,-5,   2,  2,  2,   4,  4,  4/ 
      Save IB, IT
*
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
*.......
*..ipar(21)      : W-exchange: > 0 tb, <0 tau nu, 1 W, 2 H, 3 (W+H+Int) 
      IF(first) then
       If(    Ipar(1).eq.4.or.txpro(4).eq.1) then
         ipar(21) = -1                        !Ipar(1) = 4 :  W*  -> top bbar
       ElseIf(Ipar(1).eq.8.or.txpro(8).eq.1) then
         ipar(21) = +2                        ! Ipar(1) = 8 : H+- -> top bbar 
       EndIf
      ENDIF

      if(first) goto 103  
       goto 104
 103   continue
      II = 0
 102   II = II + 1
      if(ii.gt.ipar(52)) goto 111
       IQ = 0
 100   IQ = IQ + 1
       if(IQ.GT.ncomb) goto 102
 104  sigrx=0.d0
        do j1 = -6,6
        do j2 = -6,6
         xcs(j1,j2) = 0.d0
        enddo
        enddo
      
* 12 combinations are considered
* 1: u d,  2: u s,  3: u b,  4: c d,  5: c s,  6: c b 
* then two combinations correspond to beam(U) or target(U)

      if(.NOT.first) then  
 106  aran = PYR(0)
       if(aran.ge.xest(ncomb)) goto 106 
       do IQ = 1,ncomb
        if(aran.le.xest(IQ)) goto 105
       enddo 
 105   continue
         if(IQ.LT.0.OR.IQ.GT.ncomb) goto 106
      endif
*...
*  evaluate of the top on-shell mass
*      ptop(5) = TopMV(Rpar(34), mq(6))
      ptop(5) = mq(6)
       Parl(1) = ptop(5) + mq(5) 
       ParL(2) = Rpar(1)
       ParL(3) = Rpar(1)
        do j1 = 1,5
         q1(j1) = 0.d0
         q2(j1) = 0.d0
        enddo
 295  continue 
       q1(5) = mq(abs(IB(iq)))
       q2(5) = mq(abs(IT(iq)))

      if(abs(ipar(21)).eq.1)    then 
       WR(1) = Rpar(41)   ! W-boson mass
       WR(2) = Rpar(44)   ! M(W) * Width(W) 
        if(WR(1).lt.Parl(1).or.WR(1).gt.Parl(2)) then
         call X1X2GEN( ParL, X1, X2, Veslum, q1, q2, QQ)
        else
         call X1X2RES( ParL, WR, X1, X2, Veslum, q1, q2, QQ)
        endif
      elseif(abs(ipar(21)).eq.2) then 
       WR(1) = Rpar(51)   ! H-boson mass
       WR(2) = Rpar(54)   ! M(H) * Width(H) 
        if(WR(1).lt.Parl(1).or.WR(1).gt.Parl(2)) then
         call X1X2GEN( ParL, X1, X2, Veslum, q1, q2, QQ)
        else
         call X1X2RES( ParL, WR, X1, X2, Veslum, q1, q2, QQ)
        endif
      elseif(ipar(21).eq.3) then
       call X1X2GEN( ParL, X1, X2, Veslum, q1, q2, QQ)
      endif

      call mass2(q1, q2, shat, sgs)
      Rpar(74) = sgs
      Rpar(71) = shat 
      call TXQscale     ! setting Q-scale for PDF( Rpar(3)) and for alpha_s
      call pdf_BT(x1, x2, pdfbt)

      pb(5) = mq(5)
      call LIPS2 (QQ, Ptop, pb, Ves2)

      veslum = veslum * ves2 * pi2_4 / (2.*shat)
      JT = 6
      JB = 5 
       if(abs(IB(iq)).eq.2.or.abs(IB(iq)).eq.4) then
         JU = IB(iq)
         JD = IT(iq)
         Call sng_01(q1, q2, ptop, pb, vesm)
       else
         JU = IT(iq)
         JD = IB(iq)
         Call sng_01(q2, q1, ptop, pb, vesm)
       endif
      I = IB(iq)
      J = IT(iq)
      Xcs( I, J) = Veslum * vesm * pdfBT( I, J) * CKM2(i,j)
      Xcs(-I,-J) = Veslum * vesm * pdfBT(-I,-J) * CKM2(i,j)
       if(i.eq.2.or.i.eq.4.or.J.eq.2.or.J.eq.4) then
        Xcs( I, J) = BRS(1,1)  * Xcs(I,J)
        Xcs(-I,-J) = BRS(2,1)  * Xcs(-I,-J)
       else
        Xcs( I, J) = BRS(2,1) * Xcs(I,J)
        Xcs(-I,-J) = BRS(1,1) * Xcs(-I,-J)
       endif

      sigrx=0.d0
      do I=-5,5
        do J=-5,5
          if(.NOT.first) then 
           xcs(I,J) = xcs(I,J) / (xest(IQ) - xest(IQ-1))
          endif
          sigrx = sigrx + xcs(I,J)
        enddo
      enddo
*
      if(.NOT.first) goto 444
      xest(IQ) = xest(IQ) + sigrx
      goto 100
 111  continue
       
       xest(0) = 0.d0
       do IQ = 1,ncomb
        xest(IQ) = xest(IQ) / ipar(52)
        xest(0)  = xest(0) + xest(IQ)
       enddo
        xest(1) = xest(1) / xest(0) 
       do IQ = 2,ncomb
        xest(IQ) = xest(IQ) / xest(0) 
        xest(IQ) = xest(IQ) + xest(IQ-1) 
       enddo
       xest(0) = 0.d0
       sigrx = 0.d0
      first=.FALSE.
       return       
 444  continue
      NFP = 5
        call TXTQ1SMR(QQ, ptop, pb, ptop1, pb1) 
       do i = 1,5
        pus(1,i) = q1(i)
        pus(2,i) = q2(i)
        pus(3,i) = ptop1(i) + pb1(i)  ! virtual W or Higgs 
        pus(4,i) = ptop1(i)           ! final top 
        pus(5,i) = pb1(i)             ! final b
       enddo
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  25/12/2000                                  *
*     T Tbar production                                                      *
*     TopReX code = 20                                                       *
*............................................................................*
      subroutine gejzer_20(NFP) 
      Implicit None
      include "txpar.inc" 
      Integer NFP          ! number of particles in hard process 
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision p1(5),p2(5),pp1(5),pp2(5),q1(5),q2(5),qq(5)
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision x1, x2, sg, sgs
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst / pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision           sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      double precision vlum, vestt, vesq, vesg
      integer i, j, j1,j2, j3
      double precision pdfBT(-5:5, -5:5)
      double precision vhh(3,3), vtt
      common /topol2/ vtt(2,3,3)
*.......
      double precision Parl(3) !, TopMV
*..........................      

      sigrx=0.d0
        do j1 = -6,6
        do j2 = -6,6
         xcs(j1,j2) = 0.d0
        enddo
        enddo
*
        do j1 = 1,5
         q1(j1) = 0.d0
         q2(j1) = 0.d0
        enddo
*
       p1(5) = mq(6)
       p2(5) = mq(6)
       Parl(1) = p1(5) + p2(5) 
       Parl(2) = Rpar(1)
       Parl(3) = Rpar(1)
      call X1X2GEN( Parl, X1, X2, Vlum, q1, q2, QQ)
      
      call mass2(q1, q2, sg, sgs) 
      Call LIPS2(QQ, P1, P2, vestt)
      
      Rpar(76) = p1(1)**2 + p1(2)**2     ! pt(top)
      Rpar(75) = dsqrt(Rpar(76))   

      call TXQscale  ! setting Q-scale for PDF( Rpar(3)) and for alpha_s 
      call pdf_BT(x1, x2, pdfbt)

       do 123 j1 = 1,2
       do 123 j2 = 1,3
       do 123 j3 = 1,3
 123      vtt(j1,j2,j3) = 0.d0

      if(Ipar(22).eq.0.or.Ipar(22).eq.2) then  ! q qbar contribution
        Call QQTTBAR(q1, q2, p1, p2, Vhh, vesQ)
        do i = 1,3
         do j = 1,3
          vtt(2,i,j) = vhh(i,j)  ! qq-> t tbar
         enddo
        enddo
      else
        vesQ = 0.d0  ! ipar(1) = 21 : no qq~ contribution
      endif
*...
      if(Ipar(22).eq.0.or.Ipar(22).eq.1) then  ! gg contribution
       Call GGTTBAR(q1, q2, p1, p2, Vhh, vesG)
        do i = 1,3
         do j = 1,3
          vtt(1,i,j) = vhh(i,j) ! gluon
         enddo
        enddo
      else
        vesG = 0.d0  ! ipar(1) = 22 : no gg contribution
      endif
*.............
      vesQ = Vlum * Vestt * vesQ * pi2_4 / (2.* sg) ! QQ(5)**2
      vesG = Vlum * Vestt * vesG * pi2_4 / (2.* sg) ! QQ(5)**2 
       vesQ = vesQ * BRS(1,1) * BRS(2,1) 
       vesG = vesG * BRS(1,1) * BRS(2,1)

      xcs( 0, 0) = vesG * pdfBT( 0, 0)
      do I = 1,4
       J = -I
       xcs(I,J) = vesQ * pdfBT(I,J)
       xcs(J,I) = vesQ * pdfBT(J,I)
      enddo

      sigrx=0.d0
      do i = -6,6
        do j=-6,6
          sigrx = sigrx + xcs(i,j)
        enddo
      enddo
      NFP = 4

      call TXTTSMR(QQ, p1, p2, pp1, pp2)
        do i=1,5
          pus(1,i) = q1(i)
          pus(2,i) = q2(i)
          pus(3,i) = pp1(i)           ! top quark 
          pus(4,i) = pp2(i)           ! top_bar quark 
        enddo
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  26.01.2001                                  *
*     W Q Qbar production                                                    *
*     TopReX code = 5                                                        *
*............................................................................*
      subroutine gejzer_05(NFP)
      implicit None
      include "txpar.inc" 
      include "txpro.inc" 
      Integer NFP          ! number of particles in hard process 
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision CKM2
      common /CKMD/ CKM2(-6:6,-6:6)

      double precision b1(5), b2(5), Pl(5), Pn(5)
      double precision q1(5), q2(5), qq(5)
      double precision            sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      Integer L, I, j1,j2
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision  x1, x2, sg, sgs
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6

      double precision pdfbt(-5:5, -5:5)
      double precision Veslum, Ves3, VesUD, VesDU
      double precision Parl(3), masstwo   
      logical first 
      data first /.TRUE./
      save first
* 

      IF(first) THEN
       first = .false.
        print*,'                          '
        print*,'*************',' WQQ production'
        call MQQLIM   !  check M(QQ)_min/max
        print*,'*************',' WQQ production'
      ENDIF

        do j1 = -6,6
        do j2 = -6,6
         xcs(j1,j2) = 0.d0
        enddo
        enddo
*
        do j1 = 1,5
         q1(j1) = 0.d0
         q2(j1) = 0.d0
        enddo
*
       parL(1) = Rpar(41) + Rpar(77) 
       parL(2) = Rpar(1) 
       parL(3) = Rpar(1)
        NXev(ipar(1)) = NXev(ipar(1)) - 1
 1001  call X1X2GEN(ParL, X1, X2, Veslum, q1, q2, QQ)
       NXev(ipar(1)) = NXev(ipar(1)) + 1
       call Mass2(q1, q2, sg, sgs)
       b1(5) = mq(Ipar(7))
       b2(5) = mq(Ipar(7))
       call rlip43(qq, b1, b2, PL, Pn, ves3)
       if(masstwo(b1,b2).LT.rpar(77).OR.
     &    masstwo(b1,b2).GT.Rpar(78)) then
*         print*,' mass b1 b2 ',masstwo(b1,b2)
         goto 1001
       endif
      Rpar(76) = (PL(1)+PN(1))**2 + (PL(2)+PN(2))**2 ! PT(W)^2
      Rpar(75) = dsqrt(Rpar(76)) 

      call TXQscale  ! Q-scale for PDF( Rpar(3)) and for alpha_s 
      call pdf_BT(x1, x2, pdfbt)
      
      NFP = 7
       do i = 1,5
          pus(1,i)=q1(i)
          pus(2,i)=q2(i)
          pus(3,i)=PL(i) + PN(i)    ! final (virtula) W*
          pus(4,i)=PN(i)
          pus(5,i)=PL(i)
          pus(6,i)=b1(i)            ! B
          pus(7,i)=b2(i)            ! Bbar
       enddo

      call MwQQ(q1, q2, b1, b2, PL, Pn, vesud)
      call MwQQ(q2, q1, b1, b2, PL, Pn, vesdu)
      VesUd = Veslum * vesud * ves3 * pi2_4 / (2.* sg)
      VesDu = Veslum * vesdu * ves3 * pi2_4 / (2.* sg)
* W+
      xcs( 2,-1)=VesUd * CKM2(2,1) * pdfBT( 2,-1) 
      xcs( 2,-3)=VesUd * CKM2(2,3) * pdfBT( 2,-3)
      xcs( 4,-1)=VesUd * CKM2(4,1) * pdfBT( 4,-1)
      xcs( 4,-3)=VesUd * CKM2(4,3) * pdfBT( 4,-3)
      xcs(-1, 2)=VesDu * CKM2(1,2) * pdfBT(-1, 2)
      xcs(-3, 2)=VesDu * CKM2(3,2) * pdfBT(-3, 2)
      xcs(-1, 4)=VesDu * CKM2(1,4) * pdfBT(-1, 4)
      xcs(-3, 4)=VesDu * CKM2(3,4) * pdfBT(-3, 4)
* W-
      xcs(-2, 1)=VesUd * CKM2(2,1) * pdfBT(-2, 1)
      xcs(-2, 3)=VesUd * CKM2(2,3) * pdfBT(-2, 3)
      xcs(-4, 1)=VesUd * CKM2(4,1) * pdfBT(-4, 1)
      xcs(-4, 3)=VesUd * CKM2(4,3) * pdfBT(-4, 3)
      xcs( 1,-2)=VesDu * CKM2(1,2) * pdfBT( 1,-2)
      xcs( 3,-2)=VesDu * CKM2(3,2) * pdfBT( 3,-2)
      xcs( 1,-4)=VesDu * CKM2(1,4) * pdfBT( 1,-4)
      xcs( 3,-4)=VesDu * CKM2(3,4) * pdfBT( 3,-4)

* BRS(i,2),   I= 1 : single W+,   2 : single W- production  
      sigrx=0.d0
      do i = -5,5 
        do l = -5,5 
         if(i.eq.2.or.i.eq.4.or.L.eq.2.or.L.eq.4) then
           xcs(i,l) = xcs(i,l) * BRS(1,2)  ! W+
         else
           xcs(i,l) = xcs(i,l) * BRS(2,2)  ! W-
         endif        
           sigrx=sigrx + xcs(i, l)
        enddo
      enddo
*
      return
      end
*----------------------------------------------------------------------------*
*... Authors  : Serge Slabospitsky                                           *
*... 26.01.2001                                                              *
*   TopReX process  6                                                        *
*    q q~' -> W+- + H+-  -> tau nu                                           *
*----------------------------------------------------------------------------*
      subroutine gejzer_06(NFP) 
      implicit None
      include "txpar.inc" 
      include "txpro.inc" 
      Integer NFP          ! number of particles in hard process 
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision  pn(5), PL(5), q1(5), q2(5), qq(5)
      double precision  Ves2, vesm
      double precision            sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      Integer L, I, J, II, j1,j2
      integer        ju, jd, jt,jb 
      common /isng01/ju, jd, jt,jb 
      double precision mql, mql2
      common/massql/ mql(0:20), mql2(0:20)
      double precision  x1, x2, ves, veslum
      dimension ves(-6:6,-6:6)
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision pdfbt(-5:5, -5:5)
      double precision CKM2
      common /CKMD/ CKM2(-6:6,-6:6)
      double precision ParL(3), WR(2)
      save ParL 
      double precision XEST(0:12), aran, PYR
      save  XEST
*
      integer IB(12), IT(12), IQ
       data ib/ 2, 2, 2,   4, 4, 4,  -1, -3, -5,  -1, -3, -5/ 
       data it/-1,-3,-5, - 1,-3,-5,   2,  2,  2,   4,  4,  4/ 
      Save IB, IT
*
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
      double precision hr 
      common /topol1/ hr(4)    ! TAU lepton polarisation vector
*..............

      if(first) then 
 999   format(a80)
*..Rpar(51)     : charged Higgs mass                                         *
*..Rpar(53)     : total charged Higgs decay width                            *
*..RPAR(101)      : sqrt(Shat_MIN) for hard process                          *
*..RPAR(102)      : sqrt(Shat_MAX) for hard process                          *
*
      If(    Ipar(1).eq.6.or.txpro(6).eq.1) then
        ipar(21) = -1                       ! Ipar(1)=6 : W* -> tau nu   
      ElseIf(Ipar(1).eq.9.or.txpro(9).eq.1) then
       ipar(21) = -2                        ! Ipar(1) = 9 : H+- -> tau nu 
      EndIf
       ParL(1) = rpar(101)      ! M(W*)_min for production
       ParL(2) = rpar(102)      ! M(W*)_max for production
      write(*,7051) ParL(1), Parl(2) 
 7051 format(/,'   sqrt(Shat) from ',f8.2,' to ',f8.2)
       if(Parl(1).ge.Parl(2)) then
       write(*,7053)
 7053    format(/,' Shat_min greater than Shat_max : stop running')
        STOP 
       endif
       Parl(3) = Rpar(1)
      ENDIF

      if(first) goto 103  
       goto 104
 103   continue
       II = 0
 102   II = II + 1
      if(ii.gt.Ipar(51)) goto 111
       IQ = 0
 100   IQ = IQ + 1
      if(IQ.GT.12) goto 102

 104  sigrx=0.d0
        do j1 = -6,6
        do j2 = -6,6
         xcs(j1,j2) = 0.d0
        enddo
        enddo
*
* 12 combinations are considered
* 1: u d,  2: u s,  3: u b,  4: c d,  5: c s,  6: c b 
* then two combinations correspond to beam(U) or target(U)

      if(.NOT.first) then  
 106  aran = PYR(0)
       if(aran.ge.xest(12))   goto 106 
       do IQ = 1,12
        if(aran.le.xest(IQ))  goto 105
       enddo 
 105   continue
      if(IQ.LT.0.OR.IQ.GT.12) goto 106
      endif
*
        do j1 = 1,5
         q1(j1) = 0.d0
         q2(j1) = 0.d0
        enddo
*...
 295  continue 
* 
       q1(5) = mql(abs(IB(iq)))
       q2(5) = mql(abs(IT(iq)))

      if(abs(ipar(21)).eq.1)    then 
       WR(1) = Rpar(41)   ! W-boson mass
       WR(2) = Rpar(44)   ! M(W) * Width(W) 
       call X1X2RES( ParL, WR, X1, X2, Veslum, q1, q2, QQ)
      elseif(abs(ipar(21)).eq.2) then 
       WR(1) = Rpar(51)   ! H-boson mass
       WR(2) = Rpar(54)   ! M(H) * Width(H) 
       call X1X2RES( ParL, WR, X1, X2, Veslum, q1, q2, QQ)
      elseif(ipar(21).eq.3) then
       call X1X2GEN( ParL, X1, X2, Veslum, q1, q2, QQ)
      endif

* check 
      if(QQ(5).lt.Parl(1).or.QQ(5).gt.PARL(2)) goto 295 
 296  continue

      Rpar(74) = QQ(5)      ! sqrt(s-hat)  
      Rpar(71) = QQ(5)**2   ! sqrt(s-hat)  
      call TXQscale     ! setting Q-scale for PDF( Rpar(3)) and for alpha_s 
      call pdf_BT(x1, x2, pdfbt)
        pn(5) = mql(16)  ! tau-neutrino
        PL(5) = mql(15)  ! tau-lepton
      call LIPS2 (QQ, pn, pl, Ves2)

      veslum = veslum * ves2 * pi2_4 / (2.* QQ(5) * QQ(5)) 

        do j1 = -6,6
        do j2 = -6,6
         ves(j1,j2) = 0.d0
        enddo
        enddo
*
      JT = 16
      JB = 15 
       if(abs(IB(iq)).eq.2.or.abs(IB(iq)).eq.4) then
         JU = IB(iq)
         JD = IT(iq)
         call sng_01(q1, q2, pn, pl, vesm)
       else
         JU = IT(iq)
         JD = IB(iq)
         call sng_01(q2, q1, pn, pl, vesm)
       endif
      I = IB(iq)
      J = IT(iq)
      Xcs( I, J) = Veslum * vesm * pdfBT( I, J) * CKM2(i,j)
      Xcs(-I,-J) = Veslum * vesm * pdfBT(-I,-J) * CKM2(i,j)

      sigrx=0.d0
      do i=-6,6
        do l=-6,6
          if(.NOT.first) then 
           xcs(i,l) = xcs(i,l) / (xest(IQ) - xest(IQ-1))
          endif
         sigrx = sigrx + xcs(i,l)
        enddo
      enddo

      if(.NOT.first) goto 444
      xest(IQ) = xest(IQ) + sigrx
      goto 100
 111  continue
       
       xest(0) = 0.d0
       do IQ = 1,12
        xest(IQ) = xest(IQ) / ipar(52) 
        xest(0)  = xest(0) + xest(IQ)
       enddo
        xest(1) = xest(1) / xest(0) 
       do IQ = 2,12
        xest(IQ) = xest(IQ) / xest(0) 
        xest(IQ) = xest(IQ) + xest(IQ-1) 
       enddo
       xest(0) = 0.d0
       sigrx = 0.d0
      first=.FALSE.
       return       
 444  continue
      NFP = 5
       do i = 1,5
        pus(1,i) = q1(i)
        pus(2,i) = q2(i)
        pus(3,i) = pn(i) + PL(i)  ! virtual W or Higgs 
        pus(4,i) = pn(i)          ! final neutrino 
        pus(5,i) = PL(i)          ! final tau
       enddo 
      return
      end
*----------------------------------------------------------------------------*
*... Authors  : Serge Slabospitsky                                           *
*... 29.01.2001                                                              *
*    q q~' -> H+- JET -> tau nu                                              *
*............................................................................*
      subroutine gejzer_07(NFP)
      implicit None
      include "txpar.inc" 
      include "txpro.inc" 
      Integer NFP          ! number of particles in hard process 
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision  pn(5), PL(5)
      double precision  q1(5), q2(5), qq(5) 
      double precision  pu(5), pd(5), pg(5)
      double precision            sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      Integer I, J, L, j1,j2 
      double precision mql, mql2
      common/massql/ mql(0:20), mql2(0:20)
      double precision  x1, x2, sg, sgs

      double precision  ves
      dimension ves(-6:6,-6:6)
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision pdfbt(-5:5, -5:5)
      double precision veslum, vesm, ves1, Ves2 
      double precision CKM2
      common /CKMD/ CKM2(-6:6,-6:6)
      double precision sqhat_min, sqhat_max, parl(3) 
      save   sqhat_max, sqhat_min 
      double precision PYR
*
      integer IQ, IK,   LU, LD, LG 
      common /hjetfl/ ik(3)   ! KF code of beam, target, and final
      integer iqb(18), iqt(18), iqf(18)
      data iqb/
     & 2, 2, 2, 4, 4, 4,  2, 2, 2, 4, 4, 4, -1,-3,-5,-1,-3,-5/ 
      data iqt/
     &-1,-3,-5,-1,-3,-5,  0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0, 0/
      data iqf/
     & 0, 0, 0, 0, 0, 0, -1,-3,-5,-1,-3,-5,  2, 2, 2, 4, 4, 4/
      Save IQB, IQT, IQF
      double precision PH(5), pf(5) 
*
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
      double precision PARR(4),   PT
      double precision XEST(0:18), aran
      integer II 
      save  XEST
*..............
      if(first) THEN
 999  format(a80)
*..Rpar(51)     : charged Higgs mass                                         
*..Rpar(53)     : total charged Higgs decay width                            
*..RPAR(101)    : sqrt(Shat_MIN) for hard process                          
*..RPAR(102)    : sqrt(Shat_MAX) for hard process                            
*
      If(    Ipar(1).eq.7.or.txpro(7).eq.1) then
        ipar(21) = -1                            ! Ipar(1)=7 : JET + W* -> tau nu 
      ElseIf(Ipar(1).eq.10.or.txpro(10).eq.1) then
        ipar(21) = -2                            ! Ipar(1) = 10 : JET H+- -> tau nu
      EndIf

       sqhat_min = rpar(101)
       sqhat_max = rpar(102)
      write(*,7051) sqhat_min, sqhat_max 
 7051 format(/,' sqrt(Shat) from ',f8.2,' to ',f8.2)
         if(sqhat_min.ge.sqhat_max) then
          write(*,7053) 
 7053    format(/,' Shat_min greater than Shat_max  stop running')
          STOP 
         endif
*

        if(abs(ipar(21)).eq.1) then
         ParR(1) = Rpar(41) 
         ParR(2) = Rpar(44) 
        else 
         ParR(1) = Rpar(51) 
         ParR(2) = Rpar(54) 
        endif
        ParR(3) = sqhat_min
        ParR(4) = sqhat_max
         pn(5) = mql(16)  !  neutrino
         PL(5) = mql(15)
      ENDIF
      
      if(first) goto 103  
       goto 104
 103   continue
       II = 0
 102   II = II + 1
      if(ii.gt.ipar(52)) goto 111
       IQ = 0
 100   IQ = IQ + 1
      if(IQ.GT.18) goto 102
 104   sigrx=0.d0
        do j1 = -6,6
        do j2 = -6,6
         xcs(j1,j2) = 0.d0
        enddo
        enddo
*

       if(.NOT.first) then  
 106  aran = PYR(0)
       if(aran.ge.xest(18))   goto 106 
       do IQ = 1,18
        if(aran.le.xest(IQ))  goto 105
       enddo 
 105   continue
      if(IQ.LT.0.OR.IQ.GT.18) goto 106
      endif
*
        do j1 = 1,5
         q1(j1) = 0.d0
         q2(j1) = 0.d0
        enddo
* 18 combinations are considered
* 1: u d,  2: u s,  3: u b,  4: c d,  5: c s,  6: c b 
* and 6 different variants of (G q -> q`) or (q q~' -> g)
*
* all combinations correspond to H+ production 
      if(pyr(0).gt.0.5) then
       ik(1) = IQB(iq)   
       ik(2) = IQT(iq)
       ik(3) = IQF(iq) 
      else
       ik(2) = IQB(iq)   
       ik(1) = IQT(iq)
       ik(3) = IQF(iq) 
      endif

        q1(5) = mql(abs(ik(1)))     
        q2(5) = mql(abs(ik(2))) 

        pf(5) = mql(abs(ik(3)))
       parL(1) = rpar(103) + dsqrt(sqhat_min**2+rpar(103)**2) 
       parL(2) = Rpar(1)
       parL(3) = Rpar(1)

      call X1X2GEN(parl, X1, X2, Veslum, q1, q2, QQ)
        q1(5) = mql(abs(ik(1)))     
        q2(5) = mql(abs(ik(2))) 
       q1(4) = dsqrt(q1(3)**2 + q1(5)**2) 
       q2(4) = dsqrt(q2(3)**2 + q2(5)**2) 

       veslum = 2.d0 * veslum  ! takes into account beam/target permutation
        call mass2(q1, q2, sg, sgs)

      call LIPS_RES_ONE(QQ, ParR, PH, pf, Ves1)      
*  check for PT(pf) > rpar(103) - min PT(pf)      
      if(pt(pf).lt.rpar(103)) then 
        if(first) goto 100
        return
      endif

      Rpar(5) = PH(5)   ! mass(H* or W*) ==> Q-scale for PDF
      call TXQscale  ! setting Q-scale for PDF( Rpar(3)) and for alpha_s    
      call pdf_BT(x1, x2, pdfbt)

      call LIPS2 (PH, pn, pl, Ves2)

        do j1 = -6,6
        do j2 = -6,6
         ves(j1,j2) = 0.d0
        enddo
        enddo
      veslum = veslum * ves1 * ves2 * pi2_4 / (2.*sg)
* all combinations correspond to H+ production 
* in sng_03 :  pU, pD, pG
      

      do i = 1,5
        pus(1,i) = q1(i)
        pus(2,i) = q2(i)
        pus(3,i) = pf(i) 
      enddo  
       do J = 1,3
        if(abs(ik(j)).eq.2.OR.abs(ik(j)).eq.4)   LU = J
        if(abs(ik(j)).eq.1.OR.abs(ik(j)).eq.3.
     &  OR.abs(ik(j)).eq.5)                      LD = J
        if(abs(ik(j)).eq.0)                      LG = J
       enddo
 
       do J = 1,4
         pu(J) = pus(LU,J) 
         if(LU.eq.3) pu(J) = -pu(J) 
         pd(J) = pus(LD,J) 
         if(LD.eq.3) pd(J) = -pd(J) 
         pg(J) = pus(LG,J) 
         if(LG.eq.1.or.LG.eq.2) pg(J) = -pg(J) 
        enddo
         pu(5) = pus(LU,5) 
         pd(5) = pus(LD,5) 
         pg(5) = pus(LG,5) 
*
         Call sng_03(pu, pd, pg, pn, pl, vesm)
      if    (LG.eq.1.OR.LG.eq.2) then 
       veslum = -veslum / 3.d0 / 8.d0   ! quark*gluon colors
      elseif(LG.eq.3) then
       veslum = veslum / 3.d0 / 3.d0   ! quark*quark colors
      else
       veslum = 0.d0
      endif

      veslum = Veslum * vesm * CKM2(abs(ik(lu)),abs(ik(ld)))
      Xcs( ik(1), ik(2)) = Veslum * pdfBT( ik(1), ik(2))
      Xcs(-ik(1),-ik(2)) = Veslum * pdfBT(-ik(1),-ik(2))

      sigrx=0.d0
      do i= -5 ,5
        do l= -5, 5 
            if(.NOT.first) then 
              xcs(i,l) = xcs(i,l) / (xest(IQ) - xest(IQ-1))
            endif
          sigrx = sigrx + xcs(i,l)
        enddo
      enddo

      if(.NOT.first) goto 444
      xest(IQ) = xest(IQ) + sigrx
      goto 100
 111  continue
       
       xest(0) = 0.d0
       do IQ = 1,18
        xest(IQ) = xest(IQ) / ipar(52)
        xest(0)  = xest(0) + xest(IQ)
       enddo
        xest(1) = xest(1) / xest(0) 
       do IQ = 2,18
        xest(IQ) = xest(IQ) / xest(0) 
        xest(IQ) = xest(IQ) + xest(IQ-1) 
       enddo
       xest(0) = 0.d0
       sigrx = 0.d0
      first=.FALSE.
       return       
 444  continue
       NFP = 6
       do i = 1,5
        pus(1,i) = q1(i)
        pus(2,i) = q2(i)
        pus(3,i) = pf(i)          ! final quark or gluon 
        pus(4,i) = ph(i)          ! virtual H* or W*
        pus(5,i) = pn(i)          ! final neutrino 
        pus(6,i) = PL(i)          ! final tau
       enddo
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  26.01.2002                                  *
*     H+ H-   production                                                     *
*............................................................................*
      subroutine gejzer_61(NFP) 
      Implicit None
      include "txpar.inc" 
      Integer NFP          ! number of particles in hard process 
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision k1(5), k2(5)        ! H+ and H- 5-momenta
      double precision q1(5), q2(5), qq(5)
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision x1, x2, sg, sgs
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst / pi, pi2, pi4, pi2_3, pi2_4, pi2_6

      double precision           sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      double precision vlum, vesq, vesr 
      Integer i, j, iq, II, j1,j2
      double precision pdfBT(-5:5, -5:5)
      double precision Parl(3)
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
      double precision XEST(0:5), aran, PYR
      save  XEST
*.......
      if(first) goto 103  
       goto 104
 103   continue
       II = 0
 102   II = II + 1
      if(ii.gt.ipar(52)) goto 111
       IQ = 0
 100   IQ = IQ + 1
       if(IQ.GT.5) goto 102
 104   sigrx=0.d0

       if(.NOT.first) then  
 106  aran = PYR(0)
       if(aran.ge.xest(5))   goto 106 
       do IQ = 1,5
        if(aran.le.xest(IQ))  goto 105
       enddo 
 105   continue
      if(IQ.LT.1.OR.IQ.GT.5) goto 106
      endif
*..
        do j1 = -6,6
        do j2 = -6,6
         xcs(j1,j2) = 0.d0
        enddo
        enddo
*
        do j1 = 1,5
         q1(j1) = 0.d0
         q2(j1) = 0.d0
        enddo
* evaluate of the top on-shell mass
       Parl(1) = rpar(51) + rpar(51) 
       Parl(2) = Rpar(1)
       Parl(3) = Rpar(1)

 295  continue 
      q1(5) = mq(iq) 
      q2(5) = mq(iq)
      call X1X2GEN( Parl, X1, X2, Vlum, q1, q2, QQ)
* check 
      if(QQ(5).lt.Parl(1).or.QQ(5).gt.PARL(2)) goto 295 
 296  continue
      call mass2(q1, q2, sg, sgs)

      call TXQscale   !  setting Q-scale for PDF( Rpar(3)) and for alpha_s  
      call pdf_BT(x1, x2, pdfbt)


      k1(5) = rpar(51)
      k2(5) = rpar(51)
      Call LIPS2(QQ, k1, k2, vesr) 
       vesq = vesr
      call QQHH(iq, q1, q2, k1, k2, vesr) 

      vesQ = Vlum * VesQ * vesr * pi2_4 / (2.* sg)

       xcs( IQ,-IQ) = vesQ * pdfBT( IQ,-IQ) * BRS(1,3)*BRS(2,3)
       xcs(-IQ, IQ) = vesQ * pdfBT(-IQ, IQ) * BRS(1,3)*BRS(2,3)

      sigrx=0.d0
      do i = -6,6
        do j=-6,6
            if(.NOT.first) then 
              xcs(i,j) = xcs(i,j) / (xest(IQ) - xest(IQ-1))
            endif
          sigrx = sigrx + xcs(i,j)
        enddo
      enddo

      if(.NOT.first) goto 444
      xest(IQ) = xest(IQ) + sigrx
      goto 100
 111  continue
       xest(0) = 0.d0
       do IQ = 1,5
        xest(IQ) = xest(IQ) / ipar(52)
        xest(0)  = xest(0) + xest(IQ)
       enddo
        xest(1) = xest(1) / xest(0) 
       do IQ = 2,5
        xest(IQ) = xest(IQ) / xest(0) 
        xest(IQ) = xest(IQ) + xest(IQ-1) 
       enddo
       xest(0) = 0.d0
       sigrx = 0.d0
      first=.FALSE.
       return       
 444  continue

      NFP = 4
        do i=1,5
          pus(1,i) = q1(i)
          pus(2,i) = q2(i)
          pus(3,i) = k1(i)           ! top quark 
          pus(4,i) = k2(i)           ! top_bar quark 
        enddo
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  26.01.2002                                  *
*............................................................................*
      subroutine gejzer_23(NFP) 
      Implicit None
      include "txpar.inc"  
      integer NFP          ! number of particles in hard process 
      double precision           sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      integer I, J, ik1,ik3 
      common /kfzqq/ik1, ik3 
      double precision coef
*.......
      double precision sigZqq, effzqq(0:16), coeffZqq(16), ARAN, PYR
      integer jproc
      save effZqq, coeffZqq
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
      double precision eqf(2,-20:20), zff(2,-20:20)
      common /Vboscpl/ eqf, zff
*..
      IF(first) THEN
         do j = 0,16
          effzqq(j) = 0.d0
         enddo
       I = -1 
        do J = 1,15
         if(mid(j,4).ge.1) I = +1
        enddo
        if(I.eq.-1) then
         print*,' ZQQ: no open Z-boson decay channels. stop'
         STOP
        endif
        first=.FALSE.
***
         sigZqq = 0.d0
       do j = 1,16
        coeffZqq(j) = 0.d0
         if(mid(j,4).ge.1) then
           ik1 = fid(4,j,1)
          coeffZqq(j) = zff(1,ik1)**2 + zff(2,ik1)**2
           if(Ipar(23).eq.1)  coeffZqq(j) = eqf(2,ik1)**2          
         endif
         if(j.le.6) coeffZqq(j) = coeffZqq(j) * 3.d0
         sigZqq =  sigZqq + coeffZqq(j)
       enddo
*..Ipar(23)     : Zqq, 0: gam* + Z,   1: gam*, 2: Z                          *

        effZqq(0) = 0.d0
       do j = 1,16
         if(mid(j,4).ge.1) then
             coeffZqq(j) = coeffZqq(j) / sigZqq
             effZqq(j)   = effZqq(0) + coeffZqq(j) 
             effZqq(0)   = effZqq(j)
         endif
       enddo
      ENDIF
 
*..........................................
 502  continue  ! normal running
      ARAN = pyr(0) 
       do j = 1,16
         if(mid(j,4).ge.1) then
           if(aran.le.effZqq(j)) then
             jproc = j
             goto 503
           endif
         endif
       enddo
 503   continue

      ik1 = fid(4,jproc,1)
      ik3 = Ipar(7) !  5

      coef = 1.d0 / coeffZqq(jproc)
      call gejzer_zqq(coef) 

      sigrx = 0.d0
      do i = -5,5
        do j=-5,5
          sigrx = sigrx + xcs(i,j)
        enddo
      enddo
      NFP = 7
*       call examhard6(sigrx)
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  26.01.2002                                  *
*............................................................................*
      subroutine gejzer_zqq(coef) 
      Implicit None
      include "txpar.inc"  
      include "txpro.inc" 
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision k1(5), k2(5), k3(5), k4(5), pz(5)
      double precision q1(5), q2(5), qq(5)
      common /txkin/q1, q2, QQ
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision x1, x2, sg, sgs
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst / pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision           sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      double precision Parl(3), vlum, Vlum0, VesR,
     & VDDbar, VDbarD, VUUbar, VUbarU, VGG, coef
      double precision pdfBT(-5:5, -5:5)
      integer I, iq1,ik1,ik3, iniq, j1,j2 
      common /kfzqq/ik1, ik3 
      double precision masstwo, pyr 
*.......
      double precision mzz, mzz2, pt
      common /mzzz/mzz,mzz2
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
*..
      IF(first) THEN
       first = .false.
        write(*,910) Rpar(81),Rpar(82)
 910    format(//,'  Z QQbar: PTmin(q) = ',f8.3,' GeV',
     &  '  PTmin(Z) = ',f8.3,'GeV')
       if(rpar(81).lt.10.d0) then
        write(*,911) Rpar(81)
 911    format('   PTmin(q) = ',f8.3,' GeV is too small',/
     &         '   10 GeV is recommended',/)
       endif 
        print*,'                          '
        print*,'*************',' ZQQ production'
        call MQQLIM   !  check M(QQ)_min/max
        print*,'                          '
        call MFFLIM   !  check M(ff)_min/max
         if((Rpar(77)+Rpar(79)).ge.Rpar(1)) then
         print*,' min(QQ) + min(ff) = ',(Rpar(77)+Rpar(79)),
     &'  greater than sqrt(s) = ',rpar(1),' stop'
         STOP
         endif
        print*,'*************',' ZQQ production'
      ENDIF

        do j1 = -6,6
        do j2 = -6,6
         xcs(j1,j2) = 0.d0
        enddo
        enddo
      call zer5mom(q1) 
      call zer5mom(q2) 
* evaluate of the top on-shell mass
       Parl(1) = Rpar(45) + 2.d0 * mq(Ipar(7)) 
       if(Rpar(80).lt.Rpar(45)) then
          Parl(1) = Rpar(79) + 2.d0 * mq(Ipar(7))
       endif
        if(Parl(1).lt.(2.d0*mq(ik1) + 2.d0*mq(ik3))) then
          Parl(1) = 2.d0*(mq(ik1) + mq(ik3)) 
        endif
        if(Parl(1).lt.(Rpar(77)+Rpar(79))) then
          Parl(1) = Rpar(77) + Rpar(79) 
        endif
       Parl(2) = Rpar(1)
       Parl(3) = Rpar(1)
      q1(5) = 0.d0 
      q2(5) = 0.d0 
      NXev(ipar(1)) = NXev(ipar(1)) - 1
 295  continue
      call X1X2GEN2( Parl, X1, X2, Vlum0)   ! , q1, q2, QQ)
      NXev(ipar(1)) = NXev(ipar(1)) + 1
* check 
      if(QQ(5).lt.Parl(1).or.QQ(5).gt.PARL(2)) goto 295 
 296  continue
      call mass2(q1, q2, sg, sgs)

      call TXQscale   !  setting Q-scale for PDF( Rpar(3)) and for alpha_s  
      call pdf_BT(x1, x2, pdfbt)
 
      k1(5) =  mq(ik1)
      k2(5) =  mq(ik1)
      k3(5) =  mq(ik3)
      k4(5) =  mq(ik3)

 227   continue

      If(Ipar(22).eq.0) then
        if(pyr(0).ge.0.5) then
          iniq = 1
          call Rlip42(QQ, k1, k2, k3, k4, pz, vesr)
          vesr = 2.d0 * vesr
        else 
          iniq = 2
          call Rlip42(QQ, k1, k2, k3, k4, pz, vesr)
          vesr = 2.d0 * vesr
        endif
      ElseIf(Ipar(22).eq.1) then
          iniq = 1
          call Rlip423(QQ, k1, k2, k3, k4, pz, vesr)
      ElseIf(Ipar(22).eq.2) then
          iniq = 2
          call Rlip42(QQ, k1, k2, k3, k4, pz, vesr)
      Else
          return
      EndIf



      if(vesr.le.0.d0) return 
      if(pt(pz).le.rpar(82)) goto 295
      if(pt(k3).le.rpar(81).OR.pt(k4).le.rpar(81)) goto 295
      if(ik1.eq.ik3) then
       if(pt(k1).le.rpar(81).OR.pt(k2).le.rpar(81)) goto 295
      endif
      call mass2(k1, k2, mzz2, mzz) 
       if(masstwo(k3,k4).LT.rpar(77)) goto 295
       if(masstwo(k3,k4).GT.Rpar(78)) goto 295
       if(masstwo(k1,k2).LT.rpar(79)) goto 295
       if(masstwo(k1,k2).GT.Rpar(80)) goto 295
      Rpar(76) = (k1(1)+k2(1))**2 + (k1(2)+k2(2))**2 ! PT(Z)^2
      Rpar(75) = dsqrt(Rpar(76)) 

      Vgg = 0.d0 
      vDDbar = 0.d0
      vDbarD = 0.d0 
      vUUbar = 0.d0 
      vUbarU = 0.d0 

      vlum = vlum0 * coef * vesR * pi2_4 / (2.*sg)
*
      if(Ipar(22).eq.0.or.Ipar(22).eq.1) then  ! gg contribution
       call ZGGtoQQ(ik1, ik3, q1,q2, k1,k2,k3,k4, VGG) 
      endif 

      if(Ipar(22).eq.0.or.Ipar(22).eq.2) then  ! q qbar contribution
        iq1 = 1
       call ZqqtoQQ(iq1,ik1,ik3, q1,q2, k1,k2,k3,k4, vDDbar) ! d    dbar
       call ZqqtoQQ(iq1,ik1,ik3, q2,q1, k1,k2,k3,k4, vDbarD) ! dbar d
        iq1 = 2
       call ZqqtoQQ(iq1,ik1,ik3, q1,q2, k1,k2,k3,k4, vUUbar) ! U    Ubar
       call ZqqtoQQ(iq1,ik1,ik3, q2,q1, k1,k2,k3,k4, vUbarU) ! Ubar U
      endif

      xcs( 0, 0) = Vlum * VGG    * pdfBT( 0,0) 
      xcs( 1,-1) = Vlum * VDDbar * pdfBT( 1,-1) 
      xcs(-1, 1) = Vlum * VDbarD * pdfBT(-1, 1) 
      xcs( 3,-3) = Vlum * VDDbar * pdfBT( 3,-5) 
      xcs(-3, 3) = Vlum * VDbarD * pdfBT(-3, 3) 
      xcs( 5,-5) = Vlum * VDDbar * pdfBT( 3,-5) 
      xcs(-5, 5) = Vlum * VDbarD * pdfBT(-5, 5) 

      xcs( 2,-2) = Vlum * VUUbar * pdfBT( 2,-2) 
      xcs(-2, 2) = Vlum * VUbarU * pdfBT(-2, 2) 
      xcs( 4,-4) = Vlum * VUUbar * pdfBT( 4,-4) 
      xcs(-4, 4) = Vlum * VUbarU * pdfBT(-4, 4) 
***
        do i=1,5
          pus(1,i) = q1(i)
          pus(2,i) = q2(i)
          pus(3,i) = pz(i) 
          pus(4,i) = k1(i)
          pus(5,i) = k2(i) 
          pus(6,i) = k3(i) 
          pus(7,i) = k4(i) 
        enddo
          pus(3,5)=dsqrt(pz(4)**2-pz(1)**2-pz(2)**2-pz(3)**2) 

      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  30.01.2005                                  *
*   gg -> box -> Z Z                                                         *
*   TopReX code = 24                                                         *
*............................................................................*
      subroutine gejzer_24(NFP) 
      Implicit None
      include "txpar.inc" 
      include "txpro.inc" 
      Integer NFP          ! number of particles in hard process 
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision q1(5), q2(5)        
      double precision p3(5), p4(5), qq(5)
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision x1, x2, sg, sgs 

      double precision           sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      double precision vlum, vesr, vesm, Parl(3), PT 
      double precision pdfBT(-5:5, -5:5)
      integer i, j1,j2
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst / pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
****
      IF(first) THEN
       if(Ipar(17).eq.2) then  
          Ipar(17) = 0   ! normal case
       else 
          Ipar(17) = 1   ! if sigRX> sigMX events is NOT accepted 
       endif             ! and  sigRX is NOT added to Xsig
*
       first = .false.
       if(Rpar(103).gt.Rpar(67)) Rpar(67) = Rpar(103) ! min PT(Z)
       print*,' PT(Z)min = ',Rpar(67)
      ENDIF
* 
        do j1 = -6,6
        do j2 = -6,6
         xcs(j1,j2) = 0.d0
        enddo
        enddo
      call zer5mom(q1) 
      call zer5mom(q2) 
      call zer5mom(p3) 
      call zer5mom(p4) 
*
       Parl(1) = 2.d0*dsqrt(rpar(46) + rpar(67)**2) 
       Parl(2) = Rpar(1)
       Parl(3) = Rpar(1)

      NXev(ipar(1)) = NXev(ipar(1)) - 1
 295  continue 
      call X1X2GEN( Parl, X1, X2, Vlum, q1, q2, QQ)
      NXev(ipar(1)) = NXev(ipar(1)) + 1
      call mass2(q1, q2, sg, sgs)
      call pdf_BT(x1, x2, pdfbt)

      p3(5) = rpar(45)
      p4(5) = rpar(45)
      call LIPS2(QQ, p3, p4, vesr) 
      if(PT(p3).lt.Rpar(67)) goto 295

      Rpar(75) = PT(p3)
      Rpar(76) = Rpar(75)**2

      call TXQscale   !  setting Q-scale for PDF( Rpar(3)) and for alpha_s  

       call GGZZ(q1, q2, p3, p4, vesm)
       vesM = Vlum * VesR * VesM * pi2_4 / (2.* sg)
       xcs(0,0) = pdfBT( 0, 0) * Vesm 

      sigrx=xcs(0,0)
      NFP = 4
      if(ipar(8).ne.+1) return 

       do i=1,5
         pus(1,i) = q1(i)
         pus(2,i) = q2(i)
         pus(3,i) = p3(i)           ! Z-boson 
         pus(4,i) = p4(i)           ! Z-boson
        enddo
      return
      end

*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  23.11.2005                                  *
*  t tbar gamma
*............................................................................*
      subroutine gejzer_25(NFP) 
      Implicit None
      include "txpar.inc"  
      include "txpro.inc" 
      integer NFP          ! number of particles in hard process 
      double precision           sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      integer I, J, j1,j2
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision q1(5), q2(5), qq(5), p1(5), p2(5), q(5)
      common /txkin/q1, q2, QQ
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision x1, x2, PT, ptmin
*      data ptmin/10.d0/
      save ptmin
      double precision Parl(3), vlum, vesl, vesD, vesU, vesG
      double precision vhh(3,3), vtt3
      common /topol2gam/ vtt3(3,3,3)
      integer jj1, jj2, jj3     
      double precision pdfBT(-5:5, -5:5)
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision qtt(5), pp1(5), pp2(5), massone
*.......
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
*..
      IF(first) THEN
        first=.FALSE.
           ptmin = 5.d0
         if(ptmin.ge.rpar(103)) then
           ptmin = 5.d0 ! 
         else
           ptmin = rpar(103)
         endif
       PARL(1) = 2.d0*mq(6) + ptmin
       PARL(2) = Rpar(1)      ! max sqrt(S_hat) 
       PARL(3) = Rpar(1)      ! sqrt(S) 
      print*,' t tbar gamma:  PT(gamma)_min = ',ptmin,'GeV'
      ENDIF
 
*..........................................
        do j1 = -6,6
        do j2 = -6,6
         xcs(j1,j2) = 0.d0
        enddo
        enddo
      p1(5) = mq(6)
      p2(5) = mq(6)
      q(5)  = 0.d0
 502  continue  
      call zer5mom(q1) 
      call zer5mom(q2) 
      call X1X2GEN( Parl, X1, X2, Vlum, q1, q2, QQ)
      vlum = vlum * pi2_4 / (2.*QQ(5)**2)
*      call LIPS3(QQ, p1, p2, q, VesL)
      call LIPS3_TTG(QQ, ptmin, p1, p2, q, VesL)

      if(pt(q).le.ptmin) then
          NXev(ipar(1)) = NXev(ipar(1)) + 1
          goto 502  !PT of final q-quark 
       endif
*
 333  continue
       do 123 jj1 = 1,3
       do 123 jj2 = 1,3
       do 123 jj3 = 1,3
 123      vtt3(jj1,jj2,jj3) = 0.d0

      if(Ipar(22).eq.0.or.Ipar(22).eq.2) then  ! q qbar contribution
       call qqttgam(2, q1, q2, p1, p2, q, Vhh, vesU)
        do i = 1,3
         do j = 1,3
          vtt3(2,i,j) = vhh(i,j)  ! U Ubar -> t tbar
         enddo
        enddo
       call qqttgam(1, q1, q2, p1, p2, q, Vhh, vesD)
        do i = 1,3
         do j = 1,3
          vtt3(3,i,j) = vhh(i,j)  ! qq-> t tbar
         enddo
        enddo
      else
        vesU = 0.d0  ! ipar(1) = 21 : no qq~ contribution
        vesD = 0.d0  ! ipar(1) = 21 : no qq~ contribution
      endif
*...
      if(Ipar(22).eq.0.or.Ipar(22).eq.1) then  ! gg contribution
       call ggttgam(   q1, q2, p1, p2, q, Vhh, vesG)
        do i = 1,3
         do j = 1,3
          vtt3(1,i,j) = vhh(i,j) ! gluon
         enddo
        enddo
      else
        vesG = 0.d0  ! ipar(1) = 22 : no gg contribution
      endif
*.............
      
      vesG = vesl*vlum*vesG * BRS(1,1) * BRS(2,1) 
      vesD = vesl*vlum*vesD * BRS(1,1) * BRS(2,1) 
      vesU = vesl*vlum*vesU * BRS(1,1) * BRS(2,1) 
**
* setting Q-scale for PDF( Rpar(3)) and for alpha_s 
 2222 Rpar(76) = p1(1)**2 + p1(2)**2 ! pt(top)
      Rpar(75) = dsqrt(Rpar(76))   
      call TXQscale     
      call pdf_BT(x1, x2, pdfBT) 
***

      xcs( 0, 0) = vesG * pdfBT( 0, 0)
      xcs( 1,-1) = vesD * pdfBT( 1,-1)
      xcs(-1, 1) = vesD * pdfBT(-1, 1)
      xcs( 3,-3) = vesD * pdfBT( 3,-3)
      xcs(-3, 3) = vesD * pdfBT(-3, 3)
      xcs( 5,-5) = vesD * pdfBT( 5,-5)
      xcs(-5, 5) = vesD * pdfBT(-5, 5)
      xcs( 2,-2) = vesU * pdfBT( 2,-2)
      xcs(-2, 2) = vesU * pdfBT(-2, 2)
      xcs( 4,-4) = vesU * pdfBT( 4,-4)
      xcs(-4, 4) = vesU * pdfBT(-4, 4)

      sigrx=0.d0
      do i = -5,5
        do j=-5,5
          sigrx = sigrx + xcs(i,j)
        enddo
      enddo

      NFP = 5
        do i=1,4
         qtt(i) = p1(i) + p2(i)
        enddo
         qtt(5) = massone(qtt)
       call TXTTSMR(QTT, p1, p2, pp1, pp2)
        do i=1,5
          pus(1,i) = q1(i)
          pus(2,i) = q2(i)
          pus(3,i) = pp1(i)         ! top quark 
          pus(4,i) = pp2(i)         ! top_bar quark 
          pus(5,i) = q(i)          ! photon 
        enddo
*          call  EXAM_ttgam

       return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  24/11/2005                                  *
*  complex matrix element for the process                                    *
*  q qbar --> t(pol)  + t_bar(pol) + gamma                                   *
*----------------------------------------------------------------------------*
      subroutine qqttgam(ifl, q1, q2, p1, p2, q, hh, ves)
*     ---------------------------------------------------                    *
      implicit none
      include "txpar.inc" 
      double precision q1(5), q2(5)         ! momenta of the initial quarks
      double precision p1(5), p2(5), q(5)   !momenta of the final t, tbar,gamma 
      double precision x1(5), x2(5), x3(5), x4(5)
      integer I, IFL, IL
      double precision Ves, coef, S, TS, eg(5), scalp
      double precision chr(2), pp12, pp11
      save chr 
      Integer if1,if2, iq1, iq2,ig, is, jj1,jj2
      double complex v1u2(4,4), v2u1(4,4)
       save v1u2, v2u1
      double complex TM(2,2,2,2,2), PR1(4,4),PR2(4,4),PR3(4,4),PR4(4,4)
      double complex UBP1(2,4),Vp2(2,4),U0,UU1(4,4),uu2(4,4),veg(4,4),
     & vubu(4,4), ei, a11, a12, a21, a22

      data ei/(0.d0, 1.d0)/
      save ei
      LOGICAL first
      SAVE first, coef
      DATA first /.TRUE./
      double precision hh(3,3) 
*
      if(first) THEN
*        coef = (4.d0 * pi)**2             ! due to alpha_s
        coef = rpar(10) * rpar(12)         ! transform into millibarns * eq**2
        coef = coef / (2.d0 * 2.d0)        ! spins
        coef = coef * (2.d0 / 3.d0 / 3.d0) ! color normalization
        chr(1) = -1.d0/3.d0
        chr(2) =  2.d0/3.d0
        first=.FALSE.
        do 123 jj1 = 1,4
        do 123 jj2 = 1,4
          v1u2(jj1,jj2) = (0.d0, 0.d0)
 123      v2u1(jj1,jj2) = (0.d0, 0.d0)
       v1u2(2,3) =  2.d0
       v1u2(4,1) = -2.d0 
       v2u1(1,4) =  2.d0
       v2u1(3,2) = -2.d0 

      ENDIF

*      goto 800
      if(abs(ifl).eq.1.or.abs(ifl).eq.3.or.abs(ifl).eq.5) il = 1
      if(abs(ifl).eq.2.or.abs(ifl).eq.4)                  il = 2
      S   = 2.d0 * SCALP(q1, q2)
      do I=1,4
       x1(i) =  p1(i) + q(i)
       x2(i) = -p2(i) - q(i)
       x3(i) =  q1(i) - q(i)
       x4(i) =  q(i)  - q2(i)
      enddo
       pp11 = dsqrt(S)
       pp12 = dsqrt((p1(4)+p2(4))**2 - (p1(1)+p2(1))**2
     &            - (p1(2)+p2(2))**2 - (p1(3)+p2(3))**2)
       x1(5) = p1(5)
       x2(5) = p1(5)
       x3(5) = 0.d0
       x4(5) = 0.d0
       call PropF(x1, PR1)
       call PropF(x2, PR2)
       call PropF(x3, PR3)
       call PropF(x4, PR4)
      
      call Dirs2_Ubar(p1, UBP1)
      call Dirs2_V(p2,    VP2)

      do 999 if1 = 1,2
      do 999 if2 = 1,2
       call GUBARU(if1,if2,UBP1, VP2, VUBU)
      do 999 ig  = 1,2
       call vpolgam(ig, is, q, eg)
       call phat(eg, VEG)
      do 999 iq1 = 1,2
       iq2 = 3 - iq1
* M1
       call prod_2(veg, PR1, UU1)
        if(iq1.eq.1) call prod_2(UU1, v1u2, UU2)
        if(iq1.eq.2) call prod_2(UU1, v2u1, UU2)
       call UBAR_M_U(if1,if2,UBP1, VP2, UU2, U0)
       tm(iq1,iq2,if1,if2,ig) = U0 * chr(2) / pp11
* M2
       call prod_2(PR2, veg, UU1)
        if(iq1.eq.1) call prod_2(v1u2, UU1, UU2)
        if(iq1.eq.2) call prod_2(v2u1, UU1, UU2)
       call UBAR_M_U(if1,if2,UBP1, VP2, UU2, U0)
       tm(iq1,iq2,if1,if2,ig) = tm(iq1,iq2,if1,if2,ig) 
     &          + U0* chr(2) / pp11
* M3
       call prod_2(veg, PR3, UU1)
       call prod_2(UU1, VUBU, UU2)
        if(iq1.eq.1) then
         tm(iq1,iq2,if1,if2,ig) = tm(iq1,iq2,if1,if2,ig) 
     &                - UU2(1,4)*chr(il) * pp11 / pp12**2
        elseif(iq1.eq.2) then
         tm(iq1,iq2,if1,if2,ig) = tm(iq1,iq2,if1,if2,ig) 
     &                + UU2(4,1)*chr(il) * pp11 / pp12**2
        endif
* M4
       call prod_2(VUBU, PR4, UU1)
       call prod_2(UU1, veg,  UU2)
        if(iq1.eq.1) then
         tm(iq1,iq2,if1,if2,ig) = tm(iq1,iq2,if1,if2,ig) 
     &               - UU2(1,4) * chr(il) * pp11 / pp12**2
        elseif(iq1.eq.2) then
         tm(iq1,iq2,if1,if2,ig) = tm(iq1,iq2,if1,if2,ig) 
     &               + UU2(4,1) * chr(il) * pp11 / pp12**2
        endif
 999    continue

       TS = 0.d0
       do 998 iq1 = 1,2
        iq2 = 3 - iq1
       do 998 if1 = 1,2
       do 998 if2 = 1,2
       do 998 ig  = 1,2
        TS = TS 
     &  + tm(iq1,iq2,if1,if2,ig)*conjg(tm(iq1,iq2,if1,if2,ig))
 998   continue 

* polarization       
       do iq1 = 1,3
       do iq2 = 1,3
        hh(iq1,iq2) = 0.d0
       enddo
       enddo
       do 997 iq1 = 1,2
        iq2 = 3 - iq1
       do 997 ig  = 1,2
        a11 = tm(iq1,iq2, 1,1, ig)
        a12 = tm(iq1,iq2, 1,2, ig)
        a21 = tm(iq1,iq2, 2,1, ig)
        a22 = tm(iq1,iq2, 2,2, ig)

* e1_x e2_x  
        u0 = a11 + a21 - a12 - a22
        hh(1,1) = hh(1,1) + u0*conjg(u0)
* e1_x e2_y  
        u0 = a11 + a21 - ei * (a12 + a22)
        hh(1,2) = hh(1,2) + u0*conjg(u0)
* e1_x e2_z  
        u0 = a12 + a22
        hh(1,3) = hh(1,3) + 2.d0*u0*conjg(u0)

* e1_y e2_x  
        u0 = a11 - a12 - ei * (a21 - a22)
        hh(2,1) = hh(2,1) + u0*conjg(u0)
* e1_y e2_y  
        u0 = a11 - ei*(a12+a21) - a22
        hh(2,2) = hh(2,2) + u0*conjg(u0)
* e1_y e2_z  
        u0 = a12 - ei*a22
        hh(2,3) = hh(2,3) + 2.d0*u0*conjg(u0)

* e1_z e2_x  
        u0 = a11 - a12
        hh(3,1) = hh(3,1) + 2.d0*u0*conjg(u0)
* e1_z e2_y  
        u0 = a11 - ei*a12
        hh(3,2) = hh(3,2) + 2.0*u0*conjg(u0)
* e1_z e2_z  
        hh(3,3) = hh(3,3) + 4.d0*a12*conjg(a12)
 997   continue 
      do iq1 = 1,3
      do iq2 = 1,3
       hh(iq1,iq2) = (hh(iq1,iq2) - TS) / TS
      enddo
      enddo

      ves = coef * rpar(16)**2 * TS 
      return
      end
c----------------------------------------------------------------------------c
*  27.07.2003
* return PDF set parameters, PYTHIA 6... only

      subroutine Rep_PDF
*
      Implicit None
      INTEGER MSTP, MSTI
      double precision PARP, PARI
      COMMON /PYPARS/ MSTP(200),PARP(200),MSTI(200),PARI(200)
      integer i
      Character*11 IPDF, Icur
      Character*60 INAM(9)
      data INAM /
     &' = 1 : CTEQ 3L (leading order)                              ',
     &' = 2 : CTEQ 3M (MSbar)                                      ',
     &' = 3 : CTEQ 3D (DIS)                                        ',
     &' = 4 : GRV 94L (leading order)                              ',
     &' = 5 : GRV 94M (MSbar)                                      ',
     &' = 6 : GRV 94D (DIS)                                        ',
     &' = 7 : CTEQ 5L (leading order)                              ',
     &' = 8 : CTEQ 5M1 (MSbar; slightly updated version of CTEQ 5M)',
     &' = 11: GRV 92L (leading order)                              '/

      IPDF = 'Current PDF'
  
      if(MSTP(52).ne.1) return 
      write(*,4000) 
 4000 format(/,79('*'),/,
     &'  TopReX : PDF set : '/,
     &'  ------------------',/,
     &'  Current list of distributions available in PYTHIA 6...',
     &' (default is GRV 94L)',/,
     &'  In this running we use')
       do i = 1,9
        Icur = '           '
       if(MSTP(51).eq.i) Icur = IPDF
       write(*, 4001) Icur, Inam(i)
 4001  format(3x,a11,1x,a61)
       enddo
       write(*, 4002)
 4002  format(/,' Note: option 11 is only implemented to have one set',
     &'in common between',/,3x,'Pythia 5 and 6, for crosschecks',/,
     &79('*')) 

      return
      end
*----------------------------------------------------------------------------*
*  initialisation decay routines                                             *
*... author  :  Serge Slabospitsky    02.02.2002                             *
      subroutine TXDEC_INI
*...
      implicit none 
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
*
      integer IT        
* first parameter in MID, BRF, FID, and BRS has the meaning as follows
*     IT = 1 : top quark,  IT = 2 : W-boson, 
*     IT = 3 : H+- boson,  IT = 4 : Z-boson 
*......................
*... copy W-boson decay table from PYTHIA to TopReX
      IT = 2
      if(ipar(1).eq.24) goto 2237
      call W_dec_ini
*... copy Z-boson decay table from PYTHIA to TopReX
      if(ipar(1).eq.5.or.             ! W QQbar
     &   ipar(1).eq.6.or.             ! W -> tau nu 
     &   ipar(1).eq.7.or.             ! jet + W -> tau nu 
     &   ipar(1).eq.9.or.             ! H+- -> tau nu 
     &   ipar(1).eq.10.or.            ! jet + H+- -> tau nu 
     &   ipar(1).eq.61)               ! q qbar -> H+ H-    
     &   goto 2238

 2237 continue
      IT = 5
      if(Ipar(1).eq.24) then  ! H0
         call H0_dec_ini
      endif
*
      IT = 4
      if(Ipar(1).eq.23.or.Ipar(1).eq.24) then  ! final Z
         call Z_dec_ini
         goto 2238
      endif
      if(MID(15, 1).eq.-1.and.MID(16, 1).eq.-1.and
     &  .MID(17, 1).eq.-1.and.MID(18, 1).eq.-1) goto 2238
       call Z_dec_ini
 2238 continue

      if(ipar(1).eq.5.or.ipar(1).eq.23.or.
     &   ipar(1).eq.24) goto 2239
        call T_dec_ini       !  set top quark decay parameters
        call HC_dec_ini      !  set charged Higgs parameters  
        call THC_dec_ini     ! calculate BR for top and H+-     
 2239  continue

 
      return
      end
*----------------------------------------------------------------------------*
*.. author:   Serge Slabospitsky   29.06.2001                                *
      subroutine Z_dec_ini       
*     --------------------                                                   *
*     decay table for Z-boson                                                *
* Only THREE possibilities of Z-boson decay channel are considered           *
* MID((i,  3) = MDME): -1 -- closed,                                         *
*  0 -- contributes to width, but not to decay                               *
*  1 -- contribute to Z-boson decay                                          *
* order of fermions in Z-boson decay channel is identical to PYTHIA          *
*............................................................................*
      Implicit None
* IT= 1 : top quark,  IT= 2 : W-boson, IT= 3 : H+- boson,  IT= 4 : Z-boson 
* mid(0, IT) is the total number of decay channels
*
      include "txpar.inc"  
      integer IT, J        
      Character*14 INAM2(16)
      data INAM2 /
     &' D      Dbar  ', ' U      Ubar  ', ' S      Sbar  ', 
     &' C      Cbar  ', ' B      Bbar  ', ' T      Tbar  ', 
     &' B4     B4bar ', ' t4     t4bar ', ' e-  e+       ', 
     &' nu_e   nu~   ', ' mu-    mu+   ', ' nu_mu  nu~   ', 
     &' tau-   tau+  ', ' nu_tau nu~   ', ' L-     L+    ', 
     &'              ' /
* mid(N,4) Z-boson
* N = 1 : D Dbar,   N = 2 : U Ubar,    N = 3 : S Sbar,   N = 4 : C Cbar
* N = 5 : B Bbar,   N = 6 : T Tbar,    N = 7 : B4 B4bar, N = 8 : t4 t4bar
* N = 9 : e- e+,    N = 10: nu_e nu~,  N = 11: mu- mu+,  N = 12: nu_mu nu~
* N = 13: tau- tau+ N = 14: nu_tau nu~ N = 15: L- L+     N = 16: NU4 NU4~

      character*5 chl(-1:3)
      data chl /'no   ','OFF  ','Z    ','Z    ','Z    '/
*.....
       IT = 4
       do J = 1, mid(0, IT) 
       if(mid(j, IT).ge.2) then
          write(*,202) mid(j, IT), inam2(j) 
 202      format('  TopReX : Z_dec_ini  ',/,
     &3x,'mode ',i2,' is not implemented yet for Z -> ',/,
     &3x,' stop TopReX running ')
          STOP
        endif   
       enddo
      
      BRS(1,IT) = 0.0d0
      do j = 1, mid(0, IT)
        if (Mid(j, IT).ne.0.AND.Mid(j, IT).ne.-1) THEN
           if(Mid(j, IT).eq.1) BRS(1,IT) = BRS(1,IT) + brf(j, IT)
        endif 
      enddo 

      BRS(2, IT) = BRS(1, IT) 
      write(*, 71)
 71   format(/,'   TopReX : Z decay channels contributed to width',/
     &,        '   ----------------------------------------------')
       write(*, 172) (chl(mid(j, IT)),j = 1,3),
     &                  (chl(mid(j, IT)),j = 4,6),
     &                  (chl(mid(j, IT)),j = 9,10),
     &                  (chl(mid(j, IT)),j = 11,12),
     &                  (chl(mid(j, IT)),j = 13,14)
 172  format(2x,'D    Dbar: ',a5,'U    Ubar: ',a5,' S Sbar: ',a5,/,
     &       2x,'C    Cbar: ',a5,'B    Bbar: ',a5,' T Tbar: ',a5,/,
     &       2x,'e-    e+ : ',a5,'NUe   NU~: ',a5,/,
     &       2x,'mu-   mu+: ',a5,'NUmu  NU~: ',a5,/,
     &       2x,'tau- tau+: ',a5,'NUtau NU~: ',a5)

      WRITE(*,201) BRS(1, IT) 
 201  format(/,'  TopReX : total branching for Z-boson = ',1p,d10.3)
      return
      end 
c----------------------------------------------------------------------------c
*.. author:   Serge Slabospitsky   20.03.2001                                *
      subroutine W_dec_ini
*     --------------------                                                   *
*     decay table for W's                                                    *
* it is assumed, that FIRST W-boson is POSITIVE, i.e.  W(1) = W+  W(2) = W-  *
* Five possibilites of W-boson decay channel are considered MDW(==MDME) :    *
*   = -1 not considered at all,                                              *
*   =  0 contribute to width, but not to decay                               *
*   =  1 contribute to both W+ and W- decay                                  *
*   =  2 contribute to W+, but not to W- decay                               *
*   =  3 contribute to W-, but not to W+ decay                               *
*  order of fermions in W-boson decay channel is opposite to PYTHIA          *
*....  TopReX prescription
*   1 = u d~     2 = c d~     3 = t d~      4 = t4 d~
*   5 = u s~     6 = c s~     7 = t s~      8 = t4 s~
*   9 = u b~    10 = c b~    11 = t b~     12 = t4 b~
*  13 = u b4~   14 = c b4~   15 = t b4~    16 = t4 b4~
*  17 = nu e+   18 = nu mu+  19 = nu tau+  20 = nu L+
*............................................................................*
      Implicit None
      INTEGER   J
      integer IT        
*  IT= 1 : top quark,  IT= 2 : W-boson, IT= 3 : H+- boson,  IT= 4 : Z-boson 
* mid(0, IT) is NIDCmax, i.e. max. number of decay channels
*
      include "txpar.inc" 
*...........
      character*4 chl(-1:3)
      data chl /'no  ','OFF ','W+W-','W+  ','W-  '/
*.....
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
*
      if(.NOT.first) return 
      first=.FALSE.
       IT = 2
       do J = 1, mid(0, IT) 
       if(mid(j, IT).ge.4) then
          write(*,202) j,it,mid(j, IT) 
 202      format('  TopReX : W_dec_ini: MID(',i2,',',i1,') = ',i2,
     &3x,'could not be used')
          STOP
        endif   
       enddo

       BRS(1, IT) = 0.0d0   ! W+
       BRS(2, IT) = 0.0d0   ! W-
      do J = 1, mid(0, IT)
        if(Mid(j,IT).eq.1.OR.Mid(j,IT).eq.2) 
     &     BRS(1,IT) = BRS(1,IT) + brf(j, IT)        ! W+
        if(Mid(j,IT).eq.1.OR.Mid(j,IT).eq.3) 
     &     BRS(2,IT) = BRS(2,IT) + brf(j, IT)        ! W-
      enddo 
      write(*, 71)
 71   format(/,'   TopReX : W decay channels contributed to width',/
     &,        '   ----------------------------------------------')
       write(*, 172) (chl(mid(j, IT)),j = 1,3),
     &                  (chl(mid(j, IT)),j = 5,7),
     &                  (chl(mid(j, IT)),j = 9,11),
     &                  (chl(mid(j, IT)),j = 17,19)
 172  format(2x,'U Dbar: ',a4,'  C Dbar: ',a4,'  T Dbar: ',a4,/,
     &       2x,'U Sbar: ',a4,'  C Sbar: ',a4,'  T Sbar: ',a4,/,
     &       2x,'U Bbar: ',a4,'  C Bbar: ',a4,'  T Bbar: ',a4,/,
     &       2x,'NU   E: ',a4,'  NU  MU: ',a4,'  NU tau: ',a4)

      WRITE(*,201) (BRS(j,IT),j=1,2)
 201  format(/,'  TopReX : branching for W-boson',/
     &,'  W+      ',1p,d10.3,/
     &,'  W-      ',d10.3)
      return
      end 
c----------------------------------------------------------------------------c
*... authors: Lars Sonnenschein   and Serge Slabospitsky 27/02/2001          *
      subroutine Res_branch (IT, kf, idc) 
*     -------------------------------------                                  *
* returns No. of resonance decay mode  (see PYTHIA)                          * 
* We consider the case of FACTORIZED  resonance  decays                      *
* Input:  kf is KF code of resonance                                         *
* Output: IDC  is Individual Decay Channel                                   *
*............................................................................*
      Implicit none
      double precision PYR
* first parameter in MID, BRF, FID, and BRS has the meaning as follows
*     IT  = 1 : top quark,  IT = 2(5)  : W-boson, 
*     IT  = 3 : H+- boson,  IT = 4     : Z-boson 
* mid(0, i) is NIDCmax, i.e. max. number of decay channels
*
      include "txpar.inc" 
*...........
      integer IT, kf, idc, J, N1 
      double precision Brnd 
      double precision  BRHT 
      double precision Hgw !,    brtqw  ! additional BR
      common /HTdecp/  Hgw(2) !, brtqw(0:2) 
*.....
      if(IT.eq.1) goto 101    ! top quark
      if(IT.eq.3) goto 103    ! H+- boson
      if(kf.gt.0) then
       Brnd = BRS(1, IT)
       n1   = 2 
      else
       Brnd = BRS(2, IT) 
       n1   = 3 
      endif
      Brnd = Brnd*pyr(0) 
       do J = 1, MID(0, IT)
        if(Mid(J, IT).EQ.1.OR.Mid(J, IT).EQ.N1) then 
           BRND = BRND - BRF(J, IT)
        endif 
         IF (BRND.LE.0.0d0) goto 311
        enddo 
      if(J.gt.mid(0, IT)) then
       print*,'   RES_branch: IDC exhausted. Stop running'
       STOP 
      endif
 311    continue
      idc = J
      return
******--------- TOP-quark decay channles 
 101  if(kf.gt.0) then
       Brnd = BRS(1,IT)   ! top 
       n1   = 2 
      else
       Brnd = BRS(2,IT)   ! topbar
       n1   = 3 
      endif
      if(BRND.le.0.0d0) then
       write(*,1221) 
 1221  format('   total BR for top quark less than 0: stop running')
       STOP
      endif
      Brnd = Brnd*pyr(0) 

       do J = 1, MID(0, IT)
        if(MID(J, IT).eq.-1) goto 749
          BRHT = BRF(J, IT)
           if(J.eq.1.or.J.eq.2.or.J.eq.3)
     &                           BRHT = BRHT * BRS((n1-1),2)
           if(J.eq.5)            BRHT = BRHT * Hgw(n1-1)
           if(J.eq.6)            BRHT = BRHT * BRS((n1-1),2)
           if(J.eq.15.or.J.eq.16.or.J.eq.17.or.J.eq.18) 
     &                           BRHT = BRHT * BRS(1,4) 
        if(Mid(J, IT).EQ.1.OR.Mid(J, IT).EQ.N1) then 
           BRND = BRND - BRHT 
        endif 
         IF (BRND.LE.0.d0) goto 312
 749     continue
        enddo 
      if(J.gt.mid(0, IT)) STOP 
 312  continue
      idc = J
      return
*******------- H+- boson decay channels
 103  if(kf.gt.0) then
       Brnd = BRS(1,IT)   ! H+ boson 
       n1   = 2 
      else
       Brnd = BRS(2,IT)   ! H- boson 
       n1   = 3 
      endif
      if(BRND.le.0.d0) then
       write(*,1222) 
 1222  format('   total BR for H+- boson less than 0: stop running')
       STOP
      endif
      Brnd = Brnd*pyr(0) 
       do J = 1, MID(0, IT)
           BRHT = BRF(J, IT)
           if(J.eq.11) BRHT = BRHT * BRS((n1-1), 2)  ! due to W-boson
        if(Mid(J, IT).EQ.1.OR.Mid(J, IT).EQ.N1) then 
           BRND = BRND - BRHT 
*           BRND = BRND - BRF(J, IT)
        endif 
         IF (BRND.LE.0.d0) goto 314
        enddo 
      if(J.gt.mid(0, IT)) STOP 
 314  continue
      idc = J
      return

      end
c----------------------------------------------------------------------------c
*... author  :  Serge Slabospitsky                                           *
*... 10.03.2002                                                              *
*   Top decays                                                               *
*----------------------------------------------------------------------------*
      subroutine T_dec_ini 
*     --------------------                                                   *
* calculate top decay width                                                  *
* t -> H+- b  not considered here                                            *
*............................................................................*

      implicit None
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
*............................................................................*
* first parameter in MID, BRF, FID, and BRS has the meaning as follows
*     IRES = 1 : top quark,  IRES = 2 : W-boson, 
*     IRES = 3 : H+- boson,  IRES = 4 : Z-boson 
* mid(0, i) is NIDCmax, i.e. max. number of decay channels
*
      integer IT, I
      double precision wfcnc(0:6) 
      double precision twidnew 
      double precision topwid
*.............. 
      TwidNew = 0.d0   ! decay width due to uncalculated channels
*............................................................................*
* 1 : d W (SM), 2: s W (SM), 3: b W (SM)                                     *
* 5 : b H+-, 6 : b H+- (T*)                                                  *
* 11:16 FCNC couplings, see FCNC_INI                                         *
* 11(12) = U(C) gluon,  13(14) = U(C) gamma,  15(16) = U(C) Z                *
* here we calculate only SM and FCNC decays                                  *
*............................................................................*

      call FCNC_READ       ! read parameters 

      Rpar(30) = TopWid(1, mq(6))    ! SM top quark decay t -> d W 
      Rpar(31) = TopWid(3, mq(6))    ! SM top quark decay t -> s W 
      Rpar(32) = TopWid(5, mq(6))    ! SM top quark decay t -> b W 
      Rpar(34) = Rpar(30) + Rpar(31) + Rpar(32) ! total top quark width

      IT = 1
        call FCNC_INI(wfcnc)    ! initialisation of FCNC

      if(mid(1, it).eq.-1) mid(1, it) = 0  ! SM always contributes to t width
      if(mid(2, it).eq.-1) mid(2, it) = 0  ! SM always contributes to t width
      if(mid(3, it).eq.-1) mid(3, it) = 0  ! SM always contributes to t width
      do I = 0, ndch 
        wid(I, it) = 0.d0
      enddo
       wid(1, IT) = Rpar(30) ! t -> d W
       wid(2, IT) = Rpar(31) ! t -> s W
       wid(3, IT) = Rpar(32) ! t -> b W
* fcnc
      do i = 1,6
         if(MID((10+i), it).ge.0) wid((10+i), it) = wfcnc(i) 
      enddo
      wid(0, it) = TwidNew   ! total top decay width
       do i = 1, MID(0, it)
        if(MID(i, it).ne.-1) wid(0, it) = wid(0, it) + wid(i,it) 
       enddo
      RETURN
      END
*----------------------------------------------------------------------------*
*... author  :  Serge Slabospitsky                                           *
*... 10.03.2002                                                              *
*   Top decays                                                               *
*----------------------------------------------------------------------------*
      subroutine THC_dec_INI 
*     --------------------                                                   *
* it is assumed, that FIRST/SECOND top is TOP(antiTOP)-quark                 *
* we consider the case of FACTORIZED  top quark decays                       *
* two probabilities WGT(1 : Top) and WGT(2 : Topbar) are returned            *
* three summed branching fractions BS(3) are considered                      *
* bs(1:3) = sum over all channels with MDT = 1,2,3                           *
*  W and H bosons branching fractions are included                           *
* FDT(...,1(2)) is KF code for first(UP) (second=Down) f f~ in top decay    *
*............................................................................*

      implicit None
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
*............................................................................*
      double precision Hgw !,    brtqw  ! additional BR
      common /HTdecp/  Hgw(2) !, brtqw(0:2) 
*
      double precision bX(3),  bW(3),  bH(3), bHS(3), bz(3) 
* first parameter in MID, BRF, FID, and BRS has the meaning as follows
*     IT = 1 : top quark,  IT = 2 : W-boson, 
*     IT = 3 : H+- boson,  IT = 4 : Z-boson 
*...........
      integer IT, I, J, j8
      double precision bht(5), bhx(5)
      double precision  widt0,widt1,delt, widh0,widh1,delh
      double precision  htb,thb, thbts 
      double precision  delh0, delt0 
      data delh0 / 0.05d0/, delt0 /0.05d0/

      double precision  twidnew   ! , wbwz
      character*4 ctl(-1:3)
      data ctl /'no  ','OFF ','T T~','T   ','  T~'/


      Character*32 INAMT(16)
      data INAMT /
     &' t -> d  W                      ',  !  1
     &' t -> s  W                      ',  !  2
     &' t -> b  W                      ',  !  3
     &' t -> b4 W  forbidden           ',  !  4
     &' H+-     : t -> b H+ (without t)',  !  5
     &' H+-     : t -> b H+ (H+ -> t* )',  !  6
     &' channel is not used            ',  !  7
     &' channel is not used            ',  !  8
     &' channel is not used            ',  !  9
     &' channel is not used            ',  ! 10
     &' FCNC    : t -> U gluon         ',  ! 11
     &' FCNC    : t -> C gluon         ',  ! 12
     &' FCNC    : t -> U gamma         ',  ! 13
     &' FCNC    : t -> C gamma         ',  ! 14
     &' FCNC    : t -> U Z             ',  ! 15
     &' FCNC    : t -> C Z             '/  ! 16
      character*4 chl(-1:3)
      data chl /'no  ','OFF ','H+H-','H+  ','H-  '/
      character*14 INAMH(20)
      data INAMH /
     &' U      Dbar  ', ' C      Dbar  ', ' T      Dbar  ', 
     &' t4     Dbar  ', ' U      Sbar  ', ' C      Sbar  ', 
     &' T      Sbar  ', ' t4     Sbar  ', ' U      Bbar  ', 
     &' C      Bbar  ', ' T*     Bbar  ', ' t4     Bbar  ', 
     &' U      b4bar ', ' C      b4bar ', ' T      b4bar ', 
     &' t4     b4bar ', 
     &' nu_e   e     ', ' nu_mu  mu    ', ' nu_tau tau   ', 
     &' nu_L   L     '/ 
*   H+- IDC 
*  1: U   Dbar   2: C    Dbar   3: T     Dbar   4: t4   Dbar  
*  5: U   Sbar   6: C    Sbar   7: T     Sbar   8: t4   Sbar 
*  9: U   Bbar  10: C    Bbar  11: T*    Bbar  12: t4   Bbar 
* 13: U  b4bar  14: C   b4bar  15: T    b4bar  16: t4   b4bar
* 17: NUe e     18: NUmu mu    19: NUtau tau   20: nuL4 L4

*.............. 
      integer itest
      TwidNew = 0.d0   ! decay width due to uncalculated channels
*............................................................................*
* 1 : d W,  2 : s W, 3 : b W                                                 *
* 5 : b H+, 6 : b H+ (-> t*)                                                 *
* 11:16 FCNC couplings, see FCNC_INI                                         *
* 11(12) = U(C) gluon,  13(14) = U(C) gamma,  15(16) = U(C) Z                *
*.................................
          
      widt0 = wid(0, 1)   ! top width = SM + FCNC 
      widh0 = wid(0, 3)   ! H+- width = all except top 
      if(mid(5, 1).eq.-1) goto 1112  ! no interactions with top
      itest = 0
       write(66,1445) rpar(51), rpar(55)
 1445  format('  M(H+-) ',e10.4,'  tan(beta) ',e10.4,/)
 1111  Rpar(36) = widt0 * mq(6)    ! M(top) * width(top total)
       rpar(54) = Rpar(51) * widh0 ! M(H+-) * width(H+- total)
           call HTB_dec(Htb)  ! H+ -> t b~ (normalized Gamma_t(total)
       itest = itest + 1
        widH1 = wid(0, 3) + htb
         wid(11, 3) = Htb
           call THB_dec(Rpar(54), Thb) 
           call THBTS_dec(rpar(54), rpar(36), Thbts) 
        widT1 = wid(0, 1) + Thb + Thbts
         wid(5, 1) = Thb     ! t -> b H+
         wid(6, 1) = Thbts   ! t -> b H+(->t*)
       delh = abs( (widh0 - widh1)/widh0) 
       delt = abs( (widt0 - widt1)/widt0)
       write(66,1444) itest, widH1, wid(0,3), htb, 
     & widT1, wid(0,1),thb,thbts 
 1444  format(2x,'Iter',1x,i5,' H(tot) H   Htb      ',3(e10.4,1x)
     & ,/, 12x,' T(tot) TSM Thb THT* ',4(e10.4,1x))
      if(delh.ge.delh0.or.delt.ge.delt0) then 
        widT0 = widT1
        widH0 = widH1
        goto 1111
      endif
         wid(0, 3) = widH1 
         wid(0, 1) = widT1 
 1112 continue
         rpar(53) = wid(0, 3) 
         rpar(54) = Rpar(51) * Rpar(53)  ! M(H+-) * width(H+- total)
*
      rpar(34) = wid(0, 1)
      Rpar(36) = mq(6) * rpar(34) ! M(top) * width(top total) 
*      
      it = 1   !  top
        do i = 1, mid(0, it)
         brf(I, it) = 0.d0
         if(MID(i, it).ne.-1) BRF(I, it) = wid(i,it) / wid(0,it) 
        enddo
* WARNING: we ignore FCNC top decay channels in H+- -> b t* decay
      it = 3   ! H+-
        do i = 1, mid(0, it)
         brf(I, it) = 0.d0
         if(MID(i, it).ne.-1) BRF(I, it) = wid(i,it) / wid(0,it) 
        enddo
         do j8 = 1,3
           bW(j8) = 0.d0
           bHX(j8) = 0.d0
           bHT(j8) = 0.d0
         enddo
      do 512 I = 1, mid(0, it)
        if (Mid(I, it).eq.0.OR.Mid(I, it).eq.-1) goto 512
          do 513 j = 1,3
           if(Mid(I, it).ne.j) goto 513
             if(I.eq.11) then
               bht(j) = bht(j) + brf(I, it)  ! H+- -> b T*
             else
               bhx(j) = bhx(j) + brf(I, it)  ! H+- -> f1 f2 
            endif 
 513      continue 
 512      continue 


      BRS(1,it) =  bhx(1) + bhx(2)              ! H+ -> ...
     &          + (bht(1) + bht(2)) * BRS(1,2)  !brtqw(1)  ! H+ -> top 
      BRS(2,it) =  bhx(1) + bhx(3)              ! H- -> ...
     &          + (bht(1) + bht(3)) * BRS(2,2)  !brtqw(2)  ! H- -> top 

      Hgw(1)    =  bhx(1) + bhx(2)              ! H+ -> f1 f2 
      Hgw(2)    =  bhx(1) + bhx(3)              ! H- -> f1 f2 
      if(BRF(11,3).le.0.9999999d0) then      ! correct for H+ -> T*
        Hgw(1) = Hgw(1) / (1.d0 - BRF(11,3)) ! correct for H+ -> T*
        Hgw(2) = Hgw(2) / (1.d0 - BRF(11,3)) ! correct for H+ -> T*
      endif

      j = -1
      do I = 1, mid(0, it)
       if(mid(I, it).ge.0) j = 0
      enddo
      if((j.eq.-1).OR.
     & (ipar(1).eq.5.or.ipar(1).eq.6.or.ipar(1).eq.7).OR.
     &((ipar(1).eq.1.or.ipar(1).eq.2.or.ipar(1).eq.3.or.
     &  ipar(1).eq.11.               or.ipar(1).eq.4.or.
     &  ipar(1).eq.20.or.
     &  ipar(1).eq.25.or.ipar(1).eq.25).AND.
     &  mid(5, 1).eq.-1)) then 
*       write(*, 74)  
 74    format(/,3x,'TopReX :  no H+- interaction',/,
     &          3x,'----------------------------') 
       goto 2567 

      endif
*       
      write(*, 75) Rpar(51), Rpar(55) ! , Rpar(35) 
 75   format(/,3x,'TopReX :  charged Higgs',/,
     &         3x,'-----------------------',/,
     &3x,'M(H+-) = ',f6.1,'  tan(beta) = ',f7.3,5x,/, 
     &3x,' channel',14x,'ON/OFF',2x,'width(GeV)',2x,'branching')

      do I = 1, mid(0, it)
       if(mid(I, it).ge.0) then 
        write(*, 76)  inamh(I),chl(mid(I,it)),wid(I,it),brf(I,it)
       endif
      enddo
 76   format(1p,3x,a14,10x,a4,1x,d10.3,2x,0p,e10.3) 
      write(*,77) wid(0,it) 
 77   format(3x,'total H+- width (GeV)   = ',3x,1p,e10.3)

      write(*,202) (BRS(i,it),i=1,2)
 202  format(/,'  TopReX : branching for H+- boson',
     &' including BR(W) from T*', /
     &,'  BR(H+ -> all) = ',0p,e10.3,6x,'  BR(H- -> all) = ',e10.3)

* for ID = 1:3       W-boson decay branching fractions are included
* for ID = 5:6       H-boson decay branching fractions are included
* for ID = 11:18     Z-boson decay branching fractions are included

************** TOP-QUARK **************************
 2567  continue
        do j8 = 1,3
         bW(j8) = 0.d0 
         bH(j8) = 0.d0 
         bHs(j8) = 0.d0 
         bZ(j8) = 0.d0 
         bX(j8) = 0.d0 
        enddo
      IT = 1    ! top quark
      do i = 1, mid(0, it) 
       if(MID(I, it).ne.0.AND.MID(I, it).ne.-1) then 
        do J = 1,3
         if(MID(I, it).eq.j) then
           if(i.eq.1.or.i.eq.2.or.i.eq.3)  then
              bw(j) = bw(j) + brf(I, it)   ! final state: W-boson 
           elseif(i.eq.5)        then
              bh(j) = bh(j) + brf(I, it)   ! final state: H+- -> f1f2
           elseif(i.eq.6)        then
              bhs(j) = bhs(j) + brf(I, it) ! final state: H+- -> b T*
           elseif(i.eq.15.or.i.eq.16.or.i.eq.17.or.i.eq.18) then
              bz(j) = bz(j) + brf(I, it)   ! t -> q Z via FCNC interactions
           else
              bX(j) = bX(j) + brf(I, it)   ! no W, H, or Z in the final state
           endif 
        endif
        enddo
       endif
      enddo


* in t -> b H+, H+ -> T* only allowes W-boson channels is considered
*  BRS(1,1)  single T
      BRS(1,IT) = (bW(1) + bW(2)) * BRS(1,2)          ! T -> W+
     &          + (bH(1) + bH(2)) * Hgw(1)            ! T -> H+ ->f1 f2
     &          + (bhs(1)+ bhs(2))* BRS(1,2)          ! T -> b H+ -> b T*
     &          + (bZ(1) + bz(2)) * BRS(1,4)          ! T -> Z 
     &          +  bX(1) + bX(2)                      ! T -> X+ 
*  BRS(2,1)  single T~
      BRS(2,IT) = (bW(1) + bW(3)) * BRS(2,2)          ! T~ -> W-
     &          + (bH(1) + bH(3)) * Hgw(2)            ! T~ ->H- ->f1 f2
     &          + (bhs(1)+ bhs(3))* BRS(2,2)          ! T~ -> b H- -> b T*
     &          + (bZ(1) + bz(3)) * BRS(1,4)          ! T~ -> Z 
     &          +  bX(1) + bX(3)                      ! T~ -> X-

      write(*, 71) mq(6)
 71   format(/,'   TopReX : top decays ',/
     &,        '   --------------------',/
     &,        '   m(top) = ',f7.2,' GeV',/,
     &3x,' channel',26x,'ON/OFF',2x,'width(GeV)',2x,'Branching')


      do I = 1, mid(0, it)
       if(mid(I, it).ge.0) then 
        write(*, 78)  inamt(I),ctl(mid(I,it)),wid(I,it),brf(I,it)
       endif
      enddo
 78   format(1p,3x,a32,3x,a4,2x,e10.3,2x,0p,e10.3) 
      write(*,79) rpar(34)
 79   format(3x,'total top width (GeV)',17x,'=',2x,1p,e10.3)

      WRITE(*,603) (BRS(i,1),i=1,2)
 603  format('  branching ratios for top and top_bar quarks ',/
     &,'  BR(T -> all) = ',1p,e10.3,6x,'BR(Tbar -> all) = ',1p,e10.3,
     &//)
      return
      end
*----------------------------------------------------------------------------*
*.. author:   Serge Slabospitsky   10.03.2002                                *
*............................................................................*
      subroutine HC_dec_ini
*     --------------------                                                   *
*                                                                            *
* return charged Higgs decay width (in GeV)                                  *
* decay channels of H+- are considered, H+- ->                               *
* 1 : U Dbar,  2 : C Dbar,  3 : T Dbar,    4 : t4 Dbar                       *
* 5 : U Sbar,  6 : C Sbar,  7 : T Sbar,    8 : t4 Sbar                       *
* 9 : U Bbar,  10: C Bbar,  11: T Bbar,    12: t4 Bbar                       *
* 13: U brbar, 14: C b4bar, 15: T b4bar,   16: t4 b4bar                      *
* 17: nue   e, 18: numu mu, 19: nutau tau, 20: nuL L                         *
* 21: t*(W b) bbar -> W B Bbar, 22:29 reserved for future                    *
* 30: t -> B H                                                               *
*                                                                            *
*............................................................................*

      implicit none
      include "txpar.inc" 
      double precision mql,       mql2
      common  /massql/ mql(0:20), mql2(0:20)
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6

      double precision mh, tb, ctb, a, b, del !, rt !, rw, tww21
      double precision VCKM2
      common  /CKMD/ VCKM2(-6:6,-6:6)

* first parameter in MID, BRF, FID, and BRS has the meaning as follows
      integer IT        
*     It = 1 : top quark,  It = 2 : W-boson, 
*     It = 3 : H+- boson,  It = 4 : Z-boson 
*...........
      integer i,j,iu,id, nnn
      double precision  widnew   ! width to new decay channels
*............................................................................*
*..Rpar(51)     : Charged Higgs Mass                                         *
*..Rpar(53)     : total charged Higgs decay width                            *
*..Rpar(55)     : MSSM's tan(beta)                                           *

      double precision HCPL,       HCPL2   
      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)

*..HCPL(1)  = (m(D)/M_W) * tan(beta)     HCPL(2) = (m(U)/M_W) * cot(beta)    *
*..HCPL(3)  = (m(S)/M_W) * tan(beta)     HCPL(4) = (m(C)/M_W) * cot(beta)    *
*..HCPL(5)  = (m(B)/M_W) * tan(beta)     HCPL(6) = (m(T)/M_W) * cot(beta)    *
*..HCPL(11) = (m(e)/M_W)   *tan(beta) HCPL(12) = (m(nu_e)/M_W) * cot(beta)   *
*..HCPL(13) = (m(mu)/M_W)  *tan(beta) HCPL(14) = (m(nu_mu)/M_W) * cot(beta)  *
*..HCPL(15) = (m(tau)/M_W) *tan(beta) HCPL(16) = (m(nu_tau)/M_W) * cot(beta) *
*............................................................................*
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
*...............................    
      if(.NOT.first) return 
      first=.FALSE.
*
      Rpar(52) = Rpar(51)**2 
      Rpar(56) = 1.d0 / Rpar(55)

      It = 3          ! H+- 
      widnew = 0.d0   !  no uncalculated channels are considered
* always supress decays:  H+ -> T Dbar and H+ -> T Sbar
      mid(3, it) = -1
      mid(7, it) = -1
*
      tb  = Rpar(55)
      ctb = Rpar(56) 
      mh  = Rpar(51)
* always supress decays into NEW 4-generation quarks and leptons
      mid( 4, it)  = -1    
      mid( 8, it)  = -1
      mid(12, it) = -1
      mid(13, it) = -1
      mid(14, it) = -1
      mid(15, it) = -1
      mid(16, it) = -1
      mid(20, it) = -1
*   H+-  -> q qbar'
      nnn = 0 
      do j = 1,4
      do i = 1,4
       nnn = nnn + 1
       iu = 2*I
       id = 2*J - 1 
        Fid(it,nnn,1) = +iu
        Fid(it,nnn,2) = -id
       if(mid(nnn, it).eq.-1)        goto 229
        if(abs(iu).eq.6)            goto 229  ! supress t -> b H+
        if((mql(iu)+mql(id)).ge.MH) goto 229 
         a = (mql(id) / mh)**2
         b = (mql(iu) / mh)**2
         del = sqrt(1. + a**2 + b**2 - 2.*(a + b + a*b))
       wid(nnn,IT) = del*(3.* Rpar(26)**2 / (32. *pi * mh))
     &*( (mh**2 - mql2(iu)-mql2(id))*(hcpl2(iu)+hcpl2(id))
     & - 4.d0*hcpl(iu)*hcpl(id)*mql(iu)*mql(id))
       wid(nnn,IT) = WID(nnn,IT) * Vckm2(id,iu)
       goto 230 
 229   wid(nnn,IT) = 0.d0
 230  continue 
      enddo      
      enddo      

*   H+-  -> e nu_e, mu nu_mu, tau nu_tau 
      wid(17,it) = rpar(26)**2 * mh * hcpl2(11) / (32.d0 *pi) 
        Fid(it,17,1) =  12 
        Fid(it,17,2) = -11 
      wid(18,it) = rpar(26)**2 * mh * hcpl2(13) / (32.d0 *pi) 
        Fid(it,18,1) =  14 
        Fid(it,18,2) = -13 
      wid(19,it) = rpar(26)**2 * mh * hcpl2(15) / (32.d0 *pi)
        Fid(it,19,1) =  16 
        Fid(it,19,2) = -15 
*
      wid(0,it) = widnew   ! uncalculated width  
      do I = 1, 21
       if(mid(I, it).ne.-1)  wid(0,it) = wid(0,it) + wid(I,it)
      enddo
      RETURN
      END
*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   24.06.2006                                 *
*  top quark decay widths via FCNC channels                                  *
*----------------------------------------------------------------------------*
      subroutine FCNC_INI(tw) 
*     -------------------                                                    *
*                                                                            *
* anomalous couplings, see 'Top quark physics", hep-ph/0003033, M.Beneke     *
* parameters for each type (i.e. F + H gamma_5)                              *
* parameterization assumed  Ubar(t) ... ( F + H gamma_5) u(q)                *
* return the top decay width (in GeV)                                        *
*............................................................................*

      implicit none
      include "txpar.inc" 
      double precision mq,       mq2
      common  /massql/ mq(0:20), mq2(0:20)
      double precision als
      double precision tw(0:6) 
      integer I, JJ, KZ
      double complex   FL,     FR,      HL,    HR,
     &                 XL,     XR,      YL,    YR
      common /ANOMCPL/FL(20), FR(20), HL(20), HR(20), 
     &                XL(20), XR(20), YL(20), YR(20) 
      double precision rl1, rl2, rl3, xz
*............................................................................*
*..Rpar(30)     : width of t-> d  W decay at tree level (SM case)            *
*..Rpar(31)     : width of t-> s  W decay at tree level (SM case)            *
*..Rpar(32)     : width of t-> b  W decay at tree level (SM case)            *
*..Rpar(33)     : width of t-> b4 W decay at tree level (SM case)            *
*..Rpar(34)     : total t-quark decay width                                  *
*..Rpar(50)     : New Physics scale (1 TeV), FCNC                            *
*... FCNC          t GLUON q                                                 *
*............................................................................*
*
* setting KF codes for final particles in top FCNC decay
      
      FID(1,11,1) = 2   ! Up
      FID(1,11,2) = 21  ! gluon 
      FID(1,12,1) = 4   ! C 
      FID(1,12,2) = 21  ! gluon 

      FID(1,13,1) = 2   ! Up
      FID(1,13,2) = 22  ! photon 
      FID(1,14,1) = 4   ! C 
      FID(1,14,2) = 22  ! photon

      FID(1,15,1) = 2   ! Up
      FID(1,15,2) = 23  ! Z-boson 
      FID(1,16,1) = 4   ! C 
      FID(1,16,2) = 23  ! Z-boson
      FID(1,18,2) = 23  ! Z-boson
*
      if(MID(15, 1).ge.1.or.MID(16, 1).ge.1) then
      if(mid(7,  4).ge.1) mid(7,  4) = 0  ! supress b4 
      if(mid(8,  4).ge.1) mid(8,  4) = 0  ! supress t4
      if(mid(15, 4).ge.1) mid(15, 4) = 0  ! supress L4
      if(mid(16, 4).ge.1) mid(16, 4) = 0  ! supress nu_L4
       endif
                      
      if(  MID(11, 1).eq.-1.and.MID(12, 1).eq.-1
     &.and.MID(13, 1).eq.-1.and.MID(14, 1).eq.-1
     &.and.MID(15, 1).eq.-1.and.MID(16, 1).eq.-1) then
*      write(*, 175) 
 175  format(/,3x,'TopReX : no FCNC interactions',/,
     &         3x,'-----------------------------',/)
      return
      endif
*
      als = 0.1     ! we set alpha_s = 0.1
       do I = 1,6
        tw(I) = 0.d0
       enddo      
* t -> gluon U 
       JJ = 11
      if(mid(jj,1).ge.0) then
       tw(1) = 
     & 16.d0*(HR(jj)*conjg(HR(jj)) + HL(jj)*conjg(HL(jj)))
     & + mq2(6)*(XR(jj)*conjg(XR(jj)) + XL(jj)*conjg(XL(jj)))
     & -4.d0*mq(6)*
     &       (HR(jj)*conjg(XR(jj)) + XR(jj)*conjg(HR(jj))
     &      + HL(jj)*conjg(XL(jj)) + XL(jj)*conjg(HL(jj)))
       TW(1) = tw(1) * als * mq(6)**3 / 12.d0
      else
       tw(1) = 0.d0
      endif 
* t -> gluon C
       JJ = 12
      if(mid(jj,1).ge.0) then
       tw(2) = 
     & 16.d0*(HR(jj)*conjg(HR(jj)) + HL(jj)*conjg(HL(jj)))
     & + mq2(6)*(XR(jj)*conjg(XR(jj)) + XL(jj)*conjg(XL(jj)))
     & -4.d0*mq(6)*
     &       (HR(jj)*conjg(XR(jj)) + XR(jj)*conjg(HR(jj))
     &      + HL(jj)*conjg(XL(jj)) + XL(jj)*conjg(HL(jj)))
       TW(2) = tw(2) * als * mq(6)**3 / 12.d0
      else
       tw(2) = 0.d0
      endif 
* t -> gamma U 
       JJ = 13
      if(mid(jj,1).ge.0) then
       tw(3) = 
     & 16.d0*(HR(jj)*conjg(HR(jj)) + HL(jj)*conjg(HL(jj)))
     & + mq2(6)*(XR(jj)*conjg(XR(jj)) + XL(jj)*conjg(XL(jj)))
     & -4.d0*mq(6)*
     &       (HR(jj)*conjg(XR(jj)) + XR(jj)*conjg(HR(jj))
     &      + HL(jj)*conjg(XL(jj)) + XL(jj)*conjg(HL(jj)))
       TW(3) = tw(3) * rpar(11) * mq(6)**3 / 16.d0
      else
       tw(3) = 0.d0
      endif 
* t -> gamma C 
       JJ = 14
      if(mid(jj,1).ge.0) then
       tw(4) = 
     & 16.d0*(HR(jj)*conjg(HR(jj)) + HL(jj)*conjg(HL(jj)))
     & +      XR(jj)*conjg(XR(jj)) + XL(jj)*conjg(XL(jj))
     & -4.d0*(HR(jj)*conjg(XR(jj)) + XR(jj)*conjg(HR(jj))
     &      + HL(jj)*conjg(XL(jj)) + XL(jj)*conjg(HL(jj)))
       TW(4) = tw(4) * rpar(11) * mq(6)**3 / 16.d0
      else
       tw(4) = 0.d0
      endif 
* t -> Z U 
      xz = Rpar(46)/mq2(6)
      TW(5) = (rpar(11) * mq(6)**3/4.d0/Rpar(46)/Rpar(25)**2) 
     & * (1.d0 - xz)**2
      KZ = 15
      RL1=FL(kz)*conjg(FL(kz)) + FR(kz)*conjg(FR(kz))
      RL2=HR(kz)*conjg(HR(kz)) + HL(kz)*conjg(HL(kz))
      RL3=FR(kz)*conjg(HR(kz)) + FL(kz)*conjg(HL(kz))
     &   +HR(kz)*conjg(FR(kz)) + HL(kz)*conjg(FL(kz))
      TW(5) = TW(5) *
     &(  RL1 * (1.d0 + 2.d0*xz) 
     & + RL2 * 4.d0 * mq2(6) * xz * (2.d0 + xz)
     & - RL3 * 6.d0 * mq(6) * xz )
* t -> Z C,   gamma-coupling
      xz = Rpar(46)/mq2(6)
      TW(6) = (rpar(11) * mq(6)**3/4.d0/Rpar(46)/Rpar(25)**2) 
     & * (1.d0 - xz)**2
      KZ = 16
      RL1=FL(kz)*conjg(FL(kz)) + FR(kz)*conjg(FR(kz))
      RL2=HR(kz)*conjg(HR(kz)) + HL(kz)*conjg(HL(kz))
      RL3=FR(kz)*conjg(HR(kz)) + FL(kz)*conjg(HL(kz))
     &   +HR(kz)*conjg(FR(kz)) + HL(kz)*conjg(FL(kz))
      TW(6) = TW(6) *
     &(  RL1 * (1.d0 + 2.d0*xz) 
     & + RL2 * 4.d0 * mq2(6) * xz * (2.d0 + xz)
     & - RL3 * 6.d0 * mq(6) * xz )
**
      TW(0) = 0.d0
      do i = 1,6
       if(mid((I+10), 1).lt.0) tw(i) = 0.d0
        tw(0) = tw(0) + tw(i)
      enddo  
      write(*, 75) Rpar(50)
 75   format(/,3x,'TopReX :  FCNC couplings and  widths',/,
     &         3x,'------------------------------------',/,
     &3x,'New Physics scale  Lambda = ',f8.2,' GeV') 
      
      if(mid(11,1).ge.0.OR.mid(12,1).ge.0) then
       write(*,*) '  FCNC:  q GLUON T '
       write(*,74) tw(1),tw(2) 
      endif
      if(mid(13,1).ge.0.OR.mid(14,1).ge.0) then
       write(*,*) '  FCNC:  q PHOTON T '
       write(*,74) tw(3),tw(4)
      endif 
      if(mid(15,1).ge.0.OR.mid(16,1).ge.0) then
       write(*,*) '  FCNC:  q Z T '
       write(*,74) tw(5),tw(6)
      endif
       write(*,79)  tw(0)
 74   format('   Width U ',d9.3,1x,'Width C ',d9.3)
 79   format(
     &3x,'total t-quark FCNC decay width = ',d10.3,' GeV')

      return
      end
*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   10.03.2002                                 *
*.... top decay into b and H+- (-> f1(L1) f2(L2))                            *
* summed over ALL channels (includeing colors for q qbar'                    *
      subroutine THB_dec(gamh, gtot) 
*     ------------------------------                                         *
*                                                                            *
*    LIPS_3 with denominator due to H-boson                                  *
*  all momenta in top rest frame                                             *
*  width is normalized to t -> b tau NU_tau                                  *
*                                                                            *
*    |M|**2     R3(R -> B f f`~)                                             *
*  --------------------------------                                          *
*  [(pH^2 - mH^2)^2 + (G_H * mH)^2]                                          *
*                                                                            *
*     p -> b   H (-> Nu_tau Tau)                                             *
*     R    k   Ph    L1     L2                                               *
*... input :                                                                 *
*   ID = 1,2,...,21 is type of H+- decay channel                             *
*   KF = 6 (-6)  is top flavor                                               *
*    MT is initial top mass,  lepton and neutrino denoted two final fermions *
*    resulted from H-boson decay                                             *
*                                                                            *
*... output :                                                                *
*  Q, L, and N are 5-momenta of final quark, lepton, and neutrino            *
*  in the top REST frame                                                     *
*  ves is the weight                                                         * 
*  DH(3)  is 3-momentum of polarisation vector                               *
*............................................................................*

      implicit none
      include "txpar.inc" 
      double precision P(5), K(5), L1(5), L2(5), ph(5) 
      double precision ves, vs1, axa, scalp, coef
*...........
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      Integer I, ID, J1, J2, IRES 
      double precision HCPL,       HCPL2   
      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)
      double precision aa1, bb1, pmm(2),p2s, gamh, gtot ! , gtbh
      double precision VCKM
      common  /CKMD/ VCKM(-6:6,-6:6) ! CKM**2
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
* 
       ires = 3  ! H+-
      coef = (pi2_3/2.d0) * rpar(26)**4 
      coef = coef * pi2_6 / 2.d0 / mq(6) 

      aa1 = hcpl2(5) + hcpl2(6)
      bb1 = 2.d0 * hcpl(5)*hcpl(6)*mq(5)*mq(6)
      pmm(1) = rpar(70) + 2.0   ! pmin
      pmm(2) = mq(6) - mq(5)     ! pmax
      gtot = 0.d0
      p(4) = mq(6) 
      p(5) = p(4)
      k(5) = mq(5)
      ID = 0
 222  ID = ID + 1
      IF(ID.GT.mid(0, ires)) goto 112

      if(mid(ID,  ires).eq.-1) goto 115
        J1 = ABS(FID(ires,id,1))
        J2 = ABS(FID(ires,id,2))
        if(j1.eq.6.or.j2.eq.6) goto 115
        L1(5) = mq(J1)
        L2(5) = mq(J2) 
      DO I = 1, Ipar(53)
      call brtwig(pmm, rpar(51), gamh, VS1, p2s)
       VES = VS1
      ph(5)= p2s
      call LIPS2 (p,   k, ph, VS1)
       VES = VES * VS1
      call LIPS2 (ph, l1, l2, VS1)
       VES = VES * VS1
       AXA = (BB1  + AA1 * scalp(p,k)) 
     & * ((hcpl2(J1)+hcpl2(J2)) * scalp(l1,l2)
     &  -2.d0*l1(5)*l2(5)*hcpl(J1)*hcpl(J2))
       VES = VES * coef * AXA 
      if(j1.le.6) ves = ves * 3.d0 * vckm(j1,j2) 
      gtot = gtot + ves 
      ENDDO 
 115  goto 222
 112  gtot = gtot / ipar(53)

      return
      end
*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   10.03.2002                                 *
*.... H+- decay into t* (-> b W* => b f1 f2) + bbar                          *
*   is normalized to the TOTAL top-quark decay width                         *
      subroutine HTB_dec(gtot) 
*     ------------------------                                               *
*   H(ph) -> Bbar(q1) t*(p)(-> b(k1) W*(pw)(-> nu(l2) l+-(l1)))              *
*............................................................................*

      implicit none
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/   mq(0:20), mq2(0:20)
      double precision CKM2
      common /CKMD/    CKM2(-6:6,-6:6)
      double precision HCPL,       HCPL2   
      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)
*...........
      double precision  L1(5), L2(5), K1(5), q1(5) 
      double precision Ves, gtot, dh(3), mhs, ph(5), coef
      integer id,ii  
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
* 
        Gtot = 0.d0
      coef = pi2_4 / 2.d0 
   
      mhs = rpar(51) 
      ph(5) = mhs
      ph(4) = ph(5)
      do 225 id = 1,mid(0, 2) 
       if(mid(ID, 2).le.-1) goto 225
      DO ii = 1, ipar(53)
       call HPM_ME_03(id, ph, k1, q1, l1, l2, dh, ves) 
       ves = ves * coef / mhs
      Gtot = Gtot + ves 
      ENDDO
 225  continue
      Gtot = Gtot / ipar(53) 

      return
      end
*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   10.03.2002                                 *
*.... TOP decay intp b~ H+-, H+- -> t* (-> b W* => b f1 f2) + bbar           *
      subroutine THBTS_dec(gamh, gamt, gtot) 
*     --------------------------------------                                 *
* T(R) -> B(k2) H*(ph) (-> Bbar(q11) T*(p1) (-> B(k1) W*(pw) nu(l1) l+-(l2)  *
*............................................................................*

      implicit none
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/   mq(0:20), mq2(0:20)
      double precision CKM2
      common /CKMD/    CKM2(-6:6,-6:6)
      double precision HCPL,       HCPL2   
      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)
*...........
      double precision p2(5),k2(5),ph(5),k1(5),q1(5),l1(5),l2(5)
      double precision Ves, coef, Vs1, AT1, AT2, scalp
      double precision pmm(2), p2s, gamh, gamt, gtot , dh(3), vesm
      integer I, id 
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
* 
        Gtot = 0.d0
   
      coef = rpar(26)**2 / 2.d0
      coef = coef * pi2_3
      coef = coef * pi2_4 / 2.d0 / mq(6) 
      AT1 = hcpl2(6) + hcpl2(5) 
      AT2 = 2.d0 * mq(5)*mq(6)*hcpl(5)*hcpl(6)

      p2(5) = mq(6)
      p2(4) = p2(5)
      p2(3) = 0.d0
      p2(2) = 0.d0
      p2(1) = 0.d0
      k2(5) = mq(5)  
      pmm(1) = rpar(70) + 2.d0*mq(5)
      pmm(2) = mq(6) - mq(5)


      do 225 id = 1,mid(0, 2) 
       if(mid(id, 2).le.-1) goto 225

      DO i = 1,ipar(53)
      call brtwig(pmm, rpar(51), gamh, VS1, p2s)
       ves = coef * VS1 
       ph(5) = p2s
      call LIPS2 (p2, k2, ph,  VS1) 
       ves = ves * VS1 
       call HPM_ME_03(id, ph, k1, q1, l1, l2, dh, vesm) 
       vesm = vesm * (at1*scalp(p2,k2) + at2)
      Gtot = Gtot + ves * vesm
      ENDDO
 225  continue

      Gtot = Gtot / ipar(53) 

      return
      end
*----------------------------------------------------------------------------*
      subroutine HPM_ME_03(id, ph, k, q, l1, l2, dh, ves) 
*     -------------------------------                                        *
*                                                                            *
*   H+ -> Bbar(q) T*(p), T* -> B(k) W*, W* -> nu,U(l1), tau,Dbar(L2)         *
*   color are includes                                                       *
*   is normalized to the TOTAL top-quark decay width                         *
*............................................................................*

      implicit none

      include "txpar.inc" 
      double precision CKM2
      common /CKMD/    CKM2(-6:6,-6:6)

      double precision p(5), k(5), q(5), l1(5), l2(5), ves, scalp 
      double precision mhs, ph(5)
      double precision mq, mq2
      common/massql/   mq(0:20), mq2(0:20)
      double precision HCPL,       HCPL2   
      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)
*...........
      integer il1, il2, j, id 
      double precision r(5), pw(5), f1(5), f2(5), f3(5), dh(3) 
      double precision lv(4), vh(3,4) 
      double precision coef, AA1(4), AA2(4), AA3(4) 
      double precision p22, pq, rl1, rk, pwr, pwk, pwl1, pw22,l1k 
      double precision pmm(2), vs1, p2s, vem
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
* 
       dh(1) = 0.d0
       dh(2) = 0.d0
       dh(3) = 0.d0
      ves = 0.d0

      mhs = ph(5) 
*      coef = pi2_4 / 2.d0 / mhs 
      coef =  pi2_6 
      coef = coef * (3.d0/2.d0) * rpar(26)**6
      
      K(5) = mq(5) 
      q(5) = mq(5) ! bbar

       il1 = FID(2,id,1) 
       il2 = FID(2,id,2) 
      if(abs(il1).eq.6) return

        l1(5) = mq(abs(il1))        
        l2(5) = mq(abs(il2))        
      pmm(1) = rpar(70) + mq(5)
      pmm(2) = mhs - mq(5)
      call brtwig(pmm, mq(6), rpar(36), VS1, p2s)
       ves = coef * VS1 
       p(5) = p2s
      pmm(1) = rpar(70)
      pmm(2) = p(5) - mq(5)
      call brtwig(pmm, rpar(41), rpar(44), VS1, p2s)
       pw(5) = p2s
       ves = ves * VS1 
      call LIPS2 (ph, q, p,  VS1) 
      ves = ves * VS1 
      call LIPS2 (p,  k, pw,  VS1) 
      ves = ves * VS1 
      call LIPS2 (pw,  l1, l2, VS1) 
      ves = ves * VS1 
*
      p22 = scalp(p, p) 
      pq  = scalp(p, q)

      do j = 1,4
       r(j) = (hcpl2(6)*mq2(6)-hcpl2(5)*p22) * q(j)
     &      + 2.d0 * hcpl2(5)* pq * p(j)
     &      - 2.d0*mq(5)*mq(6)*hcpl(5)*hcpl(6)*p(j)
      enddo

      rl1 = scalp(r, l1) 
      rk  = scalp(r, k)
      pwr = scalp(pw, r) 
      pwk = scalp(pw, k) 
      pwl1= scalp(pw, l1)
      pw22= scalp(pw, pw) 
      l1k = scalp(l1, k)

      do j = 1,4
       f1(j) = rl1* pw(j) + pwl1 * r(j) - pwr * l1(j)
       f2(j) = rk * pw(j) + pwk  * r(j) - pwr * k(j) 
       f3(j) = rk * l1(j) + l1k  * r(j) - rl1 * k(j) 
      enddo

      AA1(1) = 4.d0 * l1k * scalp(r, l2)

      AA2(1) = 4.d0 *pwk  * scalp(l2, f1)
     &       - 4.d0 *pwl1 * scalp(l2, f2)
     &       + 2.d0 *pw22 * scalp(l2, f3)

      AA3(1) = (mq2(abs(il1))+mq2(abs(il2)))*scalp(l1,l2)
     &      * (2.d0*pwk*pwr - pw22 * rk)

      VEM = AA1(1) - AA2(1) / rpar(42) + AA3(1) / rpar(42)**2

      if(abs(il2).ne.15) goto 221 
*
      do J = 1,4
       AA1(j) = 4.d0 * l1k  * r(j) 
       AA2(j) = 4.d0 * pwk  * f1(j)
     &        - 4.d0 * pwl1 * f2(j) 
     &        + 2.d0 * pw22 * f3(j) 
       AA3(j) = (2.d0*pwk*pwr - pw22 * rk)
     &        * (-mq2(15)) * l1(j)

      lv(j) = -( mq(15) / vem) 
     & * (AA1(j) - AA2(j)/rpar(42) + AA3(j)/rpar(42)**2)
      if(il2.eq.15) lv(j) = -lv(j)
      enddo

      call vortas(l2, vh)
       do j = 1,3
        dh(j) = -(lv(4)*vh(j,4) - lv(1)*vh(j,1) - lv(2)*vh(j,2) 
     &                          - lv(3)*vh(j,3))
       enddo

 221  ves = vem  * ves
       if(abs(il1).le.6) ves = ves * 3.d0 * ckm2(il1,il2)

      RETURN
      END
*----------------------------------------------------------------------------*
*.... H+- decay into f1 f2 (excluding top Bbar)                              *
      subroutine HPM_dec_01(id, kf, MHS) 
*     ----------------------------------                                     *
*                                                                            *
*     PH -> f1  f2~                                                          *
*... input :                                                                 *
*   ID = 1,2,...,21 is type of H+- decay channel                             *
*   KF = 37(-37) is H-boson flavor                                           *
*... output :                                                                *
*............................................................................*

      implicit none
      include "txpar.inc" 
      double precision PH(5), F1(5), F2(5), DH(3)
      double precision Ves, Vs1, MHS 
      double precision PYR
      LOGICAL first
      SAVE first 
      DATA first /.TRUE./
      double precision VesMaX(30), aran 
      save VesMaX 
      integer ires
      save ires
*...........
      double precision mq, mq2
      common/massql/   mq(0:20), mq2(0:20)
      integer II, KF, IX, ID, ju, jd, iz 
*      double precision HCPL,       HCPL2   
*      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)
      integer mxdc
      parameter (mxdc=20)   
      integer ndec, kdec, j8,j9
      double precision pdm, pdpl
      common /decmom/ pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)
* 
      do j8 = 1,mxdc
       do j9 = 1,3
          pdm(j8,j9) = 0.d0
         pdpl(j8,j9) = 0.d0
         kdec(j8,j9) = 0
       enddo
          pdm(j8,4) = 0.d0
          pdm(j8,5) = 0.d0
         pdpl(j8,4) = 0.d0
      enddo
      ndec = 2 
      ires = 3
      PH(4) = MHS 
      ph(5) = ph(4)
      if(.NOT.first) goto 114 
       do j9 = 1,30
         vesmax(j9) = 0.d0
       enddo

      do 115 ix = 1,mid(0, ires) 
        if(mid(ix, ires).le.-1)    goto 115
         ju = abs(FID(ires,ix,1))
         jd = abs(FID(ires,ix,2)) 
        if(ju.eq.6.or.jd.eq.6)    goto 115
         f1(5) = mq(ju) 
         f2(5) = mq(jd) 

      do ii = 1, ipar(52)
      call LIPS2 (ph, f1, f2, VS1)
      call HPM_ME_01(ju, jd, f1, f2, dh, ves)
       Ves =  VS1 * ves
       if(Ves.gt.VesMax(ix)) VesMax(ix) = Ves 
      enddo
 115  continue 
      first = .false. 

 114  continue 

        iz =  kf / abs(kf)  ! +1(-1) for top (topbar) 
 116   ju = abs(FID(ires,id,1))
       jd = abs(FID(ires,id,2)) 
        if(ju.eq.6.or.jd.eq.6)    goto 116
         f1(5) = mq(ju) 
         f2(5) = mq(jd) 
      call LIPS2 (ph, f1, f2, VS1)
      call HPM_ME_01(ju, jd, f1, f2, dh, ves)
       Ves =  VS1 * ves
       if(Ves.gt.VesMax(id)) VesMax(id) = Ves 
       aran = VesMax(id) * PYR(0) 
       if(Ves.lt.aran) goto 116
 
       kdec(1,1) = iz * FID(ires, ID, 1) ! NU
       kdec(2,1) = iz * FID(ires, ID, 2) ! L+-

      do II = 1,5
       pdm(1,II) = f1(ii)
       pdm(2,II) = f2(ii)
      enddo

      do II = 1,3
       pdm(20,II) = dh(ii)
      enddo

      return
      end
*----------------------------------------------------------------------------*
      subroutine HPM_ME_01(il1,il2, l1, l2, dh, ves) 
*     -------------------------------                                        *
*                                                                            *
*   H+ -> nu,U(l1) L+,Dbar(L2)                                               *
*   CKM**2 is included
*............................................................................*

      implicit none

      include "txpar.inc" 
      double precision CKM2
      common /CKMD/    CKM2(-6:6,-6:6)
      double precision mq,       mq2
      common/massql/   mq(0:20), mq2(0:20)
      double precision HCPL,       HCPL2   
      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)

      double precision l1(5), l2(5), dh(3), ves, scalp
      double precision lv(4), vh(3,4) 
      integer il1, il2, j
* 
      VES = (hcpl2(il1) + hcpl2(il2))*scalp(l1,l2) 
     & - 2.d0*mq(abs(il1))*mq(abs(il2))*hcpl(il1)*hcpl(il2)

       dh(1) = 0.d0
       dh(2) = 0.d0
       dh(3) = 0.d0
      if(abs(il1).eq.6) then
       do j = 1,4
        lv(j) = ((hcpl2(il1)-hcpl2(il2))*mq(il1)*l2(j))/ves
       enddo
        call vortas(l1, vh)
      do j = 1,3
      dh(j)=lv(4)*vh(j,4)-lv(1)*vh(j,1)-lv(2)*vh(j,2)-lv(3)*vh(j,3)
      if(il1.eq.-6) dh(j) = -dh(j) 
      enddo
      elseif(abs(il2).eq.15) then
       do j = 1,4
        lv(j) = ((hcpl2(il1)-hcpl2(il2))*mq(il2)*l1(j))/ves
       enddo
      call vortas(l2, vh)
      do j = 1,3
      dh(j)=lv(4)*vh(j,4)-lv(1)*vh(j,1)-lv(2)*vh(j,2)-lv(3)*vh(j,3)
      if(il1.eq.-6) dh(j) = -dh(j) 
      enddo
      endif      

       ves = rpar(26)**2 * ves
       if(abs(il1).le.6) ves = ves * 3.d0 * ckm2(il1,il2)
      RETURN
      END
c----------------------------------------------------------------------------c
*********************  top quark decay routines  *****************************
c----------------------------------------------------------------------------c
*.. author : Serge Slabospitsky   17.10.2002                                 *
*... anomalous top decay : FCNC :  t -> q gamma (gluon)                      * 
      subroutine Top_dec_01(id, kf, MT) 
*     -------------------------------------------                            *
*                                                                            *
*  all momenta in top rest frame                                             *
*  |M|**2 is constant                                                        *
*                                                                            *
*     t -> gamma (gluon) + quark                                             *
*     R    q               k                                                 *
*... input :                                                                 *
*  Id = 11(12) : t -> U(C) + gluon                                           *
*  Id = 13(14) : t -> U(C) + photon                                          *
*  KF = 6 (-6)  is top flavor,  MT is initial top mass                       *
*... output :                                                                *
*  K and Q are 5-momenta of final quark and photon (gluon) in top rest frame *
*............................................................................*

      implicit none
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
*...........
      integer mxdc
      parameter (mxdc=20)   
      integer ndec, kdec
      double precision pdm, pdpl, pol(5)
      common /decmom/ pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)
      double precision MT, R(5), k(5), q(5), Ves
      double precision H0(4), X0(4), B0(4), AH(4), AX(4), BB(4) 
      integer idc, I, J, KF, ID, j8,j9
      LOGICAL first
      SAVE first 
      DATA first /.TRUE./
      double complex   FL,     FR,      HL,    HR,
     &                 XL,     XR,      YL,    YR
      common /ANOMCPL/FL(20), FR(20), HL(20), HR(20), 
     &                XL(20), XR(20), YL(20), YR(20) 
*.................................. 

      idc = id - 10
      ndec = 2     ! number of final particles
         
      do j8 = 1,mxdc
       do j9 = 1,3
          pdm(j8,j9) = 0.d0
         pdpl(j8,j9) = 0.d0
         kdec(j8,j9) = 0
       enddo
          pdm(j8,4) = 0.d0
          pdm(j8,5) = 0.d0
         pdpl(j8,4) = 0.d0
      enddo

      IF(first) then 
      if(ipar(33).ge.2) then
       print*,'********************************************'
       print*,'*  IPAR(33) value = ',ipar(33) 
       print*,'*  is implemented for t -> q gamma(gluon)  *'
       print*,'********************************************'
      endif 
        
       do j9 = 1,4
         H0(j9) = 0.d0
         X0(j9) = 0.d0
         B0(j9) = 0.d0
         AH(j9) = 0.d0
         AX(j9) = 0.d0
         BB(j9) = 0.d0
       enddo

       do J = 11, 14
        I = J - 10
        H0(I) = HR(j)*conjg(HR(j)) + HL(j)*conjg(HL(j))
         AH(I) = HL(j)*conjg(HR(j)) - HR(j)*conjg(HL(j))
        X0(I) = XR(j)*conjg(XR(j)) + XL(j)*conjg(XL(j))
         AX(I) = XL(j)*conjg(XR(j)) - XR(j)*conjg(XL(j))
        B0(I) = HR(j)*conjg(XR(j)) + XR(j)*conjg(HR(j))
     &        + HL(j)*conjg(XL(j)) + XL(j)*conjg(HL(j))
         BB(I) = HL(j)*conjg(XL(j)) + XL(j)*conjg(HL(j))
     &         - HR(j)*conjg(XR(j)) - XR(j)*conjg(HR(j))
       enddo

      first = .false. 

      ENDIF

       kdec(2,1) = FID(1,id,1) * kf / abs(kf)   ! for t -> q A quark
       kdec(1,1) = FID(1,id,2)                  ! KF code of gluon or photon 
       k(5)  = mq(ABS(kdec(2,1)))               ! quark
       Q(5)  = 0.d0                             ! gluon(photon)


      R(4) = MT 
      R(5) = R(4)

      call LIPS2 (R,  k, q, VES)
      ves = 16.d0*H0(idc) + x0(idc)*mt**2 - 4.d0*MT*b0(idc)


       pol(4) = 0.d0
       pol(5) = 0.d0
      do I = 1,3
       pol(I) = 
     & 32.d0*AH(idc) + 2.d0*AX(idc)*mt**2 - 8.d0*MT*BB(idc)
       pol(I) = pol(i)*q(i)/MT/ves
       pol(I) = -pol(i) ! transit to 3-dimensional space 
      enddo

      do I = 1,5
       pdm(2,I) = k(i)
       pdm(1,I) = q(i)
       pdm(20,I) = pol(i)
       if(kf.eq.-6) pdm(20,I) = -pdm(20,I) 
      enddo
      return
      end
c----------------------------------------------------------------------------c
*.. author : Serge Slabospitsky   25.10.2002                                 *
*....
      subroutine Top_dec_02(id, kf, MT) 
*     ------------------------------                                         *
*                                                                            *
*     R -> q(ib)  W (-> el nu)                                               *
*     P    q   Pw    L  N                                                    *
*... input :                                                                 *
*  KF = 6 (-6)  is top flavor                                                *
*  MT is initial top mass,  L and N stand for two final fermions from W decay*
*... output :                                                                *
* particle's order in decmom list                                            *
*    1:W  2:B, 3:NU(U), 4: L+-(D)                                            *
*  Q, L, and N are 5-momenta of final quark, lepton, and neutrino            *
*  in the top REST frame                                                     *
*............................................................................*

      implicit none
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer mxdc
      parameter (mxdc=20)   
      integer                      ndec, kdec
      double precision pdm, pdpl
      common /decmom/ pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)
*...........
      double precision MT,P(5),Q(5),L(5),N(5),pw(5),Ves,  PYR,
     &  vesL,  vesR 
      LOGICAL first
      SAVE first 
      DATA first /.TRUE./
      double precision VesMax(5,2), aran, ps1(5) 
      save VesMax 
      integer I, KF, KV, idc, iz, iq, id, ib, iqq,iqt,j8,j9 
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision cos3, nv(3)
      common /nvv/nv
* 
      do j8 = 1,mxdc
       do j9 = 1,3
          pdm(j8,j9) = 0.d0
         pdpl(j8,j9) = 0.d0
         kdec(j8,j9) = 0
       enddo
          pdm(j8,4) = 0.d0
          pdm(j8,5) = 0.d0
         pdpl(j8,4) = 0.d0
      enddo
       ndec = 4
      if(.NOT.first) goto 114 

      do j8 = 1,5
        Vesmax(j8,1) = 0.d0
        Vesmax(j8,2) = 0.d0
      enddo

       P(4) = MT 
       P(5) = P(4)
       l(5) = 0.d0
       n(5) = 0.d0

      do I = 1,  ipar(52)
       do iqt = 1,3
        iqq = 2*iqt - 1
        q(5) = mq(iqq)
        l(5) = 0.d0
        n(5) = 0.d0
        call top_dec_wff(iqq,  p, q, pw, l, n, ps1, ves)
        iz =  kf / abs(kf)  ! +1(-1) for top (topbar) 
         if(ipar(33).eq.2) ves = ves * (1.d0-ps1(3))/2.d0
         if(ipar(33).eq.3) ves = ves * (1.d0+ps1(3))/2.d0
         if(ipar(33).eq.4) then  ! tt~ LL
             vesL = ves * (1.d0-ps1(3))/2.d0
             vesR = vesL 
         elseif(ipar(33).eq.5) then ! tt~ LR
             vesL = ves * (1.d0-ps1(3))/2.d0
             vesR = ves * (1.d0+ps1(3))/2.d0
         elseif(ipar(33).eq.6) then ! tt~ RL
             vesL = ves * (1.d0+ps1(3))/2.d0
             vesR = ves * (1.d0-ps1(3))/2.d0
         elseif(ipar(33).eq.7) then ! ~ tt~ RR
             vesL = ves * (1.d0+ps1(3))/2.d0
             vesR = vesL
         endif

       if(ipar(33).ge.4.AND.ipar(33).le.7) then 
         if(vesL.ge.VesMax(iqq,1)) VesMax(iqq,1) = vesL
         if(vesR.ge.VesMax(iqq,2)) VesMax(iqq,2) = vesR
       else
         if(Ves.gt.VesMax(iqq,1)) VesMax(iqq,1) = Ves 
       endif

       enddo
      enddo
      first = .false. 

 114  continue 
        ib = 2*id - 1       
        iz =  kf / abs(kf)  ! +1(-1) for top (topbar) 
        kv  = iz * 24       ! KF code of W-boson from top 
        iq  = iz * ib       ! for t -> b W(H)
       call Res_branch(2, kv, idc)
       iqq = abs(iq)
       Q(5) = mq(iqq) 
       N(5) = mq(ABS(FID(2, IDC, 1))) 
       L(5) = mq(ABS(FID(2, IDC, 2))) 

       call zer5mom(p) 
      P(4) = MT 
      P(5) = P(4)
 115   call top_dec_wff(iqq,  p, q, pw, l, n, ps1, ves)
    
        cos3 = 
     & nv(1)*ps1(1) + nv(2)*ps1(2) + nv(3)*ps1(3)
        if(ipar(33).eq.2) ves = ves*(1.d0 - cos3) / 2.d0 
        if(ipar(33).eq.3) ves = ves*(1.d0 + cos3) / 2.d0 
         if(ipar(33).eq.4) then       ! tt~ LL
             vesL = ves * (1.d0 - cos3)/2.d0
             vesR = vesL 
         elseif(ipar(33).eq.5) then  ! tt~ LR
             vesL = ves * (1.d0 - cos3)/2.d0
             vesR = ves * (1.d0 + cos3)/2.d0
         elseif(ipar(33).eq.6) then  ! tt~ RL
             vesL = ves * (1.d0 + cos3)/2.d0
             vesR = ves * (1.d0 - cos3)/2.d0
         elseif(ipar(33).eq.7) then ! tt~ RR
             vesL = ves * (1.d0 + cos3)/2.d0
             vesR = vesL
         endif

      If(ipar(33).ge.4.AND.ipar(33).le.7) then 
        if(iz.gt.0) then   
         if(vesL.ge.VesMax(iqq,1)) VesMax(iqq,1) = vesL
         ves = vesL
         aran = VesMax(iqq,1) * PYR(0) 
        else 
         if(vesR.ge.VesMax(iqq,2)) VesMax(iqq,2) = vesR
         ves = vesR
         aran = VesMax(iqq,2) * PYR(0) 
        endif
      Else 
         if(Ves.gt.VesMax(iqq,1)) VesMax(iqq,1) = Ves 
         aran = VesMax(iqq,1) * PYR(0) 
      EndIf 

       if(Ves.lt.aran) goto 115 
**
       kdec(1,1) = KV                  ! W-boson
       kdec(2,1) = IQ                  ! Q-quark from t -> Q W
       kdec(3,1) = iz * FID(2, IDC, 1) ! NU
       kdec(4,1) = iz * FID(2, IDC, 2) ! L 

      do I = 1,5
       pdm(1,I) = PW(I) 
       pdm(2,I) = Q(i)
       pdm(3,I) = N(i)
       pdm(4,I) = L(i)
       pdm(20,I) = IZ*ps1(I) ! top polarization vector in top rest frame
      enddo
      return
      end
c----------------------------------------------------------------------------c
*.. author : Serge Slabospitsky   14.05.2006                                 *
*....
      subroutine Top_dec_wff(iq, P, Q, PW, L, N, ps1, ves)
*     ------------------------------                                         *
*     R -> q(ib)  W (-> el nu)                                               *
*     P    q      Pw    L  N                                                 *
*............................................................................*
      implicit none
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision P(5),Q(5),L(5),N(5),pw(5),ps1(5),
     & Ves, vs1, pmm(2), p2s, coef
      save coef
      LOGICAL first
      SAVE first 
      DATA first /.TRUE./
      integer IQ
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
* 
      if(first) then 
        coef = pi2_3 * pi2_4 / 2.d0
        first = .false. 
      endif

      pmm(1) = rpar(70)
      pmm(2) = P(5) - mq(5)
       call brtwig_2(pmm, rpar(41), rpar(44), VS1, p2s)
       pw(5) = p2s 
        VES = vs1 
       call LIPS2 (P,  q, pw, VS1)
       ves = ves * vs1
       call LIPS2 (pw, l, n,  VS1)
        ves = ves * vs1 
        call  tbwff(iq, P, Q, L, N, VS1, ps1) 
      VES = coef * VES * VS1 / p(5)
      return 
      end
c----------------------------------------------------------------------------c
*.. author : Serge Slabospitsky   14.12.2000                                 *
*.... top decay in to b and H+- (-> Nu(L1) L+-(L2))                          *
      subroutine Top_dec_03(kf, MT) 
*     ------------------------------------------                             *
*                                                                            *
*    LIPS_3 with denominator due to H-boson                                  *
*  all momenta in top rest frame                                             *
*  width is normalized to t -> b tau NU_tau                                  *
*                                                                            *
*    |M|**2     R3(R -> B f f`~)                                             *
*  --------------------------------                                          *
*  [(pH^2 - mH^2)^2 + (G_H * mH)^2]                                          *
*                                                                            *
*     R -> b   H (-> Nu_tau Tau)                                             *
*     R    k   Ph    L1     L2                                               *
*... input :                                                                 *
*   ID = 1,2,...,21 is type of H+- decay channel                             *
*   KF = 6 (-6)  is top flavor                                               *
*    MT is initial top mass,  lepton and neutrino denoted two final fermions *
*    resulted from H-boson decay                                             *
*    arbirary normalization                                                  *
*... output :                                                                *
*  Q, L, and N are 5-momenta of final quark, lepton, and neutrino            *
*  in the top REST frame                                                     *
*  ves is the weight                                                         * 
*  DH(3)  is 3-momentum of polarisation vector                               *
*............................................................................*

      implicit none
      include "txpar.inc" 
      double precision MT
      double precision P(5), K(5), L1(5), L2(5), ph(5) 
      double precision Ves, Vs1, PYR
      LOGICAL first
      SAVE first 
      DATA first /.TRUE./
      double precision VesMaX(30), aran, scalp 
      save VesMaX 
      integer ires
      save ires
*...........
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer mxdc
      parameter (mxdc=20)   
      integer ndec, kdec
      double precision pdm, pdpl
      common /decmom/ pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)
      integer II, KF, IDH, J1, J2, IZ, KV, IQ,j8,j9  
      double precision HCPL,       HCPL2   
      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)
      double precision aa1,aa2, bb1, pmm(2), p2s, AXA, AXB 
      save aa1, aa2, bb1
* 
      do j8 = 1,mxdc
       do j9 = 1,3
          pdm(j8,j9) = 0.d0
         kdec(j8,j9) = 0
       enddo
          pdm(j8,4) = 0.d0
          pdm(j8,5) = 0.d0
      enddo
      ndec = 4

      pmm(1) = rpar(70) + 2.0   ! pmin
      pmm(2) = MT -  mq(5)       ! pmax
       call zer5mom(p) 
      p(4) = MT 
      p(5) = p(4)
      k(5) = mq(5)
      ires = 3
*...
      if(.NOT.first) goto 114 
      if(ipar(33).ge.2) then
       print*,'********************************************'
       print*,'*  IPAR(33) value = ',ipar(33)
       print*,'*  is implemented for t -> b H+-           *'
       print*,'********************************************'
      endif 

      aa1 = hcpl2(5) + hcpl2(6)
      aa2 = 2.d0 * hcpl(5)*hcpl(6)*mq(5)*MT 
      bb1 = hcpl2(6) - hcpl2(5)

      do j8 = 1,30
        vesmax(j8) = 0.d0
      enddo
*
      do 115 IDH = 1,mid(0, 2) 
       if(mid(idh, ires).le.-1)    goto 115
       J1 = ABS(FID(ires,idh,1))
       J2 = ABS(FID(ires,idh,2))
       if(j1.eq.6.or.j2.eq.6) goto 115
       L1(5) = mq(J1)
       L2(5) = mq(J2) 

      do ii = 1, ipar(52)
      call brtwig(pmm, rpar(51), rpar(54), VS1, p2s)
       VES = VS1
      ph(5)= p2s
      call LIPS2 (p,   k, ph, VS1)
       VES = VES * VS1
      call LIPS2 (ph, l1, l2, VS1)
       VES = VES * VS1
       AXA = (AA1 * scalp(p,k) + AA2) 
       AXB = (hcpl2(J1)+hcpl2(J2)) * scalp(l1,l2)
     &  -2.d0*l1(5)*l2(5)*hcpl(J1)*hcpl2(J2)
       VES = VES * AXA * AXB
       if(Ves.gt.VesMax(idh)) VesMax(idh) = Ves 
      enddo
 115  continue
      first = .false. 

 114  continue
        iz =  kf / abs(kf)  ! +1(-1) for top (topbar) 
        kv  = iz * 37       ! KF code of H-boson from top 
        iq  = iz *  5       ! for t -> b W(H)
 116   call Res_branch(ires, kv, idh)
       J1 = ABS(FID(ires,idh,1))
       J2 = ABS(FID(ires,idh,2))
       if(j1.eq.6.or.j2.eq.6) goto 116
       L1(5) = mq(J1)
       L2(5) = mq(J2) 
      call brtwig(pmm, rpar(51), rpar(54), VS1, p2s)
       VES = VS1
      ph(5)= p2s
      call LIPS2 (p,   k, ph, VS1)
       VES = VES * VS1
      call LIPS2 (ph, l1, l2, VS1)
       VES = VES * VS1
       AXA = (BB1 * MT + AA1 * scalp(p,k)) 
       AXB = (hcpl2(J1)+hcpl2(J2)) * scalp(l1,l2)
     &  -2.d0*l1(5)*l2(5)*hcpl(J1)*hcpl2(J2)
       VES = VES * AXA * AXB
       if(Ves.gt.VesMax(idh)) VesMax(idh) = Ves 
       aran = VesMax(idh) * PYR(0) 
       if(Ves.lt.aran) goto 116 


       kdec(1,1) = KV                ! H-boson
       kdec(2,1) = IQ                ! B-quark
       kdec(3,1) = iz * FID(ires, IDH, 1) ! NU
       kdec(4,1) = iz * FID(ires, IDH, 2) ! L+- 
*       kdec(4,3) = +10  ! will be used in TAUOLA

      do II = 1,5
       pdm(1,II) = PH(II) 
       pdm(2,II) = K(II)
       pdm(3,II) = L1(II)
       pdm(4,II) = L2(II)
       pdm(20,II) = MT*BB1*K(II) / AXA 
        if(kf.eq.-6) pdm(20,II) = -pdm(20,II) 
      enddo
      return
      end
c----------------------------------------------------------------------------c
*.. author : Serge Slabospitsky   22.05.2006                                 *
*                                                                            *
      subroutine Top_dec_04(id, kf, MT) 
*     --------------------------------------------                           *
* FCNC top quark decay into u(c)-quark and Z (-> L- L+), L+- = e, mu, tau    *
*                                                                            *
*    LIPS_3 with denominator due to Z-boson                                  *
*  all momenta in top rest frame                                             *
*  width is normalized to t -> q Z( -> L- L+)                                *
*                                                                            *
*     |M|^2   R3(R -> Q L1 L2)                                               *
*  --------------------------------                                          *
*  [(pZ^2 - mZ^2)^2 + (G_Z * mZ)^2]                                          *
*                                                                            *
*     R -> Q   Z (-> L- L+)                                                  *
*     R    q   Pw    L1 L2                                                   *
*... input :                                                                 *
*   KF = 6 (-6)  is top flavor                                               *
*    MT is initial top mass                                                  *
*  id is Z-boson decay channel                                               *
*                                                                            *
*... output :                                                                *
*  Q, L1, and L2 are 5-momenta of final quark, L+ and L- and L+              *
*  in the top REST frame                                                     *
*  ves is the weight                                                         * 
*  DH(3)  is 3-momentum of polarisation vector                               *
*............................................................................*

      implicit none
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer mxdc
      parameter (mxdc=20)   
      integer ndec, kdec
      double precision pdm, pdpl
      common /decmom/ pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)
*...........
      double precision MT, R(5), K(5), L1(5), L2(5) 
      double precision hh(5) 
      double precision Ves,  PYR 
      LOGICAL first
      SAVE first 
      DATA first /.TRUE./
      double precision aran, u0
      double precision vesmax(2,16) 
      double precision vestot(2,16) 
      save VesMax
      integer JQ, JL, JD,j8,j9 
      integer I, KF, id, idz, ires, KV, iq, j1, j2
*
      R(4) = MT 
      R(5) = R(4)
      ndec = 4
      ires = 4
      do j8 = 1,mxdc
       do j9 = 1,5
          pdm(j8,j9) = 0.d0
       enddo
      enddo 
*
      if(first) then
      if(ipar(33).ge.2) then
       print*,'********************************************'
       print*,'*  IPAR(33) value = ',ipar(33) 
       print*,'*  is implemented for t -> u(c) Z          *'
       print*,'********************************************'
      endif 
      endif

      if(.NOT.first) goto 114 

      do j8 = 1,2
       do j9 = 1,16
        vestot(j8,j9) = 0.d0
       enddo
      enddo

       do JQ = 1,2 
        if(jq.eq.1) then 
          iq = 2  ! UP
          jd = 15
        elseif(jq.eq.2) then
          iq = 4  ! charm 
          jd = 16
        endif 
       do JL = 1,16 
        VesMax(jq, jl) = 0.d0
        if(jl.eq.6.or.jl.eq.7.or.jl.eq.8) goto 222
        j1 = fid(4,jl,1)
         DO I = 1, ipar(52)
          k(5)  = mq(iq)
          l1(5) = mq(j1) 
          l2(5) = mq(j1) 

      call Rlip44(R, l1, l2, k, ves)
      call top_dec_qZ(jd, iq, j1, R, k, l1, l2, U0, hh)
       Ves = VES * U0 
       vestot(jq,jl) = vestot(jq,jl) + VES
       if(Ves.gt.VesMax(jq,jl)) VesMax(jq,jl) = Ves 
      ENDDO
 222  continue
      enddo
      enddo

       do JQ = 1,2 
        ves = 0.d0
       do JL = 1,16 
       vestot(jq,jl) = vestot(jq,jl) / ipar(52)
        print*,' Q L ves ',jq,jl,vestot(jq,jl)
        ves = ves + vestot(jq,jl)
       enddo
        print*,' Q gam ',jq,ves
       enddo
***
      first = .false. 

 114  continue
        kv  = 23                          ! KF code of Z-boson from top 
        iq  = FID(1,id,1) * kf / abs(kf)  ! for t -> q Z
        if(iq.eq.2) jd = 15
        if(iq.eq.4) jd = 16
 116   call Res_branch(ires, kv, idz)
       J1 = ABS(FID(ires,idz,1))
       J2 = ABS(FID(ires,idz,2))
       L1(5) = mq(J1)
       L2(5) = mq(J2) 
       k(5) = mq(abs(iq))
      call Rlip44(R, l1, l2, k, ves)
      call top_dec_qZ(jd, iq, J1, R, k, l1, l2, U0, hh)
       Ves = VES * U0 
       if(Ves.gt.VesMax((jd-14),idz)) VesMax((jd-14),idz) = Ves 
        aran = VesMax((jd-14),idz) * PYR(0) 
       if(Ves.lt.aran) goto 116

       kdec(1,1) = KV                ! H-boson
       kdec(2,1) = IQ                ! B-quark
       kdec(3,1) = FID(ires, IDZ, 1) ! L- 
       kdec(4,1) = FID(ires, IDZ, 2) ! L+

      do I = 1,5
       pdm(1,I) = L1(i) +  L2(i)
       pdm(2,I) = k(i)
       pdm(3,I) = L1(i)
       pdm(4,I) = L2(i)
       pdm(20,I) = hh(I) 
        if(kf.eq.-6) pdm(20,I) = -pdm(20,I) 
      enddo
       pdm(1,5) = dsqrt(pdm(1,4)**2 - pdm(1,1)**2
     &                - pdm(1,2)**2 - pdm(1,3)**2)
      return
      end
c----------------------------------------------------------------------------c
*.. author : Serge Slabospitsky   22.05.2006                                 *
*....
      subroutine Top_dec_qZ(id, iq, il1, p, k, l1, l2, ves, hh) 
*     --------------------------------------------                           *
* FCNC top quark decay into u(c)-quark and Z (-> f fbar)                     *
*                                                                            *
*  Z-boson denominator excluded                                              *
*............................................................................*

      implicit none
      include "txpar.inc" 
*...........
      double precision p(5), k(5), l1(5), l2(5)
      double precision Ves, coef, scalp
      LOGICAL first
      SAVE first, COEF 
      DATA first /.TRUE./
      integer id, Iq, il1
      double precision eqf(2,-20:20), zff(2,-20:20)
      common /Vboscpl/ eqf, zff
      double precision F0(2),H0(2),U0(2), AF(2), AH(2), W0(2),
     &  AA, AB, mt, mt2, pk
      double precision hh(5), q(5), kl1,kl2,pl1,pl2,qk,t1,t2,
     & q2, zn1
      integer j, j4, idd
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double complex   FL,     FR,      HL,    HR,
     &                 XL,     XR,      YL,    YR
      common /ANOMCPL/FL(20), FR(20), HL(20), HR(20), 
     &                XL(20), XR(20), YL(20), YR(20) 
* 
      if(first) THEN
       coef = Rpar(27)**2 * pi2_4 / 2.d0 / 2.d0
*       coef = pi2_4 / 2.d0 / 2.d0
*..Rpar(27)     : g_z         = e / sin(2*theta_W) 
       do J = 1, 2
        j4 = J + 14
        F0(j) = FL(j4)*conjg(FL(j4)) + FR(j4)*conjg(FR(j4))
        AF(j) = FL(j4)*conjg(FL(j4)) - FR(j4)*conjg(FR(j4))
        H0(j) = HL(j4)*conjg(HL(j4)) + HR(j4)*conjg(HR(j4))
        AH(j) = HL(j4)*conjg(HL(j4)) - HR(j4)*conjg(HR(j4))
        U0(j) = FL(j4)*conjg(HL(j4)) + conjg(FL(j4))*HL(j4)
     &        + FR(j4)*conjg(HR(j4)) + conjg(FR(j4))*HR(j4)
        W0(j) = FL(j4)*conjg(HL(j4)) + conjg(FL(j4))*HL(j4)
     &        - FR(j4)*conjg(HR(j4)) - conjg(FR(j4))*HR(j4)
       enddo
      first = .false. 
      ENDIF

      idd = id - 14
      AA = zff(1,il1)**2 + zff(2,il1)**2
      AB = zff(1,il1) * zff(2,il1) 

      pl1 = scalp(p, l1)        
      pl2 = scalp(p, l2)        
      kl1 = scalp(k, l1)        
      kl2 = scalp(k, l2)        
       do J = 1, 4
        q(j) = l1(j) + l2(j)
       enddo
      q2 = q(4)**2 - q(1)**2 - q(2)**2 - q(3)**2 
      zn1 = (q2 - Rpar(46))**2 + rpar(48)**2

       q(5) = dsqrt(q2)
*
      qk  = scalp(k, q)        
      pk  = scalp(k, p)        
      mt  = p(5)
      mt2 = p(5)**2

      t1 =  F0(idd)     *(pl1*kl2 + pl2*kl1)
     & + 4.d0*q2*H0(idd)*(pl1*kl1 + pl2*kl2)
     & - mt * q2 * qk * U0(idd)

      t2 = AF(idd)   *(pl1*kl2 - pl2*kl1)
     & - 4.d0*q2*AF(idd)*(pl1*kl1 - pl2*kl2)
     & + 2.d0*mt*q2*W0(idd)*(kl1-kl2)

      ves = 16.d0*AA*t1 + 32.d0*AB*t2

      hh(5) = 0.d0
      do j = 1,4
      t1 = -mt*AF(idd)*  (kl2*l1(j) + kl1*l2(j))
     & + 4.d0*q2*AH(idd)*(kl1*l1(j) + kl2*l2(j))
     & - 2.d0*W0(idd)*(pl1*pl2-pl2**2+2.d0*mt*kl2)*l1(j)
     & - 2.d0*W0(idd)*(pl1*pl2-pl1**2+2.d0*mt*kl1)*l2(j)

      t2 = mt*F0(idd)*      (kl1*l2(j) - kl2*l1(j))
     & + 4.d8*mt*q2*H0(idd)*(kl1*l2(j) - kl1*l1(j))
     & + 4.d0*W0(idd)*pk*(pl2*l1(j) - pl1*l2(j))
        hh(j) = (16.d0*AA*t1 + 32.d0*AB*t2) / ves
        hh(j) = -hh(j) ! transit to 3-space 
      enddo

      ves = ves * coef / mt / zn1
      if(abs(il1).le.5) ves = ves * 3.d0
      RETURN
      end
c----------------------------------------------------------------------------c
*.. author : Serge Slabospitsky   06.09.2002                                 *
*.... top decay in to b and H+- (-> bbar t* -> W*)                           *
      subroutine Top_dec_05(kf, MT) 
*     ----------------------------------                                     *
*                                                                            *
*   KFT = 6 (-6)  is top flavor, ITP top position in HEPEUP list             *
*   MT is initial top mass                                                   * 
*   DH(3)  is 3-momentum of polarisation vector                              *
*............................................................................*

      implicit none
      include "txpar.inc" 
      LOGICAL first
      SAVE first 
      DATA first /.TRUE./
      double precision VesMaX(30), aran, scalp, coef
      save VesMaX, coef
      integer ires, kf
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision HCPL,       HCPL2   
      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)
      integer mxdc
      parameter (mxdc=20)   
      integer ndec, kdec
      double precision pdm,  pdpl
      common /decmom/ pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)

      integer I, II, IX, ID, iz, irw 
      double precision at1,at2, at3, pmm(2), p2s 
      save at1,at2, at3, pmm 
      double precision p2(5), ph(5),k1(5),k2(5),q1(5),l1(5),l2(5) 
      double precision MT, DH(5), axa, Ves, Vs1, PYR
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
* 
      ires = 3
      ndec = 8

      IF(first) then 
      if(ipar(33).ge.2) then
       print*,'*********************************************'
       print*,'*  IPAR(33) value = ',ipar(33)
       print*,'*  is implemented for t -> b H*+- (t* bbar) *'
       print*,'*********************************************'
      endif 
      ENDIF
      if(.NOT.first) goto 114 
        do IX = 1,mid(0, ires)
         VesMax(iX) = 0.d0
        enddo
      coef = rpar(26)**2 / 2.d0
      coef = coef * pi2_3 
      coef = coef * pi2_4 / 2.d0 / mq(6) 
      AT1 = hcpl2(6) + hcpl2(5) 
      AT2 = 2.d0 * mq(5)*mq(6)*hcpl(5)*hcpl(6)
      AT3 = mq(6) * (hcpl2(6) - hcpl2(5)) 


      p2(5) = MT 
      p2(4) = p2(5)
      p2(3) = 0.d0
      p2(2) = 0.d0
      p2(1) = 0.d0
      k2(5) = mq(5)  
      pmm(1) = rpar(70) + 2.d0*mq(5)
      pmm(2) = p2(5) - mq(5)


      do 225 iX = 1,mid(0, 2) 
       if(mid(ix, 2).le.-1) goto 225

      DO ii = 1,ipar(52)
      call brtwig(pmm, rpar(51), rpar(53), VS1, p2s)
       ves = coef * VS1 
       ph(5) = p2s
      call LIPS2 (p2, k2, ph,  VS1) 
       ves = ves * VS1 
       call HPM_ME_03(ix, ph, k1, q1, l1, l2, dh, vs1) 
       ves = ves * VS1 * (at1*scalp(p2,k2) + at2)
      if(ves.gt.vesmax(ix)) vesmax(ix) = ves 
      ENDDO
 225  continue

      first = .false. 

 114  continue
      irw  = 2       ! W+-
      call Res_branch (IRW, kf, id) 
*
      call brtwig(pmm, rpar(51), rpar(53), VS1, p2s)
       ves = coef * VS1 
       ph(5) = p2s
      call LIPS2 (p2, k2, ph,  VS1) 
       ves = ves * VS1 
       call HPM_ME_03(id, ph, k1, q1, l1, l2, dh, vs1) 
       axa = at1*scalp(p2,k2) + at2
       ves = ves * VS1 * axa 
      if(ves.gt.vesmax(id)) vesmax(id) = ves 
      aran = vesmax(id) * pyr(0)
      if(aran.gt.ves) goto 114

        iz =  kf / abs(kf)  ! +1(-1) for top (topbar) 

       kdec(1,1) = iz *  5            ! B-quark from initial top
       kdec(2,1) = iz * 37            ! H-boson
       kdec(3,1) = iz * (-5)          ! Bbar-quark from H+-
       kdec(4,1) = kf                 ! second top* 
       kdec(5,1) = iz * 24            ! W from second top  
       kdec(6,1) = iz *  5            ! B-quark from second top  
       kdec(7,1) = iz*FID(irw, ID, 1) ! NU, U
       kdec(8,1) = iz*FID(irw, ID, 2) ! L+, Dbar

      do I = 1,5
       pdm(1,I) = k2(i) 
       pdm(2,I) = ph(i) 
       pdm(3,I) = q1(i) 
       pdm(4,I) = k1(i) + l1(I) + l2(I) 
       pdm(5,I) = L1(I) + L2(I) 
       pdm(6,I) = K1(i)
       pdm(7,I) = L1(i)
       pdm(8,I) = L2(i)
       pdm(20,I) = at3 * k2(i) / AXA
        if(kf.eq.-6) pdm(20,I) = -pdm(20,I) 
      enddo
       pdm(4,5) = dsqrt(pdm(4,4)**2 - pdm(4,1)**2
     &                - pdm(4,2)**2 - pdm(4,3)**2)
       pdm(5,5) = dsqrt(pdm(5,4)**2 - pdm(5,1)**2
     &                - pdm(5,2)**2 - pdm(5,3)**2)
       RETURN
       END

*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  24/06/2000                                  *
      subroutine pdf_BT(x1, x2,  pdfbt)
*     -------------------------------------------                            *
* returns the product of x1*f_B(x1) * x2*f_T(x2)                             *
* 0      1    2    3    4    5    6                                          *
* gluon  d    u    s    c    b    t                                          *
*       -1   -2   -3   -4   -5   -6                                          *
*       dbar ubar sbar cbar bbar tbar                                        *
*............................................................................*
      Implicit none
      include "txpar.inc" 
      double precision x1, x2
      Integer IB, IT 
      double precision pdfb(-5:5), pdfBT(-5:5,-5:5)
* PYTHIA 6... 
      double precision Q2
      INTEGER MINT
      double precision VINT
      COMMON/PYINT1/MINT(400),VINT(400)
      double precision dxpdf(-25:25)
*....
*      Q2 = qqsf*qqsf 
      Q2 = Rpar(3)**2 
* PYTHIA 6...       !         call PyPDFU (Iprot, x2, Q2, dxpdf)
*.. Mint(11)=Beam, Mint(12)=Target particle      
*.. target
      CALL PYPDFU(MINT(11), x1, Q2, dxpdf)
      do IB = -5, 5 
       pdfB(IB)  = dxpdf(IB)
      enddo
c  beam
      CALL PYPDFU(MINT(12), x2, Q2, dxpdf)
      do IB = -5, 5
       do IT = -5, 5
        pdfBT(IB, IT)  = pdfB(IB) * dxpdf(IT)
       enddo
      enddo
      return
      end
*----------------------------------------------------------------------------*

******************************************************************************
*                                                                            *
*          ROUTINES : TopReX                                                 *
*                                                                            *
*----------------------------------------------------------------------------*
*                                                                            *
*... author : Serge Slabospitsky                                             *
*... 17.01.2003                                                              *
******************************************************************************
*----------------------------------------------------------------------------*
*             <<<<  Lorentz Invariant Phase Space >>>>  routines             *
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  15.02.2001                                  *
      Subroutine X1X2GEN(PAR, X1, X2, Wht, q1, q2, Q)
*     -----------------------------------------------                        *
*  MC generation of the parton's fractions X1, X2 and corresponding momenta  *
*       d X1   d X2                                                          *
*       ----   ----                                                          *
*         X1     X2                                                          *
*                                                                            *
*... Input  :                                                                *
*  PAR(1) and PAR(2) are the minimal and maximal values of the sqrt(S_hat)   *
*  PAR(3) = sqrt(S)  is total initial hadron's energy, i.e. sqrt(S)          *
*... Output :                                                                *
*  X1, X2 and q1(5) and q2(5)                                                *
*  WHT is the weight                                                         *
*............................................................................*
      Implicit None
      include "txpar.inc" 
      double precision x1, x2, wht, par(3), YT0, tau, PYR
      double precision q1(5), q2(5), Q(5) 
      integer I
*      
       wht = 0.d0
       if(par(2).gt.par(3)) return
       YT0 = (  par(2)/par(1))**2                ! shat_max/shat_min  
       tau = ( (par(1)/par(3))**2) * YT0**PYR(0) ! shat_max/ S
       x1 = tau**PYR(0) 
       x2 = tau / x1
       Wht = DLOG(YT0) * (-DLOG(tau))  
      call zer5mom(q1) 
      call zer5mom(q2) 
      q1(4) =  0.5 * PAR(3) * x1
      q1(3) =  q1(4)
       q2(4) =  0.5 * PAR(3) * x2
       q2(3) = -q2(4)
        do I = 1,4
         q(I) = q1(I) + q2(I)
        end do
      Q(5) = Par(3) * dsqrt(x1 * x2)
      Rpar(74) = Q(5)     ! sqrt(Shat)
      Rpar(71) = Q(5)**2  ! Shat
      Rpar(7) = x1
      Rpar(8) = x2
      return
      end
*----------------------------------------------------------------------------*
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  15.02.2001                                  *
      Subroutine X1X2GEN_22(PAR, X1, X2, Wht, q1, q2, Q)
*     -----------------------------------------------                        *
*  MC generation of the parton's fractions X1, X2 and corresponding momenta  *
*       d X1   d X2                                                          *
*       ----   ----                                                          *
*         X1     X2                                                          *
*                                                                            *
*... Input  :                                                                *
*  PAR(1) and PAR(2) are the minimal and maximal values of the sqrt(S_hat)   *
*  PAR(3) = sqrt(S)  is total initial hadron's energy, i.e. sqrt(S)          *
*... Output :                                                                *
*  X1, X2 and q1(5) and q2(5)                                                *
*  WHT is the weight                                                         *
*............................................................................*
      Implicit None
      include "txpar.inc" 
      double precision x1, x2, wht, par(3), YT0, tau, PYR
      double precision q1(5), q2(5), Q(5) 
      integer I
*      
       wht = 0.d0
       if(par(2).gt.par(3)) return
       YT0 = (  par(2)/par(1))**2                ! shat_max/shat_min  
       tau = ( (par(1)/par(3))**2) * YT0**PYR(0) ! shat_max/ S
       x1 = tau**PYR(0) 
       x2 = tau / x1
       Wht = DLOG(YT0) * (-DLOG(tau))
      call zer5mom(q1) 
      call zer5mom(q2) 
       x1 = 0.05
       x2 = 0.025
      q1(4) =  0.5 * PAR(3) * x1
      q1(3) =  q1(4)
       q2(4) =  0.5 * PAR(3) * x2
       q2(3) = -q2(4)
        do I = 1,4
         q(I) = q1(I) + q2(I)
        end do
      Q(5) = Par(3) * dsqrt(x1 * x2)
      Rpar(74) = Q(5)     ! sqrt(Shat)
      Rpar(71) = Q(5)**2  ! Shat
      Rpar(7) = x1
      Rpar(8) = x2
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  15.02.2001                                  *
      Subroutine X1X2GEN2(PAR, X1, X2, Wht)
*     -------------------------------------
*  MC generation of the parton's fractions X1, X2 and corresponding momenta  *
*       d X1   d X2                                                          *
*       ----   ----                                                          *
*         X1     X2                                                          *
*                                                                            *
*... Input  :                                                                *
*  PAR(1) and PAR(2) are the minimal and maximal values of the sqrt(S_hat)   *
*  PAR(3) = sqrt(S)  is total initial hadron's energy, i.e. sqrt(S)          *
*... Output :                                                                *
*  X1, X2 and q1(5) and q2(5)                                                *
*  WHT is the weight                                                         *
*............................................................................*
      Implicit None
      include "txpar.inc" 
      double precision x1, x2, wht, par(3), YT0, tau, PYR
      double precision q1(5), q2(5), Q(5) 
      common /txkin/q1, q2, Q
      save /txkin/
      integer I
*      
       wht = 0.d0
       if(par(2).gt.par(3)) return
       YT0 = (  par(2)/par(1))**2                ! shat_max/shat_min  
       tau = ( (par(1)/par(3))**2) * YT0**PYR(0) ! shat_max/ S
       x1 = tau**PYR(0) 
       x2 = tau / x1
       Wht = DLOG(YT0) * (-DLOG(tau))
      call zer5mom(q1) 
      call zer5mom(q2) 
      q1(4) =  0.5 * PAR(3) * x1
      q1(3) =  q1(4)
       q2(4) =  0.5 * PAR(3) * x2
       q2(3) = -q2(4)
        do I = 1,4
         Q(I) = q1(I) + q2(I)
        end do
      Q(5) = Par(3) * dsqrt(x1 * x2)
      Rpar(74) = Q(5)     ! sqrt(Shat)
      Rpar(71) = Q(5)**2  ! Shat
      Rpar(7) = x1
      Rpar(8) = x2
      return
      end
c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky  15.02.2001                                  *
      Subroutine X1X2RES(PAR, WR, X1, X2, Wht, q1, q2, Q)
*     ---------------------------------------------------                    *
*  MC generation of the parton's fractions X1, X2 and corresponding momenta  *
*       d X1   d X2                                                          *
*       ----   ----  ---------------------------                             *
*         X1     X2  [(P**2 - MR**2)**2 + g1**2]                             *
*                                                                            *
*... Input  :                                                                *
*  PAR(1) = sqrt(Shat_min),          PAR(2) = sqrt(Shat_max)                 *
*  PAR(3) = sqrt(S)  is total initial hadron's energy                        *
*  WR(1)  = mass of the resonance,   WR(2) = width(R) * WR(1)                *
*... Output :                                                                *
*  X1, X2 and q1(5) and q2(5)                                                *
*  WHT is the weight                                                         *
*............................................................................*
      Implicit None
      include "txpar.inc" 
      double precision par(3), WR(2)
      double precision t0, d1, tau, S, PYR, zn
      double precision x1, x2, wht, q1(5), q2(5), Q(5), pq1(5)
*      
       wht = 0.d0
       if(par(2).gt.par(3)) return
      S = par(3) * par(3)

      t0 = atan((Par(1)**2 - WR(1)**2)/WR(2))
      D1 = atan((Par(2)**2 - WR(1)**2)/WR(2)) - t0
      tau = (WR(1)**2 + WR(2) * tan(t0 + D1 * PYR(0) )) / S 
       x1 = tau**PYR(0) 
       x2 = tau / x1
      Rpar(7) = x1
      Rpar(8) = x2
       Wht = (-DLOG(tau)) * D1 / WR(2) / S  / tau
      zn = (tau*S - WR(1)**2)**2 + WR(2)**2 
      Wht = Wht * zn
**
      Q(5) = dsqrt(S*tau)
      Q(4) = (x1 + x2)*par(3) / 2.d0
      Q(3) = (x1 - x2)*par(3) / 2.d0
      Q(2) = 0.d0
      Q(1) = 0.d0
       pq1(4) = (s*tau + q1(5)**2 - q2(5)**2) / 2.d0 / Q(5)
       pq1(3) = dsqrt(pq1(4)**2 - q1(5)**2) 
       pq1(5) = q1(5)
*        q2(4) = Q(5) - q1(4) 
*        q2(3) = -q1(3) 
* now PP is momentum of 1-particle in the rest frame of Q 
      call lorenb_s(Q, pq1, q1) ! Lorentz transformation into initial frame
       q1(1) = 0.d0
       q1(2) = 0.d0
      q2(4) = Q(4) - q1(4)
      q2(3) = Q(3) - q1(3)
      q2(1) = 0.d0
      q2(2) = 0.d0
       return
       end
c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky  15.02.2001                                  *
      Subroutine X1X2DELF(PAR, WR, X1, X2, Wht, q1, q2, Q)
*     ---------------------------------------------------                    *
*  MC generation of the parton's fractions X1, X2 and corresponding momenta  *
*       d X1   d X2                                                          *
*       ----   ----  delta(S x1 x2 - M2)                                     *
*         X1     X2                                                          *
*   M2 will generate with Breit-Wigner shape                                 *
*... Input  :                                                                *
*  PAR(1) = sqrt(Shat_min),          PAR(2) = sqrt(Shat_max)                 *
*  PAR(3) = sqrt(S)  is total initial hadron's energy                        *
*  WR(1)  = mass of the resonance,   WR(2) = width(R) * WR(1)                *
*... Output :                                                                *
*  X1, X2 and q1(5) and q2(5)                                                *
*  WHT is the weight                                                         *
*............................................................................*
      Implicit None
      include "txpar.inc" 
      double precision par(3), WR(2), pmm(2), vs1, p2s
      double precision tau, S, PYR 
      double precision x1, x2, wht, q1(5), q2(5), Q(5), pq1(5)
*      
       wht = 0.d0

      pmm(1) = par(1)
      pmm(2) = par(2)
       call brtwig_2(pmm, WR(1), WR(2), VS1, p2s)

      S = par(3) * par(3)

      tau = p2s**2/S
       x1 = (tau)**PYR(0) 
       x2 = tau / x1
        Rpar(7) = x1
        Rpar(8) = x2
       Wht = -DLOG(tau) / p2s**2
**
      Q(5) = p2s
      Q(4) = (x1 + x2)*par(3) / 2.d0
      Q(3) = (x1 - x2)*par(3) / 2.d0
      Q(2) = 0.d0
      Q(1) = 0.d0
       pq1(4) = (s*tau + q1(5)**2 - q2(5)**2) / 2.d0 / Q(5)
       pq1(3) = dsqrt(pq1(4)**2 - q1(5)**2) 
       pq1(5) = q1(5)
* now PP is momentum of 1-particle in the rest frame of Q 
      call lorenb_s(Q, pq1, q1) ! Lorentz transformation into initial frame
       q1(1) = 0.d0
       q1(2) = 0.d0
       q2(4) = Q(4) - q1(4)
       q2(3) = Q(3) - q1(3)
       q2(1) = 0.d0
       q2(2) = 0.d0
       return
      end
c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky  20.11.2004                                  *
*   M(q qbar) min/max for  W/Z Q Qbar production                             *
*............................................................................*
      subroutine MQQLIM
      implicit None
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer LD, LU
*
      Ld = 1
*     
      if(Rpar(77).eq.-1.d0) then
         Rpar(77) = 2.*mq(Ipar(7)) ! default 
         Ld = 0
      elseif(Rpar(77).lt.(2.*mq(Ipar(7))).OR.
     &       Rpar(77).ge.Rpar(1)) then
         Ld = -1
          print*,' user value of min(M(QQ))',rpar(77),
     &' is outside kinematic limits - stop'           
         STOP
      endif 
*  check max M(QQ)
      Lu = 1
      if(Rpar(78).eq.-1.d0) then
         Lu = 0
         Rpar(78) = Rpar(1)  ! default
      elseif(Rpar(78).ge.Rpar(1)) then
         Lu = 0
        print*,' M(QQ)-max ',rpar(78),
     &' is greater then sqrt(s). Value from LIPS will be used'
          Rpar(78) = Rpar(1)
      elseif(Rpar(78).gt.0.d0.AND.Rpar(78).le.rpar(77)) then
        Lu = -1 
        print*,' M(QQ)-max',rpar(78),
     &' less then M(QQ)-min ',rpar(77),' stop'           
           STOP
       endif
**
       if(Ld.eq.0) then 
        print*,' default M(QQ)-min = 2M(Q) = ',rpar(77)
       elseif(Ld.eq.1) then 
         print*,' M(QQ)-min = ',rpar(77)
       else
        STOP
       endif
       if(Lu.eq.0)  then
         print*,' M(QQ)-max from LIPS'
       elseif(Lu.eq.1) then
         print*,' M(QQ)-max = ',rpar(78)
       else
        STOP
       endif
      RETURN
      end

*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  20.11.2004                                  *
*   M(f fbar) min/max for  Z Q Qbar production                               *
*............................................................................*
      subroutine MFFLIM
      implicit None
      include "txpar.inc" 
      integer LD, LU
*
      Ld = 1
*     
      if(Rpar(79).eq.-1.d0) then
         Rpar(79) = Rpar(70)
         Ld = 0
      elseif(Rpar(79).ge.Rpar(1)) then
         Ld = -1
          print*,' user value of min(M(ff))',rpar(79),
     &' is outside kinematic limits - stop'           
         STOP
      elseif(Rpar(79).gt.0.d0.AND.Rpar(79).lt.rpar(70)) then
           print*,' M(ff)-min ',rpar(79),
     &' is too low. Rpar(70)) ',Rpar(70),' will be used'
           rpar(79) = Rpar(70) 
         Ld = 0
      endif 
*  check max M(QQ)
      Lu = 1
      if(Rpar(80).eq.-1.d0) then
         Lu = 0
         Rpar(80) = Rpar(1)
      elseif(Rpar(80).ge.Rpar(1)) then
         Lu = 0
        print*,' M(ff)-max ',rpar(80),
     &' is greater then sqrt(s). Value from LIPS will be used'
          Rpar(80) = Rpar(1)
      elseif(Rpar(80).gt.0.d0.AND.Rpar(80).le.rpar(79)) then
        Lu = -1 
        print*,' M(ff)-max',rpar(80),
     &' less then M(ff)-min ',rpar(79),' stop'           
           STOP
       endif
**
       if(Ld.eq.0) then 
        print*,' default M(ff)-min = ',rpar(79)
       elseif(Ld.eq.1) then 
         print*,' M(ff)-min = ',rpar(79)
       else
        STOP
       endif
       if(Lu.eq.0)  then
         print*,' M(ff)-max from LIPS'
       elseif(Lu.eq.1) then
         print*,' M(ff)-max = ',rpar(80)
       else
        STOP
       endif
      RETURN
      end

c----------------------------------------------------------------------------*
*... author  :  Serge Slabospitsky                                           *
*... 01.03.2002                                                              *
*... return charge Higgs Yukawa couplings with running quark masses          *
*... at M(H+-)**2                                                            *
*..HCPL(1)  = (m(D)/M_W) * tan(beta)     HCPL(2) = (m(U)/M_W) * cot(beta)    *
*..HCPL(3)  = (m(S)/M_W) * tan(beta)     HCPL(4) = (m(C)/M_W) * cot(beta)    *
*..HCPL(5)  = (m(B)/M_W) * tan(beta)     HCPL(6) = (m(T)/M_W) * cot(beta)    *
*..HCPL(7)  = (m(B4)/M_W) * tan(beta)    HCPL(8) = (m(T4)/M_W) * cot(beta)   *
*..HCPL(11) = (m(e)/M_W)   *tan(beta) HCPL(12) = (m(nu_e)/M_W) * cot(beta)   *
*..HCPL(13) = (m(mu)/M_W)  *tan(beta) HCPL(14) = (m(nu_mu)/M_W) * cot(beta)  *
*..HCPL(15) = (m(tau)/M_W) *tan(beta) HCPL(16) = (m(nu_tau)/M_W) * cot(beta) *
* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .  *
      subroutine HIGCPL 
*     -----------------
      implicit None
      include "txpar.inc" 
      integer IQ, j1
      double precision mqrun, Q2 
      double precision mq, mq2
      common/massql/   mq(0:20), mq2(0:20)
      double precision HCPL,       HCPL2   
      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)
*
      Q2 = rpar(51)**2   ! M(H+-)**2
       do j1 = -20,20
        hcpl(j1) = 0.d0
       enddo
      
      do iq = 11,16 
       if(iq.eq.11.or.iq.eq.13.or.iq.eq.15)  then
        HCPL(iq) = mq(iq) * rpar(55)          ! charged lepton 
       elseif(iq.eq.12.or.iq.eq.14.or.iq.eq.16)  then
        HCPL(iq) = mq(iq) / rpar(55)          ! neutrino
       endif
      enddo
      do iq = 1,6
        if(iq.eq.2.or.iq.eq.4.or.iq.eq.6)     then
         HCPL(iq) = mqrun(IQ, Q2) * 1.d0/rpar(55)  !  M(U) * cot(beta) 
        elseif(iq.eq.1.or.iq.eq.3.or.iq.eq.5) then
         HCPL(iq) = mqrun(IQ, Q2) * rpar(55)       !  M(D) * tan(beta) 
        endif
      enddo
      do iq = 1,16 
       HCPL(iq)   = HCPL(iq) / rpar(41) 
       HCPL(-iq)  = HCPL(iq) 
       HCPL2(iq)  = HCPL(iq)**2
       HCPL2(-iq) = HCPL2(iq) 
      enddo
      return
      end

c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky  22/10/2000                                  *
*                                                                            *
      subroutine TXWEAK 
*     ------------------                                                     *
*   electro-weak parameters, masses of gauge bosons and quarks, etc          *
*   part of parameter values are taken from PYTHIA                           *
*............................................................................*

      Implicit None
      include "pydat_62.inc"
      include "txpar.inc" 
      double precision mql,       mql2
      common /massql/  mql(0:20), mql2(0:20)
      double precision CKM2
      common /CKMD/ CKM2(-6:6,-6:6)

      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
*--- Numerical data are from RPP-98
      double precision gfermi, a42, ad9
      data gfermi /1.16639d-5/
      Integer I, J, II, JJ
      save /massql/, /CKMD/, /piconst/
      double precision mqPDG(8)
* mass(q)    PDG: d        u        s        c       b       t     
      data mqPDG /0.009d0, 0.005d0, 0.150d0, 1.25d0, 4.62d0, 175.0d0, 
     &            -1.d0, -1.d0/   ! b-prime t-prime
*........
*
      pi=DACOS(-1.d0)
      pi2   = 2.d0*pi
      pi4   = 4.d0*pi
      pi2_3 = pi2**3
      pi2_4 = pi2**4
      pi2_6 = pi2**6

      Rpar(50) = 1000.d0  ! new scale      

*...recalculate conversion factor mb/GeV**2,  transformation 1/GeV**2 to mb
      rpar(10) = PARU(5) 
       a42 = Ipar(42)
       ad9 = 9.d0 - a42
         rpar(18) = 10**ad9 ! mbpb
         rpar(10) = rpar(10) * 10**a42
*
         print*,' transformation MB into PB:  10**',a42,
     &   ' addition ',rpar(18) 

      Rpar(14) = gFermi

       do J = 1,20
        mql(j) = 0.d0
       enddo
* leptons
       do J = 1,6
        mql((J+10)) = PMAS( (J+10),1)   ! leptons
       enddo 

       mql(0) = 0.d0    ! gluon

       do J = 1, 6
        if    (ipar(5).eq.0)  then
          mql(J) = PMAS(J,1)     ! PYTHIA values for quark masses
        elseif(ipar(5).eq.1)  then
          mql(J) = mqPDG(J)      ! PDG    values for quark masses
        endif 
       enddo
       mql(6) = PMAS(6,1)
       mql(5) = PMAS(5,1) !  4.62d0 ! comp

 777  format(2x,e12.5)
*
      do J = 0, 20
       mql2(J)   = mql(J)  * mql(J) 
      enddo

*      write(*, 244) (mql(J),J=1,6),(mql(J),J=11,16)
 244  format(/,'  mass (q) :   D      U      S      C      B      T',/,
     &12x,5(f6.3,1x),f7.2,/,
     &       '  leptons  :   E    NU_E    MU    NU_MU   TAU   NU_TAU',/,
     &12x,f6.4,1x,5(f6.3,1x))
*
* B mass       ! 4.6d0 - 4.8d0 polmass in ME!
* W-boson parameters
      Rpar(41) = PMAS(24,1) 
      Rpar(42) = PMAS(24,1)**2 
      Rpar(43) = PMAS(24,2) 
      Rpar(44) = Rpar(41) * Rpar(43) 
* Z-boson parameters
      Rpar(45) = PMAS(23,1)      !  mass
      Rpar(46) = PMAS(23,1)**2 
      Rpar(47) = PMAS(23,2) 
      Rpar(48) = Rpar(45) * Rpar(47) 
* H-boson (SM) parameters
      Rpar(57) = PMAS(25,1)      !  mass
      Rpar(58) = PMAS(25,2) 
      Rpar(59) = Rpar(57) * Rpar(58) 
* couplings,  here  theta_W = theta_Weinberg  
      Rpar(23) = PARU(102)                  ! sin(theta_W)**2 
      Rpar(21) = DSQRT(Rpar(23))            ! sin(theta_W)
      Rpar(24) = 1.d0 - Rpar(23)            ! cos^2(theta_W)
      Rpar(22) = DSQRT(Rpar(24))            ! cos(theta_W)
      Rpar(25) = 2.d0 * Rpar(21) * Rpar(22) ! sin(2*theta_W)
*...set alpha electromagnetic at vanishing momentum transfers
cls      rpar(11) = PARU(101)
      rpar(11) = PARU(103)  ! 1.d0 / 131.d0  ! 28.d0               ! alpha_QED
      Rpar(12) =       4.d0*pi*rpar(11)      ! electric charge**2
      Rpar(13) = dsqrt(4.d0*pi*rpar(11))     ! electric charge
      rpar(26) = Rpar(13) / Rpar(21)         ! g = g_weak = e / sin(theta_W)
      Rpar(27) = Rpar(13) / Rpar(25)         ! g_z        = e / sin(2*theta_W)
*
      Rpar(28) = 246.d0 / dsqrt(2.d0) 
*CKM matrix elements
      do i = -6,6
       do j = -6,6
        CKM2(i,j) = 0d0
       enddo
      enddo 
 
      do I = 1,3
       do J = 1,3
        II = 2 * I
        JJ = 2 * J -1
         CKM2( II, JJ) = VCKM(I, J)  ! squared CKM matrix elements 
         CKM2(-II, JJ) = VCKM(I, J)
         CKM2( II,-JJ) = VCKM(I, J)
         CKM2(-II,-JJ) = VCKM(I, J)
         CKM2( JJ, II) = VCKM(I, J)
         CKM2(-JJ, II) = VCKM(I, J)
         CKM2( JJ,-II) = VCKM(I, J)
         CKM2(-JJ,-II) = VCKM(I, J)
       enddo
      enddo
      call Vbosoncpl  ! evaluate gamma/Z-boson couplings
      return
      end
*----------------------------------------------------------------------------*
*... author  :  Serge Slabospitsky                                           *
*... 20.02.2002                                                              *
* J.A.M. Vermaseren, S.A. Larin, T. van Ritbergen,                           *
* "The 4-loop quark mass anomalous dimension and the invariant quark  mass"  *
*  Phys. Lett.  B405, 327 (1997), arXiv:hep-ph/9703284                       *
*
*
*............................................................................*
*
      function mqrun(IQ, Q2) 
*     ----------------------
*
      Implicit None
      include "pydat_62.inc"
      include "txpar.inc" 
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/   pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      integer IQ
      double precision mqrun 
      double precision Q2, PYalps, alq, alb, cf(6,0:3), gam(6) 
      double precision Q2thr
      double precision mq, mq2
      common/massql/   mq(0:20), mq2(0:20)
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
*......
* we calculate the running values for S, C, B, T quarks only
      
      if(iq.eq.0.or.iq.eq.1.or.iq.eq.2.or.Ipar(6).eq.0) then
*      if(iq.eq.0.or.Ipar(6).eq.0) then
        Mqrun = mq(iq)
        return
      elseif(iq.ge.7)        then
        Mqrun = -1.
        return 
      endif
* 
      if(first) THEN
*
       gam(3) = 4.d0/9.d0    ! s-quark
       cf(3,0) = 1.d0                 
       cf(3,1) = 0.895062d0
       cf(3,2) = 1.37143d0
       cf(3,3) = 1.95168d0
*
       gam(4) = 12.d0/25.d0  ! c-quark
       cf(4,0) = 1.d0                  
       cf(4,1) = 1.01413d0
       cf(4,2) = 1.38921d0
       cf(4,3) = 1.09054d0
*
       gam(5) = 12.d0/23.d0  ! b-quark
       cf(5,0) = 1.d0        
       cf(5,1) = 1.17549d0
       cf(5,2) = 1.50071d0
       cf(5,3) = 0.172478d0
*
       gam(6) = 4.d0/7.d0    ! t-quark
       cf(6,0) = 1.d0       
       cf(6,1) = 1.39796d0 
       cf(6,2) = 1.79348d0
       cf(6,3) =-0.683433d0
      first=.FALSE.
      ENDIF
*
      Q2THR=PARU(113)*MQ2(IQ) 
      if(q2thr.le.paru(114)) q2thr = paru(114)
      if(q2.le.q2thr) then
       Mqrun = mq(iq)
       return
      endif

      alq = PYalps(q2) /pi
      alb = PYalps(q2thr)/pi

      Mqrun = mq(iq) * (alq/alb)**gam(iq) 
     & * (cf(iq,0) + cf(iq,1)*alq + cf(iq,2)*alq**2 + cf(iq,3)*alq**3)
     & / (cf(iq,0) + cf(iq,1)*alb + cf(iq,2)*alb**2 + cf(iq,3)*alb**3)
      return
      end
c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky  24/06/2000                                  *
      double precision Function TopWid(IQ, mt) 
*     ---------------                                                        *
*   Width of the top decay t -> W q evaluated in LO                          *
*   return the SM total top decay (in GeV)                                   *
*   IQ = 1(d), 3(s), 5(b)  light quark flavor                                *
*............................................................................*

      implicit none
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision mq,       mq2
      common /massql/  mq(0:20), mq2(0:20)
      double precision mt,p(5),q(5),pw(5),l(5),n(5),ps1(5),ves
      include "txpar.inc" 
      integer IQ, I
      double precision CKM2
      common /CKMD/    CKM2(-6:6,-6:6)
      integer Ntot
      data ntot/10000/
*
      TopWid = 0.d0 
      if(iq.eq.1.OR.iq.eq.3.OR.iq.eq.5) then 
       TopWid = 0.d0
       call zer5mom(p) 
       p(5) = mt
       p(4) = mt
       q(5) = mq(iq)
      do I = 1, Ntot
        call top_dec_wff(iq,  p, q, pw, l, n, ps1, ves)
        TopWid = TopWid + VES
      enddo
      TopWid = TopWid * CKM2(6, iq) / Ntot  ! times to Vtq**2
      endif
      return
      end
c----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  16.12.2003                                  *
      function TopMV(tw, mt0)
*                                                                            * 
*  calculate the current top mass according Breit-Wigner distribution        *
*         1/((M_t**2 - Mt_0**2)**2 + Width(t)**2 * Mt_0**2)                  *
*... Input  :                                                                *
*  M = M_0 +- ND*width(TOP)                                                  *
*  tw  is total top quark width at the pole mass                             *
*  mt0 is the top pole mass                                                  *
*... Output :                                                                *
*  top current mass                                                          *
*............................................................................*

      implicit None
      double precision topmv, mt0, tw, PYR, nd, mu, md, t0, del, mt2
      data nd/20.d0/
      include "txpar.inc" 
*
      LOGICAL first
      DATA first /.TRUE./
      SAVE first, mt2, t0, del, nd, mu,md 
*
      if(first) THEN
       mt2 = mt0**2
       mu = mt0 + tw*nd 
       md = mt0 - tw*nd
        if(md.lt.(mt0 - mt0/5.d0)) then
          nd =  mt0/5.d0/tw
          mu = mt0 + tw*nd 
          md = mt0 - tw*nd
        endif 
      t0  = datan((md**2 - mt2) / tw / mt0)      
      del = datan((mu**2 - mt2) / tw / mt0) - t0 
      first=.FALSE.
      ENDIF
*
      if(ipar(31).eq.0) then
        topmv = mt0
        return
      endif 
 11   topmv = dsqrt(mt2 + tw*mt0 * dtan(t0 + del*PYR(0)) )
       if(topmv.lt.md.OR.topmv.gt.mu) goto 11 
       rpar(37) = topmv
      return
      end

c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky  24/06/2000                                  *
      subroutine qflqw(QI, QF)
*     ------------------------                                               *
* calculate the flavor of final quark, originated from initial quark         *
* transition into W-boson and quark                                          *
*  q_in(QI) -> Q_fin(QF) W(QI)                                               *
* Input :  QI is PYTHIA code of initial quark                                *
* Output:  FC are factors for weight, calculated at the FIRST call           *
*       :  QF is PYTHIA code of final quark                                  *
*       :  QI PYTHIA code of W-boson                                         *
*............................................................................*
      implicit none
      double precision CKM2   !  V_ij**2
      common /CKMD/ CKM2(-6:6,-6:6)
      double precision fc, fc1(4) 
      common /sng1fc/ fc(4) !  are factors for weight  
      Integer QI, QF, ifl(4,2)
      double precision PYR, aran
      Save IFL
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
*......
      if(first) THEN
*  D-quark
       FC1(1) = CKM2(1,2)
       FC(1)  = FC1(1) + CKM2(1,4)
       IFL(1,1) = 2         ! D -> U
       IFL(1,2) = 4         ! D -> C
*  U-quark
       FC1(2) = CKM2(2,1)
       FC(2)  = FC1(2) + CKM2(2,3)
       IFL(2,1) = 1         ! U -> D
       IFL(2,2) = 3         ! U -> S     we ignore U -> B transition
*  S-quark
       FC1(3)  = CKM2(3,2)
       FC(3)  = FC1(3) + CKM2(3,4)
       IFL(3,1) = 2         ! S -> U
       IFL(3,2) = 4         ! S -> C
*  C-quark
       FC1(4) = CKM2(4,1)
       FC(4)  = FC1(4) + CKM2(4,3)
       IFL(4,1) = 1         ! C -> D
       IFL(4,2) = 3         ! C -> S     we ignore C -> B transition
*
      first=.FALSE.
      ENDIF
       aran = FC(abs(QI)) * PYR(0) 
        if(aran.le.FC1(abs(QI))) then
         QF = IFL(abs(QI), 1)
        else
         QF = IFL(abs(QI), 2)
        endif
       if(QI.lt.0) QF = -QF
*  calculate W-boson code
          if(QI.eq.1.or.QI.eq.3.or.QI.eq.-2.or.QI.eq.-4) then
         QI = -24    ! W-
      elseif(QI.eq.-1.or.QI.eq.-3.or.QI.eq.2.or.QI.eq.4) then
         QI = +24    ! W+ 
        endif
      return
      end
*----------------------------------------------------------------------------*
************------------------------------------------------------************
*. . . . . . . MATRIX element calculation . . . . . . . . . . . . . . . . . .*
*----------------------------------------------------------------------------*
*  author : Serge Slabospitsky                                               *
*  01.03.2002                                                                *
*  matrix element for the H* process                                         *
*  U(q1)  D_bar(q2) --> W + H(q) -> t(p1) b~(p2)                             *
* Yukawa couplings with running q-masses                                     *
*  
*............................................................................*

      subroutine sng_01(q1, q2, p1, p2, ves)

      implicit none

      include "txpar.inc" 
      double precision  q1(5), q2(5)   ! momenta of initial light quarks
      double precision  p1(5), p2(5)   ! momenta of top, b 
      double precision  q(5)           ! =  q1 + q2 
      double precision Ves, vesH, vesW, vesI, coef, zW, zH, dW, dH

      double precision SCALP, s, sqs, LWW, LW(4), LH(4), LI(4)
      integer I
      double precision vt(3,4), epsi(4), HR 
      common /topol1/ HR(4) 
      double precision rs(5), rb(5), f(5) 
      double precision p1p2,p1q2,p1q,p1rs,p1f, p2q1,p2q,p2rs,p2f, 
     & rbrs,rbq,q1q2, rsq, qf
      double precision u1, u2, u3, u4,u5,u6 
      double precision mu1, mu2, m1, m2, dm12 
      integer iu,id, it, ib  ! flavors of initial (iu id) and final (it ib)
      common /isng01/iu,id,it,ib
      double precision HCPL,       HCPL2   
      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)
      double precision ga1,gb1,ga2,gb2
*
      LOGICAL first
      SAVE first, coef
      DATA first /.TRUE./
*......... 
*..RPAR(10)     : 0.38939d0     transformation 1/GeV**2 to mb                *
*..RPAR(26)     : g = g_weak  = e / sin(theta_W)                             *
*..Rpar(41)     : W-boson mass,       Rpar(42) = Rpar(41)**2                 *
*..Rpar(43)     : W-boson width,      Rpar(44) = M(W) * Width(W)             *
*..Rpar(51)     : charged Higgs mass, Rpar(52) = Rpar(51)**2                 *
*..Rpar(53)     : total charged Higgs decay width                            *
*..Rpar(54)     : M(H+-) * Width(H+-)                                        *
*..Rpar(55)     : tan(beta),          Rpar(56) = (1/tan(beta))               *
*..ipar(21)      : W-exchange: > 0 tb, <0 tau nu, 1 W, 2 H, 3 (W+H+Int)       *
*............................................................................*
      IF(first) THEN        ! initializing
       coef = rpar(10) * rpar(26)**4 / 4.d0      ! W-exchange
       if(ipar(21).lt.0) coef = coef/ 3.d0       ! tau nu production 
      first=.FALSE.
      ENDIF
* masses sqared
       mu1 = q1(5)**2    ! m1**2
       mu2 = q2(5)**2
       m1  = p1(5)**2
       m2  = p2(5)**2
       dm12 = m1 - m2 
      call Mass2(q1, q2, s, sqs) 
      q(5) = sqs
      zW = s - Rpar(42)
*      zW = s
      zH = s - Rpar(52)
      dW = zW*zW + Rpar(44)**2
*      dW = zW*zW 
    
      dH = zH*zH + Rpar(54)**2

      ga1 = hcpl(iu)
      gb1 = hcpl(id)
      ga2 = hcpl(it)
      gb2 = hcpl(ib)
       do i = 1,4
        q(I) = q1(i) + q2(i)
        rs(I) = mu1 * q2(i) + mu2 * q1(i) 
        rb(I) = m1  * p2(i) + m2  * q1(i) 
        f(I)  = q1(5)*ga1 * q2(i) - q2(5)*gb1 * q1(i) 
       enddo
*
      p1p2 = scalp(p1, p2) 
      p1q2 = scalp(p1, q2) 
      p1rs = scalp(p1, rs) 
      p1f  = scalp(p1, f) 
      p1q  = scalp(p1, q) 
      p2q1 = scalp(p2, q1) 
      p2rs = scalp(p2, rs) 
      p2q  = scalp(p2, q) 
      p2f  = scalp(p2, f) 
      rbrs = scalp(rb, rs) 
      rbq  = scalp(rb, q ) 
      q1q2 = scalp(q1,q2) 
      qf   = scalp(q, f) 
      rsq  = scalp(rs, q) 
* additional variables
*..Rpar(131) = m(D) * tan(beta)      Rpar(132) = m(U) * cot(beta)            *
*..Rpar(133) = m(S) * tan(beta)      Rpar(134) = m(C) * cot(beta)            *
*..Rpar(135) = m(B) * tan(beta)      Rpar(136) = m(T) * cot(beta)            *
*
      U1 = (ga1**2 + gb1**2) * q1q2 - 2.d0 * ga1 * gb1 * q1(5)*q2(5)
      U2 = (ga2**2 + gb2**2) * p1p2 - 2.d0 * ga2 * gb2 * p1(5)*p2(5)
      U3 =  ga2**2 - gb2**2 
      U4 =  p1(5)*ga2 + p2(5)*gb2 
      U5 = zW * ZH       + Rpar(44) * Rpar(54)
      U6 = zW * Rpar(54) - ZH * Rpar(44) 
*  W contribution
      vesw = 4.d0*p1q2*p2q1 - 2.d0*rbrs/Rpar(42)+Rbq/Rpar(42)**2
      vesW = vesW * coef / dW 
* Higgs exchange
      vesH = coef * U1 * U2 / dH
* interference
      vesI = p1(5)*ga2*p2f - p2(5)*gb2*p2f 
     & - (qf/Rpar(42))*(p1(5)*p2(5)*(p2(5)*ga2 - p1(5)*gb2) 
     &                   +   p1p2  *(p1(5)*ga2 - p2(5)*gb2)) 
      vesI = vesI * (-2.d0 * coef * U5) / dw / dH
* total weight
      if    (abs(ipar(21)).eq.1)  then
       ves = vesW                    ! W exchange, t bbar
      elseif(abs(ipar(21)).eq.2) then
       ves = vesH                    ! H exchange, t bbar
      elseif(abs(ipar(21)).eq.3) then
       ves = vesW + vesH + vesI      ! W +  H + Interf 
      endif
*... polarisation

      call EPSPR(f, p2, p1, epsi)

      if(ipar(21).gt.0) then     
*                      t b~ production   : top polarisation
      call Vortas(p1, vt)

       do i = 1,4
        LWW = -4.d0 * p1(5)* p2q1 * q2(I)
     &      -  2.d0 * p1(5)* (p2q*rs(I) - p1rs*p2(I)) / Rpar(42)  
     &      +  rsq * p1(5)* dm12 * p2(I)    / Rpar(42)**2
        LW(I) = coef * LWW        / dW          ! W contribution
        LH(I) = coef * p1(5) * U1 * U3*p2(I) / dH       ! H contribution

        LWW = p1(5)*p2(5)*gb2*f(I) + ga2*(p1f*p2(I) - p1p2*f(I))
     &      - (qf/Rpar(42)) * p1(5)* U4 * p2(I)
        LWW = U5 * LWW  + U6 * ga2 * epsi(I)
        LI(I) = -2.d0* coef * LWW / dw / dH            ! interference
       enddo
      elseif(ipar(21).lt.0) then     
*                      tau nu production   : tau polarisation
      call vortas(p2, vt)

       do i = 1,4
        LWW = 4.d0 * p2(5) * p1q2 * q1(I)
     &      - 2.d0 * p2(5) * (p1q*rs(I) - p2rs*p1(I)) / Rpar(42)  
     &      +  rsq * p2(5) * dm12 * p1(I)     / Rpar(42)**2
        LW(I) = coef * LWW          / dW                ! W contribution
        LH(I) = coef * p2(5) * U1*U3*p1(I) / dH         ! H contribution

        LWW = p1(5)*p2(5)*ga2*f(I) + gb2*(p2f*p1(I) - p1p2*f(I))
     &      - (qf/Rpar(42)) * p2(5)*U4 * p1(I)
        LWW = U5 * LWW  +  U6 * gb2 * epsi(I)
        LI(I) = -2.d0 * coef * LWW / dw / dH            ! interference
       enddo
      endif

      do i = 1,3
      if    (abs(ipar(21)).eq.1) then
       lww = LW(4)*vt(i,4) - LW(1)*vt(i,1)   ! W exchange
     &     - LW(2)*vt(i,2) - LW(3)*vt(i,3) 
      elseif(abs(ipar(21)).eq.2) then
       lww = LH(4)*vt(i,4) - LH(1)*vt(i,1)   ! H exchange
     &     - LH(2)*vt(i,2) - LH(3)*vt(i,3) 
      elseif(abs(ipar(21)).eq.3) then         ! W +  H + Interf 
       lww = (LW(4)+LH(4)+LI(4))*vt(i,4) 
     &     - (LW(1)+LH(1)+LI(1))*vt(i,1) 
     &     - (LW(2)+LH(1)+LI(2))*vt(i,2) 
     &     - (LW(3)+LH(1)+LI(3))*vt(i,3) 
      endif
       HR(I) = LWW / Ves
*       HR(I) = - LWW / Ves
      enddo
       HR(4) = 0.d0
      if(ipar(33).eq.2) ves = ves * (1.d0-hr(3))/2.d0
      if(ipar(33).eq.3) ves = ves * (1.d0+hr(3))/2.d0

      return
      end
c----------------------------------------------------------------------------c
*  new matrix element for the Wg process : 2 -> 3                            *
*.. author: Serge Slabospitsky                                               *
*.. 09/01/2001                                                               *
*                                                                            *
      subroutine sng_02(ich, q, K1, K2, P, B, ves)
*     --------------------------------------------                           *
*                                                                            *
*  ich = 1   default kinematics : q G -> q' t bbar                           *
*  ich = -1  kinematics for tW  : b G -> t W (-> f f~')                      *
*  gluon q --> q' t* b_bar,     top quark is ON-SHELL                        *
*  q     K1    K2 P  B                                                       *
*                                                                            *
*     G U    -> D    T    Bbar                                               *
*     G Dbar -> Ubar T    Bbar                                               *
*     G Ubar -> Dbar Tbar B                                                  *
*     G D    -> U    Tbar B                                                  *
*............................................................................*
      implicit none
      include "txpar.inc" 
      double precision  q(5), K1(5)  ! momenta of initial gluon and u-quark
      double precision  P(5), K2(5), B(5) 
*          4-momenta of top,  q'     b  
      double precision Ves, coef, scalp
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/   pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
* internal variables
      double precision T1, T2, T12, lv(5), vh(3,4), vv(5), hp
      common /topol1/ hp(4)
      double precision bk1, bk2, bq, qk1, qk2, pq, pb, pk1,pk2, omw
*
      integer I, J, ich
      LOGICAL first
      DATA first /.TRUE./
      SAVE first, Coef 
*....
      if(first) THEN
*..RPAR(26)     : g = g_weak  = e / sin(theta_W)                             *
*..RPAR(10)     : 0.38939d0     transformation 1/GeV**2 to mb                *
*..Rpar(41)     : W-boson mass                                               *
*..Rpar(42)     : Rpar(41)**2                                                *
      coef = rpar(10) * 2.d0 * pi * rpar(26)**4 
      if(ich.eq.-1) coef = coef * 3.d0  ! 3 = (u d~) + (c s~) + 3*(e mu tau)
      first=.FALSE.
      ENDIF
*
      bk1 = scalp(b, k1)
      bk2 = scalp(b, k2)
      bq  = scalp(b, q) 
      qk1 = scalp(q, k1)
      qk2 = scalp(q, k2)
      pq  = scalp(p, q)
      pb  = scalp(p, b)
      pk1 = scalp(p, k1)
      pk2 = scalp(p, k2)
      omw = Rpar(42) + 2.d0 * scalp(k1,k2)
*
      T1 = b(5)**2 * (bk1 - qk1) - bq * qk1
       do I = 1,4
        lv(i) = - p(5)*k2(I) * t1 / bq**2
       enddo
      t1 = pk2 * t1 / bq**2
*
      T2 = bk1*(p(5)**2 * (pk2 - qk2) - pq*qk2) / pq**2 
       do I = 1,4
        lv(i) = lv(i) + (bk1/pq**2) * p(5)
     & *(-p(5)**2*k2(I) + (qk2-pk2)*q(i) + pq*k2(i))
       enddo
*
      T12 = (pb*qk1 + pq*bk1 - bq*pk1)*pk2
     & - bk1*(2.d0*pb*pk2 - bq*pk2 - pb*qk2 + pq*bk2)
      t12 = t12 / bq / pq

       do I = 1,4
        lv(i) = lv(i) + (p(5)/bq/pq)
     & *(-(pb*qk1 + pq*bk1 - bq*pk1)*k2(i)
     &   - bk1*(-2.d0*pb*k2(i) + qk2*b(i) + bq*k2(i) - bk2*q(i)))
       enddo

      call vortas(p, vh)
       do i = 1,3
         do j = 1,4
          vv(J) = vh(I,J)
         enddo 
        hp(I) = -scalp(lv,vv) / (t1+t2+t12)
       enddo
      Ves = -rpar(15) * coef * (T1 + T2 + T12 ) 

      if(ipar(33).eq.2) ves = ves * (1.d0-hp(3))/2.d0
      if(ipar(33).eq.3) ves = ves * (1.d0+hp(3))/2.d0

* now Ves is the default |M|^2 without denominator from W-boson propagator
* we transform M^2 for two variants of W-boson exchange
      if    (ich.eq.1) then
       Ves = Ves * bq  / omw / omw 
      elseif(ich.eq.-1) then
       Ves = Ves  ! W-denominator is included in LIPS
      endif
      return
      end
*----------------------------------------------------------------------------*
*  Authors: Serge Slabospitsky                                               *
*   29.01.2001                                                               *
*  matrix element for the (W* or H*) + JET   production process              *
*  U   D~  --> G  H ( -> nu  tau+)                                           *
*  k1  k2      q         p   L                                               * 
*  denominator from propagator of W-boson or Higgs is included in LIPS       *
*............................................................................*
      subroutine sng_03(k1, k2, q, p, l, ves)

      implicit none
      include "txpar.inc" 
      double precision  k1(5), k2(5)        ! initial U and D~ quarks 
      double precision  q(5),  p(5), L(5)   ! final gluon, nu and tau
      integer I
      double precision Ves, coefH, coefW, SCALP, AM
      double precision t1, t2, t12, tn2, ct2 
      save coefW, coefH, tn2, ct2
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst / pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision mq1, mq2, k1k2, qk1, qk2
      double precision pk1, pk2, pq, lk1, lk2, pl, fk1,fk2, pf, qf, ql 
      double precision lv(4), vt(3,4)
      double precision f(5), mw4, mu2, tmp, f2, c4
      save mw4
*
      double precision hr 
      common /topol1/ hr(4)    ! TAU lepton polarisation vector
*
      LOGICAL first
      SAVE first
      DATA first /.TRUE./
*......... 
      IF(first) THEN        ! initializing
      first=.FALSE.
*..RPAR(26)     : g = g_weak  = e / sin(theta_W)                             *
*..Rpar(41)     : W-boson mass, Rpar(42) = Rpar(41)**2                       *
*..Rpar(55)     : tan(beta),    Rpar(56) = (1/tan(beta))                     *

       coefH = rpar(10) * 4.d0  * pi * rpar(26)**4 / Rpar(41)**4
       coefH = coefH * l(5)**2 * Rpar(55)**2
       coefW = rpar(10) * 8.d0 * pi * rpar(26)**4 
       mw4 = Rpar(42)**2
*   spin averaging is included,  alpha_s will be included below
       tn2 = Rpar(55)**2
       ct2 = Rpar(56)**2
      ENDIF
* running
      mq1 = k1(5)**2
      mq2 = k2(5)**2
      AM = mq1 * ct2 + mq2 * tn2
      k1k2 = scalp(k1, k2)
      qk1  = scalp(q, k1)
      qk2  = scalp(q, k2)

*..ipar(21)     : W-exchange: > 0 tb, <0 tau nu, 1 W, 2 H, 3 (W+H+Int)       *
      if(abs(ipar(21)).eq.2) then
* Higgs contribution     
       T1 = AM*(mq1*(k1k2-qk2)-qk1*qk2) - 2.d0*mq1*mq2*(mq1-qk1) 
       T2 = AM*(mq2*(k1k2-qk1)-qk1*qk2) - 2.d0*mq1*mq2*(mq2-qk2) 
       T12= AM*(-mq1*qk2 - mq2*qk1 - 2.d0*(qk1-k1k2)*(qk2-k1k2))
     &   + 2.d0*mq1*mq2*(2.d0*k1k2 - qk1 - qk2)
*      ves = T1/qk1/qk1 + T2/qk2/qk2 + T12/qk1/qk2

      ves = -coefH * rpar(15) * scalp(p, l)
     &    *  (T1/qk1/qk1 + T2/qk2/qk2 + T12/qk1/qk2)
      call vortas(l, vt)
        t1 = (l(5) / scalp(p, l)) 
       do I = 1,3
        hr(i) = t1 * (vt(i,4)*p(4) - vt(i,1)*p(1) 
     &             -  vt(i,2)*p(2) - vt(i,3)*p(3))
       enddo
        hr(4) = 0.d0
      elseif(abs(ipar(21)).eq.1) then
* W-boson contribution WITHOUT interference !!!
      lk1 = scalp(l, k1)
      lk2 = scalp(l, k2)
      ql  = scalp(q, L)
      pk1 = scalp(p, k1)
      pk2 = scalp(p, k2)
      pq  = scalp(p, q)
      pl  = scalp(p, l)
      mu2 = L(5)**2
       do I = 1,4
        F(I) = p(I) + L(I)
       enddo
        F2 = f(4)**2-f(1)**2-f(2)**2-f(3)**2
        f(5) = dsqrt(f2)
      fk1 = scalp(f, k1)
      fk2 = scalp(f, k2)
      pf  = scalp(p, f) 
      qf  = scalp(q, f)
*
      T1 = 2.d0*pk2 * ql  
     & -(mu2/Rpar(42))*(k1k2*pq + qk1*pk2 - qk2*pk1)
     & +(mu2/mw4)*qk1*k1k2*pl
      T1 = -T1 / qk1
* polarisation vector
      do I = 1,4
       tmp = 2.d0*pk2*q(I) 
     & -(1.d0/Rpar(42)) 
     &    * ( f2*pk2*q(I)
     &      + p(I) *(mu2*qk2 - 2.d0*ql*fk2) 
     &      - k2(I)*(f2 *pq  - 2.d0*pf*qf )  ) 
     & -(mu2/mw4)*qk1*k1k2*p(I) 
       lv(I) = -L(5)*tmp / qk1
      enddo

      T2 = 2.d0*pq * lk1 
     & -(mu2/Rpar(42))*(k1k2*pq + qk2*pk1 - qk1*pk2)
     & +(mu2/mw4)*qk2*k1k2*pl
      T2 = -T2 / qk2
* polarisation vector
      do I = 1,4
       tmp = 2.d0*pq*k1(I) 
     & -(1.d0/Rpar(42)) 
     &    * ( f2*pq*k1(I)
     &      + p(I) *(mu2*qk1 - 2.d0*lk1*qf) 
     &      - q(I) *(f2 *pk1 - 2.d0*pf*fk1)  ) 
     & -(mu2/mw4)*qk2*k1k2*p(I) 
       lv(I) = lv(I) - L(5)*tmp / qk2
      enddo

      C4 = pk2*(qk1 + qk2 - 2.d0*k1k2) + pq*k1k2 - pk1*qk2
      T12 = 2.d0*(k1k2*pk2*ql - qk1*pk2*lk2) + 2.d0*C4*lk1
     &-(mu2/Rpar(42)) * (qk1*qk2*pk1 + qk1*qk2*pk2
     &  + k1k2*pq*qf - qk1*qk1*pk2 - qk2*qk2*pk1)
     &+(2.d0*mu2/mw4)*qk1*qk2*k1k2*pl
      T12 = T12 / qk1 / qk2
* polarisation vector
      do I = 1,4
       tmp = k1k2*pk2*q(I) - qk1*pk2*k2(I) + C4 * k1(I) 
       tmp = 2.d0*tmp - (1.d0/Rpar(42)) * ( 
     & 2.d0*qk1*qk2*( pl*q(I) - (mu2+ql)*p(I))
     & + qf * ( f2*pk2*k1(I)
     &      + p(I) *(mu2*k1k2 - 2.d0*lk1*fk2) 
     &      - k2(I)*(mu2*pk1  - 2.d0*pl*lk1 )  ) )    
     & -(2.d0*mu2/mw4)*qk1*qk2*k1k2*p(I) 
       lv(I) = lv(I) + L(5)*tmp / qk1 / qk2
      enddo

      ves = -coefW * rpar(15) * (T1 + T2 + T12)

      call vortas(l, vt)
      do I = 1,3
       hr(I) = -(1.d0 / (T1 + T2 + T12))  
     & * (vt(i,4)*lv(4)-vt(i,1)*lv(1)-vt(i,2)*lv(2)-vt(i,3)*lv(3))
      enddo
       hr(4) = 0.d0 
      ELSE
       print*, '  STOP running : not implemented ipar(21) = ',ipar(21) 
       STOP
      ENDIF

      if(ipar(33).eq.2) ves = ves * (1.d0-hr(3))/2.d0
      if(ipar(33).eq.3) ves = ves * (1.d0+hr(3))/2.d0

      return
      end



*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   02.05.2006                                 *
*....                                                                        *
      subroutine EPSIL4(A, B, C, D, EPS4)
*     ------------------------------                                         *
*                                                                            *
* EPS4 = epsilon(al, bl, cl, dl) A(al) B(bl) C(cl) D(dl)                     *
* A, B, C, D are 5-vectors                                                   *
*............................................................................*
      implicit None
      double precision A(5), B(5), C(5), D(5), EPS4, V(4)
 
*
      V(4) = - B(1) * (C(2)*D(3) - C(3)*D(2))
     &       + B(2) * (C(1)*D(3) - C(3)*D(1))
     &       - B(3) * (C(1)*D(2) - C(2)*D(1))
      V(1) = - B(4) * (C(2)*D(3) - C(3)*D(2))
     &       + B(2) * (C(4)*D(3) - C(3)*D(4))
     &       - B(3) * (C(4)*D(2) - C(2)*D(4))
      V(2) =   B(4) * (C(1)*D(3) - C(3)*D(1))
     &       - B(1) * (C(4)*D(3) - C(3)*D(4))
     &       + B(3) * (C(4)*D(1) - C(1)*D(4))
      V(3) = - B(4) * (C(1)*D(2) - C(2)*D(1))
     &       + B(1) * (C(4)*D(2) - C(2)*D(4))
     &       - B(2) * (C(4)*D(1) - C(1)*D(4))
      EPS4  = A(4)*V(4) - A(1)*V(1) - A(2)*V(2) - A(3)*V(3)
      return
      end
*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   02.05.2006                                 *
*....                                                                        *
      subroutine EPSIL3(B, C, D, EPS)
*     ------------------------------                                         *
*                                                                            *
* EPS(nu) = epsilon(nu, bl, cl, dl)  B(bl) C(cl) D(dl) is 5-vector           *
* B, C, D,  are 5-vectors                                                    *
*............................................................................*
      implicit None
      double precision EPS(5), B(5), C(5), D(5) 
*
      eps(4) = - B(1) * (C(2)*D(3) - C(3)*D(2))
     &         + B(2) * (C(1)*D(3) - C(3)*D(1))
     &         - B(3) * (C(1)*D(2) - C(2)*D(1))
      eps(1) = - B(4) * (C(2)*D(3) - C(3)*D(2))
     &         + B(2) * (C(4)*D(3) - C(3)*D(4))
     &         - B(3) * (C(4)*D(2) - C(2)*D(4))
      eps(2) =   B(4) * (C(1)*D(3) - C(3)*D(1))
     &         - B(1) * (C(4)*D(3) - C(3)*D(4))
     &         + B(3) * (C(4)*D(1) - C(1)*D(4))
      eps(3) = - B(4) * (C(1)*D(2) - C(2)*D(1))
     &         + B(1) * (C(4)*D(2) - C(2)*D(4))
     &         - B(2) * (C(4)*D(1) - C(1)*D(4))
      return
      end
*----------------------------------------------------------------------------*
*  matrix element for the W Q Qbar process                                   *
*.. author: Serge Slabospitsky                                               *
*.. 21/06/2000                                                               *
*                                                                            *
      subroutine MwQQ(k1,k2, q1, q2, PL, PN, ves)
*     ---------------------------------------------------                    *
*   U    Dbar --> W+ (-> e+(l1) nu(l2)) Q  Qbar                              *
*   k1   k2              PL     PN      q1 q2                                *
*   W-boson decay is included and W-boson is OFF-SHELL                       * 
*   denominators from gluon and W-boson propagators are removed and          *
*   calculated in LIPS (see RLIP43 routine)                                  *
*   amq is mass of q1 (or q2)                                                *
*............................................................................*
      Implicit none
      include "txpar.inc" 
      double precision amq, amq2
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision k1(5), k2(5), q1(5), q2(5), PL(5), pn(5)
      double precision q(5), r(5), x1(5), x2(5)
      double precision SCALP, t1, t2, t3 
      double precision qq2, s, t, U, R2, rk1, rk2, rl1, rl2
      double precision qk1, qk2, ql1, ql2, k1l1, k1l2, k2l1,k2l2, all
      double precision coef, ves 
      integer i

      LOGICAL first
      DATA first /.TRUE./
      SAVE first, Coef
*......
      if(first) THEN
      coef = 1024.*2.*rpar(10)*((4.*pi)**2)*(rpar(26)/2./dsqrt(2.d0))**4 
      coef = coef / (3. * 3. * 2. * 2.)  ! colors & spins
      coef = coef * 9.   !"*9" due to normalization to Br(W -> e+ nu) = 1
      first=.FALSE.
      ENDIF
* running
      amq = q1(5)
      amq2 = amq**2
      do i=1,4
       q(i) = q1(i) + q2(i)
       r(i) = q1(i) - q2(i)
       x1(i) = q(i) - k2(i)
       x2(i) = k1(i) - q(i)
      enddo

      qq2 = SCALP(q, q)
      t   = SCALP(x1, x1)
      U   = SCALP(x2, x2)
      S   = 2. * SCALP(k1, k2)
      R2  = SCALP(r, r)
      rk1 = SCALP(r, k1)
      rl1 = SCALP(r, pl)
      rk2 = SCALP(r, k2)
      rl2 = SCALP(r, pn)
      qk1 = SCALP(q, k1)
      ql1 = SCALP(q, PL)
      qk2 = SCALP(q, k2)
      ql2 = SCALP(q, pn)
      k1l1 = SCALP(k1, PL)
      k1l2 = SCALP(k1, pn)
      k2l1 = SCALP(k2, PL)
      k2l2 = SCALP(k2, pn)
      all   = SCALP(PL, pn)

      t1 = qq2*(- qk2*ql2 + 2.*qk2*k2l2 - rk2*rl2 + 2.*amq2*k2l2)
     & +qk2*(- 4.*ql2*amq2 + 2*rk2*rl2 - 2*qk2*k2l2) - 2*ql2*rk2**2
     &+ 2*rk2**2*k2l2

      t2 = qq2*(- qk1*ql1 + 2*qk1*k1l1 - rk1*rl1 + 2*amq2*k1l1)
     & - 4*qk1*ql1*amq2 + 2*qk1*rk1*rl1 - 2*qk1**2*k1l1 - 2*ql1*rk1**2
     &+ 2*rk1**2*k1l1

      t3 = s*qq2*(- 0.5*ql1*ql2 + ql1*k2l2 + ql2*k1l1 + 0.5*rl1*rl2
     &- 2*amq2*all - 2*k1l1*k2l2) + 2*s*ql1*ql2*amq2 - qq2*qk1*qk2*all
     &+ qq2*qk1*ql2*k2l1 - 2*qq2*qk1*k2l1*k2l2 + qq2*qk2*ql1*k1l2
     &- 2*qq2*qk2*k1l1*k1l2 + qq2*rk1*rk2*all - qq2*rk1*rl2*k2l1
     &- qq2*rk2*rl1*k1l2 + 4*qq2*amq2*k1l2*k2l1 - 2*qk1*qk2*rl1*rl2
     &+ 4*qk1*qk2*amq2*all + 4*qk1*qk2*k1l1*k2l2 + 2*qk1*ql2*rk2*rl1
     &- 4*qk1*ql2*amq2*k2l1 - 2*qk1*rk2*rl1*k2l2 + 2*qk2*ql1*rk1*rl2
     &- 4*qk2*ql1*amq2*k1l2 - 2*qk2*rk1*rl2*k1l1 - 2*ql1*ql2*rk1*rk2
     &+2*ql1*rk1*rk2*k2l2+2*ql2*rk1*rk2*k1l1 -4*rk1*rk2*k1l1*k2l2


      t1 = k1l1 * t1
      t2 = k2l2 * t2

      t1 = t1 / t**2
      t2 = t2 / u**2
      t3 = t3 / (t*u)

      ves = -(t1 + t2 + t3) * coef * rpar(15)**2
      ves = ves / qq2
      end
*----------------------------------------------------------------------------*
*  matrix element for the W Q Qbar process                                   *
*.. author: Serge Slabospitsky                                               *
*.. 09.11.2003                                                               *
*                                                                            *
      subroutine MwQQ_new(k1,k2, q1, q2, L1, L2, ves)
*     ---------------------------------------------------                    *
*   q1  qbar2 --> W+ (-> e+(l1) nu(l2)) Q  Qbar                              *
*   k1   k2              PL     PN      q1 q2                                *
*   W-boson decay is included and W-boson is OFF-SHELL                       * 
*   denominators from gluon and W-boson propagators are removed and          *
*   calculated in LIPS (see RLIP43 routine)                                  *
*   amq is mass of q1 (or q2)                                                *
*............................................................................*
      Implicit none
      include "txpar.inc" 
      double precision amq, amq2
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision k1(5), k2(5), q1(5), q2(5), L1(5), L2(5)
      double precision q(5), r(5), x1(5), x2(5)
      double precision SCALP, t1, t2, t3 
      double precision qq2, xx1, xx2, R2, rk1, rk2, rl1, rl2, k1k2,l1l2
      double precision qk1, qk2, ql1, ql2, k1l1, k1l2, k2l1, k2l2 
      double precision coef, ves 
      integer i

      LOGICAL first
      DATA first /.TRUE./
      SAVE first, Coef
*......
      if(first) THEN
      coef = 32.d0 * rpar(10)*((4.*pi)**2)*(rpar(26)/dsqrt(2.d0))**4 
      first=.FALSE.
      ENDIF
* running
      amq = q1(5)
      amq2 = amq**2
      do i=1,4
       q(i) = q1(i) + q2(i)
       r(i) = q1(i) - q2(i)
       x1(i) = q(i) - k2(i)
       x2(i) = k1(i) - q(i)
      enddo

      qq2 = SCALP(q, q)
      xx1 = SCALP(x1, x1)
      xx2 = SCALP(x2, x2)
      R2  = SCALP(r, r)
      rk1 = SCALP(r, k1)
      rk2 = SCALP(r, k2)
      rl1 = SCALP(r, L1)
      rl2 = SCALP(r, L2)
      qk1 = SCALP(q, k1)
      ql1 = SCALP(q, L1)
      qk2 = SCALP(q, k2)
      ql2 = SCALP(q, L2)
      k1k2 = SCALP(k1, k2)
      k1l1 = SCALP(k1, L1)
      k1l2 = SCALP(k1, L2)
      k2l1 = SCALP(k2, L1)
      k2l2 = SCALP(k2, L2)
      L1L2 = SCALP(L1, L2)

      t1 = xx1*rk2*rl2 
     &+ ql2*(qq2*qk2 + 2.d0*rk2**2 + 4.d0*amq2*qk2)
     &- 2.d0*k2l2*(qq2*amq2 + rk2**2 + qq2*qk2 - qk2**2)
      t1 = t1 * k1l1

      t2 = xx2*rk1*rl1 
     &+ ql1*(qq2*qk1 + 2.d0*rk1**2 + 4.d0*amq2*qk1)
     &- 2.d0*k1l1*(qq2*amq2 + rk1**2 + qq2*qk1 - qk1**2)
      t2 = t2 * k2l2

      t3 = -xx1*xx2*k1l1*k2l2
     & + qq2*qq2*(L1L2*K1K2 + K1L1*K2L2 - K1L2*K2L1)
     & + 4.d0*QQ2*K1K2*K1L1*K2L2
     & - 2.d0*QQ2*K1L1*(QL2*K1K2 + QK1*K2L2 - QK2*K1L2)
     & - 2.d0*QQ2*K2L2*(QL1*K1K2 + QK2*K1L1 - QK1*K2L1)
     & + QQ2*R2*(L1L2*K1K2 - K1L2*K2L1)
     & + RK1*RK2*(4.d0*K1L1*K2L2 - 2.d0*K1L1*QL2 - 2.d0*K2L2*QL1
     &          + 2.d0*QL1*QL2 - QQ2*L1L2)
     & + RK1*RL2*(2.d0*K1L1*QK2 - 2.d0*QL1*QK2 + QQ2*K2L1)
     & + RL1*RK2*(2.d0*K2L2*QK1 - 2.d0*QL2*QK1 + QQ2*K1L2)
     & + RL1*RL2*(2.d0*QK1*QK2 - QQ2*K1K2)
     & + R2*QK1*(QL2*K2L1 - QK2*L1L2)
     & + R2*QL1*(QK2*K1L2 - QL2*K1K2)

      t1 = t1 / XX1**2
      t2 = t2 / XX2**2
      t3 = t3 / (XX1*XX2) 

      ves =  ( (t1 + t2 + t3) / qq2) * coef * rpar(15)**2
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  19/11/2006                                  *
*  complex matrix element for the process                                    *
*  G  G  --> t(pol)  + t_bar(pol)                                            *
* we calculate in t tbar center of mass system!
*----------------------------------------------------------------------------*
      subroutine ggttbar(q1, q2, p1, p2, hh, ves)
*     -------------------------------------------                            *
      implicit none
      include "txpar.inc" 
      double precision q1(5), q2(5)   ! momenta of initial gluons 
      double precision p1(5), p2(5)   ! momenta of final t and tbar 
      DOUBLE COMPLEX ei   
      data ei/(0.d0, 1.d0)/
      double precision Ves, coef, zn1, zn2
      COMMON /colden/ zn1, zn2
      double precision         pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision S, SCALP,sqr,pp1(5),pp2(5),ptt(5)
      double precision hh0, hh(3,3), tm1, tm2 
      Integer I1, I2, j1,j2
      double complex T1, T2,  
     & UVex, UVey, UVq1, UVq2, UVq1exy, UVq2exy, F0 
      double complex b1(2,2,2,2), b2(2,2,2,2), U(2,4), V(2,4) 
c      double precision ZM11, ZM12, ZM21, ZM22
      LOGICAL first
      SAVE first, coef
      DATA first /.TRUE./
*
      if(first) THEN
        coef = (4.d0 * pi)**2                     ! due to alpha_s
        coef = coef * rpar(10)                    ! transform into millibarns
        coef = coef / (8.d0 * 8.d0 * 2.d0 * 2.d0) ! colors & spins
        coef = coef / 3.d0                        ! color normalization
        first=.FALSE.
      ENDIF

      S   = 2.d0 * SCALP(q1, q2)
      ZN1 = 2.d0 * SCALP(p1, q1)
      ZN2 = 2.d0 * SCALP(p1, q2)
* boost to QQbar rest frame
      sqr = dsqrt(s)
       do i1 = 1,4
        ptt(i1) = p1(i1) + p2(i1)
       enddo
       ptt(5) = dsqrt(scalp(ptt, ptt))
       call lorenf_s(ptt, p1, pp1)
       call lorenf_s(ptt, p2, pp2)
* pp1 and pp2 are in QQbar rest frame

      call Dirs2_Ubar(pp1, U) 
      call Dirs2_V   (pp2, V) 

      Tm1 = 0.d0
      Tm2 = 0.d0
*  b(i1,i2,j1,j2) i1,i2 are final fermion's indexes
*                 j1,j2 are initial gluon's indexes

      do 990 i1 = 1,2
      do 990 i2 = 1,2
      do 990 j1 = 1,2
      do 990 j2 = 1,2
       b1(i1,i2,j1,j2) = (0.d0,  0.d0)
 990   b2(i1,i2,j1,j2) = (0.d0,  0.d0)


      do 999 i1 = 1,2
      do 999 i2 = 1,2
       if(ipar(33).eq.0.or.ipar(33).eq.1) goto 991
       if(ipar(33).eq.4.and.i1.eq.1.and.i2.eq.1) goto 991
       if(ipar(33).eq.5.and.i1.eq.1.and.i2.eq.2) goto 991
       if(ipar(33).eq.6.and.i1.eq.2.and.i2.eq.1) goto 991
       if(ipar(33).eq.7.and.i1.eq.2.and.i2.eq.2) goto 991
        goto 999
 991   continue
* e_x:  Ubar [ e_x ] V 
      UVex = +U(i1,1)*V(i2,4) + U(i1,2)*V(i2,3)
     &       -U(i1,3)*V(i2,2) - U(i1,4)*V(i2,1)  
* e_y:  Ubar [ e_y ] V 
      UVey = -U(i1,1)*V(i2,4) + U(i1,2)*V(i2,3)
     &       +U(i1,3)*V(i2,2) - U(i1,4)*V(i2,1)  
      UVey = ei * UVey
* Ubar [ q1 ] V
      UVq1 = sqr * ( U(i1,1)*V(i2,3) + U(i1,4)*V(i2,2))
      UVq2 = sqr * ( U(i1,2)*V(i2,4) + U(i1,3)*V(i2,1))
* Ubar [ q1 e_x e_y ] V
      UVq1exy = ei*sqr * (-U(i1,1)*V(i2,3) + U(i1,4)*V(i2,2))
      UVq2exy = ei*sqr * ( U(i1,2)*V(i2,4) - U(i1,3)*V(i2,1))

      F0 = -U(i1,1)*V(i2,3) + U(i1,2)*V(i2,4)
     &     +U(i1,3)*V(i2,1) - U(i1,4)*V(i2,2)  
      F0 = sqr * F0
* g_1(1) + g_2(1)
      T1 = (-2.d0*pp1(1)*UVex - UVq1) / zn1
     &   + (-2.d0*pp1(1)*UVex - UVq2) / zn2
      T2 = (-2.d0*pp1(1)*UVex - UVq1) / zn1
     &   - (-2.d0*pp1(1)*UVex - UVq2) / zn2
     &   - 2.d0 * F0 / s
       b1(i1,i2,1,1) = T1
       b2(i1,i2,1,1) = T2
       tm1 = tm1 + T1 * conjg (T1)
       tm2 = tm2 + T2 * conjg (T2)
* g_1(1) + g_2(2)
      T1 = (-2.d0*pp1(1)*UVey + UVq1exy) / zn1 
     &   + (-2.d0*pp1(2)*UVex - UVq2exy) / zn2
      T2 = (-2.d0*pp1(1)*UVey + UVq1exy) / zn1 
     &   - (-2.d0*pp1(2)*UVex - UVq2exy) / zn2
       b1(i1,i2,1,2) = T1
       b2(i1,i2,1,2) = T2
       tm1 = tm1 + T1 * conjg (T1)
       tm2 = tm2 + T2 * conjg (T2)
* g_1(2) + g_2(1)
      T1 = (-2.d0*pp1(2)*UVex - UVq1exy) / zn1
     &   + (-2.d0*pp1(1)*UVey + UVq2exy) / zn2
      T2 = (-2.d0*pp1(2)*UVex - UVq1exy) / zn1
     &   - (-2.d0*pp1(1)*UVey + UVq2exy) / zn2
       b1(i1,i2,2,1) = T1
       b2(i1,i2,2,1) = T2
       tm1 = tm1 + T1 * conjg (T1)
       tm2 = tm2 + T2 * conjg (T2)
* g_1(2) + g_2(2)
      T1 = (-2.d0*pp1(2)*UVey - UVq1) / zn1
     &   + (-2.d0*pp1(2)*UVey - UVq2) / zn2
      T2 = (-2.d0*pp1(2)*UVey - UVq1) / zn1
     &   - (-2.d0*pp1(2)*UVey - UVq2) / zn2
     &     - 2.d0 *  F0 / s
       b1(i1,i2,2,2) = T1
       b2(i1,i2,2,2) = T2
      tm1 = tm1 + T1 * conjg (T1)
      tm2 = tm2 + T2 * conjg (T2)
 999  continue  

      hh0 = 7.d0*TM1 + 9.d0*TM2

       do 956 j1 = 1,3
       do 956 j2 = 1,3
 956     hh(j1,j2) = 0.d0

       do 988 i1 = 1,2
       do 988 i2 = 1,2
* hh(1,1) xx
        T1 = b1(1,1,i1,i2) + b1(2,1,i1,i2)  
     &     - b1(1,2,i1,i2) - b1(2,2,i1,i2) 
        T2 = b2(1,1,i1,i2) + b2(2,1,i1,i2)  
     &     - b2(1,2,i1,i2) - b2(2,2,i1,i2) 
       hh(1,1) = hh(1,1) +       7.d0*T1*conjg(T1)+9.d0*T2*conjg(T2)
* hh(2,1) : yx
        T1 = b1(1,1,i1,i2) - b1(1,2,i1,i2)  
     & - ei*(b1(2,1,i1,i2) - b1(2,2,i1,i2)) 
        T2 = b2(1,1,i1,i2) - b2(1,2,i1,i2)  
     & - ei*(b2(2,1,i1,i2) - b2(2,2,i1,i2)) 
       hh(2,1) = hh(2,1)  +      7.d0*T1*conjg(T1)+9.d0*T2*conjg(T2)
* hh(3,1) : zx
        T1 = b1(1,1,i1,i2) - b1(1,2,i1,i2) 
        T2 = b2(1,1,i1,i2) - b2(1,2,i1,i2)  
       hh(3,1) = hh(3,1) + 4.d0*(7.d0*T1*conjg(T1)+9.d0*T2*conjg(T2))
* hh(1,2) : xy
        T1 = b1(1,1,i1,i2) + b1(2,1,i1,i2)  
     & - ei*(b1(1,2,i1,i2) + b1(2,2,i1,i2)) 
        T2 = b2(1,1,i1,i2) + b2(2,1,i1,i2)  
     & - ei*(b2(1,2,i1,i2) + b2(2,2,i1,i2)) 
       hh(1,2) = hh(1,2)  +      7.d0*T1*conjg(T1)+9.d0*T2*conjg(T2)
* hh(2,2) : yy
        T1 = b1(1,1,i1,i2) - b1(2,2,i1,i2)  
     & - ei*(b1(1,2,i1,i2) + b1(2,1,i1,i2)) 
        T2 = b2(1,1,i1,i2) - b2(2,2,i1,i2)  
     & - ei*(b2(1,2,i1,i2) + b2(2,1,i1,i2)) 
       hh(2,2) = hh(2,2)  +      7.d0*T1*conjg(T1)+9.d0*T2*conjg(T2)
* hh(3,2) :zy
        T1 = b1(1,1,i1,i2) - ei*b1(1,2,i1,i2) 
        T2 = b2(1,1,i1,i2) - ei*b2(1,2,i1,i2)
       hh(3,2) = hh(3,2) + 4.d0*(7.d0*T1*conjg(T1)+9.d0*T2*conjg(T2))
* hh(1,3) :xz
        T1 = b1(1,2,i1,i2) + b1(2,2,i1,i2)
        T2 = b2(1,2,i1,i2) + b2(2,2,i1,i2)
       hh(1,3) = hh(1,3) + 4.d0*(7.d0*T1*conjg(T1)+9.d0*T2*conjg(T2))
* hh(2,3) : yz
        T1 = b1(1,2,i1,i2) - ei*b1(2,2,i1,i2)
        T2 = b2(1,2,i1,i2) - ei*b2(2,2,i1,i2)
       hh(2,3) = hh(2,3) + 4.d0*(7.d0*T1*conjg(T1)+9.d0*T2*conjg(T2))
* hh(3,3) : zz
        T1 = b1(1,2,i1,i2) 
        T2 = b2(1,2,i1,i2) 
       hh(3,3) = hh(3,3) + 4.d0*(7.d0*T1*conjg(T1)+9.d0*T2*conjg(T2))
 988   continue
      do i1 = 1,3
      do i2 = 1,3
       hh(i1,i2) = (hh(i1,i2) - hh0) / hh0
      enddo
      enddo
c      write(*,*) '*****'
c      write(*,121) (hh(1,i1),i1=1,3)
c 121  format(' XX XY XZ ',3(f10.4,1x))
c      write(*,122) (hh(2,i1),i1=1,3)
c 122  format(' YX YY YZ ',3(f10.4,1x))
c      write(*,123) (hh(3,i1),i1=1,3)
c 123  format(' ZX ZY ZZ ',3(f10.4,1x))
      ves = coef * rpar(15)**2 * hh0 
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  19/11/2006                                  *
*  complex matrix element for the process                                    *
*  q  qabr --> t(pol)  + t_bar(pol)                                          *
* we calculate in t tbar center of mass system!                              *
*----------------------------------------------------------------------------*
      subroutine qqttbar(q1, q2, p1, p2, hh, ves)
*     -------------------------------------------                            *
      implicit none
      include "txpar.inc" 
      double precision q1(5), q2(5)   ! momenta of initial gluons 
      double precision p1(5), p2(5)   ! momenta of final t and tbar 
      DOUBLE COMPLEX ei   
      data ei/(0.d0, 1.d0)/
      double precision Ves, coef, zn1, zn2
      COMMON /colden/ zn1, zn2
      double precision         pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision S, SCALP,sqr,pp1(5),pp2(5),ptt(5)
      double precision hh0, hh(3,3), tm 
      Integer I1, I2, j1,j2
      double complex T1
      double complex bb(2,2,2), U(2,4), V(2,4) 
      LOGICAL first
      SAVE first, coef
      DATA first /.TRUE./
*
      if(first) THEN
        coef = (pi4)**2     ! due to alpha_s
        coef = coef * rpar(10)    ! transform into millibarns
        coef = coef * (2.d0/3.d0/3.d0/2.d0/2.d0) ! colors & spins
        first=.FALSE.
      ENDIF

      S   = 2.d0 * SCALP(q1, q2)
* boost to QQbar rest frame
      sqr = dsqrt(s)
       do i1 = 1,4
        ptt(i1) = p1(i1) + p2(i1)
       enddo
       ptt(5) = dsqrt(scalp(ptt, ptt))
       call lorenf_s(ptt, p1, pp1)
       call lorenf_s(ptt, p2, pp2)
* pp1 and pp2 are in QQbar rest frame

      call Dirs2_Ubar(pp1, U) 
      call Dirs2_V   (pp2, V) 

*  bb(i1,i2,j1) i1,i2 are final fermion's indexes
*                 j1    is  initial quark's indexes: two states
      tm = 0.d0
      do 999 i1 = 1,2
      do 999 i2 = 1,2
       if(ipar(33).eq.0.or.ipar(33).eq.1) goto 991
       if(ipar(33).eq.4.and.i1.eq.1.and.i2.eq.1) goto 991
       if(ipar(33).eq.5.and.i1.eq.1.and.i2.eq.2) goto 991
       if(ipar(33).eq.6.and.i1.eq.2.and.i2.eq.1) goto 991
       if(ipar(33).eq.7.and.i1.eq.2.and.i2.eq.2) goto 991
        goto 999
 991   continue
      bb(i1,i2,1) = U(i1,2)*V(i2,3) - U(i1,4)*V(i2,1)
      bb(i1,i2,2) = U(i1,1)*V(i2,4) - U(i1,3)*V(i2,2)
       tm = tm + bb(i1,i2,1) * conjg(bb(i1,i2,1)) 
     &         + bb(i1,i2,2) * conjg(bb(i1,i2,2)) 
 999  continue  

      hh0 = TM * 2.d0 / sqr

       do 956 j1 = 1,3
       do 956 j2 = 1,3
 956     hh(j1,j2) = 0.d0

       do 988 j1 = 1,2
* hh(1,1) xx
        T1 = bb(1,1,j1) + bb(2,1,j1)  
     &     - bb(1,2,j1) - bb(2,2,j1) 
       hh(1,1) = hh(1,1) +      T1*conjg(T1) 
* hh(2,1) : yx
        T1 = bb(1,1,j1) - bb(1,2,j1)  
     & - ei*(bb(2,1,j1) - bb(2,2,j1)) 
       hh(2,1) = hh(2,1)  +     T1*conjg(T1)
* hh(3,1) : zx
        T1 = bb(1,1,j1) - bb(1,2,j1) 
       hh(3,1) = hh(3,1) + 4.d0*T1*conjg(T1)
* hh(1,2) : xy
        T1 = bb(1,1,j1) + bb(2,1,j1)  
     & - ei*(bb(1,2,j1) + bb(2,2,j1)) 
       hh(1,2) = hh(1,2)  +     T1*conjg(T1)
* hh(2,2) : yy
        T1 = bb(1,1,j1) - bb(2,2,j1)  
     & - ei*(bb(1,2,j1) + bb(2,1,j1)) 
       hh(2,2) = hh(2,2)  +     T1*conjg(T1)
* hh(3,2) :zy
        T1 = bb(1,1,j1) - ei*bb(1,2,j1) 
       hh(3,2) = hh(3,2) + 4.d0*T1*conjg(T1)
* hh(1,3) :xz
        T1 = bb(1,2,j1) + bb(2,2,j1)
       hh(1,3) = hh(1,3) + 4.d0*T1*conjg(T1)
* hh(2,3) : yz
        T1 = bb(1,2,j1) - ei*bb(2,2,j1)
       hh(2,3) = hh(2,3) + 4.d0*T1*conjg(T1)
* hh(3,3) : zz
        T1 = bb(1,2,j1) 
       hh(3,3) = hh(3,3) + 4.d0*T1*conjg(T1)
 988   continue
      do i1 = 1,3
      do i2 = 1,3
       hh(i1,i2) = (hh(i1,i2) - hh0) / hh0
      enddo
      enddo
      ves = coef * rpar(15)**2 * hh0 * 2.d0/sqr
      return
      end
*----------------------------------------------------------------------------*
*  author: Serge Slabospitsky                                                *
*   26.01.2002                                                               *
*  matrix element for the H+ H-              production process              *
*  q   q~ --> H+  H-                                                         *
*  q1  q2     k1  k2                                                         * 
*............................................................................*
      subroutine qqHH(iq, q1, q2, k1, k2, ves)

      implicit none
      include "txpar.inc" 
      double precision  q1(5), q2(5)        ! initial q and q~ quarks 
      double precision  k1(5), k2(5)        ! final H+ and H- 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision Ves, coefQ, coefV, coefI, SCALP
      save coefQ, coefV, coefI 
      double precision a(6), b(6), r(5), x(5) 
*
      double precision kap, kas, KAZ, ad,bd, au,bu, mt2, mu2 
      save kap, kas, KAZ, ad,bd, au,bu 
      double precision qq2,q1r,q2r,q1x,q2x,q1q2,r22,x22,z,rx, q1k1
      double precision TV, TQ, TI, ga, gb
      integer IQ, J
      double precision HCPL,       HCPL2   
      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)
      LOGICAL first
      SAVE first
      DATA first /.TRUE./
*......... 
      IF(first) THEN        ! initializing
      first=.FALSE.
c  pure Higgs
*..RPAR(26)     : g = g_weak  = e / sin(theta_W)                             *
*..Rpar(41)     : W-boson mass                                               *
*..Rpar(42)     : Rpar(41)**2                                                *
*..Rpar(55)     : tan(beta)                                                  *
*..Rpar(56)     : (1/tan(beta))                                              *

       coefQ = rpar(10) * rpar(26)**4 / 4. 
       coefQ = coefQ / 4.d0 / 3.d0         ! spin & colors
        coefV = rpar(10) * rpar(13)**4     ! e^4 
        coefV = coefV / 4.d0 / 3.d0        ! spin & colors
       coefI = rpar(10) * rpar(26)**2 * rpar(13)**2 / 2. 
       coefI = coefI / 4.d0 / 3.d0         ! spin & colors
*
*      Rpar(25) =  sin(2*theta_W)
       kap = (rpar(24)-rpar(23))/rpar(25)**2
       kas = (2.d0/3.d0)*rpar(23)
       ad = kap * (-1.d0 +      kas ) 
       bd = kap * ( 1.d0) * kas 
       au = kap * (+1.d0 - 2.d0*kas ) 
       bu = kap * (-2.d0) * kas 
       ga = hcpl(6) 
       gb = hcpl(5)  
      ENDIF
* running

      mt2 = mq2(6)
      mu2 = q1(5)**2
      qq2 = q1(5)**2 + q2(5)**2 + 2.d0*scalp(q1,q2) ! shat
       kaz = qq2 - rpar(46)
       a(1) = (-1.d0/3.d0)/qq2 + kap*ad / kaz ! d 
       b(1) = (-1.d0/3.d0)/qq2 + kap*bd / kaz ! d 
       a(2) = (+2.d0/3.d0)/qq2 + kap*au / kaz ! u 
       b(2) = (+2.d0/3.d0)/qq2 + kap*bu / kaz ! u 
      do J = 1,2
        a(2*j+1) = a(1)
        b(2*j+1) = b(1)
        a(2*j+2) = a(2)
        b(2*j+2) = b(2)
      enddo
      do J = 1,5
       r(j) = k1(j) - k2(j)
       x(j) = q1(j) - k1(j) 
      enddo

      
      q1r = scalp(q1, r) 
      q2r = scalp(q2, r) 
      q1x = scalp(q1, x) 
      q2x = scalp(q2, x) 
      rx  = scalp(r,  x)
      q1q2 = scalp(q1, q2)
      r22  = scalp(r, r) 
      q1k1 = scalp(q1, k1)
      x22  = scalp(x, x)
      z = mq2(6) - x22
*
      TV = 2.d0*(a(iq)**2 + b(iq)**2)*
     & (2.d0*q1r*q2r - q1q2*r22) - 4.d0*mu2*a(iq)*b(iq)*r22
*
      TQ = 0.d0
      TI = 0.d0
      if(IQ.eq.5) then
      TQ = 4.d0*ga**2*gb**2 * (mt2*q1q2-mt2*mu2-mu2*x22) 
     &   + 2.d0*(ga**4+gb**4)*(2.d0*q1x*q2x - x22*q1q2)
     &   + 4.d0*mq(6)*mq(5)*ga*gb*(ga**2+gb**2)*(q2x-q1x)
*
      TI = 4.d0*mq(5)*mq(6)*ga*gb*(a(iq)+b(iq))*(q2r - q1r) 
     & - 4.d0*( b(iq)*ga**2 + a(iq)*gb**2)*mu2*rx
     & + 4.d0*( b(iq)*gb**2 + a(iq)*ga**2) 
     & * (q1x*q2r + q1r*q2x - q1q2*rx) 
      endif
*
       ves = coefV * TV + coefQ * TQ / Z**2 + coefI * TI / Z
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  04.06.2002                                  *
*   b b_bar  -->  t(pol)  + t_bar(pol)                                       *
*----------------------------------------------------------------------------*
      subroutine bbttbar(q1, q2, p1, p2, ves)
*     --------------------------------------------                           *
      implicit none
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision HCPL,       HCPL2   
      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)
      double precision q1(5), q2(5)   ! momenta of initial gluons 
      double precision p1(5), p2(5)   ! momenta of final t and tbar 
      double precision Ves, coefg, coefv, mt2, mb2, scalp 
      save coefg, coefv  
      double precision TG, TW, TH 
      double precision S, A, B, p1p2, q1q2   ! A = q1p1      B = q2p1
      double precision zw, zh 
      LOGICAL first
      DATA first /.TRUE./
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
*
      if(first) THEN
        coefg = pi4**2          ! due to alpha_s
        coefg = coefG * rpar(10)               ! transform into millibarns
        coefg = coefG * 2.d0 
       coefV  = rpar(10)*(rpar(26)**2 / 2.d0)**2
       coefV = 9.d0 * coefV 
        coefG = coefG / (3.d0*3.d0*2.d0*2.d0)   ! color & spin
        coefV = coefV / (3.d0*3.d0*2.d0*2.d0)   ! color & spin
        first=.FALSE.
      ENDIF

   
      mt2 = p1(5)**2
      mb2 = q1(5)**2
      p1p2 = SCALP(P1, P2)
      q1q2 = SCALP(Q1, Q2)
      S = 2.d0*(mt2 + p1p2 ) 
      A = SCALP(P1, Q1) 
      B = SCALP(P1, Q2)
      zw = mb2 + mt2 - 2.d0*A - rpar(42)
      zh = mb2 + mt2 - 2.d0*A - rpar(52)

      TG = 2.d0*mb2*mt2 + mb2*p1p2 + mt2*q1q2 + A*A + B*B 
      TG = 32.d0 * rpar(15)**2 * coefg * TG / S / S 

      TW = 16.d0 * B**2 
     & + (8.d0/rpar(42))*(mb2**2*p1p2+mt2**2*q1q2-2.d0*mb2*mt2*B)
     & + (4.d0/rpar(42)**2)*( (mb2+mt2)*A - 2.d0*mb2*mt2)**2
      TW = coefV * TW / zw**2

      TH = 4.d0 * (2.d0*q1(5)*p1(5)*hcpl(5)*hcpl(6)
     &   + (hcpl2(5)+hcpl2(6))*A)**2
      TH = coefV * TH / zh**2

*      ves = TG + TW + TH
      ves = TH 

      return
      end
c----------------------------------------------------------------------------*
*... author  :  Serge Slabospitsky                                           *
*... 02.07.2006                                                              *
*............................................................................*
*
	Subroutine TXmatching(istat)
*	-------------------
*
      Implicit None
      include "txpar.inc" 
      include "txpro.inc" 
      integer  kmc , istat
      double precision pmc(5)
      double precision pt, ptcut, pttt
      integer imatch
      common /wmtch/imatch 
      LOGICAL first
      DATA first /.TRUE./
      SAVE first, ptcut
      integer icall,ical2
      double precision pt0, ptmin, ptmax
      common /promtch/ptmin, ptmax
      double precision nsng1, nsng2
      common /xmatch/ nsng1(2), nsng2(2)
* test
      integer    nd 
      parameter (ND=50) 
      double precision nh1, nh2, xpt 
      common /ahist/nh1(nd), nh2(nd), xpt(nd)
*
      IF(first) THEN
       icall = 0
       nsng1(1) = 0.d0
       nsng1(2) = 0.d0
       nsng2(1) = 0.d0
       nsng2(2) = 0.d0
        if(txsel.eq.1) ptcut  = 12.5d0 ! t-channel single top
        if(txsel.eq.2) ptcut  = 80.d0  ! FCNC
       first=.FALSE.
      ENDIF 

      istat = 0
      if(txsel.eq.1.or.txsel.eq.2) then
       continue
      else
       return 
      endif


      icall = icall + 1
      if(imatch.eq.1.or.imatch.eq.2) then 
       call tx_mtch0(kmc, pmc) 
*       call tsng_finder(kmc, pmc) 
        if(kmc.ne.0) then
          if    (imatch.eq.1) then
            if(pt(pmc).ge.ptcut) istat = 1       
          elseif(imatch.eq.2) then
            if(pt(pmc).lt.ptcut) istat = 1       
          endif 
        endif
      else
       return
      endif

          if    (imatch.eq.1) then
            if(pt(pmc).lt.ptcut) nsng1(1) = nsng1(1) + 1.d0
            if(pt(pmc).ge.ptcut) nsng1(2) = nsng1(2) + 1.d0
          elseif(imatch.eq.2) then
            if(pt(pmc).lt.ptcut) nsng2(1) = nsng2(1) + 1.d0
            if(pt(pmc).ge.ptcut) nsng2(2) = nsng2(2) + 1.d0
          endif 
       pttt = pt(pmc)

       call tx_mtch1(pttt,imatch)
        ical2 = mod(icall,200) 
        if(icall.ge.100.and.ical2.eq.1) then
        call tx_mtch2(pt0) 
         if(pt0.gt.PTmin.and.pt0.lt.PTmax) ptcut = pt0
       endif
*       write(67,*) 'IPAR(81) ',ipar(81) 
       if(ipar(81).eq.1) then
         if(mod(icall,100).eq.1) then
         write(67,122) NXev(11), ptcut
 122     format('  ipar(1) = 11  Nev = ',i20,' PTcut = ',f6.3)
         endif
       endif
 999   continue
      return
      end 
c----------------------------------------------------------------------------*
*... author  :  Serge Slabospitsky                                           *
*... 02.07.2006                                                              *
*... search sing Top in FCNC 2 -> 1 and 2 -> 2 processes in PYJETS list      *
*... should be applied for TopReX process with txsel = 2                     *
*... search Bbar (B) additional to TOP(TOPbar) in PYJETS list                *
*... should be applied for TopReX process with ipar(1) = 1 and 2             *
*............................................................................*
*
	Subroutine tx_mtch0(kmc, pmc) 
*	-------------------
*
      Implicit None
      include "txpar.inc" 
      include "txpro.inc" 
      INTEGER         NN, NPAD, KK
      DOUBLE PRECISION                      PP,         VV
      COMMON /PYJETS/ NN, NPAD, KK(4000,5), PP(4000,5), VV(4000,5)
      integer I
      integer        kmc, ks, kb 
      double precision  pmc(5) 
*
       kmc = 0
        do i = 1,5
         pmc(i) = 0.d0
        enddo 
       if(txsel.le.0) return 
      IF(txsel.eq.1) then
       kb = 0
       kmc = 0
        do i = 5, NN
         if(abs(kk(i,2)).eq.6) goto 21
        enddo
       return      ! no top-quark 
 21   ks = I ! top
       do i = ks, NN
        if((kk(i,2)*kk(ks,2)).eq.-30) goto 22 
       enddo
      return      ! no requested b-quark
 22   kmc = I 
        do I = 1,5
         Pmc(I)   = PP(kmc, I)
        enddo
       kmc = kk(kmc,2)
       return
      ENDIF
*
      IF(txsel.eq.2) then
        kb = 0
        ks = 0
       If(Ipar(1).eq.30) then
         do i = 7, NN 
          if(kb.ge.1.and.ks.ge.1) goto 23
          if(abs(kk(i,2)).eq.5)  kb = I
          if(abs(kk(i,2)).eq.24) ks = I
         enddo
 23      continue
       if(kb.eq.0.or.ks.eq.0) then
         print*,'TopReX matching for FCNC single top'
         print*,'process 30: 2 -> 1  - no B or W',kb,ks
         print*,'stop run'
          STOP   ! no t-quark is found
        endif                 
        do I = 1,5
         Pmc(I)   = PP(kb, I) + PP(ks, I)
        enddo
       kmc = +1 
      ElseIf(Ipar(1).eq.31.OR.Ipar(1).eq.32.
     &    OR.Ipar(1).eq.33) then
        kmc = 0
       do i = 7, NN
        if(kmc.ge.1) goto 24
        if(abs(kk(i,2)).eq.6)  kmc = I
       enddo
 24    continue
       if(kmc.eq.0) then
        print*,'TopReX matching for FCNC single top'
        print*,'process 31 or 32 or 33: 2 -> 2  - no TOP'
        print*,'stop run'
         STOP    ! no t-quark is found
       endif                 
        do I = 1,5
         Pmc(I)   = PP(kmc, I) 
        enddo
       EndIf
       return
      ENDIF
      return
      end
c----------------------------------------------------------------------------*
*... author  :  Serge Slabospitsky                                           *
*... 09.02.2002                                                              *
*... search Bbar (B) additional to TOP(TOPbar) in PYJETS list                *
*... should be applied for TopReX process with ipar(1) = 1 and 2             *
*............................................................................*
*
	Subroutine tsng_finder(kfb, pb) 
*	-------------------
*
      Implicit None
      INTEGER         NN, NPAD, KK
      DOUBLE PRECISION                      PP,         VV
      COMMON /PYJETS/ NN, NPAD, KK(4000,5), PP(4000,5), VV(4000,5)
      integer I
      integer        kft, kfb 
      double precision  pb(5) 
*
      kfb = 0
      kft = 0
       do i = 5, NN
        if(abs(kk(i,2)).eq.6) goto 21
       enddo
      return      ! no top-quark 
 21   kft = I 
       do i = kft, NN
        if((kk(i,2)*kk(kft,2)).eq.-30) goto 22 
       enddo
      return      ! no requested b-quark
 22   kfb = I 
        do I = 1,5
         Pb(I)   = PP(kfb, I)
        enddo
       kfb = kk(kfb,2)
      return
      end
c----------------------------------------------------------------------------*
*... author  :  Serge Slabospitsky                                           *
*... 08.04.2002                                                              *
*............................................................................*
*
	Subroutine tx_mtch1(pt,is) 
*	-------------------
*
      Implicit None
      include "txpar.inc"
      include "txpro.inc" 
      integer    nd
      parameter (ND=50) 
      double precision pt,del, ptmin,ptmax
      SAVE del 
      double precision nh1, nh2, xpt 
      common /ahist/nh1(nd), nh2(nd), xpt(nd)
      save /ahist/
      integer I, IS
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
      common /promtch/ptmin, ptmax
      SAVE /promtch/ 
***
      IF(first) THEN
       if(txsel.eq.1) then
         ptmin = 5.d0   ! t-channel single top
         ptmax = 25.d0 
       elseif(txsel.eq.2) then
         ptmin =  50.d0   ! FCNC  single top
         ptmax = 150.d0 
       endif

      del = (ptmax - ptmin)/(nd-1)
       do i=1,  nd 
        xpt(i) = ptmin - del/2.0 + del * i  ! 12.08.2003
        nh1(i) = 0.d0
        nh2(i) = 0.d0
       enddo
      first=.FALSE.
      ENDIF
*
      if(pt.lt.ptmin.OR.pt.ge.ptmax) then 
       return
      endif

      do i=1,nd
       if(pt.ge.(xpt(i)-del/2.d0).and.pt.lt.(xpt(i)+del/2.d0)) then
        if(is.eq.1) nh1(i) = nh1(i) + 1.d0
        if(is.eq.2) nh2(i) = nh2(i) + 1.d0
       endif
      enddo
      return
      end

c----------------------------------------------------------------------------*
*... author  :  Serge Slabospitsky                                           *
*... 08.04.2002                                                              *
*............................................................................*
*
      Subroutine tx_mtch2(pt0) 
      Implicit None
      integer    nd
      parameter (ND=50) 
      double precision ptmin,ptmax,xpt 
      double precision nh1, nh2 
      common /ahist/nh1(nd), nh2(nd), xpt(nd)
      double precision z0,z1,z2,z3,z4,al1,b1,al2,b2,pt0,alx 
      common /promtch/ptmin, ptmax
      integer I 
*   fitting
      pt0 = 0.d0
      z0 = 0.d0
      z1 = 0.d0
      z2 = 0.d0
      z3 = 0.d0
      z4 = 0.d0
      do I = 1,nd
       if(nh1(i).eq.0) goto 221
       z0 = z0 + 1.d0*nh1(i)
       z1 = z1 + xpt(i)*nh1(i)
       z2 = z2 + xpt(i)**2*nh1(i)
       z3 = z3 + dlog(nh1(i)) * nh1(i)
       z4 = z4 + xpt(i)*dlog(nh1(i)) * nh1(i)
 221	continue
      enddo
      alx = z0*z2 - z1*z1
      if(abs(alx).le.0.000001) return
      al1 = (z2*z3 - z1*z4) / alx
      b1  = (z1*z3 - z0*z4) / alx
*
      z0 = 0.d0
      z1 = 0.d0
      z2 = 0.d0
      z3 = 0.d0
      z4 = 0.d0
      do I = 1,nd
       if(nh2(i).eq.0) goto 222
       z0 = z0 + 1.d0*nh2(i)
       z1 = z1 + xpt(i)*nh2(i)
       z2 = z2 + xpt(i)**2*nh2(i)
       z3 = z3 + dlog(nh2(i)) * nh2(i)
       z4 = z4 + xpt(i)*dlog(nh2(i)) * nh2(i)
 222	continue
      enddo
      alx = z0*z2 - z1*z1
      if(abs(alx).le.0.000001) return
      al2 = (z2*z3 - z1*z4) / alx
      b2  = (z1*z3 - z0*z4) / alx
      pt0 = (al2 - al1) / (b2 - b1)
      return
      end
*----------------------------------------------------------------------------*
 
      BLOCK DATA TXDATA
 
C...double precision and integer declarations.
      IMPLICIT NONE 
*............................................................................*
*..... GLOBAL     TopReX    parameters                                       *
*. . . . . .  INTEGER parametrs . . . . . . . . . . . . . . . . . . . . . .  *
*..Ipar(1)      ! internal TopReX code of the process                        *
*  -1 : PYTHIA process                                                       *
*  Ipar(1) =  1  :  EW top : W g(2->2)                                       *
*  Ipar(1) =  2  :  EW top : W g(2->3)                                       *
*  Ipar(1) =  3  :  EW top : t W                                             *
*  Ipar(1) =  4  :  EW top : W* -> t bbar                                    *
*  Ipar(1) =  5  :  W Q Qbar                                                 *
*  Ipar(1) =  6  :  W+-  -> tau nu                                           *
*  Ipar(1) =  7  :  W+- (-> tau nu) JET                                      *
*  Ipar(1) =  8  :  H+-  -> t bbar                                           *
*  Ipar(1) =  9  :  H+-  -> tau nu                                           *
*  Ipar(1) = 10  :  H+- (-> tau nu) JET                                      *
*  Ipar(1) = 11  :  EW top : W g(2->2) and W g(2->3)                         *
*  Ipar(1) = 20  :  gg+qq~ -> tt~,  'on-shel ',  S. Slabospitsky             *
*  Ipar(1) = 21  :  gg     -> tt~,  'on-shel ',  S. Slabospitsky             *
*  Ipar(1) = 22  :     qq~ -> tt~,  'on-shel ',  S. Slabospitsky             *
*  Ipar(1) = 31  :  q q~   -> H+ H-                                          *
*  Ipar(1) = 50  :  gg+qq~ -> tt~,  'on-shel ',  W. Bernreuther et al        *
*  Ipar(1) = 51  :  gg     -> tt~,  'on-shel ',  W. Bernreuther et al        *
*  Ipar(1) = 52  :     qq~ -> tt~,  'on-shel ',  W. Bernreuther et al        *
*............................................................................*
*................                                                            *
*  Ipar(2)      : num. of current event                                      *
*..Ipar(3)      : evolution scale type for PDF                               *
*..Ipar(4)      : evolution scale type for alpha_S                           *
*  Ipar(5)      : 0(1) quark masses are taken from PYTHIA(PDG)               *
*  Ipar(6)      : 0(1) s,c,b,t mass value are QCD-evaluated(fixed)           *
*               : Ipar(6) is used only for evaluation of H+- couplings       *
*..Ipar(7)      : KF code of Q-quark for WQQbar                              *
*..Ipar(8)      : INIT flag                                                  *
*..Ipar(9)      : continuation flag                                          *
*..Ipar(10)     : 1(0) (no)print  sigma for each q, qbar contribution        *
*..Ipar(11)     : 0/1 to NOT/print output from single top production         *
*..Ipar(12)     : 0/1 print information about hard process                   *
*..Ipar(16)     : flag for first/second order in alpha-s evaluation          *
*..Ipar(17)     : check max. diff. X-section, during run                     *
*      D=0 : always check, 1 : events with diff.sig. > sigmax NOT accepted   *
*..Ipar(18)     : 1/0 evaluate PDF uncertainty                               *
*..Ipar(21)     : W-exchange: > 0 tb, <0 tau nu, 1 W, 2 H, 3 (W+H+Int)       *
*..Ipar(22)     : 0: gg + qqbar + g q, 1: gg,   2: q qbar, 3: g q            *
*..Ipar(23)     : Zqq, 0: gam* + Z,   1: gam*, 2: Z                          *
*..Ipar(24)     : gg->ZZ, 0: SM box, 1: box + Higgs, 2: Higgs                *
*..Ipar(25)     : number etimates X-sections for Ipar(1) = 11    (D=1000)    *
*..Ipar(26)     : bW 0 SM + FCNC, 1 - SM, 2 - FCNC                           *
*  Ipar(31)     : 1(0) running (fixed) top-mass according top width          *
*..Ipar(32)     : 1/0 finite/zero width of the W-boson in decay chain        *
*  ipar(33)     : 1(0) take (not) into account spin of produced top quarks   *
*..Ipar(41)     : number of the particles in the hard process                *
*..Ipar(42)     : sig*10**(Ipar(42))                                         *
*  ipar(50)     : number of current color                                    *
*..Ipar(51)      : num. of events used for estimation of SigMax               *
*..ipar(52)      : num. of events used for estimation of M**2                 *
*..Ipar(53)     : num. of MC entries  for estimates  of H+- and T decays     *
*..Ipar(100)    : current process number = Ipar(1)                           *
*..Ipar(101)    : current process number in /HEPRUP/ list, i.e. 1,2,3..NPRUP *
*..Ipar(120)    : final leptons for ADD:                                     *
*. . . . . .  double precision parameters . . . . . . . . . . . . . . . . .  *
*..Rpar(1)      : Ecm                                                        *
*..Rpar(2)      : S = Ecm**2                                                 *
*..Rpar(3)      : Evolution scale for PDF                                    *
*..Rpar(4)      : Evolution scale for alpha_s                                *
*..Rpar(5)      : parameter for Q-scale evaluation for PDF                   *
*..Rpar(6)      : parameter for Q-scale evaluation for alpha_s               *
*
*.............. couplings ...................................................*
*..Rpar(10)     : 0.38939d0     transformation 1/GeV**2 to mb                *
*..Rpar(11)     : alpha_QED = (1/128) is electromagnetic coupling            *
*..Rpar(12)     : 4.*pi*rpar(11)  = (electric charge)**2                     *
*..Rpar(13)     : sqrt(4.*pi*rpar(11)) is electric charge                    *
*..Rpar(14)     : G_Fermi                                                    *
*..Rpar(15)     : alpha_QCD = QCD coupling used for event                    *
*..Rpar(16)     : 4*pi * Rpar(15) = (QCD charge)**2                          *
*..Rpar(17)     : sqrt(4*pi * Rpar(15)) = QCD charge                         *
*............................                                                *
*..Rpar(21)     : sin(theta_W)                                               *
*..Rpar(22)     : cos(theta_W)                                               *
*..Rpar(23)     : sin(theta_W)**2                                            *
*..Rpar(24)     : cos(theta_W)**2                                            *
*..Rpar(25)     : sin(2*theta_W) = 2 * sin(theta_W) * cos(theta_W)           *
*..rpar(26)     : g = g_weak  = e / sin(theta_W)                             *
*..Rpar(27)     : g_z         = e / sin(2*theta_W)                           *
*..Rpar(28)     : v vacuum expectation value * 246/sqrtr(2) GeV              *
*.............. top quark parameters ........................................*
*..Rpar(30)     : width of t-> d  W decay at tree level (SM case)            *
*..Rpar(31)     : width of t-> s  W decay at tree level (SM case)            *
*..Rpar(32)     : width of t-> b  W decay at tree level (SM case)            *
*..Rpar(33)     : width of t-> b4 W decay at tree level (SM case)            *
*..Rpar(34)     : total t-quark decay width                                  *
*..Rpar(35)     : width of t -> b H+- decay channel                          *
*..Rpar(36)     : M(top) * width(total top)                                  *
*..rpar(37)     : current value of M(top) generated with B.W.                *
*.............. W-boson and Z-boson parameters  .............................*
*..Rpar(41)     : W-boson mass                                               *
*..Rpar(42)     : Rpar(41)**2                                                *
*..Rpar(43)     : W-boson width                                              *
*..Rpar(44)     : M(W) * Width(W)                                            *
*...                                                                         *
*..Rpar(45)     : Z-boson mass                                               *
*..Rpar(46)     : Rpar(45)**2                                                *
*..Rpar(47)     : Z-boson width                                              *
*..Rpar(48)     : M(Z) * Width(Z)                                            *
*............................................................................*
*..Rpar(50)     : New Physics scale (1 TeV), FCNC                            *
*.............. charged Higgs parameters  ...................................*
*..Rpar(51)     : charged Higgs mass                                         *
*..Rpar(52)     : Rpar(51)**2                                                *
*..Rpar(53)     : total charged Higgs decay width                            *
*..Rpar(54)     : M(H+-) * Width(H+-)                                        *
*..Rpar(55)     : tan(beta)                                                  *
*..Rpar(56)     : (1/tan(beta))                                              *
*............................................................................*
*..Rpar(57)     : neutral Higgs (SM) mass                                    *
*..Rpar(58)     : total Higgs decay width                                    *
*..Rpar(59)     : M(H) * Width(H)                                            *
*............................................................................*
*..Rpar(61:63) are for processes Ipar(1) = 50                                *
*..Rpar(61)    : gVV, relative coupling of Higgs boson(H0) to W and Z bosons *
*..Rpar(62)    : a, scalar Yukawa coupling of Higgs boson(H0) to top quarks  *
*..Rpar(63)    : a~, pseudoscalar Yukawa coupling of H0 boson to top quarks  *
*............................................................................* 
*..Rpar(64)    : total X-section for the process, evaluated for each event   *
*..Rpar(65)    : differential cross section (in PB) for current event        *
*..Rpar(67)    : 2.d0,  PTmin(Z), IPAR(1) = 24, ZZ-production                *
*..Rpar(68)    : 20.d0, PTmin(q)    ==> Rpar(81), IPAR(1) = 11, T-channel    *
*..Rpar(69)    : 10.d0, PTmin(Bbar) ==> Rpar(82), IPAR(1) = 11, T-channel    *
*..Rpar(70)    : MW_min  for final W*/Z*                                     *
*............................................................................* 
*..Rpar(71)    : Shat       for hard process                                 *
*..Rpar(72)    : That       for hard process                                 *
*..Rpar(73)    : Uhat       for hard process                                 *
*..Rpar(74)    : sqrt(Shat) for hard process                                 *
*..Rpar(75)    : PThat      for hard process                                 *
*..Rpar(76)    : PThat**2   for hard process                                 *
*..Rpar(77)    : M(QQbar)_MIN  for W/Z Q Qbar production                     *
*..Rpar(78)    : M(QQbar)_MAX  for W/Z Q Qbar production                     *
*..Rpar(79)    : M(ffbar)_MIN  for gamma* or Z*                              *
*..Rpar(80)    : M(ffbar)_MAX  for gamma* or Z*                              *
*..Rpar(81)    : kinematic cut,  >=3 final state, PTmin(q) for txpro(11)     *
*..Rpar(82)    : kinematic cut,  >=3 final state, PTmin(Bbar) for txpro(11)  *
*..Rpar(83:99) : kinematic cuts, >=3 final state                             *
*............................................................................* 
*..Rpar(101)   : CKIN(1) = sqrt(Shat_MIN) for hard process                   *
*..Rpar(102)   : CKIN(2) = sqrt(Shat_MAX) for hard process                   *
*..Rpar(103)   : CKIN(3) = PThat_MIN                                         *
*..Rpar(104)   : CKIN(4) = PThat_MAX                                         *
*............................................................................*
*...........  Graviton* production,  ADD scenario                            *
*..Rpar(121)     : M_exdim,                         ADD scenario             *
*..Rpar(122)     : n_exdim,  Graviton* production,  ADD scenario             *
*..Rpar(123)     : mKK mass of KK-excitation,       ADD scenario             *
*..Rpar(124)     : recommended PThat_MIN            ADD scenario             *
*..Rpar(125)     : factor_ADD                                                *
*............................................................................*
*...........  Black Hole (BH) production                                     *
*  Rpar(131)     : Planck scale, GeV                                         *
*  Rpar(132)     : n extra dimensions                                        *
*  Rpar(133)     : BR(BH -> q qbar X)                                        *
*  Rpar(134)     : BR(BH -> g g    X) / 2                                    *
*  Rpar(135)     : BR(BH -> l l'   X)                                        *
*  Rpar(136)     : BR(BH -> gamma,W,Z X) + BR(BH -> Higgs  X)                *
*  Rpar(137)     : BR(BH -> Higgs  X)                                        *
*............................................................................*
      double precision         Rpar     ! global TopReX real    parameters
      Integer       Ipar                ! global TopReX integer parameters  
      common /TXPAR/Ipar(200), Rpar(200)
      save   /TXPAR/
*.......
      integer ndch   ! maximum number of decay channels
      parameter (ndch=50)
      integer        MID(0:ndch,4),             FID(4,ndch,5) 
      double precision   wid(0:ndch,4),brf(ndch,4),     BRS(2,4)
      common /TXdec/ MID, WID,         BRF,     FID,    brs
      save   /TXdec/
*
      integer  maxpro 
      parameter (maxpro=500)  ! max.num. of TopReX process
*
      integer         txmup, txsel, txpro,         txext
      common /trxpro/ txmup, txsel, txpro(maxpro), txext(maxpro)
      save   /trxpro/
*
      integer dectop(ndch), dechpm(ndch) 
      common /TXdecRE/dectop, dechpm 
      double complex ei,e1,e0
      common /cunits/ e0, e1, ei
      data e0/(0.d0,0.d0)/,e1/(1.d0,0.d0)/,ei/(0.d0,1.d0)/
      save /cunits/
*...........
      data Ipar/0,   !  1: internal TopReX code of the process
     &          0,   !  2: num. of current event
     &          1,   !  3: default Q-scale type for PDF 
     &          0,   !  4: Q-scale for alpha_s <== Q-scale(PDF)
     &          0,   !  5:  0(1) quark masses are taken from PYTHIA(PDG)
     &          0,   !  6:  0(1) s,c,b,t mass value are QCD-evaluated(fixed)
*                    Ipar(6) is used only for evaluation of H+- couplings
     &          5,   !  7: KF code of Q-quark for W Q Qbar production
     &          0,   !  8:  INIT flag 
     &          1,   !  9: continuation flag
     &          0,   ! 10: no print X-sections for each q qbar contr
     &          0,   ! 11:  0/1 to NOT/print output from single top production
     &          0,   ! 12: 0/1 print information about hard process
     &          0,   ! 13: free
     &          0,   ! 14: free
     &          0,   ! 15: free
     &          2,   ! 16: first/second order in alpha-s evaluation (PYTHIA)
     &          0,   ! 17: check max. diff. X-section, during run 
*        D=0 : always check, 1 : events with diff.sig. > sigmax NOT accepted 
     &          0,   ! 18: free
     &          0,   ! 19: free
     &          0,   ! 20: free
     &          0,   ! 21: W-exc.: > 0 tb, <0 tau nu, 1 W, 2 H, 3 (W+H+Int)
     &          0,   ! 22: Zqq, 0: gg + qqbar, 1: gg,   2: qqbar 
     &          0,   ! 23: Zqq, 0: gam* + Z,   1: gam*, 2: Z  
     &          0,   ! 24: gg->ZZ, 0: SM box, 1: box + Hiigs, 2: Higgs   
     &          0,   ! 25: free
     &          0,   ! 26: bW: 0 SM + FCNC, 1 - SM, 2 - FCNC
     &        4*0,   ! 27:30 free
     &          1,   ! 31: running (0 - fixed) top-mass according top width 
     &          1,   ! 32: 1/0 finite/zero width of W-boson in decay chain
     &          1,   ! 33: take(0:not) into account spin of produced top quark
     &        7*0,   ! 34-40 not used
     &          0,   ! 41: number of the particles in the hard process 
     &          9,   ! 42: sig*10**(Ipar(42))    
     &          0,   ! 43: free
     &          0,   ! 44: free 
     &          0,   ! 45: free 
     &          0,   ! 46: free 
     &          0,   ! 47: free 
     &          0,   ! 48: free 
     &          0,   ! 49: free 
     &          0,   ! 50: current color (see colorf_xxx)  
     &     100000,   ! 51: num. of MC calls to estimate SigMax
     &     100000,   ! 52: num. of MC calls to estimate ME**2
     &      10000,   ! 53: num. of MC calls to estimate of H+- and T width
     &          0,   ! 54: free 
     &          0,   ! 55: free 
     &          0,   ! 56: free 
     &          0,   ! 57: free 
     &          0,   ! 58: free 
     &          0,   ! 59: free 
     &          0,   ! 60: free 
     &      140*0/   ! 42 - 200 not used
*... double precision parameters
      data Rpar/0.d0, !  1: Ecm
     &          0.d0, !  2: S = Ecm**2                                   
     &        100.d0, !  3: Evolution scale for PDF 
     &          0.d0, !  4: Evolution scale for alpha_s 
     &          0.d0, !  5: parameter for Q-scale evaluation for PDF 
     &          0.d0, !  6: parameter for Q-scale evaluation for alpha_s 
     &        3*0.d0, !  7 - 9: not used
* almost all these parameters are evaluated or readed in TopReX
     &     0.38939d0, ! 10: transformation 1/GeV**2 to mb
     &          0.d0, ! 11: alpha_QED = (1/128) is electromagnetic coupling
     &          0.d0, ! 12:      4.*pi*rpar(11) = (electric charge)**2   
     &          0.d0, ! 13: sqrt(4.*pi*rpar(11)) is electric charge   
     &          0.d0, ! 14: G_Fermi
     &          0.d0, ! 15: alpha_QCD = coupling used for event
     &          0.d0, ! 16: 4*pi * Rpar(15) = (QCD charge)**2
     &          0.d0, ! 17: sqrt(4*pi * Rpar(15)) = QCD charge
     &        3*0.d0, ! 18-20: not used 
     &        4*0.d0, ! 21-24 sin(theta_W), cos(cos(theta_W)), sin^2, cos^2  
     &          0.d0, ! 25: sin(2*theta_W) = 2 * sin(theta_W) * cos(theta_W)
     &          0.d0, ! 26: g = g_weak  = e / sin(theta_W)                  
     &          0.d0, ! 27: g_z         = e / sin(2*theta_W)                
     &          0.d0, ! 28: v is vacumm expectation                
     &          0.d0, ! 28-29: not used
     &          0.d0, ! 30: width of t-> d  W decay at tree level (SM case)
     &          0.d0, ! 31: width of t-> s  W decay at tree level (SM case)
     &          0.d0, ! 32: width of t-> b  W decay at tree level (SM case)
     &          0.d0, ! 33: width of t-> b4 W decay at tree level (SM case)
     &          0.d0, ! 34: total t-quark decay width
     &          0.d0, ! 35: width of t -> b H+- decay channel 
     &          0.d0, ! 36: M(top) * width(total)_top
     &          0.d0, ! 37: current value of M(top) generated with B.W.       
     &        3*0.d0, ! 38-40: not used
     &        8*0.d0, ! 41=MW, 42=MW**2, 43=Width(W), 44= MW * Width(W)   
*                     ! 45=MZ, 46=MZ**2, 47=Width(Z), 48= MZ * Width(Z)   
     &          0.d0, ! 49- not used
     &       1000.d0, ! 50: New Physics scale (1 TeV) 
     &        150.d0, ! 51: charged Higgs mass, default value
     &          0.d0, ! 52: M(H+-)**2
     &          0.d0, ! 53: Width(H+-)
     &          0.d0, ! 54: M(H+-) * Width(H+-)
     &         0.3d0, ! 55: tan(beta)
     &          0.d0, ! 56: (1/tan(beta))
     &        115.d0, ! 57: neutral Higgs mass, default value
     &          0.d0, ! 58: Width(H)
     &          0.d0, ! 59: M(H) * Width(H)
     &          0.d0, ! 60 - not used
     &        3*0.d0, ! 61 - 63: for processes Ipar(1) = 50, 51, 52 only 
     &          0.d0, ! 64: total X-section (process), evaluated for event
     &          0.d0, ! 65: diff. X-section (in PB) for current event
     &          0.d0, ! 66 - not used
     &          2.d0, ! 67 PT(Z)min for ZZ-production, Ipar(1) = 24
     &         20.d0, ! 68: PTmin(q)    ==> Rpar(81), IPAR(1) = 11, T-channel 
     &         10.d0, ! 69: PTmin(Bbar) ==> Rpar(82), IPAR(1) = 11, T-channel 
     &         15.d0, ! 70: min value for W*/Z* decay
*  hard process kinematics:  2 -> 2
     &        6*0.d0, !71-76: Shat, That, Uhat, sqrt(Shat), PThat, PTHAT**2
     &         -1.d0, !77: M(QQ)MIN, WQQbar, 
     &         -1.d0, !78: M(QQ)MAX  WQQbar, if(eq.-1) => from LIPS 
     &         -1.d0, !79: M(ff)MIN, ZQQbar 
     &         -1.d0, !80: M(ff)MAX, ZQQbar, if(eq.-1) => from LIPS 
     &       19*0.d0, !81-99: basic  kinematic cuts
     &          0.d0, !100 - not used
     &         20.d0, !101: CKIN(1) = sqrt(Shat_MIN) for hard process
     &          0.d0, !102: CKIN(2) = sqrt(Shat_MAX) for hard process
     &          0.d0, !103: CKIN(3) = PThat_MIN  
     &          0.d0, !104: CKIN(4) = PThat_MAX
     &       96*0.d0/ !111 - 200: not used
*............................................................................*
      data MID/    18, !  0,   1: number of top-quark decay channels
     &              1, !  1,   1: SM decay channel, t -> d  W   
     &              1, !  2,   1: SM decay channel, t -> s  W   
     &              1, !  3,   1: SM decay channel, t -> b  W   
     &             -1, !  4,   1: SM decay channel, t -> b4 W   
     &             -1, !  5,   1: t -> b H+ 
     &             -1, !  6,   1: t -> b H+, H+ -> t* bbar
     &             -1, !  7,   1: is not used
     &             -1, !  8,   1: is not used
     &             -1, !  9,   1: is not used
     &             -1, ! 10,   1: is not used
     &             -1, ! 11,   1: FCNC:  t gluon  Up
     &             -1, ! 12,   1: FCNC:  t gluon  Charm
     &             -1, ! 13,   1: FCNC:  t photon Up
     &             -1, ! 14,   1: FCNC:  t photon Ccharm
     &             -1, ! 15,   1: FCNC:  t Z      Up    :  gamma^mu
     &             -1, ! 16,   1: FCNC:  t Z      Charm :  gamma^mu
     &             -1, ! 17,   1: FCNC:  t Z      Up    :  sigma^mu^nu
     &             -1, ! 18,   1: FCNC:  t Z      Charm :  sigma^mu^nu
     &         32*0 , ! 19-50,1: is not used
*       W-boson
     &              0, !  0,   2: number of W-boson decay channels
     &         ndch*0, ! 1-50, 2: will be readed from PYTHIA
*   charged Higgs decay parameters
     &             19, !  0,   3: number of H+- decay channels
     &              1, !  1,   3: d U 
     &              1, !  2,   3: d C 
     &             -1, !  3,   3: d T
     &             -1, !  4,   3: d Tprime 
     &              1, !  5,   3: s U 
     &              1, !  6,   3: s C
     &             -1, !  7,   3: s T 
     &             -1, !  8,   3: s Tprime
     &              1, !  9,   3: b U
     &              1, ! 10,   3: b C
     &             -1, ! 11,   3: b T
     &             -1, ! 12,   3: b Tprime
     &             -1, ! 13,   3: bprime U
     &             -1, ! 14,   3: bprime C
     &             -1, ! 15,   3: bprime T
     &             -1, ! 16,   3: bprime Tprime
     &             -1, ! 17,   3: e   nue
     &              1, ! 18,   3: mu  numu
     &              1, ! 19,   3: tau nutau
     &         31*-1,! 20-50 3: is not used
*       Z-boson
     &              0, !  0,   4: number of W-boson decay channels
     &         ndch*0/ ! 1-50, 4: will be readed from PYTHIA

*
      data txmup /0/, txsel/0/,  txpro/500*0/, txext/500*0/
      data dectop/
     &              1, !  1,   1: SM decay channel, t -> d  W   
     &              1, !  2,   1: SM decay channel, t -> s  W   
     &              1, !  3,   1: SM decay channel, t -> b  W   
     &             -1, !  4,   1: SM decay channel, t -> b4 W   
     &             -1, !  5,   1: t -> b H+ 
     &             -1, !  6,   1: t -> b H+, H+ -> t* bbar
     &             -1, !  7,   1: is not used
     &             -1, !  8,   1: is not used
     &             -1, !  9,   1: is not used
     &             -1, ! 10,   1: is not used
     &             -1, ! 11,   1: FCNC:  t gluon  Up
     &             -1, ! 12,   1: FCNC:  t gluon  Charm
     &             -1, ! 13,   1: FCNC:  t photon Up
     &             -1, ! 14,   1: FCNC:  t photon Ccharm
     &             -1, ! 15,   1: FCNC:  t Z      Up    :  gamma^mu
     &             -1, ! 16,   1: FCNC:  t Z      Charm :  gamma^mu
     &             -1, ! 17,   1: FCNC:  t Z      Up    :  sigma^mu^nu
     &             -1, ! 18,   1: FCNC:  t Z      Charm :  sigma^mu^nu
     &         32*0 /  ! 19-50,1: is not used

      data  dechpm /
     &              1, !  1,   3: d U 
     &              1, !  2,   3: d C 
     &             -1, !  3,   3: d T
     &             -1, !  4,   3: d Tprime 
     &              1, !  5,   3: s U 
     &              1, !  6,   3: s C
     &             -1, !  7,   3: s T 
     &             -1, !  8,   3: s Tprime
     &              1, !  9,   3: b U
     &              1, ! 10,   3: b C
     &             -1, ! 11,   3: b T
     &             -1, ! 12,   3: b Tprime
     &             -1, ! 13,   3: bprime U
     &             -1, ! 14,   3: bprime C
     &             -1, ! 15,   3: bprime T
     &             -1, ! 16,   3: bprime Tprime
     &             -1, ! 17,   3: e   nue
     &              1, ! 18,   3: mu  numu
     &              1, ! 19,   3: tau nutau
     &         31*-1 / ! 20-50 3: is not used
      END
*----------------------------------------------------------------------------*
*... author : Serge Slabospitsky                                             *
*... 31.01.2005                                                              *
* this routine evaluates Q-scales for PDF (Rpar(3)) and alpha_S (Rpar(4)**2) *
*..Ipar(3, 4) is the evolution scale type for PDF (alpha_S)                  *
*  if ipar(4) = 0, then Q^2(PDF) ==> Q^2(alphas)                             *
*  ipar(3,4) < 0 corresponds to user's input                                 *
*..Rpar(3)      : Evolution scale for PDF                                    *
*..Rpar(4)      : Evolution scale for alpha_s                                *
*
      subroutine TXQscale
*     -------------------                                                    *
* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .*
      implicit None
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision PYalps, Q22 
      logical first
      data first /.TRUE./
      save first
      CHARACTER*25 np          ! process's name 
      COMMON /NAMPROCESS/np(200)
      character*30 namQpdf(200,10), namQalf(200,10)
      integer iprc, ipr4
      double precision sqq, alps, alpsZ
      common /testpdf/ sqq, alps 
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
*
      IF(first) THEN
      if(Ipar(1).eq.1.or.Ipar(1).eq.2.or.Ipar(1).eq.11) Iprc = 1
      if(Ipar(1).eq.3)                                  Iprc = 3
      if(Ipar(1).eq.4)                                  Iprc = 4
      if(Ipar(1).eq.20)                                 Iprc = 20
      if(Ipar(1).eq.5)                                  Iprc = 5 
      if(Ipar(1).eq.6.or.Ipar(1).eq.9)                  Iprc = 6
      if(Ipar(1).eq.7.or.Ipar(1).eq.10)                 Iprc = 7
      if(Ipar(1).eq.8)                                  Iprc = 8 
      if( Ipar(1).eq.30.or.Ipar(1).eq.31.
     & or.Ipar(1).eq.32.or.Ipar(1).eq.33.
     & or.Ipar(1).eq.34)                               Iprc = 30
      if(Ipar(1).eq.23)                                 Iprc = 23
      if(Ipar(1).eq.24)                                 Iprc = 24
      if(Ipar(1).eq.25)                                 Iprc = 25
      if(Ipar(1).eq.61)                                 Iprc = 61
      if(Ipar(1).eq.99)                                 Iprc = 1

*  Ipar(1) = 1, 2, 11   single top production
       namQpdf(1,1) = 'm(top)/sqrt(2)                '     
       namQpdf(1,2) = 'm(top)                        '
       namQpdf(1,3) = 'm(W)                          '
       namQalf(1,1) = 'm(top)/sqrt(2)                '
       namQalf(1,2) = 'm(top)                        '
       namQalf(1,3) = 'm(W)                          '
*  Ipar(1) = 3          single top production
       namQpdf(3,1) = 'm(top)/sqrt(2)                '
       namQpdf(3,2) = 'm(top)                        '
       namQpdf(3,3) = 'm(W)                          '
       namQalf(3,1) = 'm(top)/sqrt(2)                '
       namQalf(3,2) = 'm(top)                        '
       namQalf(3,3) = 'm(W)                          '
*  Ipar(1) = 4          single top production
       namQpdf(4,1) = 'm(top)/sqrt(2)                '
       namQpdf(4,2) = 'm(top)                        '
       namQpdf(4,3) = 'm(W)                          '
       namQpdf(4,4) = 'sqrt(Shat)                    '
       namQalf(4,1) = 'm(top)/sqrt(2)                '
       namQalf(4,2) = 'm(top)                        '
       namQalf(4,3) = 'm(W)                          '
       namQalf(4,4) = 'sqrt(Shat)                    '
*  Ipar(1) = 20, 21, 22  t tbar    production
       namQpdf(20,1) = 'sqrt(m(top)**2 + PT(top)**2)  '
       namQpdf(20,2) = 'm(top)/sqrt(2)                '
       namQpdf(20,3) = 'm(top)                        '
       namQalf(20,1) = 'sqrt(m(top)**2 + PT(top)**2)  '
       namQalf(20,2) = 'm(top)/sqrt(2)                '
       namQalf(20,3) = 'm(top)                        '
*  Ipar(1) = 25  (t tbar gamma)   production
       namQpdf(25,1) = 'm(top)/sqrt(2)                '
       namQpdf(25,2) = 'm(top)                        '
       namQalf(25,1) = 'm(top)/sqrt(2)                '
       namQalf(25,2) = 'm(top)                        '
*  Ipar(1) = 5      W Q Qbar       production
       namQpdf(5,1) = 'M(W)                          '   
       namQpdf(5,2) = 'sqrt(m(W)**2 + PT(W)**2)      '
       namQalf(5,1) = 'M(W)                          '
       namQalf(5,2) = 'sqrt(m(W)**2 + PT(W)**2)      '
*  Ipar(1) = 23      Z Q Qbar       production
       namQpdf(23,1) = 'M(Z)                          '
       namQpdf(23,2) = 'sqrt(m(Z)**2 + PT(Z)**2)      '
       namQalf(23,1) = 'M(Z)                          '
       namQalf(23,2) = 'sqrt(m(Z)**2 + PT(Z)**2)      '
*  Ipar(1) = 24      Z Q Qbar       production
       namQpdf(24,1) = 'M(Z)                          '
       namQpdf(24,2) = 'sqrt(m(Z)**2 + PT(Z)**2)      '
       namQalf(24,1) = 'M(Z)                          '
       namQalf(24,2) = 'sqrt(m(Z)**2 + PT(Z)**2)      '
*  Ipar(1) = 6      q q~' -> W+- + H+-  -> tau nu 
       namQpdf(6,1) = 'Shat                          '
       namQalf(6,1) = 'Shat                          '
*  Ipar(1) = 7      q q~' -> H+- JET  -> tau nu 
       namQpdf(7,1) = 'mass(W* or H*)                '
       namQalf(7,1) = 'mass(W* or H*)                '
*  Ipar(1) = 8         H* -> t bbar 
       namQpdf(8,1) = 'm(top)/sqrt(2)                '
       namQpdf(8,2) = 'm(top)                        '
       namQpdf(8,3) = 'm(H+-)                        '
       namQpdf(8,4) = 'sqrt(Shat)                    '
       namQalf(8,1) = 'm(top)/sqrt(2)                '
       namQalf(8,2) = 'm(top)                        '
       namQalf(8,3) = 'm(H+-)                        '
       namQalf(8,4) = 'sqrt(Shat)                    '
*  Ipar(1) = 30        FCNC g U -> t 
       namQpdf(30,1) = 'm(top)                        '
       namQpdf(30,2) = 'sqrt(Shat)                    '
       namQalf(30,1) = 'm(top)                        '
       namQalf(30,2) = 'sqrt(Shat)                    '
*  Ipar(1) = 31 or Ipar(1) = 32   FCNC: q q -> T q
       namQpdf(31,1) = 'sqrt(m(top)**2 + PT(top)**2)  '
       namQpdf(31,2) = 'm(top)/sqrt(2)                '
       namQpdf(31,3) = 'm(top)                        '
       namQalf(31,1) = 'sqrt(m(top)**2 + PT(top)**2)  '
       namQalf(31,2) = 'm(top)/sqrt(2)                '
       namQalf(31,3) = 'm(top)                        '
*  Ipar(1) = 61, 62    H+ H-  production
       namQpdf(61,1) = 'm(H+-)                        '
       namQalf(61,1) = 'm(H+-)                        '
*
      ENDIF 
**

      if(Ipar(1).eq.1.or.Ipar(1).eq.2.or.Ipar(1).eq.11) goto 1 
      if(Ipar(1).eq.3)                                  goto 3 
      if(Ipar(1).eq.4)                                  goto 4 
      if(Ipar(1).eq.20)                                 goto 20
      if(Ipar(1).eq.5)                                  goto 5 
      if(Ipar(1).eq.6.or.Ipar(1).eq.9)                  goto 6
      if(Ipar(1).eq.7.or.Ipar(1).eq.10)                 goto 7
      if(Ipar(1).eq.8)                                  goto 8 
      if(Ipar(1).eq.30.or.Ipar(1).eq.31.
     &or.Ipar(1).eq.32.or.Ipar(1).eq.33.
     &or.Ipar(1).eq.34)                                 goto 30
      if(Ipar(1).eq.23)                                 goto 23
      if(Ipar(1).eq.24)                                 goto 24
      if(Ipar(1).eq.25)                                 goto 25
      if(Ipar(1).eq.61)                                 goto 61
      if(Ipar(1).eq.99)                                 goto 1 
      return
*...
 1    continue !  t-channel top production 
*   Q-scale for PDF
       if(    Ipar(3).eq.-1) then
         continue  ! Rpar(3) = ...(user's input)  
       elseif(Ipar(3).eq.1) then
         Rpar(3) = mq(6) / dsqrt(2.d0)     ! PDF: m_t/sqrt(2) 
       elseif(Ipar(3).eq.2) then
         Rpar(3) = mq(6)                   ! PDF: m_t
       elseif(Ipar(3).eq.3) then
         Rpar(3) = Rpar(41)                ! PDF: M(W) 
       else
         Ipar(3) = 1                       ! return to default version
         Rpar(3) = mq(6) / dsqrt(2.d0)     ! PDF: m_t/sqrt(2) 
       endif
*   Q-scale for alpha_s 
       if(    Ipar(4).eq.-1) then
         continue  ! Rpar(4) = ...(user's input)  
       elseif(Ipar(4).eq.0) then
         Rpar(4) = Rpar(3)                 ! equals to PDF Q-scale
       elseif(Ipar(4).eq.1) then
         Rpar(4) = mq(6) / dsqrt(2.d0)     ! alpha_s: m(top)/ sqrt(2)
       elseif(Ipar(4).eq.2) then
         Rpar(4) = mq(6)                   ! alpha_s: m(top)
       elseif(Ipar(4).eq.3) then
         Rpar(4) = Rpar(41)                ! alpha_s: M(W) 
       else
         Ipar(4) = 0                       ! return to default version
         Rpar(4) = Rpar(3)
       endif
      goto 5555
***
 3    continue !  tW-channel single top production 
*   Q-scale for PDF
       if(    Ipar(3).eq.-1) then
         continue  ! Rpar(3) = ...(user's input)  
       elseif(Ipar(3).eq.1) then
         Rpar(3) = mq(6) / dsqrt(2.d0)     ! PDF: m_t/sqrt(2) 
       elseif(Ipar(3).eq.2) then
         Rpar(3) = mq(6)                   ! PDF: m_t
       elseif(Ipar(3).eq.3) then
         Rpar(3) = Rpar(41)                ! PDF: M(W) 
       else
         Ipar(3) = 1                       ! return to default version
         Rpar(3) = mq(6) / dsqrt(2.d0)     ! PDF: m_t/sqrt(2) 
       endif
*   Q-scale for alpha_s 
       if(    Ipar(4).eq.-1) then
         continue  ! Rpar(4) = ...(user's input)  
       elseif(Ipar(4).eq.0) then
         Rpar(4) = Rpar(3)                 ! equals to PDF Q-scale
       elseif(Ipar(4).eq.1) then
         Rpar(4) = mq(6) / dsqrt(2.d0)     ! alpha_s: m(top) / sqrt(2) 
       elseif(Ipar(4).eq.2) then
         Rpar(4) = mq(6)                   ! alpha_s: m(top)
       elseif(Ipar(4).eq.3) then
         Rpar(4) = Rpar(41)                ! alpha_s: M(W) 
       else
         Ipar(4) = 0                       ! return to default version
         Rpar(4) = Rpar(3)
       endif
      goto 5555
***
 4    continue !  s-channel single top production 
*   Q-scale for PDF
       if(    Ipar(3).eq.-1) then
         continue  ! Rpar(3) = ...(user's input)  
       elseif(Ipar(3).eq.1) then
         Rpar(3) = mq(6) / dsqrt(2.d0)     ! PDF: m_t/sqrt(2) 
       elseif(Ipar(3).eq.2) then
         Rpar(3) = mq(6)                   ! PDF: m_t
       elseif(Ipar(3).eq.3) then
         Rpar(3) = Rpar(41)                ! PDF: M(W) 
       elseif(Ipar(3).eq.4) then
         Rpar(3) = Rpar(74)               ! PDF: sqrt(Shat) 
       else
         Ipar(3) = 1                       ! return to default version
         Rpar(3) = mq(6) / dsqrt(2.d0) 
       endif
*   Q-scale for alpha_s 
       if(    Ipar(4).eq.-1) then
         continue  ! Rpar(4) = ...(user's input)   
       elseif(Ipar(4).eq.0) then
         Rpar(4) = Rpar(3)                 !  equals to PDF Q-scale
       elseif(Ipar(4).eq.1) then
         Rpar(4) = mq(6) / dsqrt(2.d0)     ! alpha_s: m(top) / sqrt(2)
       elseif(Ipar(4).eq.2) then
         Rpar(4) = mq(6)                   ! alpha_s: m(top)           
       elseif(Ipar(4).eq.3) then
         Rpar(4) = Rpar(41)                ! alpha_s: M(W)
       elseif(Ipar(4).eq.4) then
         Rpar(4) = Rpar(74)               ! alpha_s: sqrt(Shat)
       else
         Ipar(4) = 0                       ! return to default version
         Rpar(4) = Rpar(3)
       endif
      GOTO 5555
***
 20   continue !  t tbar production 
*   Q-scale for PDF
       if(    Ipar(3).eq.-1) then
         continue  ! Rpar(3) = ...(user's input)  
       elseif(Ipar(3).eq.1) then
         Rpar(3) = dsqrt(mq2(6) + Rpar(76)) ! Mt^2+pt(t)^2==> PDF
       elseif(Ipar(3).eq.2) then
         Rpar(3) = mq(6) / dsqrt(2.d0)       ! PDF: m(top) / sqrt(2)
       elseif(Ipar(3).eq.3) then
         Rpar(3) = mq(6)                     ! PDF: m_t
       else
         Ipar(3) = 1                         ! return to default version
         Rpar(3) = dsqrt(mq2(6) + Rpar(76)) ! Mt^2+pt(t)^2==> PDF
       endif
*   Q-scale for alpha_s 
       if(    Ipar(4).eq.-1) then
         continue  ! Rpar(4) = ...(user's input)  
       elseif(Ipar(4).eq.0) then
         Rpar(4) = Rpar(3)                   !  equals to PDF Q-scale
       elseif(Ipar(4).eq.1) then
         Rpar(4) = dsqrt(mq2(6) + Rpar(76)) ! Mt^2+pt(t)^2==> alpha_s
       elseif(Ipar(4).eq.2) then
         Rpar(4) = mq(6) / dsqrt(2.d0)       ! PDF: m(top) / sqrt(2)
       elseif(Ipar(4).eq.3) then
         Rpar(4) = mq(6)                    ! alpha_s: m(top)
       else
         Ipar(4) = 0                       ! return to default version
         Rpar(4) = Rpar(3) 
       endif
      GOTO 5555
***
 5    continue !  W Q Qbar production 
*   Q-scale for PDF
       if(    Ipar(3).eq.-1) then
         continue  ! Rpar(3) = ...(user's input)  
       elseif(Ipar(3).eq.1) then
         Rpar(3) =  Rpar(41)               ! PDF: M(W) 
       elseif(Ipar(3).eq.2) then
         Rpar(3) =  dsqrt(Rpar(42) + Rpar(76))  ! PDF: sqrt(M(W)^2 + PT(W)^2)
       else
         Ipar(3) = 1                       ! return to default version
         Rpar(3) = Rpar(41) 
       endif
*   Q-scale for alpha_s 
       if(    Ipar(4).eq.-1) then
         continue  ! Rpar(4) = ...(user's input)  
       elseif(Ipar(4).eq.0) then
         Rpar(4) = Rpar(3)                       ! equals to PDF Q-scale
       elseif(Ipar(4).eq.1) then
         Rpar(4) = Rpar(41)                      ! alpha_s: M(W)
       elseif(Ipar(4).eq.2) then
         Rpar(4) = dsqrt(Rpar(42) + Rpar(76))   ! M(W)^2 + PT(W)^2
       else
         Ipar(4) = 0                       ! return to default version
         Rpar(4) = Rpar(3)
       endif
      GOTO 5555
***
 23    continue !  Z Q Qbar production 
*   Q-scale for PDF
       if(    Ipar(3).eq.-1) then
         continue  ! Rpar(3) = ...(user's input)  
       elseif(Ipar(3).eq.1) then
         Rpar(3) =  Rpar(45)               ! PDF: M(Z) 
       elseif(Ipar(3).eq.2) then
         Rpar(3) =  dsqrt(Rpar(46) + Rpar(76)) ! PDF: sqrt(M_Z^2 + PT(Z)^2)
       else
         Ipar(3) = 1                       ! return to default version
         Rpar(3) = Rpar(45) 
       endif
*   Q-scale for alpha_s 
       if(    Ipar(4).eq.-1) then
         continue  ! Rpar(4) = ...(user's input)  
       elseif(Ipar(4).eq.0) then
         Rpar(4) = Rpar(3)                       ! equals to PDF Q-scale
       elseif(Ipar(4).eq.1) then
         Rpar(4) = Rpar(45)                      ! alpha_s: M(Z)
       elseif(Ipar(4).eq.2) then
         Rpar(4) = dsqrt(Rpar(46) + Rpar(76))   ! M(Z)^2 + PT(Z)^2
       else
         Ipar(4) = 0                       ! return to default version
         Rpar(4) = Rpar(3)
       endif
      GOTO 5555
***
 24    continue !  g g -> Z Z production 
*   Q-scale for PDF
       if(    Ipar(3).eq.-1) then
         continue  ! Rpar(3) = ...(user's input)  
       elseif(Ipar(3).eq.1) then
         Rpar(3) =  Rpar(45)               ! PDF: M(Z) 
       elseif(Ipar(3).eq.2) then
         Rpar(3) =  dsqrt(Rpar(46) + Rpar(76)) ! PDF: sqrt(M_Z^2 + PT(Z)^2)
       elseif(Ipar(3).eq.3) then
         Rpar(3) =  Rpar(74)    ! PDF: sqrt(Shat)
       else
         Ipar(3) = 1                       ! return to default version
         Rpar(3) = Rpar(45) 
       endif
*   Q-scale for alpha_s 
       if(    Ipar(4).eq.-1) then
         continue  ! Rpar(4) = ...(user's input)  
       elseif(Ipar(4).eq.0) then
         Rpar(4) = Rpar(3)                       ! equals to PDF Q-scale
       elseif(Ipar(4).eq.1) then
         Rpar(4) = Rpar(45)                      ! alpha_s: M(Z)
       elseif(Ipar(4).eq.2) then
         Rpar(4) = dsqrt(Rpar(46) + Rpar(76))   ! M(Z)^2 + PT(Z)^2
       elseif(Ipar(4).eq.3) then
         Rpar(4) =  Rpar(74)                    ! alpha_s: sqrt(Shat)
       else
         Ipar(4) = 0                       ! return to default version
         Rpar(4) = Rpar(3)
       endif
      GOTO 5555
***
 25    continue !  q qbar -> t tbar gamma roduction 
*   Q-scale for PDF
       if(    Ipar(3).eq.-1) then
         continue  ! Rpar(3) = ...(user's input)  
       elseif(Ipar(3).eq.1) then
         Rpar(3) = mq(6) / dsqrt(2.d0)       ! PDF: m(top) / sqrt(2)
       elseif(Ipar(3).eq.2) then
         Rpar(3) = mq(6)                     ! PDF: m(top) 
*       elseif(Ipar(3).eq.3) then
*         Rpar(3) =  Rpar(74)    ! PDF: sqrt(Shat)
       else
         Ipar(3) = 1                       ! return to default version
         Rpar(3) = mq(6) 
       endif
*   Q-scale for alpha_s 
       if(    Ipar(4).eq.-1) then
         continue  ! Rpar(4) = ...(user's input)  
       elseif(Ipar(4).eq.0) then
         Rpar(4) = Rpar(3)                       ! equals to PDF Q-scale
       elseif(Ipar(4).eq.1) then
         Rpar(4) = mq(6) / dsqrt(2.d0)           ! alpha_s:
       elseif(Ipar(4).eq.2) then
         Rpar(4) = mq(6) 
*       elseif(Ipar(4).eq.3) then
*         Rpar(4) =  Rpar(74)                    ! alpha_s: sqrt(Shat)
       else
         Ipar(4) = 0                       ! return to default version
         Rpar(4) = Rpar(3)
       endif
      GOTO 5555
***
 6    continue !   q q~' -> W+- + H+-  -> tau nu   
*   Q-scale for PDF
       if(    Ipar(3).eq.-1) then
         continue  ! Rpar(3) = ...(user's input)  
       elseif(Ipar(3).eq.1) then
         Rpar(3) =  Rpar(74)            ! PDF: sqrt(Shat) 
       else
         Ipar(3) = 1                       ! return to default version
         Rpar(3) =  Rpar(74) 
       endif
*   Q-scale for alpha_s 
       if(    Ipar(4).eq.-1) then
         continue  ! Rpar(4) = ...(user's input)  
       elseif(Ipar(4).eq.0) then
         Rpar(4) = Rpar(3)           !  equals to PDF Q-scale
       elseif(Ipar(4).eq.1) then
         Rpar(4) = Rpar(74)         ! alpha_s: sqrt(Shat)
       else
         Ipar(4) = 0                       ! return to default version
         Rpar(4) = Rpar(3) 
       endif
      GOTO 5555
***
 7    continue !   q q~' -> H+- JET  -> tau nu   
*   Q-scale for PDF
       if(    Ipar(3).eq.-1) then
         continue  ! Rpar(3) = ...(user's input)  
       elseif(Ipar(3).eq.1) then
         Rpar(3) =  Rpar(5)            ! PDF: mass(H* or W*)
       else
         Ipar(3) = 1                       ! return to default version
         Rpar(3) =  Rpar(5)
       endif
*   Q-scale for alpha_s 
       if(    Ipar(4).eq.-1) then
         continue  ! Rpar(4) = ...(user's input)  
       elseif(Ipar(4).eq.0) then
         Rpar(4) = Rpar(3)           ! equals to PDF Q-scale
       elseif(Ipar(4).eq.1) then
         Rpar(4) = Rpar(5)           ! alpha_s: mass(H* or W*)
       else
         Ipar(4) = 0                 ! return to default version
         Rpar(4) = Rpar(3) 
       endif
      GOTO 5555
***
 8    continue           !  H* -> t bbar 
*   Q-scale for PDF
       if(    Ipar(3).eq.-1) then
         continue  ! Rpar(3) = ...(user's input)  
       elseif(Ipar(3).eq.1) then 
         Rpar(3) = mq(6) / dsqrt(2.d0)     ! PDF: m_t/sqrt(2) 
       elseif(Ipar(3).eq.2) then
         Rpar(3) = mq(6)                   ! PDF: m_t
       elseif(Ipar(3).eq.3) then
         Rpar(3) = Rpar(51)                ! PDF: M(H) 
       elseif(Ipar(3).eq.4) then
         Rpar(3) = Rpar(74)               ! PDF: sqrt(Shat) 
       else
         Ipar(3) = 1                       ! return to default version
         Rpar(3) = mq(6) / dsqrt(2.d0)
       endif
*   Q-scale for alpha_s 
       if(    Ipar(4).eq.-1) then
         continue  ! Rpar(4) = ...(user's input)   
       elseif(Ipar(4).eq.0) then
         Rpar(4) = Rpar(3)                 !  equals to PDF Q-scale
       elseif(Ipar(4).eq.1) then
         Rpar(4) = mq(6) / dsqrt(2.d0)     ! alpha_s: m(top) / dsqrt(2)
       elseif(Ipar(4).eq.2) then
         Rpar(4) = mq(6)                   ! alpha_s: m(top)
       elseif(Ipar(4).eq.3) then
         Rpar(4) = Rpar(51)                ! alpha_s: M(H)
       elseif(Ipar(4).eq.4) then
         Rpar(4) = Rpar(74)               ! alpha_s: sqrt(Shat)
       else
         Ipar(4) = 0                       ! return to default version
         Rpar(4) = Rpar(3) 
       endif
      GOTO 5555
***
 30    continue            !  FCNC g U -> t 
*   Q-scale for PDF
       if(    Ipar(3).eq.-1) then
         continue  ! Rpar(3) = ...(user's input)  
       elseif(Ipar(3).eq.1) then
         Rpar(3) = mq(6)                   ! PDF: m_t
       elseif(Ipar(3).eq.2) then
         Rpar(3) = Rpar(74)               ! PDF: sqrt(Shat) 
       else
         Ipar(3) = 1                       ! return to default version
         Rpar(3) = mq(6)
       endif
*   Q-scale for alpha_s 
       if(    Ipar(4).eq.-1) then
         continue  ! Rpar(4) = ...(user's input)   
       elseif(Ipar(4).eq.0) then
         Rpar(4) = Rpar(3)                 !  equals to PDF Q-scale
       elseif(Ipar(4).eq.1) then
         Rpar(4) = mq(6)                   ! alpha_s: m(top)
         Rpar(4) = Rpar(74)                ! alpha_s: sqrt(Shat)
       else
         Ipar(4) = 0                       ! return to default version
         Rpar(4) = Rpar(3) 
       endif
      GOTO 5555
***
 31    continue            !  FCNC: 2 -> 2
*   Q-scale for PDF

       if(    Ipar(3).eq.-1) then
         continue  ! Rpar(3) = ...(user's input)  
       elseif(Ipar(3).eq.1) then
         Rpar(3) = dsqrt(mq2(6) + Rpar(76)) ! Mt^2+pt(t)^2==> PDF
       elseif(Ipar(3).eq.2) then
         Rpar(3) = mq(6) / dsqrt(2.d0)       ! PDF: m(top) / sqrt(2)
       elseif(Ipar(3).eq.3) then
         Rpar(3) = mq(6)                     ! PDF: m_t
       else
         Ipar(3) = 1                         ! return to default version
         Rpar(3) = dsqrt(mq2(6) + Rpar(76)) ! Mt^2+pt(t)^2==> PDF
       endif
*   Q-scale for alpha_s 
       if(    Ipar(4).eq.-1) then
         continue  ! Rpar(4) = ...(user's input)  
       elseif(Ipar(4).eq.0) then
         Rpar(4) = Rpar(3)                   !  equals to PDF Q-scale
       elseif(Ipar(4).eq.1) then
         Rpar(4) = dsqrt(mq2(6) + Rpar(76)) ! Mt^2+pt(t)^2==> alpha_s
       elseif(Ipar(4).eq.2) then
         Rpar(4) = mq(6) / dsqrt(2.d0)       ! PDF: m(top) / sqrt(2)
       elseif(Ipar(4).eq.3) then
         Rpar(4) = mq(6)                    ! alpha_s: m(top)
       else
         Ipar(4) = 0                       ! return to default version
         Rpar(4) = Rpar(3) 
       endif
      GOTO 5555
*******
 61   continue !   H+ H- 
*   Q-scale for PDF
       if(    Ipar(3).eq.-1) then
         continue  ! Rpar(3) = ...(user's input)  
       elseif(Ipar(3).eq.1) then
         Rpar(3) =  Rpar(51)            ! PDF: mass(H+-) 
       else
         Ipar(3) = 1                       ! return to default version
         Rpar(3) = Rpar(51)
       endif
*   Q-scale for alpha_s 
       if(    Ipar(4).eq.-1) then
         continue  ! Rpar(4) = ...(user's input)  
       elseif(Ipar(4).eq.0) then
         Rpar(4) = Rpar(3)          ! equals to PDF Q-scale
       elseif(Ipar(4).eq.1) then
         Rpar(4) = Rpar(51 )        ! alpha_s: mass(H+-) 
       else
         Ipar(4) = 0                       ! return to default version
         Rpar(4) = Rpar(3) 
       endif
      GOTO 5555
***************************
 5555 continue   ! evaluate alpha_s
      Q22 = Rpar(4)**2
      rpar(15) = PYalps(Q22)   ! alpha_QCD = QCD coupling used for event   
      alpsZ    = PYalps(Rpar(46))  ! alpha_QCD = at MZ 
*      rpar(15) = 0.130d0 ! PYalps(Q22) !alpha_s = QCD coupling used for event   

      Rpar(16) = pi4 * Rpar(15)   
      Rpar(17) = dsqrt(Rpar(16)) 
      IF(first) THEN
       first = .false.
       write(*,1000) 
 1000  format(//,'   TopReX Q-scales',/,
     &           '   ----------------')
       ipr4 = ipar(4)
*       if(ipr4.eq.0) ipr4 = 1
       if(ipr4.eq.0) ipr4 = Ipar(3)
      If(ipar(3).ge.1) then 
        write(*,1001) namQpdf(Iprc, Ipar(3)),rpar(3) 
 1001  format('   PDF:     Q-scale is  ',a30,' = ',f10.3)
        if(ipar(4).ge.0)  write(*,1003) namQalf(Iprc, Ipr4),rpar(15),
     &              alpsz
        if(ipar(4).eq.-1) write(*,1004) Rpar(4),rpar(15), alpsz
      ElseIf(ipar(3).eq.-1) then
        write(*,1002) Rpar(3)
 1002  format('   PDF:     Q-scale, user input ',f10.3)
        if(ipar(4).ge.1)   write(*,1003) namQalf(Iprc, Ipr4),rpar(15),
     &            alpsz
        if(ipar(4).eq.0.OR.Ipar(4).eq.-1) write(*,1004) Rpar(4),
     &      rpar(15),   alpsz            
      EndIf
*
*      write(*,*) rpar(3),rpar(4)
*
 1003  format('   alpha_s: Q-scale is  ',a30,/,
     &        '   alpha_s = ',f7.4,'  alpha_s(MZ) = ',f7.4)
 1004  format('   alpha_s: Q-scale, user input ',f10.3,/,
     &        '   alpha_s = ',f7.4,'  alpha_s(MZ) = ',f7.4)
      ENDIF
      return
      end    
*----------------------------------------------------------------------------*

*----------------------------------------------------------------------------*
*... author : Serge Slabospitsky                                             *
*... 16.12.2003                                                              *
*                                                                            *
      subroutine TXTTSMR(Q, p1, p2, pp1, pp2)
*     ---------------------------------------                                *
* smear mtop according Breit-Wigner and rescale T and Tbar 5-momenta         *
      implicit none
      include "txpar.inc" 
      double precision q(5), p1(5), p2(5), pp1(5), pp2(5)
      double precision mt1, mt2, v0, v1, TopMV
      double precision mq, mq2
      common /massql/  mq(0:20), mq2(0:20)
      integer i, Nc
*
      nc = 0
 101  mt1 = TopMV(Rpar(34), mq(6))
      mt2 = TopMV(Rpar(34), mq(6))
      nc = nc + 1
       if(nc.ge.100) then
         do i = 1,5
          pp1(I) = p1(I)
          pp2(I) = p2(I)
         enddo
        return
       endif
      if((mt1+mt2).ge.Q(5)) goto 101
*
      call lorenf_s (Q, p1, pp2) ! pp1 is defined in TTbar rest frame
       v0 = dsqrt(pp2(4)**2 - mq2(6))
      pp2(5) = mt1
      pp2(4) = 0.5d0*(Q(5)**2+mt1**2-mt2**2)/Q(5)
       v1 = dsqrt(pp2(4)**2 - mt1**2) / v0
         do i = 1,3
          pp2(I) = v1 * pp2(I)
         enddo
      call lorenb_s(q, pp2, pp1) 
*
      pp2(5) = mt2
         do i = 1,4
          pp2(I) = Q(I) - pp1(I)
         enddo
      return
      end
*----------------------------------------------------------------------------*
*... author : Serge Slabospitsky                                             *
*... 16.12.2003                                                              *
*                                                                            *
      subroutine TXTQ1SMR(Q, p1, k1, pp1, kk1)
*     ---------------------------------------                                *
* smear mtop according Breit-Wigner and rescale T 5-momentum and 4-mom.(q)   *
      implicit none
      include "txpar.inc" 
      double precision q(5), p1(5), k1(5), pp1(5), kk1(5)
      double precision mt1, v0, v1, TopMV
      double precision mq, mq2
      common /massql/  mq(0:20), mq2(0:20)
      integer i, Nc
*
      nc = 0
 101  mt1 = TopMV(Rpar(34), mq(6))
      nc = nc + 1
       if(nc.ge.100) then
         do i = 1,5
          pp1(I) = p1(I)
          kk1(I) = k1(I)
         enddo
        return
       endif
      if((mt1 + k1(5)).ge.Q(5)) goto 101
*
      call lorenf_s (Q, p1, kk1) ! kk1 is T momentum in TTbar rest frame
       v0 = dsqrt(kk1(4)**2 - mq2(6))
      kk1(5) = mt1
      kk1(4) = 0.5d0*(Q(5)**2+mt1**2 - k1(5)**2)/Q(5)
       v1 = dsqrt(kk1(4)**2 - mt1**2) / v0
         do i = 1,3
          kk1(I) = v1 * kk1(I)
         enddo
      call lorenb_s(q, kk1, pp1) 
*
       kk1(5) = k1(5)
         do i = 1,4
          kk1(I) = Q(I) - pp1(I)
         enddo
      return
      end
*----------------------------------------------------------------------------*
*... author : Serge Slabospitsky                                             *
*... 17.12.2003                                                              *
*                                                                            *
      subroutine TXTQ2SMR(Q, p1, k1, k2, pp1, kk1, kk2)
*     -------------------------------------------------                      *
* smear mtop according Breit-Wigner and rescale T 5-momentum and 4-mom.(q)   *
      implicit none
      include "txpar.inc" 
      double precision q(5), p1(5),k1(5),k2(5), pp1(5),kk1(5), kk2(5)
      double precision ps(5), ps1(5), pk(5), scalp 
      double precision mt1, v0, v1, TopMV
      double precision mq, mq2
      common /massql/  mq(0:20), mq2(0:20)
      integer i, Nc
*
      do i = 1,4
       ps(I) = k1(I) + k2(I)
      enddo
      ps(5) = dsqrt(scalp(ps,ps))
      nc = 0
 101  mt1 = TopMV(Rpar(34), mq(6))
      nc = nc + 1
       if(nc.ge.100) then
         do i = 1,5
          pp1(I) = p1(I)
          kk1(I) = k1(I)
          kk2(I) = k2(I)
         enddo
        return
       endif
      if((mt1 + ps(5)).ge.Q(5)) goto 101
*
      call lorenf_s (Q, p1, kk1) ! kk1 is T momentum in TTbar rest frame
       v0 = dsqrt(kk1(4)**2 - mq2(6))
      kk1(5) = mt1
      kk1(4) = 0.5d0*(Q(5)**2+mt1**2 - ps(5)**2)/Q(5)
       v1 = dsqrt(kk1(4)**2 - mt1**2) / v0
         do i = 1,3
          kk1(I) = v1 * kk1(I)
         enddo
      call lorenb_s(q, kk1, pp1) 
*
       ps1(5) = ps(5)
         do i = 1,4
          ps1(I) = Q(I) - pp1(I)
         enddo
      call lorenf_s (ps,  k1, pk) ! kk1 is T momentum in TTbar rest frame
      call lorenb_s (ps1, pk, kk1) 
       kk2(5) = k2(5)
         do i = 1,4
          kk2(I) = Q(I) - pp1(I) - kk1(I)
         enddo
      return
      end

*----------------------------------------------------------------------------*
* Matrix element: g g -> Z Q(k3) Qbar(k4), Z -> f(k1) fbar(k2) 
      subroutine ZGGtoQQ(kfk1, kfk3,q1,q2,ak1,ak2,ak3,ak4, ves) 
*     -------------------------------------------                            *
      implicit none
      include "txpar.inc"
      double precision q1(5), q2(5), k1(5), k2(5), k3(5), k4(5)
      double precision ak1(5),ak2(5),ak3(5),ak4(5), rr(5)
      double precision u1(5), u2(5), u3(5), u4(5) 
      double precision pz(5), q2z, Q2gl
      double precision VES 
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision scalp, denZ
      integer kfk1, kfk3
      integer J, iq1, iq2, ik1, ik2, ik3, ik4
      integer j1, j2, j3, j4, j5, j6         
      double complex PHM_u1(4,4), PHM_u2(4,4), PHM_u3(4,4), PHM_u4(4,4) 
      double complex KUB1(2,4), KUB3(2,4), KV2(2,4), KV4(2,4)
      double complex cgV, czV, czA 
      double complex UU, UU1, UU2, UU3, UU4,
     & TA1(2,2,2,2,2,2), TB1(2,2,2,2,2,2), TC1(2,2,2,2), 
     & TA2(2,2,2,2,2,2), TB2(2,2,2,2,2,2), TC2(2,2,2,2), 
     & TA3(2,2,2,2,2,2), TB3(2,2,2,2,2,2), TC3(2,2,2,2), 
     & TA4(2,2,2,2,2,2), TB4(2,2,2,2,2,2), TC4(2,2,2,2) 
      double complex UZB(4,4),V1(4,4),V2(4,4),V3(4,4), Q1Q2(4,4) 
      double complex VV1(4,4),VV(4,4),VV3(4,4) 
      double complex VS1(4,4),VS2(4,4),VS3(4,4)
      double complex HGA(2,2,4), HGZ(2,2,4)
      double complex GZK(2,2,4,4)
      double precision coef0, coef 
      SAVE coef0, coef 
      double complex ei 
      data ei/(0.d0, 1.d0)/
      double precision eqf(2,-20:20), zff(2,-20:20) 
      save eqf, zff
      double precision eqf0(2,-20:20), zff0(2,-20:20)
      common /Vboscpl/ eqf0, zff0
      double complex g4(4,4),g1(4,4),g2(4,4),g3(4,4),g5(4,4)
      common /gmatr/g4, g1, g2, g3, g5
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
      double precision zn1, zn2
      COMMON /colden/ zn1, zn2
      save /colden/
* test
      double precision zv1(5), zv2(5), zv3(5), zv4(5),wa,wb,TTT
*
      if(first) THEN
      do j1 = 1,2
      do j = 1,20
         eqf(j1,j) = eqf0(j1,j)
         zff(j1,j) = zff0(j1,j)
        if(Ipar(23).eq.1) then    
          zff(j1,j) = 0.d0  ! only gamma
        endif 
        if(Ipar(23).eq.2) then    
          eqf(j1,j) = 0.d0  ! only Z-boson
        endif 
      enddo
      enddo

       call gamdir

        coef0 = Rpar(10) / (2.d0 * 2.d0)  ! spins
        coef0 = coef0 / (8.d0 * 8.d0)    ! colors 
      first=.FALSE.
      ENDIF


      if(abs(kfk1).le.6) then
        if(kfk1.eq.kfk3) then
         coef = coef0 / 4.d0  ! z -> q qbar two pairs of identical qq~qq~
        else
         coef = 3.d0 * coef0  ! z -> q qbar 
        endif
      elseif(abs(kfk1).ge.11) then
       coef = coef0  ! z -> l+ li or nu nubar
      endif

* evaluate Dirac spinors
       do j = 1,5
        k1(j) = ak1(j)
        k2(j) = ak2(j)
        k3(j) = ak3(j)
        k4(j) = ak4(j)
       enddo

       do j = 1,4
        rr(j) = q1(j) - q2(j)
        pz(j) = k1(j) + k2(j)
        u1(j) = pz(j) + k3(j) 
        u2(j) = q2(j) - k4(j)
        u3(j) = k3(j) - q1(j)
        u4(j) = -k4(j) - pz(j)
       enddo
        u1(5) = k3(5)
        u2(5) = k3(5)
        zn1 = k3(5)**2 - scalp(u2,u2)
        u3(5) = k3(5)
        u4(5) = k3(5)
        pz(5) = rpar(45)
        q2z = scalp(pz, pz)
        q2gl = (q1(4)+q2(4))**2 - (q1(1)+q2(1))**2
     &       - (q1(2)+q2(2))**2 - (q1(3)+q2(3))**2
        denZ = (rpar(46) - q2z)**2 + rpar(48)**2 
* test
       goto 334
       do j = 1,4
        zv1(j) = scalp(q1,k4)*q2(j) + scalp(q2,k4)*q1(j)
        zv1(j) = zv1(j) / scalp(q1,q2)
       enddo

       do j = 1,4
        zv2(j) = k3(5)**2 * zv1(j) + 2.d0*k3(5)**2*u2(j)
     & + 2.d0*scalp(u2,zv1)*u2(j) - scalp(u2,u2)*zv1(j)
       enddo

       wa = scalp(zv1,q1)
       wa = scalp(zv1,q2)
       wa = k3(5)**3 + 2.d0*k3(5)*scalp(zv1,u2) 
     & + k3(5)*scalp(u2,u2)
       do j = 1,4
        zv3(j) = - scalp(q1,zv2)*q2(j)
     &         - scalp(q2,zv2)*q1(j)
        zv3(j) = zv3(j) / scalp(q1,q2)
       enddo

       do j = 1,4
        zv4(j) = k3(5)**2 * zv3(j) + 2.d0*k3(5)*wa*u1(j)
     & + 2.d0*scalp(u1,zv3)*u1(j) - scalp(u1,u1)*zv3(j)
       enddo
       wb = wa*k3(5)**2 + 2.d0*k3(5)*scalp(zv3,u1) 
     & + wa*scalp(u1,u1)

       ttt = 4.d0*8.d0*4.d0*(-k3(5)*wb*scalp(k1,k2)
     & + scalp(k1,k3)*scalp(k2,zv4)
     & + scalp(k2,k3)*scalp(k1,zv4))
       ttt = ttt / (scalp(u1,u1)-k3(5)**2)**2
       ttt = ttt / (scalp(u2,u2)-k3(5)**2)**2
*      ves = -ttt * coef * denZ * rpar(16)**2 * 
      ves = -ttt * coef * rpar(16)**2 * 
     & eqf(2,kfk1)**2 * eqf(2,kfk3)**2 /q2z**2 
*      return
 334   continue

*
      call Dirs_Ubar(k1, KUB1)
      call Dirs_Ubar(k3, KUB3)
      call Dirs_V(k2, KV2)
      call Dirs_V(k4, KV4)

      call Phat(rr, Q1Q2)
      call Propf(u1, phm_u1)
      call Propf(u2, phm_u2)
      call Propf(u3, phm_u3)
      call Propf(u4, phm_u4)

*
       cgV = eqf(2,kfk1)/Q2z
       czV = zff(1,kfk1)/(Q2z - rpar(46) + ei*rpar(48))
       czA = zff(2,kfk1)/(Q2z - rpar(46) + ei*rpar(48))
       call Us_ZbA_Uc(PZ, cgv, czv, cza, KUB1, KV2, HGA, HGZ) 
       cgV = eqf(2,kfk3) 
       czV = zff(1,kfk3)
       czA = zff(2,kfk3)
       call MATR_ZbA(cgV, czV, czA, HGA, HGZ, GZK) 

      do 1001 iq1 = 1,2
        call prod_EhatA(iq1, phm_u3, V3)
        call prod_EhatA(iq1, phm_u2, VV)
        call prod_2(phm_u1, VV, V1)
      do 1001 iq2 = 1,2
        call prod_AEhat(iq2, phm_u2, V2)
        call prod_AEhat(iq2, V1, VV1)

        call prod_AEhat(iq2, V3, VV)
        call prod_2(VV, phm_u4, VV3)
      do 1002 ik1 = 1,2
      do 1002 ik2 = 1,2
        call V4toU(ik1, ik2, GZK, UZB) 

        call prod_2(UZB, VV1, VS1) 
        call prod_2(VV3, UZB, VS3) 
        call prod_2(V3, UZB, VV) 
        call prod_2(VV, V2, VS2) 

       call Matr_Add_2(VS1, VS2, VV)
       call Matr_Add_2(VV, VS3, VS1)
      do 1003 ik3 = 1,2
      do 1003 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS1, KV4, UU)
       TA1(iq1,iq2,ik1,ik2,ik3,ik4) = UU
 1003 continue 
 1002 continue 
 1001 continue 

       call prod_2(phm_u1, q1q2, V1) 
       call prod_2(q1q2, phm_u4, V2) 
      do 1011 ik1 = 1,2
      do 1011 ik2 = 1,2
        call V4toU(ik1, ik2, GZK, UZB) 
        call prod_2(UZB, V1, VS1) 
        call prod_2(V2, UZB, VS2) 
       call Matr_Add_2(VS1, VS2, VS3)
      do 1011 ik3 = 1,2
      do 1011 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS3, KV4, UU)
       TC1(ik1,ik2,ik3,ik4) = UU
 1011 continue 
**
*  gluon1 <==> gluon2
       do j = 1,4
        u2(j) = q1(j) - k4(j)
        u3(j) = k3(j) - q2(j)
       enddo
        zn2 = k3(5)**2 - scalp(u2,u2)

      call Propf(u2, phm_u2)
      call Propf(u3, phm_u3)
*
      do 1021 iq2 = 1,2
        call prod_EhatA(iq2, phm_u3, V3)
        call prod_EhatA(iq2, phm_u2, VV)
        call prod_2(phm_u1, VV, V1)
      do 1021 iq1 = 1,2
        call prod_AEhat(iq1, phm_u2, V2)
        call prod_AEhat(iq1, V1, VV1)

        call prod_AEhat(iq1, V3, VV)
        call prod_2(VV, phm_u4, VV3)
      do 1022 ik1 = 1,2
      do 1022 ik2 = 1,2
        call V4toU(ik1, ik2, GZK, UZB) 

        call prod_2(UZB, VV1, VS1) 
        call prod_2(VV3, UZB, VS3) 
        call prod_2(V3, UZB, VV) 
        call prod_2(VV, V2, VS2) 

       call Matr_Add_2(VS1, VS2, VV)
       call Matr_Add_2(VV, VS3, VS1)
      do 1023 ik3 = 1,2
      do 1023 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS1, KV4, UU)
       TB1(iq1,iq2,ik1,ik2,ik3,ik4) = UU
 1023 continue 
 1022 continue 
 1021 continue 

       if(kfk1.eq.kfk3) goto 2000
      ves = 0.d0
      do 111 j1 = 1,2 
      do 111 j2 = 1,2 
      do 111 j3 = 1,2 
      do 111 j4 = 1,2 
      do 111 j5 = 1,2 
      do 111 j6 = 1,2 
      UU = TA1(j1,j2,j3,j4,j5,j6) + TB1(j1,j2,j3,j4,j5,j6)
         ves = ves + (7.d0/3.d0) * UU * conjg(UU)

      UU = TA1(j1,j2,j3,j4,j5,j6) - TB1(j1,j2,j3,j4,j5,j6)
      if(j1.eq.j2) then
        UU = UU - 2.d0*TC1(j3,j4,j5,j6) / Q2gl
      endif
      ves = ves + 3.d0 * UU * conjg(UU)
 111  continue
      ves = ves * coef * rpar(16)**2 
      return
*  indentical final quarks, start permutations

 2000 continue
*      z -> k1 k4     + k3 k2
       do j = 1,5
        k1(j) = ak1(j)
        k2(j) = ak4(j)
        k3(j) = ak3(j)
        k4(j) = ak2(j)
       enddo

       do j = 1,4
        pz(j) = k1(j) + k2(j)
        u1(j) = pz(j) + k3(j) 
        u2(j) = q2(j) - k4(j)
        u3(j) = k3(j) - q1(j)
        u4(j) = -k4(j) - pz(j)
       enddo
        u1(5) = k3(5)
        u2(5) = k3(5)
        u3(5) = k3(5)
        u4(5) = k3(5)
        pz(5) = rpar(45)
        q2z = scalp(pz, pz)
*
      call Dirs_Ubar(k1, KUB1)
      call Dirs_Ubar(k3, KUB3)
      call Dirs_V(k2, KV2)
      call Dirs_V(k4, KV4)

      call Propf(u1, phm_u1)
      call Propf(u2, phm_u2)
      call Propf(u3, phm_u3)
      call Propf(u4, phm_u4)

*
       cgV = eqf(2,kfk1)/Q2z
       czV = zff(1,kfk1)/(Q2z - rpar(46) + ei*rpar(48))
       czA = zff(2,kfk1)/(Q2z - rpar(46) + ei*rpar(48))
       call Us_ZbA_Uc(PZ, cgv, czv, cza, KUB1, KV2, HGA, HGZ) 

       cgV = eqf(2,kfk3) 
       czV = zff(1,kfk3)
       czA = zff(2,kfk3)
       call MATR_ZbA(cgV, czV, czA, HGA, HGZ, GZK) 

      do 1201 iq1 = 1,2
        call prod_EhatA(iq1, phm_u3, V3)
        call prod_EhatA(iq1, phm_u2, VV)
        call prod_2(phm_u1, VV, V1)
      do 1201 iq2 = 1,2
        call prod_AEhat(iq2, phm_u2, V2)
        call prod_AEhat(iq2, V1, VV1)

        call prod_AEhat(iq2, V3, VV)
        call prod_2(VV, phm_u4, VV3)
      do 1202 ik1 = 1,2
      do 1202 ik2 = 1,2
        call V4toU(ik1, ik2, GZK, UZB) 

        call prod_2(UZB, VV1, VS1) 
        call prod_2(VV3, UZB, VS3) 
        call prod_2(V3, UZB, VV) 
        call prod_2(VV, V2, VS2) 

       call Matr_Add_2(VS1, VS2, VV)
       call Matr_Add_2(VV, VS3, VS1)
      do 1203 ik3 = 1,2
      do 1203 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS1, KV4, UU)
       TA2(iq1,iq2,ik1,ik2,ik3,ik4) = -UU
 1203 continue 
 1202 continue 
 1201 continue 

       call prod_2(phm_u1, q1q2, V1) 
       call prod_2(q1q2, phm_u4, V2) 
      do 1211 ik1 = 1,2
      do 1211 ik2 = 1,2
        call V4toU(ik1, ik2, GZK, UZB) 
        call prod_2(UZB, V1, VS1) 
        call prod_2(V2, UZB, VS2) 
       call Matr_Add_2(VS1, VS2, VS3)
      do 1211 ik3 = 1,2
      do 1211 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS3, KV4, UU)
       TC2(ik1,ik2,ik3,ik4) = -UU
 1211 continue 
**
*  gluon1 <==> gluon2
       do j = 1,4
        u2(j) = q1(j) - k4(j)
        u3(j) = k3(j) - q2(j)
       enddo

      call Propf(u2, phm_u2)
      call Propf(u3, phm_u3)
*
      do 1221 iq2 = 1,2
        call prod_EhatA(iq2, phm_u3, V3)
        call prod_EhatA(iq2, phm_u2, VV)
        call prod_2(phm_u1, VV, V1)
      do 1221 iq1 = 1,2
        call prod_AEhat(iq1, phm_u2, V2)
        call prod_AEhat(iq1, V1, VV1)

        call prod_AEhat(iq1, V3, VV)
        call prod_2(VV, phm_u4, VV3)
      do 1222 ik1 = 1,2
      do 1222 ik2 = 1,2
        call V4toU(ik1, ik2, GZK, UZB) 

        call prod_2(UZB, VV1, VS1) 
        call prod_2(VV3, UZB, VS3) 
        call prod_2(V3, UZB, VV) 
        call prod_2(VV, V2, VS2) 

       call Matr_Add_2(VS1, VS2, VV)
       call Matr_Add_2(VV, VS3, VS1)
      do 1223 ik3 = 1,2
      do 1223 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS1, KV4, UU)
       TB2(iq1,iq2,ik1,ik2,ik3,ik4) = -UU
 1223 continue 
 1222 continue 
 1221 continue 

*      z -> k3 k2     + k1 k4
       do j = 1,5
        k1(j) = ak3(j)
        k2(j) = ak2(j)
        k3(j) = ak1(j)
        k4(j) = ak4(j)
       enddo

       do j = 1,4
        pz(j) = k1(j) + k2(j)
        u1(j) = pz(j) + k3(j) 
        u2(j) = q2(j) - k4(j)
        u3(j) = k3(j) - q1(j)
        u4(j) = -k4(j) - pz(j)
       enddo
        u1(5) = k3(5)
        u2(5) = k3(5)
        u3(5) = k3(5)
        u4(5) = k3(5)
        pz(5) = rpar(45)
        q2z = scalp(pz, pz)
*
      call Dirs_Ubar(k1, KUB1)
      call Dirs_Ubar(k3, KUB3)
      call Dirs_V(k2, KV2)
      call Dirs_V(k4, KV4)

      call Propf(u1, phm_u1)
      call Propf(u2, phm_u2)
      call Propf(u3, phm_u3)
      call Propf(u4, phm_u4)

*
       cgV = eqf(2,kfk1)/Q2z
       czV = zff(1,kfk1)/(Q2z - rpar(46) + ei*rpar(48))
       czA = zff(2,kfk1)/(Q2z - rpar(46) + ei*rpar(48))
       call Us_ZbA_Uc(PZ, cgv, czv, cza, KUB1, KV2, HGA, HGZ) 

       cgV = eqf(2,kfk3) 
       czV = zff(1,kfk3)
       czA = zff(2,kfk3)
       call MATR_ZbA(cgV, czV, czA, HGA, HGZ, GZK) 

      do 1301 iq1 = 1,2
        call prod_EhatA(iq1, phm_u3, V3)
        call prod_EhatA(iq1, phm_u2, VV)
        call prod_2(phm_u1, VV, V1)
      do 1301 iq2 = 1,2
        call prod_AEhat(iq2, phm_u2, V2)
        call prod_AEhat(iq2, V1, VV1)

        call prod_AEhat(iq2, V3, VV)
        call prod_2(VV, phm_u4, VV3)
      do 1302 ik1 = 1,2
      do 1302 ik2 = 1,2
        call V4toU(ik1, ik2, GZK, UZB) 

        call prod_2(UZB, VV1, VS1) 
        call prod_2(VV3, UZB, VS3) 
        call prod_2(V3, UZB, VV) 
        call prod_2(VV, V2, VS2) 

       call Matr_Add_2(VS1, VS2, VV)
       call Matr_Add_2(VV, VS3, VS1)
      do 1303 ik3 = 1,2
      do 1303 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS1, KV4, UU)
       TA3(iq1,iq2,ik1,ik2,ik3,ik4) = -UU
 1303 continue 
 1302 continue 
 1301 continue 

       call prod_2(phm_u1, q1q2, V1) 
       call prod_2(q1q2, phm_u4, V2) 
      do 1311 ik1 = 1,2
      do 1311 ik2 = 1,2
        call V4toU(ik1, ik2, GZK, UZB) 
        call prod_2(UZB, V1, VS1) 
        call prod_2(V2, UZB, VS2) 
       call Matr_Add_2(VS1, VS2, VS3)
      do 1311 ik3 = 1,2
      do 1311 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS3, KV4, UU)
       TC3(ik1,ik2,ik3,ik4) = -UU
 1311 continue 
**
*  gluon1 <==> gluon2
       do j = 1,4
        u2(j) = q1(j) - k4(j)
        u3(j) = k3(j) - q2(j)
       enddo

      call Propf(u2, phm_u2)
      call Propf(u3, phm_u3)
*
      do 1321 iq2 = 1,2
        call prod_EhatA(iq2, phm_u3, V3)
        call prod_EhatA(iq2, phm_u2, VV)
        call prod_2(phm_u1, VV, V1)
      do 1321 iq1 = 1,2
        call prod_AEhat(iq1, phm_u2, V2)
        call prod_AEhat(iq1, V1, VV1)

        call prod_AEhat(iq1, V3, VV)
        call prod_2(VV, phm_u4, VV3)
      do 1322 ik1 = 1,2
      do 1322 ik2 = 1,2
        call V4toU(ik1, ik2, GZK, UZB) 

        call prod_2(UZB, VV1, VS1) 
        call prod_2(VV3, UZB, VS3) 
        call prod_2(V3, UZB, VV) 
        call prod_2(VV, V2, VS2) 

       call Matr_Add_2(VS1, VS2, VV)
       call Matr_Add_2(VV, VS3, VS1)
      do 1323 ik3 = 1,2
      do 1323 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS1, KV4, UU)
       TB3(iq1,iq2,ik1,ik2,ik3,ik4) = -UU
 1323 continue 
 1322 continue 
 1321 continue 

*      z -> k3 k4     + k1 k2
       do j = 1,5
        k1(j) = ak3(j)
        k2(j) = ak4(j)
        k3(j) = ak1(j)
        k4(j) = ak2(j)
       enddo

       do j = 1,4
        pz(j) = k1(j) + k2(j)
        u1(j) = pz(j) + k3(j) 
        u2(j) = q2(j) - k4(j)
        u3(j) = k3(j) - q1(j)
        u4(j) = -k4(j) - pz(j)
       enddo
        u1(5) = k3(5)
        u2(5) = k3(5)
        u3(5) = k3(5)
        u4(5) = k3(5)
        pz(5) = rpar(45)
        q2z = scalp(pz, pz)
*
      call Dirs_Ubar(k1, KUB1)
      call Dirs_Ubar(k3, KUB3)
      call Dirs_V(k2, KV2)
      call Dirs_V(k4, KV4)

      call Propf(u1, phm_u1)
      call Propf(u2, phm_u2)
      call Propf(u3, phm_u3)
      call Propf(u4, phm_u4)

*
       cgV = eqf(2,kfk1)/Q2z
       czV = zff(1,kfk1)/(Q2z - rpar(46) + ei*rpar(48))
       czA = zff(2,kfk1)/(Q2z - rpar(46) + ei*rpar(48))
       call Us_ZbA_Uc(PZ, cgv, czv, cza, KUB1, KV2, HGA, HGZ) 

       cgV = eqf(2,kfk3) 
       czV = zff(1,kfk3)
       czA = zff(2,kfk3)
       call MATR_ZbA(cgV, czV, czA, HGA, HGZ, GZK) 

      do 1401 iq1 = 1,2
        call prod_EhatA(iq1, phm_u3, V3)
        call prod_EhatA(iq1, phm_u2, VV)
        call prod_2(phm_u1, VV, V1)
      do 1401 iq2 = 1,2
        call prod_AEhat(iq2, phm_u2, V2)
        call prod_AEhat(iq2, V1, VV1)

        call prod_AEhat(iq2, V3, VV)
        call prod_2(VV, phm_u4, VV3)
      do 1402 ik1 = 1,2
      do 1402 ik2 = 1,2
        call V4toU(ik1, ik2, GZK, UZB) 

        call prod_2(UZB, VV1, VS1) 
        call prod_2(VV3, UZB, VS3) 
        call prod_2(V3, UZB, VV) 
        call prod_2(VV, V2, VS2) 

       call Matr_Add_2(VS1, VS2, VV)
       call Matr_Add_2(VV, VS3, VS1)
      do 1403 ik3 = 1,2
      do 1403 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS1, KV4, UU)
       TA4(iq1,iq2,ik1,ik2,ik3,ik4) = UU
 1403 continue 
 1402 continue 
 1401 continue 

       call prod_2(phm_u1, q1q2, V1) 
       call prod_2(q1q2, phm_u4, V2) 
      do 1411 ik1 = 1,2
      do 1411 ik2 = 1,2
        call V4toU(ik1, ik2, GZK, UZB) 
        call prod_2(UZB, V1, VS1) 
        call prod_2(V2, UZB, VS2) 
       call Matr_Add_2(VS1, VS2, VS3)
      do 1411 ik3 = 1,2
      do 1411 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS3, KV4, UU)
       TC4(ik1,ik2,ik3,ik4) = UU
 1411 continue 
**
*  gluon1 <==> gluon2
       do j = 1,4
        u2(j) = q1(j) - k4(j)
        u3(j) = k3(j) - q2(j)
       enddo

      call Propf(u2, phm_u2)
      call Propf(u3, phm_u3)
*
      do 1421 iq2 = 1,2
        call prod_EhatA(iq2, phm_u3, V3)
        call prod_EhatA(iq2, phm_u2, VV)
        call prod_2(phm_u1, VV, V1)
      do 1421 iq1 = 1,2
        call prod_AEhat(iq1, phm_u2, V2)
        call prod_AEhat(iq1, V1, VV1)

        call prod_AEhat(iq1, V3, VV)
        call prod_2(VV, phm_u4, VV3)
      do 1422 ik1 = 1,2
      do 1422 ik2 = 1,2
        call V4toU(ik1, ik2, GZK, UZB) 

        call prod_2(UZB, VV1, VS1) 
        call prod_2(VV3, UZB, VS3) 
        call prod_2(V3, UZB, VV) 
        call prod_2(VV, V2, VS2) 

       call Matr_Add_2(VS1, VS2, VV)
       call Matr_Add_2(VV, VS3, VS1)
      do 1423 ik3 = 1,2
      do 1423 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS1, KV4, UU)
       TB4(iq1,iq2,ik1,ik2,ik3,ik4) = UU
 1423 continue 
 1422 continue 
 1421 continue 
*********
      ves = 0.d0
      do 211 j1 = 1,2 
      do 211 j2 = 1,2 
      do 211 j3 = 1,2 
      do 211 j4 = 1,2 
      do 211 j5 = 1,2 
      do 211 j6 = 1,2 
      UU1 = TA1(j1,j2,j3,j4,j5,j6) + TB1(j1,j2,j3,j4,j5,j6)
      UU2 = TA2(j1,j2,j3,j4,j5,j6) + TB2(j1,j2,j3,j4,j5,j6)
      UU3 = TA3(j1,j2,j3,j4,j5,j6) + TB3(j1,j2,j3,j4,j5,j6)
      UU4 = TA4(j1,j2,j3,j4,j5,j6) + TB4(j1,j2,j3,j4,j5,j6)
         ves = ves + (7.d0/3.d0) * 
     & (  2.d0* UU1*conjg(UU1) + 2.d0*UU2*conjg(UU2)
     &  + 2.d0* UU3*conjg(UU3) + 2.d0*UU4*conjg(UU4)
     &  + (UU1+UU2+UU3+UU4)*conjg(UU1+UU2+UU3+UU4)
     &  - UU1*conjg(UU4) - UU4*conjg(UU1)
     &  - UU2*conjg(UU3) - UU3*conjg(UU2))

      UU1 = TA1(j1,j2,j3,j4,j5,j6) - TB1(j1,j2,j3,j4,j5,j6)
      UU2 = TA2(j1,j2,j3,j4,j5,j6) - TB2(j1,j2,j3,j4,j5,j6)
      UU3 = TA3(j1,j2,j3,j4,j5,j6) - TB3(j1,j2,j3,j4,j5,j6)
      UU4 = TA4(j1,j2,j3,j4,j5,j6) - TB4(j1,j2,j3,j4,j5,j6)
      if(j1.eq.j2) then
        UU1 = UU1 - 2.d0*TC1(j3,j4,j5,j6) / Q2gl
        UU2 = UU2 - 2.d0*TC2(j3,j4,j5,j6) / Q2gl
        UU3 = UU3 - 2.d0*TC3(j3,j4,j5,j6) / Q2gl
        UU4 = UU4 - 2.d0*TC4(j3,j4,j5,j6) / Q2gl
      endif

      ves = ves + 3.d0 * 
     & (  2.d0* UU1*conjg(UU1) + 2.d0*UU2*conjg(UU2)
     &  + 2.d0* UU3*conjg(UU3) + 2.d0*UU4*conjg(UU4)
     &  + (UU1+UU2+UU3+UU4)*conjg(UU1+UU2+UU3+UU4)
     &  - UU1*conjg(UU4) - UU4*conjg(UU1)
     &  - UU2*conjg(UU3) - UU3*conjg(UU2))
 211  continue
      ves = ves * coef * rpar(16)**2 
      return
      end       

*----------------------------------------------------------------------------*
* Matrix element:   q qbar -> Z Q(k3) Qbar(k4), Z -> f(k1) fbar(k2) 
      subroutine ZqqtoQQ(kfq1, kfk1, kfk3,q1,q2,ak1,ak2,ak3,ak4, ves) 
*     -------------------------------------------                            *
      implicit none
      include "txpar.inc"
      double precision q1(5), q2(5), k1(5), k2(5), k3(5), k4(5)
      double precision ak1(5),ak2(5),ak3(5),ak4(5)
      double precision x1(5), x2(5), x3(5), x4(5),ng(6)
      double precision pg1(5), q2g1, pg2(5), q2g2, pz1(5), q2z1
      double precision VES 
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision scalp, denZ
      integer kfq1, kfk1, kfk3
      integer I,J, iq1, iq2, ik1, ik2, ik3, ik4
      double complex PHM_x1(4,4), PHM_x2(4,4), PHM_x3(4,4), PHM_x4(4,4) 
      double complex KUB1(2,4), KUB3(2,4), KV2(2,4), KV4(2,4),
     &               QVB2(2,4), QU1(2,4)
      double complex cgV, czV, czA, cgl1, cgl2
      double complex UU, TM1(2,2,2,2,2,2) 
      double complex TM2(2,2,2,2,2,2), TM3(2,2,2,2,2,2), 
     &               TM4(2,2,2,2,2,2) 
      double complex U1(4,4),U2(4,4),UZB(4,4),UGL(4,4),VS(4,4) 
      double complex HGA(2,2,4), HGZ(2,2,4)
      double complex GZQ(2,2,4,4), GZK(2,2,4,4), GLK(2,2,4,4)
      double precision coef0, coef 
      SAVE coef0, coef 
      double complex ei 
      data ei/(0.d0, 1.d0)/
      double precision eqf(2,-20:20), zff(2,-20:20) 
      save eqf, zff
      double precision eqf0(2,-20:20), zff0(2,-20:20)
      common /Vboscpl/ eqf0, zff0
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
* test
      double precision v1(5), v2(5), TTT 
*
      if(first) THEN
*       call Vbosoncpl 
      do i = 1,2
      do j = 1,20
         eqf(i,j) = eqf0(i,j)
         zff(i,j) = zff0(i,j)
        if(Ipar(23).eq.1) then    
          zff(i,j) = 0.d0  ! only gamma
        endif 
        if(Ipar(23).eq.2) then    
          eqf(i,j) = 0.d0  ! only Z-boson
        endif 
      enddo
      enddo

       coef0 =  Rpar(10) / (2.d0 * 2.d0)  ! spins
       coef0 = coef0 * 2.d0 / (3.d0 * 3.d0)    ! colors 
      first=.FALSE.
      ENDIF

      
      if(abs(kfk1).le.6) then
        if(kfk1.eq.kfk3) then
         coef = coef0 / 4.d0 ! z -> q qbar two pairs of identical qq~qq~
        else
         coef = 3.d0 * coef0  ! z -> q qbar 
        endif
      elseif(abs(kfk1).ge.11) then
       coef = coef0  ! z -> l+ li or nu nubar
      endif
* evaluate Dirac spinors
       do j = 1,5
        k1(j) = ak1(j)
        k2(j) = ak2(j)
        k3(j) = ak3(j)
        k4(j) = ak4(j)
       enddo

       do j = 1,4
        pg1(j) = k3(j) + k4(j)
        pg2(j) = q1(j) + q2(j)
        ng(j)  = q1(j) + q2(j) 
        pz1(j) = k1(j) + k2(j)
        x1(j)  = q1(j) - pz1(j)
        x2(j)  = q1(j) - pg1(j)
        x3(j)  =  k3(j) + pz1(j)
        x4(j)  = -k4(j) - pz1(j)
       enddo
        x1(5) = q1(5)
        x2(5) = q1(5)
        x3(5) = k3(5)
        x4(5) = k3(5)

        pz1(5) = rpar(45)
        pg1(5) = dsqrt(scalp(pg1,pg1))
        q2z1 = scalp(pz1, pz1)
        denZ = (rpar(46) - q2z1)**2 + rpar(48)**2 
        q2g1 = scalp(pg1, pg1)
        q2g2 = scalp(pg2, pg2)
        ng(5)=ng(4)*ng(4) -ng(1)*ng(1) -ng(2)*ng(2) -ng(3)*ng(3)
        ng(6)=ng(4)*pg1(4)-ng(1)*pg1(1)-ng(2)*pg1(2)-ng(3)*pg1(3)
*

* test
       goto 2001
       do j = 1,4
        v1(j) = scalp(q1,k1)*k2(j) + scalp(q1,k2)*k1(j)  
     &        + q1(j)*k1(5)**2
        v2(j) = scalp(q2,k3)*k4(j) + scalp(q2,k4)*k3(j)  
     &        + q2(j)*k3(5)**2
       enddo
      ttt = 256.d0 * (2.d0*scalp(v1,x1)*scalp(v2,x1)
     & - scalp(x1,x1)*scalp(v1,v2))
      ttt = ttt /(x1(5)**2-scalp(x1,x1))**2
 2001 continue
      call Dirs_Ubar(k1, KUB1)
      call Dirs_Ubar(k3, KUB3)
      call Dirs_V(k2, KV2)
      call Dirs_V(k4, KV4)
      call Dirs_Vbar(q2, QVB2)
      call Dirs_U(q1,    QU1)
      call Propf(x1, phm_x1)
      call Propf(x2, phm_x2)
      call Propf(x3, phm_x3)
      call Propf(x4, phm_x4)
*
       cgV = eqf(2,kfk1)/Q2z1
       czV = zff(1,kfk1)/(Q2z1 - rpar(46) + ei*rpar(48))
       czA = zff(2,kfk1)/(Q2z1 - rpar(46) + ei*rpar(48))
       call Us_ZbA_Uc(PZ1, cgv, czv, cza, KUB1, KV2, HGA, HGZ) 

       cgV = eqf(2,kfq1) 
       czV = zff(1,kfq1)
       czA = zff(2,kfq1)
       call MATR_ZbA(cgV, czV, czA, HGA, HGZ, GZQ) 

       cgV = eqf(2,kfk3) 
       czV = zff(1,kfk3)
       czA = zff(2,kfk3)
       call MATR_ZbA(cgV, czV, czA, HGA, HGZ, GZK) 

       cgl1 = rpar(16) / Q2g1 
       call Us_gluon_Uc(pg1, ng, cgl1, KUB3, KV4, GLK) 

       cgl2 = rpar(16) / Q2g2 
      do 1000 ik1 = 1,2
      do 1000 ik2 = 1,2
       call V4toU(ik1, ik2, GZQ, UZB) 
      do 1000 ik3 = 1,2
      do 1000 ik4 = 1,2
       call V4toU(ik3, ik4, GLK, UGL) 
       call prod_3XPY(UGL, phm_x1, UZB, U1)
       call prod_3XPY(UZB, phm_x2, UGL, U2)
       call Matr_Add_2(U1, U2, VS)
*
      if(q1(3).gt.0.d0) then
       TM1(1,1,ik1,ik2,ik3,ik4) = -VS(4,1) 
       TM1(1,2,ik1,ik2,ik3,ik4) = -VS(4,4) 
       TM1(2,1,ik1,ik2,ik3,ik4) = -VS(1,1) 
       TM1(2,2,ik1,ik2,ik3,ik4) = -VS(1,4) 
      elseif(q1(3).lt.0.d0) then
       TM1(1,1,ik1,ik2,ik3,ik4) = VS(2,3) 
       TM1(1,2,ik1,ik2,ik3,ik4) = VS(2,2) 
       TM1(2,1,ik1,ik2,ik3,ik4) = VS(3,3) 
       TM1(2,2,ik1,ik2,ik3,ik4) = VS(3,2) 
      endif      
 1000  continue

      do 1001 ik1 = 1,2
      do 1001 ik2 = 1,2
       call V4toU(ik1, ik2, GZK, UZB) 
      do 1001 iq1 = 1,2
      do 1001 iq2 = 1,2
       if(iq1.ne.iq2) goto 1003
       call prod_3ZPGL(iq1, UZB, phm_x3, U1)
       call prod_3GLPZ(iq1, phm_x4, UZB, U2)
       call Matr_Add_2(U1, U2, VS)
      do 1002 ik3 = 1,2
      do 1002 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS, KV4, UU)
       TM1(iq1,iq2,ik1,ik2,ik3,ik4) = 
     & TM1(iq1,iq2,ik1,ik2,ik3,ik4) + 2.d0 * cgl2 * UU
 1002  continue
 1003  continue
 1001  continue

       if(kfk1.eq.kfk3) goto 2000
      ves = 0.d0
      do 1010 iq1 = 1,2
      do 1010 iq2 = 1,2
      do 1010 ik1 = 1,2
      do 1010 ik2 = 1,2
      do 1010 ik3 = 1,2
      do 1010 ik4 = 1,2
       ves = ves  + TM1(iq1,iq2,ik1,ik2,ik3,ik4)   
     &      * conjg(TM1(iq1,iq2,ik1,ik2,ik3,ik4))
 1010  continue
      ves = ves * coef * 4.d0 * q1(4) * q2(4)
      return

 2000 continue
       do j = 1,5
        k1(j) = ak1(j)
        k2(j) = ak4(j)
        k3(j) = ak3(j)
        k4(j) = ak2(j)
       enddo

       do j = 1,4
        pg1(j) = k3(j) + k4(j)
        pz1(j) = k1(j) + k2(j)
        x1(j)  = q1(j) - pz1(j)
        x2(j)  = q1(j) - pg1(j)
        x3(j)  =  k3(j) + pz1(j)
        x4(j)  = -k4(j) - pz1(j)
       enddo
        x1(5) = q1(5)
        x2(5) = q1(5)
        x3(5) = k3(5)
        x4(5) = k3(5)

        pz1(5) = rpar(45)
        pg1(5) = dsqrt(scalp(pg1,pg1))
        q2z1 = scalp(pz1, pz1)
*        denZ = (rpar(46) - q2z1)**2 + rpar(48)**2 
        q2g1 = scalp(pg1, pg1)
*        ng(5)=ng(4)*ng(4) -ng(1)*ng(1) -ng(2)*ng(2) -ng(3)*ng(3)
        ng(6)=ng(4)*pg1(4)-ng(1)*pg1(1)-ng(2)*pg1(2)-ng(3)*pg1(3)
*

      call Dirs_Ubar(k1, KUB1)
      call Dirs_Ubar(k3, KUB3)
      call Dirs_V(k2, KV2)
      call Dirs_V(k4, KV4)
*      call Dirs_Vbar(q2, QVB2)
*      call Dirs_U(q1,    QU1)
      call Propf(x1, phm_x1)
      call Propf(x2, phm_x2)
      call Propf(x3, phm_x3)
      call Propf(x4, phm_x4)
*
       cgV = eqf(2,kfk1)/Q2z1
       czV = zff(1,kfk1)/(Q2z1 - rpar(46) + ei*rpar(48))
       czA = zff(2,kfk1)/(Q2z1 - rpar(46) + ei*rpar(48))
       call Us_ZbA_Uc(PZ1, cgv, czv, cza, KUB1, KV2, HGA, HGZ) 

       cgV = eqf(2,kfq1) 
       czV = zff(1,kfq1)
       czA = zff(2,kfq1)
       call MATR_ZbA(cgV, czV, czA, HGA, HGZ, GZQ) 

       cgV = eqf(2,kfk3) 
       czV = zff(1,kfk3)
       czA = zff(2,kfk3)
       call MATR_ZbA(cgV, czV, czA, HGA, HGZ, GZK) 

       cgl1 = pi4 * rpar(15) / Q2g1 
       call Us_gluon_Uc(pg1, ng, cgl1, KUB3, KV4, GLK) 

      do 1100 ik1 = 1,2
      do 1100 ik2 = 1,2
       call V4toU(ik1, ik2, GZQ, UZB) 
      do 1100 ik3 = 1,2
      do 1100 ik4 = 1,2
       call V4toU(ik3, ik4, GLK, UGL) 
       call prod_3XPY(UGL, phm_x1, UZB, U1)
       call prod_3XPY(UZB, phm_x2, UGL, U2)
       call Matr_Add_2(U1, U2, VS)
*
      if(q1(3).gt.0.d0) then
       TM2(1,1,ik1,ik2,ik3,ik4) = -VS(4,1) 
       TM2(1,2,ik1,ik2,ik3,ik4) = -VS(4,4)
       TM2(2,1,ik1,ik2,ik3,ik4) = -VS(1,1) 
       TM2(2,2,ik1,ik2,ik3,ik4) = -VS(1,4) 
      elseif(q1(3).lt.0.d0) then
       TM2(1,1,ik1,ik2,ik3,ik4) =  VS(2,3) 
       TM2(1,2,ik1,ik2,ik3,ik4) =  VS(2,2) 
       TM2(2,1,ik1,ik2,ik3,ik4) =  VS(3,3) 
       TM2(2,2,ik1,ik2,ik3,ik4) =  VS(3,2) 
      endif      
 1100  continue

      do 1101 ik1 = 1,2
      do 1101 ik2 = 1,2
       call V4toU(ik1, ik2, GZK, UZB) 
      do 1101 iq1 = 1,2
      do 1101 iq2 = 1,2
       if(iq1.ne.iq2) goto 1103
       call prod_3ZPGL(iq1, UZB, phm_x3, U1)
       call prod_3GLPZ(iq1, phm_x4, UZB, U2)
       call Matr_Add_2(U1, U2, VS)
      do 1102 ik3 = 1,2
      do 1102 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS, KV4, UU)
       TM2(iq1,iq2,ik1,ik2,ik3,ik4) = -(
     & TM2(iq1,iq2,ik1,ik2,ik3,ik4) + 2.d0 * cgl2 * UU)
 1102  continue
 1103  continue
 1101  continue
* k1 ==> k3 
       do j = 1,5
        k1(j) = ak3(j)
        k2(j) = ak2(j)
        k3(j) = ak1(j)
        k4(j) = ak4(j)
       enddo

       do j = 1,4
        pg1(j) = k3(j) + k4(j)
        pz1(j) = k1(j) + k2(j)
        x1(j)  = q1(j) - pz1(j)
        x2(j)  = q1(j) - pg1(j)
        x3(j)  =  k3(j) + pz1(j)
        x4(j)  = -k4(j) - pz1(j)
       enddo
        x3(5) = k3(5)
        x4(5) = k3(5)

        pz1(5) = rpar(45)
        pg1(5) = dsqrt(scalp(pg1,pg1))
        q2z1 = scalp(pz1, pz1)
*        denZ = (rpar(46) - q2z1)**2 + rpar(48)**2 
        q2g1 = scalp(pg1, pg1)
        ng(6)=ng(4)*pg1(4)-ng(1)*pg1(1)-ng(2)*pg1(2)-ng(3)*pg1(3)
      call Dirs_Ubar(k1, KUB1)
      call Dirs_Ubar(k3, KUB3)
      call Dirs_V(k2, KV2)
      call Dirs_V(k4, KV4)
      call Propf(x1, phm_x1)
      call Propf(x2, phm_x2)
      call Propf(x3, phm_x3)
      call Propf(x4, phm_x4)
*
       cgV = eqf(2,kfk1)/Q2z1
       czV = zff(1,kfk1)/(Q2z1 - rpar(46) + ei*rpar(48))
       czA = zff(2,kfk1)/(Q2z1 - rpar(46) + ei*rpar(48))
       call Us_ZbA_Uc(PZ1, cgv, czv, cza, KUB1, KV2, HGA, HGZ) 

       cgV = eqf(2,kfq1) 
       czV = zff(1,kfq1)
       czA = zff(2,kfq1)
       call MATR_ZbA(cgV, czV, czA, HGA, HGZ, GZQ) 

       cgV = eqf(2,kfk3) 
       czV = zff(1,kfk3)
       czA = zff(2,kfk3)
       call MATR_ZbA(cgV, czV, czA, HGA, HGZ, GZK) 

       cgl1 = pi4 * rpar(15) / Q2g1 
       call Us_gluon_Uc(pg1, ng, cgl1, KUB3, KV4, GLK) 

*       cgl2 = pi4 * rpar(15) / Q2g2 
      do 1200 ik1 = 1,2
      do 1200 ik2 = 1,2
       call V4toU(ik1, ik2, GZQ, UZB) 
      do 1200 ik3 = 1,2
      do 1200 ik4 = 1,2
       call V4toU(ik3, ik4, GLK, UGL) 
       call prod_3XPY(UGL, phm_x1, UZB, U1)
       call prod_3XPY(UZB, phm_x2, UGL, U2)
       call Matr_Add_2(U1, U2, VS)
*
      if(q1(3).gt.0.d0) then
       TM3(1,1,ik1,ik2,ik3,ik4) = -VS(4,1) 
       TM3(1,2,ik1,ik2,ik3,ik4) = -VS(4,4) 
       TM3(2,1,ik1,ik2,ik3,ik4) = -VS(1,1) 
       TM3(2,2,ik1,ik2,ik3,ik4) = -VS(1,4) 
      elseif(q1(3).lt.0.d0) then
       TM3(1,1,ik1,ik2,ik3,ik4) = VS(2,3) 
       TM3(1,2,ik1,ik2,ik3,ik4) = VS(2,2) 
       TM3(2,1,ik1,ik2,ik3,ik4) = VS(3,3) 
       TM3(2,2,ik1,ik2,ik3,ik4) = VS(3,2) 
      endif      
 1200  continue

      do 1201 ik1 = 1,2
      do 1201 ik2 = 1,2
       call V4toU(ik1, ik2, GZK, UZB) 
      do 1201 iq1 = 1,2
      do 1201 iq2 = 1,2
       if(iq1.ne.iq2) goto 1203
       call prod_3ZPGL(iq1, UZB, phm_x3, U1)
       call prod_3GLPZ(iq1, phm_x4, UZB, U2)
       call Matr_Add_2(U1, U2, VS)
      do 1202 ik3 = 1,2
      do 1202 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS, KV4, UU)
       TM3(iq1,iq2,ik1,ik2,ik3,ik4) = -(
     & TM3(iq1,iq2,ik1,ik2,ik3,ik4) + 2.d0 * cgl2 * UU)
 1202  continue
 1203  continue
 1201  continue
* 
* k1 ==> k3 k2 ==> k4
       do j = 1,5
        k1(j) = ak3(j)
        k2(j) = ak4(j)
        k3(j) = ak1(j)
        k4(j) = ak2(j)
       enddo

       do j = 1,4
        pg1(j) = k3(j) + k4(j)
        pz1(j) = k1(j) + k2(j)
        x1(j)  = q1(j) - pz1(j)
        x2(j)  = q1(j) - pg1(j)
        x3(j)  =  k3(j) + pz1(j)
        x4(j)  = -k4(j) - pz1(j)
       enddo
        x3(5) = k3(5)
        x4(5) = k3(5)

        pz1(5) = rpar(45)
        pg1(5) = dsqrt(scalp(pg1,pg1))
        q2z1 = scalp(pz1, pz1)
*        denZ = (rpar(46) - q2z1)**2 + rpar(48)**2 
        q2g1 = scalp(pg1, pg1)
        ng(6)=ng(4)*pg1(4)-ng(1)*pg1(1)-ng(2)*pg1(2)-ng(3)*pg1(3)
      call Dirs_Ubar(k1, KUB1)
      call Dirs_Ubar(k3, KUB3)
      call Dirs_V(k2, KV2)
      call Dirs_V(k4, KV4)
      call Propf(x1, phm_x1)
      call Propf(x2, phm_x2)
      call Propf(x3, phm_x3)
      call Propf(x4, phm_x4)
*
       cgV = eqf(2,kfk1)/Q2z1
       czV = zff(1,kfk1)/(Q2z1 - rpar(46) + ei*rpar(48))
       czA = zff(2,kfk1)/(Q2z1 - rpar(46) + ei*rpar(48))
       call Us_ZbA_Uc(PZ1, cgv, czv, cza, KUB1, KV2, HGA, HGZ) 

       cgV = eqf(2,kfq1) 
       czV = zff(1,kfq1)
       czA = zff(2,kfq1)
       call MATR_ZbA(cgV, czV, czA, HGA, HGZ, GZQ) 

       cgV = eqf(2,kfk3) 
       czV = zff(1,kfk3)
       czA = zff(2,kfk3)
       call MATR_ZbA(cgV, czV, czA, HGA, HGZ, GZK) 

       cgl1 = pi4 * rpar(15) / Q2g1 
       call Us_gluon_Uc(pg1, ng, cgl1, KUB3, KV4, GLK) 

      do 1300 ik1 = 1,2
      do 1300 ik2 = 1,2
       call V4toU(ik1, ik2, GZQ, UZB) 
      do 1300 ik3 = 1,2
      do 1300 ik4 = 1,2
       call V4toU(ik3, ik4, GLK, UGL) 
       call prod_3XPY(UGL, phm_x1, UZB, U1)
       call prod_3XPY(UZB, phm_x2, UGL, U2)
       call Matr_Add_2(U1, U2, VS)
*
      if(q1(3).gt.0.d0) then
       TM4(1,1,ik1,ik2,ik3,ik4) = -VS(4,1) 
       TM4(1,2,ik1,ik2,ik3,ik4) = -VS(4,4) 
       TM4(2,1,ik1,ik2,ik3,ik4) = -VS(1,1) 
       TM4(2,2,ik1,ik2,ik3,ik4) = -VS(1,4) 
      elseif(q1(3).lt.0.d0) then
       TM4(1,1,ik1,ik2,ik3,ik4) = VS(2,3) 
       TM4(1,2,ik1,ik2,ik3,ik4) = VS(2,2) 
       TM4(2,1,ik1,ik2,ik3,ik4) = VS(3,3) 
       TM4(2,2,ik1,ik2,ik3,ik4) = VS(3,2) 
      endif      
 1300  continue

      do 1301 ik1 = 1,2
      do 1301 ik2 = 1,2
       call V4toU(ik1, ik2, GZK, UZB) 
      do 1301 iq1 = 1,2
      do 1301 iq2 = 1,2
       if(iq1.ne.iq2) goto 1303
       call prod_3ZPGL(iq1, UZB, phm_x3, U1)
       call prod_3GLPZ(iq1, phm_x4, UZB, U2)
       call Matr_Add_2(U1, U2, VS)
      do 1302 ik3 = 1,2
      do 1302 ik4 = 1,2
       call Us_M_Uc(ik3,ik4, KUB3, VS, KV4, UU)
       TM4(iq1,iq2,ik1,ik2,ik3,ik4) = 
     & TM4(iq1,iq2,ik1,ik2,ik3,ik4) + 2.d0 * cgl2 * UU
 1302  continue
 1303  continue
 1301  continue
* 
      ves = 0.d0
      do 2011 iq1 = 1,2
      do 2011 iq2 = 1,2
       if(iq1.ne.iq2) goto 2011
      do 2010 ik1 = 1,2
      do 2010 ik2 = 1,2
      do 2010 ik3 = 1,2
      do 2010 ik4 = 1,2
       ves = ves  
     &+ 2.d0*(TM1(iq1,iq2,ik1,ik2,ik3,ik4)   
     & *conjg(TM1(iq1,iq2,ik1,ik2,ik3,ik4)))
     &+ 2.d0*(TM2(iq1,iq2,ik1,ik2,ik3,ik4)   
     & *conjg(TM2(iq1,iq2,ik1,ik2,ik3,ik4)))  
     &+ 2.d0*(TM3(iq1,iq2,ik1,ik2,ik3,ik4)   
     & *conjg(TM3(iq1,iq2,ik1,ik2,ik3,ik4)))
     &+ 2.d0*(TM4(iq1,iq2,ik1,ik2,ik3,ik4)   
     & *conjg(TM4(iq1,iq2,ik1,ik2,ik3,ik4)))  
     & + (  TM1(iq1,iq2,ik1,ik2,ik3,ik4)   
     &    + TM2(iq1,iq2,ik1,ik2,ik3,ik4)
     &    + TM3(iq1,iq2,ik1,ik2,ik3,ik4)
     &    + TM4(iq1,iq2,ik1,ik2,ik3,ik4))*conjg
     &   (  TM1(iq1,iq2,ik1,ik2,ik3,ik4)   
     &    + TM2(iq1,iq2,ik1,ik2,ik3,ik4)
     &    + TM3(iq1,iq2,ik1,ik2,ik3,ik4)
     &    + TM4(iq1,iq2,ik1,ik2,ik3,ik4))
     &    -   TM1(iq1,iq2,ik1,ik2,ik3,ik4)   
     & * conjg(TM4(iq1,iq2,ik1,ik2,ik3,ik4))
     &    -   TM4(iq1,iq2,ik1,ik2,ik3,ik4)   
     & * conjg(TM1(iq1,iq2,ik1,ik2,ik3,ik4))
     &    -    TM2(iq1,iq2,ik1,ik2,ik3,ik4)   
     & * conjg(TM3(iq1,iq2,ik1,ik2,ik3,ik4))
     &    -    TM3(iq1,iq2,ik1,ik2,ik3,ik4)   
     & * conjg(TM2(iq1,iq2,ik1,ik2,ik3,ik4))
 2010  continue
 2011  continue
      ves = ves * coef * 4.d0 * q1(4) * q2(4)
      RETURN
      END
*----------------------------------------------------------------------------*
*   
      subroutine Vbosoncpl 
*     -------------------------------------------                            *
      implicit none
      include "txpar.inc"
*..Rpar(23)     : sin(theta_W)**2                                            *
*..Rpar(24)     : cos(theta_W)**2                                            *
*..Rpar(25)     : sin(2*theta_W) = 2 * sin(theta_W) * cos(theta_W)           *
*..Rpar(26)     : g = g_weak  = e / sin(theta_W)                             *
*..Rpar(27)     : g_z         = e / sin(2*theta_W)                           *
* eqf(1, n) : electric charge in |Q(electron)| units
* eqf(2, n) : e(QED) * eqf(1, n)
* zff  times  3 / sin(2 theta_W)
* zff(1, n) : gv <=> gamma^mu
* zff(2, n) : ga <=> gamma^mu * gamma^5
      double precision eqf(2,-20:20), zff(2,-20:20)
      common /Vboscpl/ eqf, zff
      save /Vboscpl/
      integer J
*
      do j = 1,20
       eqf(1,j) = 0.d0
       eqf(2,j) = 0.d0
       zff(1,j) = 0.d0
       zff(2,j) = 0.d0
      enddo

       eqf(1,1) = -1.d0 / 3.d0  ! d
       eqf(1,2) = +2.d0 / 3.d0  ! u
       eqf(1,3) = eqf(1,1)     
       eqf(1,4) = eqf(1,2)
       eqf(1,5) = eqf(1,1) 
       eqf(1,6) = eqf(1,2) 
       eqf(1,7) = eqf(1,1) 
       eqf(1,8) = eqf(1,2) 
       eqf(1,11) = -1. ! e-
       eqf(1,13) = -1. ! mu-
       eqf(1,15) = -1. ! tau
       eqf(1,17) = -1. ! L-

      do j = 1,20
       eqf(2,j)  = Rpar(13) * eqf(1,j) 
       eqf(1,-j) = -eqf(1,j) 
       eqf(2,-j) = -eqf(2,j) 
      enddo


      zff(1,1) = rpar(27) * (-0.5d0 + (2.d0/3.d0)*rpar(23))  ! D-quark V
      zff(2,1) = rpar(27) * (+0.5d0 )                        ! D-quark A
      zff(1,3) =   zff(1,1) ! S-quark
      zff(2,3) =   zff(2,1) !
      zff(1,5) =   zff(1,1) ! B-quark
      zff(2,5) =   zff(2,1) 
      zff(1,2) = rpar(27) * (+0.5d0 - (4.d0/3.d0)*rpar(23))  ! UP-quark
      zff(2,2) = rpar(27) * (-0.5d0 )                        ! UP-quark
      zff(1,4) =   zff(1,2) ! C-quark
      zff(2,4) =   zff(2,2) 
      zff(1,6) =   zff(1,2) ! T-quark
      zff(2,6) =   zff(2,2) 
*  leptons
      zff(1,11) = rpar(27) * (-0.5d0 + 2.d0*rpar(23))        ! e- 
      zff(2,11) = rpar(27) * (+0.5d0 ) 
      zff(1,13) =   zff(1,11)  ! mu-
      zff(2,13) =   zff(2,11)
      zff(1,15) =   zff(1,11)  ! tau-
      zff(2,15) =   zff(2,11)
*
      zff(1,12) = rpar(27) * (+0.5d0)           ! nu- 
      zff(2,12) = rpar(27) * (-0.5d0 ) 
      zff(1,14) =   zff(1,12)  ! nu_mu
      zff(2,14) =   zff(2,12)
      zff(1,16) =   zff(1,12)  ! nu_tau
      zff(2,16) =   zff(2,12)
      do j = 1,20
       zff(1,-j) = zff(1,j) 
       zff(2,-j) = zff(2,j) 
      enddo
      RETURN
      END
*----------------------------------------------------------------------------*
      subroutine GGZZ(p1, p2, p3, p4, vesm)
      implicit none
      include "txpar.inc" 
      double precision p1(5), p2(5), p3(5), p4(5) 
      double precision Vesm 
      double precision s,t,u,s2,s4,yr
      common /varz0/s,t,u,s2,s4,yr
      double precision gv2, ga2 
      common /gvga/    gv2, ga2 
      double precision mqq2, mqq4, mqq6
      common /masqz/   mqq2, mqq4, mqq6
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision mz2, mz4
      common /masszbos/ mz2, mz4
      double precision bet
      common /zzbet/ bet
      save /zzbet/ 
      integer I
      integer izmod, IQ
      common /izzmod/izmod, IQ
      save /izzmod/
      double complex EPS
      COMMON/SMALL/EPS
      data EPS/(0.0D0,-1.0D-8)/
      save /SMALL/
      integer NQ
      double precision EM2, EC2
      COMMON/QUARK/EM2(5),EC2(5,2),NQ
      save /QUARK/
      double precision EM(5)
      data EM/ 0.1D0, 175.D0, 0.d0, 0.d0, 0.d0/
      double precision AU,BU,AD,BD
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst / pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      LOGICAL first
      DATA first /.TRUE./
      SAVE first 
      double precision EMCUT2, PIE
      double complex RM1
      COMMON/EMCUT/EMCUT2,PIE,RM1
      data emcut2/1.d0/
      data RM1/(0.D0,1.D0)/
      save /EMCUT/
      double precision eqf(2,-20:20), zff(2,-20:20)
      common /Vboscpl/ eqf, zff

*....
      IF(first) then 
       first = .false.
      NQ = 2
      EM(2) = mq(6)
      DO 767 I=1,NQ
  767 EM2(I)=EM(I)*EM(I)
       PIE = pi
       mz2 = Rpar(46)
       mz4 = Rpar(46)**2
       EPS=(0.0D0,-1.0D-8)
* parameters from Glover's code
*      XW=0.23D0
*      AL = Rpar(11)
*      AL=1.D0/128.D0
*      ALZ=AL/XW/(1.D0-XW)
*      AU=0.25D0-2.D0*XW/3.D0
*      BU=-0.25D0
*      AD=-0.25D0+XW/3.D0
*      BD=0.25D0

* Higgs contribution
      AD = zff(1, 1)
      AU = zff(1, 2)
      BD = zff(2, 1)
      BU = zff(2, 2)

*      EM(1)=0.1D0
*      EM(2)=120.D0
      EC2(1,1)=2.D0*(AU**2+BU**2)+3.D0*(AD**2+BD**2)
      EC2(1,2)=2.D0*(AU**2-BU**2)+3.D0*(AD**2-BD**2)
      EC2(2,1)=AU**2+BU**2
      EC2(2,2)=AU**2-BU**2
      NQ=2
      ENDIF
*
      call varzz(p1,p2,p3,p4)
      Vesm = 0.d0
*       CALL A2GGZZ(S, T, U, A2TT,A2TL,A2LL, VESM)
       CALL A2GGZZ(S, T, U, VESM)
      return
      end
*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   15/02/2005                                 *
*....                                                                        *
      subroutine LEPTEN(ifr, pz, eh, lp, lm, ZLT0, ZLT)
*     ------------------------------------------------                       *
*............................................................................*
      implicit none
      double precision pz(5), q2, R(5)
      double precision lp(5), lm(5) 
      double complex eh(-1:1,4), ZLT(-1:1,-1:1), ZLT0

      double complex EPS4, ee,e1r,e2r
      double precision ml2, vap2, vam2, va2, v0am2, VES
      common /zllc/    ml2, vap2, vam2, va2, V0am2
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst / pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      integer i,ip
      double precision eqf(2,-20:20), zff(2,-20:20)
      common /Vboscpl/ eqf, zff
      double precision gv2, ga2
      integer IFR
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
*
*      il = 13
      gv2 = zff(1, ifr)**2
      ga2 = zff(2, ifr)**2
      ml2 = mq2(ifr)
      vam2 = ml2 * (gv2 - ga2)
      Vap2 = (1.d0/2.d0) * (gv2 + ga2)
      Va2  = 2 * zff(1, 11) * zff(2, 11)
      V0am2 = 2.d0 * ml2 * (gv2 - 2*ga2)
*  first Z (p3)

      lp(5) = mq(ifr)
      lm(5) = mq(ifr)

      call LIPS2 (PZ, lp, lm, Ves)
      do i = 1,4
       R(i) = lp(i) - lm(i)
      enddo      
      q2 = pz(5)**2

      do i  = -1, 1
      do ip = -1, 1
      ee  = eh(i,4)*conjg(eh(ip,4)) - eh(i,1)*conjg(eh(ip,1)) 
     &    - eh(i,2)*conjg(eh(ip,2)) - eh(i,3)*conjg(eh(ip,3))
      e1r = eh(i,4)*R(4) - eh(i,1)*R(1)-eh(i,2)*R(2)-eh(i,3)*R(3)
      e2r = conjg(eh(ip,4))*R(4) - conjg(eh(ip,1))*R(1) 
     &    - conjg(eh(ip,2))*R(2) - conjg(eh(ip,3))*R(3)
*
      eps4 = 
     & -conjg(eh(ip,4))*( eh(i,1) * (PZ(2)*R(3) - PZ(3)*R(2))
     &                   -eh(i,2) * (PZ(1)*R(3) - PZ(3)*R(1))
     &                   +eh(i,3) * (PZ(1)*R(2) - PZ(2)*R(1)) )
     & -conjg(eh(ip,1))*(-eh(i,4) * (PZ(2)*R(3) - PZ(3)*R(2))
     &                   +eh(i,2) * (PZ(4)*R(3) - PZ(3)*R(4))
     &                   -eh(i,3) * (PZ(4)*R(2) - PZ(2)*R(4)) )
     & -conjg(eh(ip,2))*( eh(i,4) * (PZ(1)*R(3) - PZ(3)*R(1))
     &                   -eh(i,1) * (PZ(4)*R(3) - PZ(3)*R(4))
     &                   +eh(i,3) * (PZ(4)*R(1) - PZ(1)*R(4)) )
     & -conjg(eh(ip,3))*(-eh(i,4) * (PZ(1)*R(2) - PZ(2)*R(1))
     &                   +eh(i,1) * (PZ(4)*R(2) - PZ(2)*R(4))
     &                   -eh(i,2) * (PZ(4)*R(1) - PZ(1)*R(4)) )
       ZLT(ip,i) = vam2*ee + vap2*((q2-2.d0*ml2)*ee + e1r*e2r)
     &   + (0.d0,1.d0)*va2 * eps4
       ZLT(ip,i) = ves * ZLT(ip,i) 
      enddo
      enddo
* 
      ZLT0 = pi * dsqrt(1.d0 - 4.d0*ml2/pz(5)**2)/2.d0/pi2_6
      ZLT0 = ZLT0 * (2.d0*vap2*pz(5)**2 + V0am2) / 3.d0
      

      return
      end
*----------------------------------------------------------------------------*
      subroutine LEPMOMS
      implicit none
      include "txpar.inc" 
      include "hepeup.inc"
      double precision ps1(5), ps2(5), ps3(5), ps4(5), QQ(5)
      common /zzmom/ps1,ps2,ps3,ps4,QQ
      double precision l3p,   l3m,   l4p,   l4m
      common /zzlep/   l3p(5),l3m(5),l4p(5),l4m(5)
      double precision ps(5)

      integer j
*
*  Lorentz transformation into initial frame
      call Lorenb_s(qq, l3p, ps)
       do j = 1,5
        l3p(j) = ps(j)
         enddo
      call Lorenb_s(qq, l3m, ps)
       do j = 1,5
        l3m(j) = ps(j)
         enddo
      call Lorenb_s(qq, l4p, ps)
       do j = 1,5
        l4p(j) = ps(j)
         enddo
      call Lorenb_s(qq, l4m, ps)
       do j = 1,5
        l4m(j) = ps(j)
         enddo
*
      return
      end
*----------------------------------------------------------------------------*
      subroutine varzz(p1,p2,p3,p4) 
      implicit none
      include "txpar.inc" 
      double precision mz2, mz4
      common /masszbos/ mz2, mz4
      double precision p1(5), p2(5), p3(5), p4(5), QQ(5)
      double precision ps1(5), ps2(5), ps3(5), ps4(5)
      common /zzmom/ps1,ps2,ps3,ps4,QQ
      integer j
      double precision s,t,u,s2,s4,yr
      common /varz0/s,t,u,s2,s4,yr
      double precision bet, pz, pt, ds, ss, cs, cz,sz
      common /zzbet/ bet
      save /zzbet/ 
*      double complex ep(2,4), em(2,4) ei
*      common /helvec/ep, em
*      save /helvec/
      double complex ex, ey, ez
      double complex ei
      data ei/(0.d0,1.d0)/
      save ei
      double complex e3(-1:1,4), e4(-1:1,4) 
      common /zbospol/ e3, e4
*      integer it1, it2
*      double complex ttt
*
      s = (p1(4)+p2(4))**2 - (p1(1)+p2(1))**2  
     &  - (p1(2)+p2(2))**2 - (p1(3)+p2(3))**2 
      u = (p2(4)-p3(4))**2 - (p2(1)-p3(1))**2  
     &  - (p2(2)-p3(2))**2 - (p2(3)-p3(3))**2 
      t = (p1(4)-p3(4))**2 - (p1(1)-p3(1))**2  
     &  - (p1(2)-p3(2))**2 - (p1(3)-p3(3))**2 
*
      s2 = s - 2.d0*mz2
      s4 = s - 4.d0*mz2
      YR = u*t - mz4
      bet = dsqrt(1.d0 - 4.d0*mz2/s)
      do J = 1,4
       qq(j) = p3(j) + p4(j)
      enddo
       qq(5) = dsqrt(s)
* Lorentz boost to QQ rest frame
      call Lorenf_s(qq, p1, ps1)
      call Lorenf_s(qq, p2, ps2)
      call Lorenf_s(qq, p3, ps3)
      call Lorenf_s(qq, p4, ps4)
* evaluate E3 and E4 helicity vectors in QQ rest frame
      PZ = dsqrt(ps3(4)**2 - mz2)
      ds = 1.d0 / dsqrt(2.d0)
      PT = dsqrt(ps3(1)**2 + ps3(2)**2) 
       cz = ps3(3) / PZ
       sz = pt     / PZ
       cs = ps3(1) / pt
       ss = ps3(2) / pt
* e3+
       e3(1,4) = (0.d0, 0.d0)
        ex = ds * (ei * cz)
        ey = ds
        ez = ds * (-ei * sz)
       e3(1,3) = ez
       e3(1,2) = ss * ex + cs * ey
       e3(1,1) = cs * ex - ss * ey
* e3-
       e3(-1,4) = (0.d0, 0.d0)
        ex = ds * (-ei * cz)
        ey = ds
        ez = ds * (ei * sz)
       e3(-1,3) = ez
       e3(-1,2) = ss * ex + cs * ey
       e3(-1,1) = cs * ex - ss * ey
* e30
       e3(0,4) = PZ / Rpar(45)
        ex = (ps3(4)/rpar(45)) * sz
        ey = (0.d0,0.d0)
        ez = (ps3(4)/rpar(45)) * cz
       e3(0,3) = ez
       e3(0,2) = ss * ex + cs * ey
       e3(0,1) = cs * ex - ss * ey
****
* e4+
       e4(1,4) = (0.d0, 0.d0)
        ex = ds * (-ei * cz)
        ey = ds
        ez = ds * (ei * sz)
       e4(1,3) = ez
       e4(1,2) = ss * ex + cs * ey
       e4(1,1) = cs * ex - ss * ey
* e4-
       e4(-1,4) = (0.d0, 0.d0)
        ex = ds * (ei * cz)
        ey = ds
        ez = ds * (-ei * sz)
       e4(-1,3) = ez
       e4(-1,2) = ss * ex + cs * ey
       e4(-1,1) = cs * ex - ss * ey
* e40
       e4(0,4) =  PZ / Rpar(45)
        ex = -(ps4(4)/rpar(45)) * sz
        ey =  (0.d0,0.d0)
        ez = -(ps4(4)/rpar(45)) * cz
       e4(0,3) = ez
       e4(0,2) = ss * ex + cs * ey
       e4(0,1) = cs * ex - ss * ey

      return
      end

c----------------------------------------------------------------------------c
      function dLi2(x)
      implicit none
      double complex dLi2
      double complex spen0, x, x1, x2 
      double complex e05 
      double complex e0, e1, ei  ! 0, 1 i
      common /cunits/ e0, e1, ei
      data e05/(0.5d0,0.d0)/
      save e05
      double precision ax
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
*
       dLi2 = e0
       if(x.eq.e0) then
        return
       elseif(x.eq.e1) then
         dLi2 = pi**2/6.d0
          return
       elseif(x.eq.-e1) then
         dLi2 = -pi**2/12.d0
          return
       elseif(x.eq.ei) then
         dLi2 = -pi**2/48.d0 + ei*0.915965594
          return
       elseif(x.eq.-ei) then
         dLi2 = -pi**2/48.d0 - ei*0.915965594
          return
       elseif(x.eq.e05) then
         dLi2 = pi**2/12.d0 - e05*(dlog(2.d0))**2
          return
       endif 

      ax = cdabs(x)
      if(ax.le.1.0d0) then
       dLi2 = spen0(x)
      else 

*      if(DREAL(X).lt.0.d0.and.DIMAG(X).eq.0.d0) x = x + ei*ax*0.00001
      if(DIMAG(X).eq.0.d0) x = x + ei*ax*0.00001
      If(dreal(x).gt.0.d0) then 
       x1 = 1.d0 - x
       dLi2 = pi**2/6.d0 - cdlog(x)*cdlog(1.d0-x)     
        if((cdabs(x1)**2).le.1.d0) then
         dLi2 = dLi2 -spen0(x1) 
        else
         x2 = 1.d0/(1.d0 - x1)
         dLi2 = dLi2 - (spen0(x2) + 0.5*(cdlog(1.d0-x1))**2 
     & -cdlog(-x1)*cdlog(1.d0-x1) - pi**2/6.d0)
         endif
       Else 
       x1 = 1.d0/(1.d0 - x)
       dLi2 = spen0(x1) + 0.5*(cdlog(1.d0-x))**2 
     & -cdlog(-x)*cdlog(1.d0-x) - pi**2/6.d0
       endif
      Endif

      return
      end
*----------------------------------------------------------------------------*
      function spen0(x)
      implicit none
      double complex spen0,x 

      integer I, N0
      data n0/100/
*
       spen0 = (0.d0,0.d0)
      if(cdabs(x).le.1.0d0) then
*      if(cdabs(x).le.0.5d0) then
       do I = 1,n0
        spen0 = spen0 + x**i/i**2
       enddo
      endif
      return
      end
*----------------------------------------------------------------------------*
* Author: Nigel Glover (1989)                                                *
* the original code is based on the article                                  *
* E.W.N. Glver and I.J. Van det Bij, Nucl.Phys. B321 (1989) 561              *
*                                                                            *
* Z-boson decay into fermion pair procedure is written by Serge Slabospitsky *
*                                                         16/02/2005         *
*----------------------------------------------------------------------------*
*      SUBROUTINE A2GGZZ(S,T,U,WTTT,WTTL,WTLL, WTOUT)

      SUBROUTINE A2GGZZ(S,T,U, WTOUT)
      implicit none 
      include "txpar.inc" 
      COMPLEX*16 BI(4),CI(4),DI(3),EPS
      COMPLEX*16 B0,TRI1,TRI2,TRI3,BOX,CRBOX
      COMPLEX*16 APPPP,APPPM,APMPP,APMPM,APPP0,APMP0,APP00,APM00,AHZZ
      COMMON/SMALL/EPS
      double precision EMCUT2, PIE
      double complex RM1
      COMMON/EMCUT/EMCUT2,PIE,RM1

      COMMON/CINTS/BI,CI,DI
      integer NQ, INQ
      double precision EM2, EC2
      COMMON/QUARK/EM2(5),EC2(5,2),NQ
*      double precision XW,AL,ALZ,ALS
*      COMMON/INFO2/XW,AL,ALZ,ALS
*      save /info2/
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
*
      double precision S, T, U
      double precision EMQ2, BP,BM, A2PB2,A2MB2 !, PT2
      double precision mz2, mz4
      common /masszbos/ mz2, mz4
      integer j1,j2,j3,j4 
      double complex MEX(-1:1,-1:1,-1:1,-1:1)

      double precision coef, WTOUT, WTS0 
      common /ggmex/ coef, WTS0, MEX
      save /ggmex/
      LOGICAL first
      DATA first /.TRUE./
      SAVE first 
      double precision eqf(2,-20:20), zff(2,-20:20)
      common /Vboscpl/ eqf, zff
C
C     FACTOR FOR BOX AMPLITUDE
C     STRONG COUPLING, 4PIE ALPHAS, ELECTROCOUPLING 4PIE ALPHAZ
C
C
C     Ipar(24) = 0 BOX ONLY
C     Ipar(24) = 1 BOX AND HIGGS
C     Ipar(24) = 2 HIGGS ONLY
C
*****
      IF(first) then 
       first = .false.
C     INCLUDE  SPIN SUM 2, COLOUR SUM, 2, COL AVERAGE, 1/64
C     SPIN AVERAGE, 1/4 AND IDENTICAL PARTICLES, 1/2
       coef = Rpar(10) * 2.D0*2.D0/64.D0/4.D0/2.D0/(4.d0*pi)**4
*       coef = 2.d0 * coef ! now Z-bosons are not identical !!! SRS
       coef = coef * BRS(1,4)**2
      ENDIF

      do 123 j1 = -1,1
      do 123 j2 = -1,1
      do 123 j3 = -1,1
      do 123 j4 = -1,1
 123     MEX(j1,j2,j3,j4) = (0.d0, 0.d0)


      DO 100 INQ=1,NQ
        EMQ2=EM2(INQ)
        A2PB2=EC2(INQ,1)
        A2MB2=EC2(INQ,2)
        BI(4)=B0(MZ2,EMQ2)
        BI(1)=B0(S,EMQ2)-BI(4)
        BI(2)=B0(T,EMQ2)-BI(4)
        BI(3)=B0(U,EMQ2)-BI(4)
        CI(1)=TRI1(S,T,U,MZ2,EMQ2)
        CI(2)=TRI2(S,T,U,MZ2,EMQ2)
        CI(3)=TRI2(S,U,T,MZ2,EMQ2)
        CI(4)=TRI3(S,T,U,MZ2,EMQ2)
        DI(2)=BOX(S,T,U,MZ2,EMQ2)
        DI(1)=BOX(S,U,T,MZ2,EMQ2)
        DI(3)=CRBOX(S,T,U,MZ2,EMQ2)
C
C    MULTIPLY BY BOX FACTOR AND PUT IN ELECTRIC CHARGE
C
        BP=DSQRT(1.D0-4.D0*MZ2/S)
        BM=-BP

        IF(Ipar(24).NE.2)THEN
*        TAMP(1)=TAMP(1)+APPPP(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
*        TAMP(2)=TAMP(2)+APPPP(S,T,U,MZ2,EMQ2,bm,A2PB2,A2MB2)
*        TAMP(3)=TAMP(3)+APPPM(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
*        TAMP(4)=TAMP(3)
*        TAMP(5)=TAMP(5)+APMPP(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
*        TAMP(6)=TAMP(5)
*        TAMP(7)=TAMP(7)+APMPM(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
*        TAMP(8)=TAMP(8)+APMPM(S,T,U,MZ2,EMQ2,bm,A2PB2,A2MB2)
*        TAMP(9)=TAMP(9)  +APPP0(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
*        TAMP(10)=TAMP(9)
*        TAMP(11)=TAMP(11)+APPP0(S,T,U,MZ2,EMQ2,bm,A2PB2,A2MB2)
*        TAMP(12)=TAMP(11)
*        TAMP(13)=TAMP(13)+APMP0(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
*        TAMP(14)=TAMP(14)+APMP0(S,T,U,MZ2,EMQ2,bm,A2PB2,A2MB2)
*        TAMP(15)=TAMP(14)
*        TAMP(16)=TAMP(13)
*        TAMP(17)=TAMP(17)+APP00(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
*        TAMP(18)=TAMP(18)+APM00(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
*
************************
         MEX(+1,+1,+1,+1) = MEX(+1,+1,+1,+1) 
     &                  + APPPP(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
         MEX(+1,+1,+1, 0) = MEX(+1,+1,+1, 0) 
     &                  + APPP0(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
         MEX(+1,+1,+1,-1) = MEX(+1,+1,+1,-1) 
     &                  + APPPM(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
************
         MEX(+1,+1, 0,+1) = MEX(+1,+1,+1, 0)
*
*         MEX(+1,+1, 0,+1) = MEX(+1,+1, 0,+1) 
*     &                  + APPP0(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
         MEX(+1,+1, 0, 0) = MEX(+1,+1, 0, 0) 
     &                  + APP00(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
         MEX(+1,+1, 0,-1) = MEX(+1,+1, 0,-1) 
     &                  + APPP0(S,T,U,MZ2,EMQ2,bm,A2PB2,A2MB2)
***************
         MEX(+1,+1,-1,+1) = MEX(+1,+1,+1,-1)
         MEX(+1,+1,-1, 0) = MEX(+1,+1, 0,-1)
**
*         MEX(+1,+1,-1,+1) = MEX(+1,+1,-1,+1) 
*     &                  + APPPM(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
*         MEX(+1,+1,-1, 0) = MEX(+1,+1,-1, 0) 
*     &                  + APPP0(S,T,U,MZ2,EMQ2,bm,A2PB2,A2MB2)
         MEX(+1,+1,-1,-1) = MEX(+1,+1,-1,-1) 
     &                  + APPPP(S,T,U,MZ2,EMQ2,bm,A2PB2,A2MB2)
*****************
         MEX(+1,-1,+1,+1) = MEX(+1,-1,+1,+1) 
     &                  + APMPP(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
         MEX(+1,-1,+1, 0) = MEX(+1,-1,+1, 0)
     &                  + APMP0(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
         MEX(+1,-1,+1,-1) = MEX(+1,-1,+1,-1) 
     &                  + APMPM(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
***********
         MEX(+1,-1, 0,+1) = MEX(+1,-1, 0,+1) 
     &                  - APMP0(S,T,U,MZ2,EMQ2,bm,A2PB2,A2MB2)
         MEX(+1,-1, 0, 0) = MEX(+1,-1, 0, 0) 
     &                  + APM00(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
         MEX(+1,-1, 0,-1) = -MEX(+1,-1,+1, 0)
*         MEX(+1,-1, 0,-1) = MEX(+1,-1, 0,-1) 
*     &                  - APMP0(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)
*************
         MEX(+1,-1,-1,+1) = MEX(+1,-1,-1,+1) 
     &                  + APMPM(S,T,U,MZ2,EMQ2,bm,A2PB2,A2MB2)
         MEX(+1,-1,-1, 0) = -MEX(+1,-1, 0,+1)
         MEX(+1,-1,-1,-1) =  MEX(+1,-1,+1,+1)
*         MEX(+1,-1,-1, 0) = MEX(+1,-1,-1, 0) 
*     &                  + APMP0(S,T,U,MZ2,EMQ2,bm,A2PB2,A2MB2)
*         MEX(+1,-1,-1,-1) = MEX(+1,-1,-1,-1) 
*     &                  + APMPP(S,T,U,MZ2,EMQ2,BP,A2PB2,A2MB2)

        ENDIF
* HIGGS contribution
        IF(INQ.EQ.2.AND.Ipar(24).NE.0)THEN
        AHZZ=+2.D0*EMQ2/(S-Rpar(57)**2+RM1*Rpar(59))*
     &   (-2.D0+(S-4.D0*EMQ2)*CI(1))
         MEX(+1,+1,+1,+1) = MEX(+1,+1,+1,+1) + AHZZ ! TAMP(1)
         MEX(+1,+1,-1,-1) = MEX(+1,+1,-1,-1) + AHZZ ! TAMP(2) 
         MEX(+1,+1, 0, 0) = MEX(+1,+1, 0, 0) 
     &      +(S-2.D0*MZ2)/2.D0/MZ2*AHZZ
        ENDIF
* end HIGGS
 100    continue  ! end main loop

C
C    HIGGS CONTRIBUTION
C
*   99 CONTINUE
*        IF(INQ.EQ.2.AND.Ipar(24).NE.0)THEN
*        AHZZ=+2.D0*EMQ2/(S-EMH2+RM1*GH*EMH)*
*     1   (-2.D0+(S-4.D0*EMQ2)*CI(1))
*        TAMP(1)=TAMP(1)+AHZZ
*        TAMP(2)=TAMP(2)+AHZZ
*        TAMP(17)=TAMP(17)+(S-2.D0*MZ2)/2.D0/MZ2*AHZZ
*        ENDIF
*  100   CONTINUE
C
C       incluDE I PIE**2 FOR B,C,D DEFINITION AND 1/(2PIE)**4 FOR LOOP
C
*      DO 120 I=1,18
*        TAMPI(I)=DREAL(TAMP(I))*BOXFAC/16.D0/PIE**2
*  120   TAMPR(I)=-DIMAG(TAMP(I))*BOXFAC/16.D0/PIE**2
C     DO 125 I=1,18
C 125 WRITE(6,126)I,TAMPI(I),TAMPR(I)
C 126 FORMAT(5X,'( ',I5,2E12.4)
C
C     INCLUDE  SPIN SUM 2, COLOUR SUM, 2, COL AVERAGE, 1/64
C     SPIN AVERAGE, 1/4 AND IDENTICAL PARTICLES, 1/2
C
*      AVFAC=2.D0*2.D0/64.D0/4.D0/2.D0
*      WTTT=0.D0
*      WTTL=0.D0
*      WTLL=0.D0
*      DO 130 I=1,8
*  130 WTTT=WTTT+TAMPI(I)**2+TAMPR(I)**2
*      WTTT=WTTT*AVFAC
*      DO 140 I=9,16
*  140 WTTL=WTTL+TAMPI(I)**2+TAMPR(I)**2
*      WTTL=WTTL*AVFAC
*      DO 150 I=17,18
*  150 WTLL=WTLL+TAMPI(I)**2+TAMPR(I)**2
*      WTLL=WTLL*AVFAC

      WTS0 = 0.d0
*       do 80 J1 = 1,1
       do 80 J2 = 1,2
       do 80 J3 = -1,1
       do 80 J4 = -1,1
 80       WTS0 = WTS0 
     & + MEX(+1, (-3+2*j2),j3,j4)*conjg(MEX(+1, (-3+2*j2),j3,j4))
*      WTS0 = wts0 * avfac * (BOXFAC/16.D0/PIE**2)**2
      WTS0 = wts0 * coef * Rpar(16)**2 
      WTOUT = wts0
      RETURN
      END
*----------------------------------------------------------------------------*
*..Rpar(57)     : neutral Higgs (SM) mass                                    *
*..Rpar(58)     : total Higgs decay width                                    *
*..Rpar(59)     : M(H) * Width(H)                                            *
*                                                                            *
      subroutine H0_dec_ini
*     ---------------------
      implicit none
      include "txpar.inc" 
      double precision GAM(3)
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision G2, GF, mh, mh2, mz, mz2, mw,mw2 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
*      COMMON/INFO/EMW,EMW2,EMZ,EMZ2,EMH,EMH2,GH,XW,AL,ALZ,ALS
*      COMMON/QUARK/EM2(5),EC2(5,2),NQ
C 1=ZZ ; 2=WW ; 3=TT
      
      INTEGER         KCHG 
      DOUBLE PRECISION            PMAS,       PARF,      VCKM
      COMMON /PYDAT2/ KCHG(500,4),PMAS(500,4),PARF(2000),VCKM(4,4)



*      XW= Rpar(23) ! sinT**2 0.23D0
*      AL= Rpar(11) ! 1.D0/128.D0
      G2 = 4.d0 * pi * Rpar(11) / Rpar(23) !      G2=4.*PI*AL/XW
      GF = G2/PI/16.d0
      mh = Rpar(57)
      mh2 = mh**2
      mz = Rpar(45)
      mz2 = mz**2
      mw = Rpar(41)
      mw2 = mw**2
C
      IF (MH .LE. (2.d0*MZ)) THEN
       GAM(1)=0.0d0
      ELSE
       GAM(1)=GF/MH*DSQRT(1.-4.*MZ2/MH2)*MZ2/rpar(24)/2.d0
     & * (3.d0-MH2/MZ2+(MH2/MZ2)**2/4.d0)
*       GAM(1)=GF/MH*DSQRT(1.-4.*MZ2/MH2)*MZ2/rpar(24)(1.D0-XW)/2.*(3.-EMH2
*     1  /EMZ2+(EMH2/EMZ2)**2/4.)
      ENDIF
C
      IF (MH .LE. (2.0*MW)) THEN
       GAM(2)=0.
      ELSE
       GAM(2)=GF/MH*DSQRT(1.-4.*MW2/MH2)*MW2
     & *(3.d0-MH2/MW2 + (MH2/MW2)**2/4.d0)
      ENDIF
C
      IF (MH .LE. (2.d0*mq(6))) THEN
       GAM(3)=0.0
      ELSE
       GAM(3)=GF/MH*DSQRT(1.-4.*mq2(6)/MH2)*(MH2-4.*mq2(6))
     & * mq2(6) /MW2/2.*3.
      ENDIF
C
      if((GAM(1)+GAM(2)+GAM(3)).gt.Rpar(58)) then
        Rpar(58) = GAM(1)+GAM(2)+GAM(3)
      endif
      Rpar(59) = Rpar(57) * Rpar(58) 
      write(*, 71)
 71   format(/,'   TopReX : Neutral Higgs parameters ',/
     &,        '   ----------------------------------')
       write(*, 172) Rpar(57),gam(1),gam(2),gam(3),Rpar(58)
 172  format(2x,'m(Higgs) = ',1p,d10.3,/,
     &2x,'Wid(H -> Z Z)  = ',1p,d10.3,/
     &2x,'Wid(H -> W+W-) = ',1p,d10.3,/
     &2x,'Wid(H -> T T~) = ',1p,d10.3,/,
     &2x,'Width(total)   = ',1p,d10.3,/)
      write(*, 173) pmas(25,1),pmas(25,2)
 173  format(2x,'m(Higgs) = ',1p,d10.3,/,
     &2x,'Width(total)   = ',1p,d10.3,/)
      RETURN
      END

*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  22.06.2004                                  *
*   color flow and showering description for PYTHIA                          *
*  Z Q Qbar production (SM)                                                  *
*   TopReX code = 23                                                         *
      subroutine COLORF_23(ip1, ip2)
*     -------------------------------                                        *
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
*..................TopReX commons and internal variables
      Integer ip1, ip2 
      integer ik1,ik3 
      common /kfzqq/ik1, ik3 
      double precision zn1, zn2
      COMMON /colden/ zn1, zn2
*...END VARIABLE'S DEFINITION
*............................................................................*
* PYUPR :        1   2        3       4  5    6  7
*      nup = 7 ! q   q~ -> Z(gamma*)  f  f~   Q  Qbar
* how PYTHIA will be treated
        istup(3) = 2  ! final Z(gamma*) 
        istup(4) = 1  ! final f
        istup(5) = 1  ! final fbar
        istup(6) = 1  ! final Q
        istup(7) = 1  ! final Qbar
* parent's lines 
          mothup(1,3)=1  
          mothup(2,3)=2  
            mothup(1,4)=3 
            mothup(2,4)=3 
            mothup(1,5)=3 
            mothup(2,5)=3 
          mothup(1,6)=1  
          mothup(2,6)=2  
          mothup(1,7)=1  
          mothup(2,7)=2  
* KF code
      if(Ipar(23).eq.0.OR.Ipar(23).eq.2) then
        idup(3) = 23  ! Z
      elseif(Ipar(23).eq.1) then
        idup(3) = 22  ! gamma*
      endif  
      idup(4) =  ik1
      idup(5) = -ik1
      idup(6) =  ik3
      idup(7) = -ik3
*
      idup(1) = ip1 
       if(idup(1).eq.0) idup(1) = 21
      idup(2) = ip2
       if(idup(2).eq.0) idup(2) = 21
       
*  color flow 
       ipar(50) = 300
       icolup(1,6) = ipar(50) + 1
       icolup(2,7) = ipar(50) + 2

        if(idup(1).eq.21) then         ! gluon gluon
         if(abs(zn1).le.abs(zn2)) then  ! t-channel
* color flow :   t-channel
*       color(g1) -> T[3]   anti-color(g1) -> g2
*       color(g2) -> g1     anti-color(g2) -> T~[4]
          icolup(1,1) = icolup(1,6)  
          icolup(2,1) = ipar(50) + 3 
          icolup(1,2) = icolup(2,1)  
          icolup(2,2) = icolup(2,7)
          else
* color flow : u-channel
*       color(g1) -> g2   anti-color(g1) -> T~[4]
*       color(g2) -> T[3] anti-color(g2) -> g1
          icolup(1,1) = ipar(50) + 3 
          icolup(2,1) = icolup(2,7) 
          icolup(1,2) = icolup(1,6)  
          icolup(2,2) = icolup(1,1)
         endif  ! finish gluon gluon color prescription 
        elseif(ip1.gt.0) then  ! quark
          icolup(1,1) = icolup(1,6)          
          icolup(2,2) = icolup(2,7)          
        elseif(ip1.lt.0) then
          icolup(2,1) = icolup(2,7)          
          icolup(1,2) = icolup(1,6)          
        endif
      if(abs(ik1).le.6) then
       icolup(1,4) = ipar(50) + 4
       icolup(2,5) = ipar(50) + 4
      endif

      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  17/02/2005                                  *
*   Z Z --> f3 f3bar   f4 f4bar                                              *
*   TopReX code = 24                                                         *
      subroutine colorf_24(ip1,ip2)
*     -----------------------------                                          *
*                                                                            *
*  g(1) g(2) --> Z1(3) Z2(4), Z1(3) -> f3 f3bar, Z(4) -> f4 f4bar            *
*                                                                            *
*............................................................................*
      implicit none
      include "hepeup.inc"
      include "txpar.inc" 
      integer ip1, ip2, if3, if4, ires, kv, idz
*
      ires = 4
        istup(3) = 2  ! final Z1 
        istup(4) = 2  ! final Z2 
        istup(5) = 1  ! final f3 
        istup(6) = 1  ! final f3bar 
        istup(7) = 1  ! final f4 
        istup(8) = 1  ! final f4bar 
* parent's lines
          mothup(1,3)=1  ! final Z1
          mothup(2,3)=2  !
          mothup(1,4)=1  ! final Z2
          mothup(2,4)=2 
        mothup(1,5)=3   ! final f3
        mothup(2,5)=3   ! 
        mothup(1,6)=3   ! final f3bar
        mothup(2,6)=3   ! 
        mothup(1,7)=4   ! final f4
        mothup(2,7)=4   ! 
        mothup(1,8)=4   ! final f4bar
        mothup(2,8)=4   ! 
* KF code
      idup(1) = 21
      idup(2) = 21
*
      idup(3) = 23 
      idup(4) = 23
*  color flow 
        ipar(50) = 300
            icolup(1,1) = ipar(50) 
            icolup(2,1) = ipar(50) + 1
            icolup(1,2) = icolup(2,1)
            icolup(2,2) = icolup(1,1)
        ipar(50) = ipar(50) + 1
*  showering
       Ires = 4                     ! Z-boson
        kv  = 23                    ! KF code of Z-boson 
        call Res_branch(ires, kv, idz)
        if3 = FID(ires,idz,1)
        idup(5) =  if3        
        idup(6) = -if3        

        call Res_branch(ires, kv, idz)
        if4 = FID(ires,idz,1)
        idup(7) =  if4        
        idup(8) = -if4        
      
       NUP = 8
      if(abs(if3).le.6) then ! quarks
        ipar(50) = ipar(50) + 1
            icolup(1,5) = ipar(50) 
            icolup(2,6) = ipar(50) 
      endif
      if(abs(if4).le.6) then ! quarks
        ipar(50) = ipar(50) + 1
            icolup(1,7) = ipar(50) 
            icolup(2,8) = ipar(50) 
      endif
       call dec_zz4f(if3,if4)
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  17/02/2005                                  *
*   Z Z --> f3 f3bar   f4 f4bar  decays                                      *
*   TopReX code = 24                                                         *
      subroutine dec_ZZ4f(if3,if4)
      implicit none 
      include "txpar.inc" 
      double complex MEX(-1:1,-1:1,-1:1,-1:1)
      double precision coef, WTS0
      common /ggmex/ coef, WTS0, MEX
      include "hepeup.inc"
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision l3p,   l3m,   l4p,   l4m
      common /zzlep/   l3p(5),l3m(5),l4p(5),l4m(5)
      double complex e3(-1:1,4), e4(-1:1,4) 
      common /zbospol/ e3, e4
      double complex LTZ3(-1:1,-1:1), LTZ4(-1:1,-1:1), 
     &  LTR30, LTR40
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer if3, if4
      double precision WTSF, RTS, rtsmax, PYR, ARAN
      data rtsmax /2.d0/
      save rtsmax
      double precision ps1,   ps2,   ps3,   ps4,   qq
      common /zzmom/   ps1(5),ps2(5),ps3(5),ps4(5),QQ(5)
      integer j1,j2,j3,j4, j31, j41
      double precision ps(5)
*
   
 1000 continue
      call LEPTEN(if3, ps3, e3, l3p, l3m, LTR30, LTZ3)
      call LEPTEN(if4, ps4, e4, l4p, l4m, LTR40, LTZ4)
      WTSF = 0.d0
       do 81 J1 = 1,1
       do 81 J2 = 1,2
       do 81 J3 = -1,1
       do 81 J31= -1,1
       do 81 J4 = -1,1
       do 81 J41= -1,1
 81    WTSF = WTSF 
     & + MEX(+1,(-3+2*j2),j3,j4)*conjg(MEX(+1,(-3+2*j2),j31,j41))
     & * LTZ3(j31,j3) * LTZ4(j41,j4)
      WTSF = wtsF * coef * Rpar(16)**2 
      RTS  = WTSF / (LTR30 * LTR40 * WTS0)
*
      IF(ipar(33).eq.1) THEN ! take into account spin correlations
*       if(rtsmax.lt.0.d0) rtsmax = rts
       if(rts.gt.rtsmax) rtsmax = rts
       if(rtsmax.ge.4.d0) then
         print*,'WARNING ZZ rat ',rtsmax
         rtsmax = 4.d0 
       endif       
       ARAN = pyr(0) * rtsmax  ! * 4.d0
       if(RTS.lt.aran) goto 1000
      ENDIF
* fill fermion momenta
      call Lorenb_s(qq, l3p, ps)
       do j1 = 1,5
        pus(5,j1) = ps(j1)        ! L- from Z1
        pup(J1,5) = ps(j1)
         enddo
      call Lorenb_s(qq, l3m, ps)
       do j1 = 1,5
        pus(6,j1) = ps(j1)        ! L+ from Z1
        pup(J1,6) = ps(j1)
         enddo
      call Lorenb_s(qq, l4p, ps)
       do j1 = 1,5
        pus(7,j1) = ps(j1)        ! L- from Z2
        pup(J1,7) = ps(j1)
         enddo
      call Lorenb_s(qq, l4m, ps)
       do j1 = 1,5
        pus(8,j1) = ps(j1)        ! L+ from Z2
        pup(J1,8) = ps(j1)
         enddo
      return
      end
*----------------------------------------------------------------------------*
      double complex FUNCTION B0(S,EQ2)
      implicit none
      double complex RM1
      double precision s, eq2,EMCUT2,pie, step, DASINH, DACOSH
      COMMON/EMCUT/EMCUT2,PIE,RM1
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst / pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double complex e0, e1, ei  ! 0, 1 i
      common /cunits/ e0, e1, ei
*
      IF(EQ2.LT.EMCUT2)THEN
        B0=-DLOG(DABS(S/EQ2))+2.D0+ei*PI*STEP(S)
      ELSEIF(EQ2.GE.EMCUT2)THEN
        IF(S.LT.0.D0)THEN
          B0=2.D0-2.D0*DSQRT(1.D0-4.D0*EQ2/S)*DASINH(DSQRT(-S/4.D0/EQ2))
        ELSEIF(S.GT.0.D0.AND.S.LT.4.D0*EQ2)THEN
          B0=2.D0-2.D0*DSQRT(4.D0*EQ2/S-1.D0)*DASIN(DSQRT(S/4.D0/EQ2))
        ELSEIF(S.GT.4.D0*EQ2)THEN
          B0=2.D0-DSQRT(1.D0-4.D0*EQ2/S)*(2.D0*DACOSH(DSQRT(S/4.D0/EQ2))
     1                                   -ei*PI)
        ENDIF
      ENDIF
      RETURN
      END
*----------------------------------------------------------------------------*
      double precision FUNCTION STEP(X)
      implicit none
      double precision X
      STEP=0.D0
      IF(X.GT.0.D0) STEP=1.D0
      RETURN
      END
*----------------------------------------------------------------------------*
      double precision function DASINH(X)
      implicit none
      double precision X
       DASINH=DLOG(X+DSQRT(X*X+1.D0))
      RETURN
      END
*----------------------------------------------------------------------------*
      double precision function DACOSH(X)
      double precision X
       DACOSH=DLOG(X+DSQRT(X*X-1.D0))
      RETURN
      END
*----------------------------------------------------------------------------*
C COMPLEX SPENCE FUNCTION
C
      BLOCK DATA SPLINT
      IMPLICIT REAL*8 (A-H,O-Z)
      COMMON/SPINT/A1,A2,A3,A4,A5,A6,A7,A8,A9,A10,ZETA2
      DATA A1,A2,A3,A4,A5,A6,A7,A8,A9,A10,ZETA2/
     1 -0.250000000000000D0,
     2 -0.111111111111111D0,
     3 -0.010000000000000D0,
     4 -0.017006802721088D0,
     5 -0.019444444444444D0,
     6 -0.020661157024793D0,
     7 -0.021417300648069D0,
     8 -0.021948866377231D0,
     9 -0.022349233811171D0,
     1 -0.022663689135191D0,
     2  1.644934066848226D0/
      END
*----------------------------------------------------------------------------*
      FUNCTION SP(X)
      COMPLEX*16 X,Y,Z,Z2
      double complex SP
      REAL*8 XR,XI,R2
      REAL*8 A1,A2,A3,A4,A5,A6,A7,A8,A9,A10,ZETA2
      COMMON/SPINT/A1,A2,A3,A4,A5,A6,A7,A8,A9,A10,ZETA2
      XR=DREAL(X)
      XI=DIMAG(X)
      R2=XR*XR+XI*XI
      IF(R2.GT.1.D0.AND.(XR/R2).GT.0.5D0)THEN
        Y=(X-1.D0)/X
        Z=-CDLOG(1.D0-Y)
        Z2=Z*Z
        SP=Z*(1.D0+A1*Z*(1.D0+A2*Z*(1.D0+A3*Z2*(1.D0+A4*Z2*
     1 (1.D0+A5*Z2*(1.D0+A6*Z2*(1.D0+A7*Z2*(1.D0+A8*Z2*(1.D0+A9*Z2*
     2 (1.D0+A10*Z2))))))))))
     3 +ZETA2-CDLOG(X)*CDLOG(1.D0-X)+0.5D0*CDLOG(X)**2
        RETURN
      ELSEIF(R2.GT.1.D0.AND.(XR/R2).LE.0.5D0)THEN
        Y=1.D0/X
        Z=-CDLOG(1.D0-Y)
        Z2=Z*Z
        SP=-Z*(1.D0+A1*Z*(1.D0+A2*Z*(1.D0+A3*Z2*(1.D0+A4*Z2*
     1 (1.D0+A5*Z2*(1.D0+A6*Z2*(1.D0+A7*Z2*(1.D0+A8*Z2*(1.D0+A9*Z2*
     2 (1.D0+A10*Z2))))))))))
     3 -ZETA2-0.5D0*CDLOG(-X)**2
        RETURN
      ELSEIF(R2.EQ.1.D0.AND.XI.EQ.0.D0)THEN
        SP=ZETA2
        RETURN
      ELSEIF(R2.LE.1.D0.AND.XR.GT.0.5D0)THEN
        Y=1.D0-X
        Z=-CDLOG(1.D0-Y)
        Z2=Z*Z
        SP=-Z*(1.D0+A1*Z*(1.D0+A2*Z*(1.D0+A3*Z2*(1.D0+A4*Z2*
     1 (1.D0+A5*Z2*(1.D0+A6*Z2*(1.D0+A7*Z2*(1.D0+A8*Z2*(1.D0+A9*Z2*
     2 (1.D0+A10*Z2))))))))))
     3 +ZETA2-CDLOG(X)*CDLOG(1.D0-X)
       RETURN
      ELSEIF(R2.LE.1.D0.AND.XR.LE.0.5D0)THEN
        Y=X
        Z=-CDLOG(1.D0-Y)
        Z2=Z*Z
        SP=Z*(1.D0+A1*Z*(1.D0+A2*Z*(1.D0+A3*Z2*(1.D0+A4*Z2*
     1 (1.D0+A5*Z2*(1.D0+A6*Z2*(1.D0+A7*Z2*(1.D0+A8*Z2*(1.D0+A9*Z2*
     2 (1.D0+A10*Z2))))))))))
        RETURN
      ENDIF
      END
*----------------------------------------------------------------------------*
      FUNCTION APPPP(S,T,U,EMZ2,EQ2,B,A2PB2,A2MB2)
      IMPLICIT REAL*8(A-H,O-Z)
      double complex APPPP 
      COMPLEX*16 BI(4),CI(4),DI(3)
      COMMON/CINTS/BI,CI,DI
      Y=U*T-EMZ2**2
      S4=S-4.D0*EMZ2
      S2=S-2.D0*EMZ2
      T1=T-EMZ2
      U1=U-EMZ2
      APPPP=A2PB2*
     1 (8.D0*S*Y*B/U1/T1/S4+8.D0*EMZ2*(2*Y-S*S4)/S4/U1/T1
     2 +4.D0/S4*BI(2)*(2.D0*EMZ2**2/T1**2-(1.D0+2.D0*T/S))*(S2+B*S)
     3 +4.D0/S4*BI(3)*(2.D0*EMZ2**2/U1**2-(1.D0+2.D0*U/S))*(S2+B*S)
     4 -4.D0/S4/S**2*(2.D0*Y-S*S4)*(S2+B*S)*(U1*CI(3)+T1*CI(2))
     5 +16.D0*EQ2/S4*((S*B+2.D0*EMZ2)*CI(1)
     6                +EMZ2*(S2+B*S)*(CI(3)/U1+CI(2)/T1))
     7 +2.D0/S4/S**2*(S2+B*S)*Y*(2.D0*Y-S*S4)*DI(3)
     8 +4.D0*EQ2/S4/S*((2.D0*Y-S*S4)*DI(3)
     9                 +2.D0*EMZ2*S*(DI(2)+DI(1)))*(S2+B*S))
     1   +A2MB2*
     2 (-16.D0*EQ2*B/S4*(S*CI(1)+U1*CI(3)+T1*CI(2))
     3  -16.D0*EQ2/S*(U1*CI(3)+T1*CI(2))
     4  +4.D0*EQ2/S*(2.D0*Y*DI(3)-S**2*(DI(2)+DI(1)))
     5  +4.D0*EQ2*B/S4*(2.D0*Y*DI(3)-S*S2*(DI(2)+DI(1)))
     6  +16.D0*EQ2**2*(DI(3)+DI(2)+DI(1)))
      RETURN
      END
*----------------------------------------------------------------------------*
      FUNCTION APPPM(S,T,U,EMZ2,EQ2,B,A2PB2,A2MB2)
      IMPLICIT REAL*8(A-H,O-Z)
      double complex APPPM
      COMPLEX*16 BI(4),CI(4),DI(3)
      COMMON/CINTS/BI,CI,DI
      Y=U*T-EMZ2**2
      S4=S-4.D0*EMZ2
      S2=S-2.D0*EMZ2
      T1=T-EMZ2
      U1=U-EMZ2
      APPPM=A2PB2*
     1 (-8.D0*S2*Y/S4/U1/T1
     2  +8.D0*EMZ2/S4*BI(2)*((1.D0+2.D0*T/S)-S4/T1-EMZ2*S2/T1**2)
     3  +8.D0*EMZ2/S4*BI(3)*((1.D0+2.D0*U/S)-S4/U1-EMZ2*S2/U1**2)
     4  +16.D0*EMZ2*Y/S**2/S4*(U1*CI(3)+T1*CI(2))
     5  -16.D0*EQ2/S4*(S2*CI(1)
     6       +(S4*U1/S+2.D0*EMZ2**2/U1)*CI(3)
     7       +(S4*T1/S+2.D0*EMZ2**2/T1)*CI(2))
     8  -8.D0*EMZ2*Y**2/S**2/S4*DI(3)
     9  +8.D0*EQ2/S4*((S-6.D0*EMZ2)*Y/S*DI(3)
     1                -2.D0*EMZ2**2*(DI(2)+DI(1)))
     2  +16.D0*EQ2**2*(DI(3)+DI(2)+DI(1))
     3  +8.D0*EQ2*S/Y*(S2*CI(1)+S4*CI(4)
     4                +2.D0*U**2/U1*CI(3)+2.D0*T**2/T1*CI(2)
     5                +T**2*DI(1)+U**2*DI(2)))
      RETURN
      END
*----------------------------------------------------------------------------*
      FUNCTION APMPP(S,T,U,EMZ2,EQ2,B,A2PB2,A2MB2)
      IMPLICIT REAL*8(A-H,O-Z)
      double complex APMPP
      COMPLEX*16 BI(4),CI(4),DI(3)
      COMMON/CINTS/BI,CI,DI
      Y=U*T-EMZ2**2
      S4=S-4.D0*EMZ2
      S2=S-2.D0*EMZ2
      T1=T-EMZ2
      U1=U-EMZ2
      APMPP=A2PB2*
     1 (-8.D0*S2*Y/S4/U1/T1
     2  +8.D0*EMZ2/S4*(BI(2)*(2.D0*EMZ2*T+Y)/T1**2
     3                 +BI(3)*(2.D0*EMZ2*U+Y)/U1**2)
     4  -8.D0*EMZ2/S4*(S*CI(1)+S2*CI(4)
     5                -(S2*T-T1**2)/T1*CI(2)
     6                -(S2*U-U1**2)/U1*CI(3))
     7  +16.D0*S2*EQ2*Y/S/S4*(CI(2)/T1+CI(3)/U1)
     8  +4.D0*S*EMZ2/S4*(U*DI(2)+T*DI(1))
     9  +8.D0*EMZ2*EQ2/S/S4*(S*S2*(DI(2)+DI(1))
     1                      +(S*S4-2*Y)*DI(3))
     2  +4.D0*S*S2*EMZ2/S4/Y*(S2*CI(1)+S4*CI(4)
     3                       +2*U**2/U1*CI(3)+2*T**2/T1*CI(2)
     4                       +T**2*DI(1)+U**2*DI(2)))
     5   +A2MB2*
     6  (16.D0*EQ2*(T*CI(2)/T1+U*CI(3)/U1-CI(4))
     7   +8.D0*EQ2*Y/S4*DI(3)
     8   +16.D0*EQ2**2*(DI(3)+DI(2)+DI(1))
     9   +8.D0*EQ2*S/Y*(S2*CI(1)+S4*CI(4)
     1                 +2.D0*U**2/U1*CI(3)+2.D0*T**2/T1*CI(2)
     2                 +T**2*DI(1)+U**2*DI(2)))
      RETURN
      END
*----------------------------------------------------------------------------*
      FUNCTION APMPM(S,T,U,EMZ2,EQ2,B,A2PB2,A2MB2)
      IMPLICIT REAL*8(A-H,O-Z)
      double complex APMPM
      COMPLEX*16 BI(4),CI(4),DI(3)
      COMMON/CINTS/BI,CI,DI
      Y=U*T-EMZ2**2
      S4=S-4.D0*EMZ2
      S2=S-2.D0*EMZ2
      T1=T-EMZ2
      U1=U-EMZ2
      APMPM=A2PB2*
     1 (4.D0*S/Y*((S/Y*(1+B*(T-U)/S4)-2.D0/S4)*
     2  (S2*(S*S4+EMZ2**2)*CI(1)+S4*(S*S4+3.D0*EMZ2**2)*CI(4)
     3   +T**4*(2.D0*CI(2)/T1+DI(1))+U**4*(2.D0*CI(3)/U1+DI(2)))
     4  +2.D0*EMZ2**2/S4*(T1*(T+EMZ2)*(2.D0*CI(2)/T1+DI(1))
     5                       +U1*(U+EMZ2)*(2.D0*CI(3)/U1+DI(2)))
     6  *(1.D0+B*(T-U)/S4)
     7  +(2.D0*S2*BI(1)+2.D0*T**3/T1**2*BI(2)
     8   +2.D0*U**3/U1**2*BI(3)-S*S2*CI(1)-(S*S4+2.D0*EMZ2**2)*CI(4)
     9   +2.D0*U**2*(2.D0*S+U)/U1*CI(3)+2.D0*T**2*(2.D0*S+T)/T1*CI(2)
     1   +2.D0*T**2*S*DI(1)+2.D0*U**2*S*DI(2))*(1.D0+B*(T-U)/S4)
     2  +2.D0*EQ2*(1.D0+B*(T-U)/S4)*(S2*CI(1)+S4*CI(4)
     3      +2.D0*U**2*(CI(3)/U1+DI(2))+2.D0*T**2*(CI(2)/T1+DI(1))))
     4  +16.D0*EQ2**2*(DI(1)+DI(3)+DI(2))
     5  +4.D0*EQ2/S4*
     6     ((8.D0*EMZ2/S*(S*S4-Y)+4.D0*U1*S4*(1.D0-B*S/S4))*CI(3)/U1
     7     +(8.D0*EMZ2/S*(S*S4-Y)+4.D0*T1*S4*(1.D0+B*S/S4))*CI(2)/T1
     8     +2.D0*S2*Y/S*DI(3)
     9     +(S*S2*(1.D0-4.D0*B)-2.D0*EMZ2*(S+2.D0*EMZ2)
     1                                  +3.D0*S*(T-U)*B)*DI(1)
     2     +(S*S2*(1.D0+4.D0*B)-2.D0*EMZ2*(S+2.D0*EMZ2)
     3                                  +3.D0*S*(T-U)*B)*DI(2))
     4  +8.D0/S4/U1/T1*(S2*Y+EMZ2*S*B*(T-U))
     5  -8.D0*S2/S4*BI(1)
     6  +4.D0*S/S4*(S2*CI(1)+S4*CI(4))
     7  +4.D0/S4*
     8  (((T*(T*S2+2.D0*EMZ2*S4)+EMZ2**2*S2)
     9    +B*(T*(3.D0*T*S-2.D0*S*EMZ2)-S*EMZ2**2))*BI(2)/T1**2
     1  +((U*(U*S2+2.D0*EMZ2*S4)+EMZ2**2*S2)
     2    -B*(U*(3.D0*U*S-2.D0*S*EMZ2)-S*EMZ2**2))*BI(3)/U1**2)
     3  +64.D0*B*EMZ2**3/S4**2*(T1*(2.D0*CI(2)/T1+DI(1))
     4                         -U1*(2.D0*CI(3)/U1+DI(2)))
     5  +4.D0/S4*
     6  ((-(T**2*(3.D0*S+2.D0*EMZ2)-T*S*(4.D0*S-10.D0*EMZ2)
     7   +EMZ2**2*(3.D0*S+2.D0*EMZ2))
     8  +B*(3.D0*T**2*S+T*(4.D0*S*S+2.D0*EMZ2*S+8.D0*EMZ2**2)
     9   -EMZ2**2*(5.D0*S+8.D0*EMZ2)))*CI(2)/T1
     1  +(-(U**2*(3.D0*S+2.D0*EMZ2)-U*S*(4.D0*S-10.D0*EMZ2)
     2   +EMZ2**2*(3.D0*S+2.D0*EMZ2))
     3  -B*(3.D0*U**2*S+U*(4.D0*S*S+2.D0*EMZ2*S+8.D0*EMZ2**2)
     4   -EMZ2**2*(5.D0*S+8.D0*EMZ2)))*CI(3)/U1)
     5  +1.D0/S4*
     6  (((-8.D0*T**2*S+6.D0*T*S*S2-8.D0*S*EMZ2**2)
     7   +B*(16.D0*T1*EMZ2**2+10.D0*T*S*S-8.D0*EMZ2**2*S))*DI(1)
     8  +((-8.D0*U**2*S+6.D0*U*S*S2-8.D0*S*EMZ2**2)
     9   -B*(16.D0*U1*EMZ2**2+10.D0*U*S*S-8.D0*EMZ2**2*S))*DI(2)))
     1   +A2MB2*
     2  (4.D0*EQ2/S4*DI(3)*(S*S4*(1.D0-B*(T-U)/S4)-2.D0*Y))
      RETURN
      END
*----------------------------------------------------------------------------*
      FUNCTION APPP0(S,T,U,EMZ2,EQ2,B,A2PB2,A2MB2)
      IMPLICIT REAL*8(A-H,O-Z)
      double complex APPP0
      COMPLEX*16 BI(4),CI(4),DI(3)
      COMMON/CINTS/BI,CI,DI
      Y=U*T-EMZ2**2
      S4=S-4.D0*EMZ2
      S2=S-2.D0*EMZ2
      T1=T-EMZ2
      U1=U-EMZ2
      FAC=DSQRT(2.D0*S4*EMZ2/Y)
      APPP0=A2PB2*FAC*(1.D0+B)/B*
     1  (4.D0*(T-U)*Y/S4/U1/T1
     2  +4.D0*Y/S/S4*((2.D0*T*T1-EMZ2*S)/T1**2*BI(2)
     3               -(2.D0*U*U1-EMZ2*S)/U1**2*BI(3))
     4  -2.D0*(T-U)*Y/S4/S**2*(2.D0*U1*CI(3)+2.D0*T1*CI(2)-Y*DI(3))
     5  +2.D0*EQ2/EMZ2/S4*
     6  (S*(T-U)*CI(1)+2.D0*EMZ2*S*S4*(CI(3)/U1-CI(2)/T1)
     7  +(T-U)/S*(U1**2*S4+2.D0*EMZ2*S*S2)/U1*CI(3)
     8  +(T-U)/S*(T1**2*S4+2.D0*EMZ2*S*S2)/T1*CI(2))
     9  +S*EQ2/EMZ2/2.D0/S4*(S*S4*(DI(2)-DI(1))+
     1                      (T-U)*S2*(DI(2)+DI(1))
     2                      -2.D0*Y*(T-U)/S**2*(S-8.D0*EMZ2)*DI(3)) )
     3    +A2MB2*FAC*(1.D0+B)*EQ2/EMZ2*
     4  (-2.D0*(T-U)/S4*(S*CI(1)+U1*CI(3)+T1*CI(2)
     5                  -Y/2.D0*DI(3)+S*EMZ2/2.D0*(DI(2)+DI(1)))
     6   +S*(U1*DI(2)-T1*DI(1)) )
      RETURN
      END
*----------------------------------------------------------------------------*
      FUNCTION APMP0(S,T,U,EMZ2,EQ2,B,A2PB2,A2MB2)
      IMPLICIT REAL*8(A-H,O-Z)
      double complex APMP0
      COMPLEX*16 BI(4),CI(4),DI(3)
      COMMON/CINTS/BI,CI,DI
      Y=U*T-EMZ2**2
      S4=S-4.D0*EMZ2
      S2=S-2.D0*EMZ2
      T1=T-EMZ2
      U1=U-EMZ2
      FAC=DSQRT(2.D0*S4*EMZ2/Y)
      APMP0=A2PB2*FAC/S4*
     1 (2.D0*S**2/Y*
     2  ((U**2+T**2)*CI(1)+S2*S4*CI(4)
     3   -2.D0*U**3/U1*CI(3)-2.D0*T**3/T1*CI(2)
     4   -U**3*DI(2)-T**3*DI(1))*(1.D0+B*(T-U)/S4)
     5  +4.D0*S*Y/U1/T1*(1.D0-B*(T-U)/S4)
     6  +4.D0*((U1**2*(U+EMZ2)*(1.D0+B*S/S4)
     7         +EMZ2*S*U*(1.D0-B*(T-U)/S4))/U1**2*BI(3)
     8        +(T1**2*(T+EMZ2)*(1.D0-B*S/S4)
     9         +EMZ2*S*T*(1.D0-B*(T-U)/S4))/T1**2*BI(2)
     1        +S*BI(1)*(1.D0+B*(T-U)/S4))
     2        -2.D0*(S*S4*CI(1)*(1.D0-B*S*(T-U)/S4/S4)
     3        +S*(S4*(1.D0+B*(T-U)/S4)+2.D0*S2)*CI(4)
     4        +2.D0*(U1**2*T1*(1.D0+B*S/S4)
     5              +EMZ2*S*(2.D0*U1+EMZ2)*(1.D0+B*(T-U)/S4)
     6              +2.D0*U1**2*(S-EMZ2))/U1*CI(3)
     7        +2.D0*(T1**2*U1*(1.D0-B*S/S4)
     8              +EMZ2*S*(2.D0*T1+EMZ2)*(1.D0+B*(T-U)/S4)
     9              +2.D0*T1**2*(S-EMZ2))/T1*CI(2))
     1  +2.D0*EQ2/EMZ2*(S**2*CI(1)*(1.D0-B*(T-U)/S)
     2   +(S*(U+EMZ2)**2*(1.D0-B*(T-U)/S4)+4.D0*EMZ2*U1**2)/U1*CI(3)
     3   +(S*(T+EMZ2)**2*(1.D0-B*(T-U)/S4)+4.D0*EMZ2*T1**2)/T1*CI(2))
     4  -2.D0*S*(U*(U1*(1.D0-B*S/S4)+2.D0*EMZ2)*DI(2)
     5          +T*(T1*(1.D0+B*S/S4)+2.D0*EMZ2)*DI(1))
     6  +EQ2/EMZ2*(S4*Y*DI(3)*(1.D0-B*S*(T-U)/S4/S4)
     7    +(8.D0*EMZ2*U1*(U+EMZ2)*(1.D0+B*S/S4)
     8    -S**2*U*(1.D0-B*(T-U)/S4)+4.D0*EMZ2*(U*S4+4*EMZ2**2))*DI(2)
     9    +(8.D0*EMZ2*T1*(T+EMZ2)*(1.D0-B*S/S4)
     1    -S**2*T*(1.D0-B*(T-U)/S4)+4.D0*EMZ2*(T*S4+4*EMZ2**2))*DI(1)))
     2   +A2MB2*FAC*EQ2/EMZ2*(1.D0-B*(T-U)/S4)*
     3  (-2.D0*S*CI(1)-2.D0*U1*CI(3)-2.D0*T1*CI(2)
     4  -(S+4.D0*EMZ2)/S4*Y*DI(3)+U*S*DI(2)+T*S*DI(1))
      RETURN
      END
*----------------------------------------------------------------------------*
      FUNCTION APP00(S,T,U,EMZ2,EQ2,B,A2PB2,A2MB2)
      IMPLICIT REAL*8(A-H,O-Z)
      double complex APP00
      COMPLEX*16 BI(4),CI(4),DI(3)
      COMMON/CINTS/BI,CI,DI
      Y=U*T-EMZ2**2
      S4=S-4.D0*EMZ2
      S2=S-2.D0*EMZ2
      T1=T-EMZ2
      U1=U-EMZ2
      APP00=A2PB2*4.D0/S*
     1 (-8.D0*Y*EMZ2*S/S4/U1/T1
     2 +4.D0*EMZ2/S4*((T1**2*(S+2.D0*T)-2.D0*S*EMZ2**2)/T1**2*BI(2)
     3               +(U1**2*(S+2.D0*U)-2.D0*S*EMZ2**2)/U1**2*BI(3))
     4 +4.D0*EMZ2*Y/S/S4*(2.D0*U1*CI(3)+2.D0*T1*CI(2)-Y*DI(3))
     5 -2.D0*EQ2/S4/EMZ2*(S*(S*S4+8.D0*EMZ2**2)*CI(1)
     6           +2.D0*EMZ2*(U1**2*S4+4.D0*EMZ2**2*S)/U1*CI(3)
     7           +2.D0*EMZ2*(T1**2*S4+4.D0*EMZ2**2*S)/T1*CI(2)
     8           -Y*EMZ2*(S-8.D0*EMZ2)*DI(3)
     9           +2.D0*EMZ2**2*S*S2*(DI(2)+DI(1)))
     1 -2.D0*EQ2**2*S*S2/EMZ2*(DI(3)+DI(2)+DI(1)))
     2   +A2MB2*4.D0/S*
     3 (2.D0*EQ2/EMZ2*(S*S*CI(1)+2.D0*EMZ2*(U1*CI(3)+T1*CI(2))
     4                -Y*EMZ2*DI(3))
     5 +2.D0*EQ2**2*S*S2/EMZ2*(DI(3)+DI(2)+DI(1)))
      RETURN
      END
*----------------------------------------------------------------------------*
      FUNCTION APM00(S,T,U,EMZ2,EQ2,B,A2PB2,A2MB2)
      IMPLICIT REAL*8(A-H,O-Z)
      double complex APM00 
      COMPLEX*16 BI(4),CI(4),DI(3)
      COMMON/CINTS/BI,CI,DI
      Y=U*T-EMZ2**2
      S4=S-4.D0*EMZ2
      S2=S-2.D0*EMZ2
      T1=T-EMZ2
      U1=U-EMZ2
      APM00=A2PB2*4.D0/S*
     1 (8.D0*Y*EMZ2*S/S4/U1/T1
     2 +4.D0*EMZ2*S/S4*((T1**2+2*T*EMZ2)/T1**2*BI(2)
     3                 +(U1**2+2*U*EMZ2)/U1**2*BI(3))
     4 +2.D0*EMZ2*S/S4*(2.D0*S*CI(1)+2.D0*S2*CI(4)
     5                 +2.D0*(U1**2-S2*U)/U1*CI(3)
     6                 +2.D0*(T1**2-S2*T)/T1*CI(2)
     7                 -U*S*DI(2)-T*S*DI(1) )
     8 +EQ2/EMZ2/S4*(2.D0*S**2*S4*CI(1)+2.D0*S*S2*S4*CI(4)
     9 +2.D0*((S*S4+8.D0*EMZ2**2)*U1**2-S**2*U*(S-6.D0*EMZ2))/U1*CI(3)
     1 +2.D0*((S*S4+8.D0*EMZ2**2)*T1**2-S**2*T*(S-6.D0*EMZ2))/T1*CI(2)
     2              +4.D0*Y*S2*EMZ2*DI(3)
     3              +S*(4.D0*EMZ2*(S*U1+2.D0*EMZ2**2)-S**2*U)*DI(2)
     4              +S*(4.D0*EMZ2*(S*T1+2.D0*EMZ2**2)-S**2*T)*DI(1))
     5 -2.D0*EQ2**2/EMZ2*S*S2*(DI(3)+DI(1)+DI(2))
     6 -2.D0*EMZ2*S**2*S2/Y/S4*(S2*CI(1)+S4*CI(4)
     7  +2.D0*U**2/U1*CI(3)+2.D0*T**2/T1*CI(2)+U**2*DI(2)+T**2*DI(1))
     8  -EQ2*S**2*S2/Y/EMZ2*(S2*CI(1)+S4*CI(4)+2.D0*U**2/U1*CI(3)
     9                  +2.D0*T**2/T1*CI(2)+U**2*DI(2)+T**2*DI(1)) )
     1    +A2MB2*4.D0/S*
     2 (-EQ2*S/EMZ2*(2.D0*S*CI(1)+2.D0*S2*CI(4)
     3      +2.D0*(U1**2-S2*U)/U1*CI(3)+2.D0*(T1**2-S2*T)/T1*CI(2)
     4      +4.D0*EMZ2*Y/S4*DI(3)-T*S*DI(1)-U*S*DI(2))
     5 +2.D0*EQ2**2/EMZ2*S*S2*(DI(3)+DI(1)+DI(2))
     6 +EQ2*S**2*S2/Y/EMZ2*(S2*CI(1)+S4*CI(4)+2.D0*U**2/U1*CI(3)
     7                  +2.D0*T**2/T1*CI(2)+U**2*DI(2)+T**2*DI(1)) )
      RETURN
      END
*----------------------------------------------------------------------------*
      FUNCTION TRI1(S,T,U,EH2,EQ2)
      IMPLICIT REAL*8(A-H,O-Z)
      double complex TRI1

      COMPLEX*16 CI2,RM1
      COMMON/EMCUT/EMCUT2,PIE,RM1
      IF(EQ2.GT.EMCUT2)THEN
        TRI1=1.D0/S*CI2(EQ2,S,0.D0)
      ELSEIF(EQ2.LE.EMCUT2)THEN
        TRI1=0.5D0/S*((DLOG(EQ2/S))**2-PIE**2
     1            +2.D0*RM1*PIE*DLOG(EQ2/S))
      ENDIF
      RETURN
      END
*----------------------------------------------------------------------------*
      FUNCTION TRI2(S,T,U,EH2,EQ2)
      IMPLICIT REAL*8(A-H,O-Z)
      double complex TRI2
      COMPLEX*16 CI2,RM1
      COMMON/EMCUT/EMCUT2,PIE,RM1
      IF(EQ2.GT.EMCUT2)THEN
        TRI2=1.D0/(T-EH2)*(CI2(EQ2,T,0.D0)-CI2(EQ2,EH2,0.D0))
      ELSEIF(EQ2.LE.EMCUT2)THEN
        TRI2=0.5D0/(T-EH2)*((DLOG(-EQ2/T)+DLOG(EQ2/EH2))*
     1   DLOG(-EH2/T)   +PIE**2-2.D0*RM1*PIE*DLOG(EQ2/EH2))
      ENDIF
      RETURN
      END
*----------------------------------------------------------------------------*
      FUNCTION TRI3(S,T,U,EH2,EQ2)
      IMPLICIT REAL*8(A-H,O-Z)
      double complex TRI3
      COMPLEX*16 CI2,RM1,B,SP
      COMMON/EMCUT/EMCUT2,PIE,RM1
      IF(EQ2.GT.EMCUT2)THEN
        AL=1.D0-S/2.D0/EH2*(1.D0+DSQRT(1.D0-4.D0*EH2/S))
      TRI3=-1.D0/S*(1.D0-AL)/(1.D0+AL)*(2.D0*CI2(EQ2,EH2,AL/(1.D0+AL))
     1 -CI2(EQ2,S,AL**2/(AL**2-1.D0)))
      ELSEIF(EQ2.LE.EMCUT2)THEN
      B=DSQRT(1.D0-4.D0*EH2/S)
        TRI3=2.D0/B/S*(-SP(-(1.D0+B)/(1.D0-B))+SP(-(1.D0-B)/(1.D0+B)))
      ENDIF
      RETURN
      END
*----------------------------------------------------------------------------*
      FUNCTION CRBOX(S,T,U,EH2,EQ2)
      IMPLICIT REAL*8(A-H,O-Z)
      double COMPLEX CRBOX 
      COMPLEX*16 CI2,EPS,RM1,CPT2,SP
      COMMON/EMCUT/EMCUT2,PIE,RM1
      COMMON/SMALL/EPS
      IF(EQ2.GT.EMCUT2)THEN
      A=S/(U*T-EH2*EH2)
      ROOT=DSQRT((U*T-EH2*EH2)**2+4.D0*S*EQ2*(U*T-EH2*EH2))
      XP=((U*T-EH2*EH2)+ROOT)/2.D0/(U*T-EH2*EH2)
      XM=1.D0-XP
      CRBOX=2.D0/ROOT*(2.D0*CI2(EQ2,EH2,XP)-CI2(EQ2,U,XP)-CI2(EQ2,T,XP)
     1 +DLOG(-XM/XP)*(2.D0*CDLOG(EQ2+EPS-EH2*XP*XM)
     2 -CDLOG(EQ2+EPS-U*XP*XM)-CDLOG(EQ2+EPS-T*XP*XM)))
      ELSEIF(EQ2.LE.EMCUT2)THEN
      PT2=(U*T-EH2**2)/S
      CPT2=PT2
      CRBOX=2.D0/S/PT2*(-2.D0*SP(-CPT2/EH2)+SP(-CPT2/U)+SP(-CPT2/T)
     1 -2.D0*DLOG(EQ2/EH2)*DLOG((PT2+EH2)/EH2)
     2 +1.D0*DLOG(-EQ2/U)*DLOG((PT2+U)/U)
     3 +1.D0*DLOG(-EQ2/T)*DLOG((PT2+T)/T)
     4 -2.D0*RM1*PIE*(DLOG(EQ2/PT2)+DLOG((PT2+EH2)/EH2)))
      ENDIF
      RETURN
      END
*----------------------------------------------------------------------------*
      FUNCTION BOX(S,T,U,EH2,EQ2)
      IMPLICIT REAL*8(A-H,O-Z)
      double complex BOX
      COMPLEX*16 CI1,CI2,RM1,R1,SP
      COMMON/EMCUT/EMCUT2,PIE,RM1
      IF(EQ2.GT.EMCUT2)THEN
      BE1=-U/(EH2-U)
      V=-DSQRT(1.D0-4.D0*EH2/S)
      BE2=0.5D0*(1.D0+V)
      ROOT=DSQRT(S*S*U*U+4.D0*EQ2*S*(U*T-EH2*EH2))
      Y1P=(-U+ROOT/S)/2.D0/(U-EH2)
      Y1M=(-U-ROOT/S)/2.D0/(U-EH2)
      Y2P=(-EH2+EH2*V-V*U+ROOT/S)/2.D0/(U-EH2+(S-S*V)/2.D0)
      Y2M=(-EH2+EH2*V-V*U-ROOT/S)/2.D0/(U-EH2+(S-S*V)/2.D0)
      BOX=1.D0/ROOT*(
     1 -CI1(S,0.D0,BE1+Y1P)+CI1(S,0.D0,BE1+Y1M)
     2 +CI1(EH2-T,EH2-U,Y1P/(1.D0-BE1))-CI1(EH2-T,EH2-U,Y1M/(1.D0-BE1))
     3 -CI1(U-EH2,EH2-U,-Y1P/BE1)+CI1(U-EH2,EH2-U,-Y1M/BE1)
     4 +CI1(S,0.D0,BE2+Y2P)-CI1(S,0.D0,BE2+Y2M)
     5 -CI1(EH2-T,EH2-U,Y2P/(1.D0-BE2))+CI1(EH2-T,EH2-U,Y2M/(1.D0-BE2))
     6 +CI1(U-EH2,EH2-U,-Y2P/BE2)-CI1(U-EH2,EH2-U,-Y2M/BE2)
     7 -CI2(EQ2,EH2,Y1P/(1.D0-BE1))+CI2(EQ2,EH2,Y1M/(1.D0-BE1))
     8 +CI2(EQ2,U,-Y1P/BE1)-CI2(EQ2,U,-Y1M/BE1)
     9 -CI2(EQ2,S,Y2P+BE2)+CI2(EQ2,S,Y2M+BE2)
     1 +CI2(EQ2,EH2,Y2P/(1.D0-BE2))-CI2(EQ2,EH2,Y2M/(1.D0-BE2))
     2 -CI2(EQ2,EH2,-Y2P/BE2)+CI2(EQ2,EH2,-Y2M/BE2))
      ELSEIF(EQ2.LE.EMCUT2)THEN
      X=U/(U-EH2)
      EM2=EQ2/X**2
      R1=X
      BOX=1.D0/S/U*(
     1 4.D0*SP(R1)+0.5D0*(DLOG(EQ2/S))**2
     2 +2.D0*DLOG(EQ2/S)*DLOG((1.D0-X)/X)+2.D0*(DLOG(X))**2+PIE**2/6.D0
     2 +RM1*PIE*(2.D0*DLOG(X*(1.D0-X))-DLOG(EQ2/S)) )
      ENDIF
      RETURN
      END
*----------------------------------------------------------------------------*
      FUNCTION CI1(A,B,Y0)
C
C     INTEGRAL LOG(AY+B-IEPS)/(Y-Y0)
C
      REAL*8 A,B,Y0
      double complex CI1, EPS,SP,Y1
      COMMON/SMALL/EPS
      IF(DABS(A*Y0+B).LT.CDABS(EPS))THEN
        WRITE(6,10)A,B,Y0
   10   FORMAT(10X,'Y0=Y1 IN CI1 A =',D12.4,' B =',D12.4,' Y0 =',D12.4)
        RETURN
      ENDIF
      Y1=-(B+EPS)/A
      CI1=SP(Y0/(Y0-Y1))-SP((Y0-1.D0)/(Y0-Y1))
      RETURN
      END
*----------------------------------------------------------------------------*
      FUNCTION CI2(A,B,Y0)
C
C     INTEGRAL  LOG(A-IEPS-BY(1-Y))/(Y-Y0)
C
      REAL*8 A,B,Y0
      double complex CI2
      COMPLEX*16 EPS,SP,Y1,Y2
      COMMON/SMALL/EPS
      IF(B.EQ.0.D0)THEN
        CI2=(0.D0,0.D0)
        RETURN
      ENDIF
C     Y1=(B+CDSQRT(B*B-4.D0*B*(A+EPS)))/2.D0/B
      Y1=0.5D0*(1.D0+CDSQRT(1.D0-4.D0*(A+EPS)/B))
      Y2=1.D0-Y1
      CI2=SP(Y0/(Y0-Y1))-SP((Y0-1.D0)/(Y0-Y1))+
     1    SP(Y0/(Y0-Y2))-SP((Y0-1.D0)/(Y0-Y2))
      RETURN
      END

*----------------------------------------------------------------------------*
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  17/01/2006                                  *
* the product of two gamma_1(2) x A x gamma_1(2)                             *
*----------------------------------------------------------------------------*
      subroutine gamagam(k1,k2,A,V)
      implicit none
      integer k1,k2, i1, i2
      double complex A(4,4), V(4,4)
      double complex ei
      data ei/(0.d0, 1.d0)/
*******
       do i1 = 1,4
        do i2 = 1,4
         V(i1,i2) = (0.d0, 0.d0)
        enddo
       enddo

      if(k1.eq.1.and.k2.eq.1) then
       V(1, 1) = -A(4,4)
       V(1, 2) = -A(4,3)
       V(1, 3) = +A(4,2)
       V(1, 4) = +A(4,1)
*
       V(2, 1) = -A(3,4)
       V(2, 2) = -A(3,3)
       V(2, 3) = +A(3,2)
       V(2, 4) = +A(3,1)
*
       V(3, 1) = +A(2,4)
       V(3, 2) = +A(2,3)
       V(3, 3) = -A(2,2)
       V(3, 4) = -A(2,1)
*
       V(4, 1) = +A(1,4)
       V(4, 2) = +A(1,3)
       V(4, 3) = -A(1,2)
       V(4, 4) = -A(1,1)
***
      elseif(k1.eq.1.and.k2.eq.2) then
       V(1, 1) = -A(4,4)
       V(1, 2) = +A(4,3)
       V(1, 3) = +A(4,2)
       V(1, 4) = -A(4,1)
*
       V(2, 1) = -A(3,4)
       V(2, 2) = +A(3,3)
       V(2, 3) = +A(3,2)
       V(2, 4) = -A(3,1)
*
       V(3, 1) = +A(2,4)
       V(3, 2) = -A(2,3)
       V(3, 3) = -A(2,2)
       V(3, 4) = +A(2,1)
*
       V(4, 1) = +A(1,4)
       V(4, 2) = -A(1,3)
       V(4, 3) = -A(1,2)
       V(4, 4) = +A(1,1)
***
      elseif(k1.eq.2.and.k2.eq.1) then
       V(1, 1) = +A(4,4)
       V(1, 2) = +A(4,3)
       V(1, 3) = -A(4,2)
       V(1, 4) = -A(4,1)
*
       V(2, 1) = -A(3,4)
       V(2, 2) = -A(3,3)
       V(2, 3) = +A(3,2)
       V(2, 4) = +A(3,1)
*
       V(3, 1) = -A(2,4)
       V(3, 2) = -A(2,3)
       V(3, 3) = +A(2,2)
       V(3, 4) = +A(2,1)
*
       V(4, 1) = +A(1,4)
       V(4, 2) = +A(1,3)
       V(4, 3) = -A(1,2)
       V(4, 4) = -A(1,1)
***
      elseif(k1.eq.2.and.k2.eq.2) then
       V(1, 1) = +A(4,4)
       V(1, 2) = -A(4,3)
       V(1, 3) = -A(4,2)
       V(1, 4) = +A(4,1)
*
       V(2, 1) = -A(3,4)
       V(2, 2) = +A(3,3)
       V(2, 3) = +A(3,2)
       V(2, 4) = -A(3,1)
*
       V(3, 1) = -A(2,4)
       V(3, 2) = +A(2,3)
       V(3, 3) = +A(2,2)
       V(3, 4) = -A(2,1)
*
       V(4, 1) = +A(1,4)
       V(4, 2) = -A(1,3)
       V(4, 3) = -A(1,2)
       V(4, 4) = +A(1,1)
      endif
      if(k1.eq.1.and.k2.eq.2) then
       do i1 = 1,4
        do i2 = 1,4
         V(i1, i2) = ei * V(i1, i2)
        enddo
       enddo
      elseif(k1.eq.2.and.k2.eq.2) then
       do i1 = 1,4
        do i2 = 1,4
         V(i1, i2) = -V(i1, i2)
        enddo
       enddo
      endif
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  17/01/2006                                  *
*  complex matrix element for the process                                    *
*  g g --> t(pol)  + t_bar(pol) + gamma                                      *
*----------------------------------------------------------------------------*
      subroutine ggttgam(k1, k2, p1, p2, q, hh, ves)
*     ----------------------------------------------                         *
      implicit none
      include "txpar.inc" 
      double precision k1(5), k2(5)         ! momenta of the initial quarks
      double precision p1(5), p2(5), q(5)   ! momenta of the final t, tbar gamma 
      double precision x1(5), x2(5), x3(5), x4(5), x5(5), x6(5)
      double precision Ves, coef, S, TS, eg(5), scalp, r(5) 
      Integer i, if1,if2, ip1, ip2,iga, is
      double complex VR(4,4)
      double complex   TM1(2,2,2,2,2), TM2(2,2,2,2,2), TM3(2,2,2,2,2),
     & TM4(2,2,2,2,2), TM5(2,2,2,2,2), TM6(2,2,2,2,2),
     & TM7(2,2,2,2,2), TM8(2,2,2,2,2), 
     & PR1(4,4),PR2(4,4),PR3(4,4),PR4(4,4)
      double complex PR5(4,4), PR6(4,4) 
      double complex UBP1(2,4),Vp2(2,4),U0,UU1(4,4),uu2(4,4),veg(4,4),
     & ei, a11, a12, a21, a22, b11,b12,b21,b22, UT
      double complex UUG1(4,4), UUG4(4,4)   

      data ei/(0.d0, 1.d0)/
      save ei
      LOGICAL first
      SAVE first, coef
      DATA first /.TRUE./
      double precision hh(3,3) 
      double precision CS, CA, CCH
      save cs,ca
      double precision zn1, zn2, znn
      COMMON /colden/ zn1, zn2
*
      if(first) THEN
        coef = rpar(10) * rpar(12)         ! transform into millibarns * eq**2
        coef = coef / (2.d0 * 2.d0)        ! spins
        coef = coef / 8.d0 / 8.d0   ! color normalization
        coef = coef * (2.d0/3.d0)**2
        cs = 7.d0 / 3.d0
        ca = 3.d0
        first=.FALSE.
      ENDIF

      S   = 2.d0 * SCALP(k1, k2)
      do I=1,4
       x1(i) =  p1(i) + q(i)
       x2(i) =  k2(i) - p2(i)
       x3(i) =  p1(i) - k1(i)
       x4(i) = -p2(i) - q(i)
       x5(i) =  k1(i) - p2(i)
       x6(i) =  p1(i) - k2(i)
       r(i)  =  k2(i) - k1(i)
      enddo
       x1(5) = p1(5)
       x2(5) = x1(5)
       x3(5) = x1(5)
       x4(5) = x1(5)
       x5(5) = x1(5)
       x6(5) = x1(5)
       call PropF(x1, PR1)
       call PropF(x2, PR2)
       call PropF(x3, PR3)
       call PropF(x4, PR4)
       call PropF(x5, PR5)
       call PropF(x6, PR6)
      
      call Dirs2_Ubar(p1, UBP1)
      call Dirs2_V(p2,    VP2)
       call phat(r, VR)

      do 999 if1 = 1,2
      do 999 if2 = 1,2
      do 999 iga  = 1,2
       call vpolgam(iga, is, q, eg)
       call phat(eg, VEG)
      do 999 ip1 = 1,2
      do 999 ip2 = 1,2
* M1
       call prod_2(veg, PR1, UUG1)
        call gamagam(ip1, ip2, PR2, UU1)
       call prod_2(UUG1, UU1, UU2)

       call UBAR_M_U(if1,if2,UBP1, VP2, UU2, U0)
       tm1(ip1,ip2,if1,if2,iga) = U0 
* M2
       call prod_2(pr3, veg, UU2)
       call prod_2(UU2, PR2, UU1)
        call gamagam(ip1, ip2, UU1, UU2)
       call UBAR_M_U(if1,if2,UBP1, VP2, UU2, U0)
       tm2(ip1,ip2,if1,if2,iga) = U0
* M3
       call prod_2(PR4, veg, UUG4)
        call gamagam(ip1, ip2, PR3, UU1)
       call prod_2(uu1, UUG4, uu2)
       call UBAR_M_U(if1,if2,UBP1, VP2, UU2, U0)
       tm3(ip1,ip2,if1,if2,iga) = U0
* M4
        call gamagam(ip1, ip2, PR5, UU1)
       call prod_2(UUG1, UU1, UU2)
       call UBAR_M_U(if1,if2,UBP1, VP2, UU2, U0)
       tm4(ip1,ip2,if1,if2,iga) = U0 
* M5
       call prod_2(pr6, veg, UU2)
       call prod_2(UU2, PR5, UU1)
        call gamagam(ip1, ip2, UU1, UU2)
       call UBAR_M_U(if1,if2,UBP1, VP2, UU2, U0)
       tm5(ip1,ip2,if1,if2,iga) = U0
* M6
        call gamagam(ip1, ip2, PR6, UU1)
       call prod_2(uu1, UUG4, uu2)
       call UBAR_M_U(if1,if2,UBP1, VP2, UU2, U0)
       tm6(ip1,ip2,if1,if2,iga) = U0
* M7 and M8
       if(ip1.eq.ip2) then
        call prod_2(UUG1, VR, UU2)
       call UBAR_M_U(if1,if2,UBP1, VP2, UU2, U0)
       tm7(ip1,ip2,if1,if2,iga) = -U0 / (-s)

        call prod_2(vr, UUG4, UU2)
       call UBAR_M_U(if1,if2,UBP1, VP2, UU2, U0)
       tm8(ip1,ip2,if1,if2,iga) = -U0 / (-s)
       endif
 999    continue


       TS = 0.d0
       zn1 = 0.d0
       zn2 = 0.d0
       do 998 ip1 = 1,2
       do 998 ip2 = 1,2
       do 998 if1 = 1,2
       do 998 if2 = 1,2
       do 998 iga  = 1,2
        U0 = tm1(ip1,ip2,if1,if2,iga) + tm2(ip1,ip2,if1,if2,iga)
     &     + tm3(ip1,ip2,if1,if2,iga) 
        zn1 = zn1 + U0 * conjg(U0)
        U0 =                            tm4(ip1,ip2,if1,if2,iga)
     &     + tm5(ip1,ip2,if1,if2,iga) + tm6(ip1,ip2,if1,if2,iga)
        zn2 = zn2 + U0 * conjg(U0)
        U0 = tm1(ip1,ip2,if1,if2,iga) + tm2(ip1,ip2,if1,if2,iga)
     &     + tm3(ip1,ip2,if1,if2,iga) + tm4(ip1,ip2,if1,if2,iga)
     &     + tm5(ip1,ip2,if1,if2,iga) + tm6(ip1,ip2,if1,if2,iga)

        TS = TS + cs * U0 * conjg(U0)
        U0 = tm1(ip1,ip2,if1,if2,iga) + tm2(ip1,ip2,if1,if2,iga)
     &     + tm3(ip1,ip2,if1,if2,iga) 
     &     - tm4(ip1,ip2,if1,if2,iga) - tm5(ip1,ip2,if1,if2,iga) 
     &     - tm6(ip1,ip2,if1,if2,iga)
     &  + 2.d0*(tm7(ip1,ip2,if1,if2,iga) + tm8(ip1,ip2,if1,if2,iga))
        TS = TS + ca * U0 * conjg(U0)
 998   continue 
        znn = zn1 + zn2
        zn1 = zn1 / znn
        zn2 = zn2 / znn

* polarization       
       do ip1 = 1,3
       do ip2 = 1,3
        hh(ip1,ip2) = 0.d0
       enddo
       enddo
       do 997 ip1 = 1,2
       do 997 ip2 = 1,2
       do 997 iga = 1,2
* 
       if1 = 1
       if2 = 1       
        A11 = tm1(ip1,ip2,if1,if2,iga) + tm2(ip1,ip2,if1,if2,iga)
     &      + tm3(ip1,ip2,if1,if2,iga) + tm4(ip1,ip2,if1,if2,iga)
     &      + tm5(ip1,ip2,if1,if2,iga) + tm6(ip1,ip2,if1,if2,iga)

        B11 = tm1(ip1,ip2,if1,if2,iga) + tm2(ip1,ip2,if1,if2,iga)
     &      + tm3(ip1,ip2,if1,if2,iga) 
     &      - tm4(ip1,ip2,if1,if2,iga) - tm5(ip1,ip2,if1,if2,iga) 
     &      - tm6(ip1,ip2,if1,if2,iga)
     &  + 2.d0*(tm7(ip1,ip2,if1,if2,iga) + tm8(ip1,ip2,if1,if2,iga))
*
       if1 = 1
       if2 = 2       
        A12 = tm1(ip1,ip2,if1,if2,iga) + tm2(ip1,ip2,if1,if2,iga)
     &      + tm3(ip1,ip2,if1,if2,iga) + tm4(ip1,ip2,if1,if2,iga)
     &      + tm5(ip1,ip2,if1,if2,iga) + tm6(ip1,ip2,if1,if2,iga)

        B12 = tm1(ip1,ip2,if1,if2,iga) + tm2(ip1,ip2,if1,if2,iga)
     &      + tm3(ip1,ip2,if1,if2,iga) 
     &      - tm4(ip1,ip2,if1,if2,iga) - tm5(ip1,ip2,if1,if2,iga) 
     &      - tm6(ip1,ip2,if1,if2,iga)
     &  + 2.d0*(tm7(ip1,ip2,if1,if2,iga) + tm8(ip1,ip2,if1,if2,iga))
*
       if1 = 2
       if2 = 1       
        A21 = tm1(ip1,ip2,if1,if2,iga) + tm2(ip1,ip2,if1,if2,iga)
     &      + tm3(ip1,ip2,if1,if2,iga) + tm4(ip1,ip2,if1,if2,iga)
     &      + tm5(ip1,ip2,if1,if2,iga) + tm6(ip1,ip2,if1,if2,iga)

        B21 = tm1(ip1,ip2,if1,if2,iga) + tm2(ip1,ip2,if1,if2,iga)
     &      + tm3(ip1,ip2,if1,if2,iga) 
     &      - tm4(ip1,ip2,if1,if2,iga) - tm5(ip1,ip2,if1,if2,iga) 
     &      - tm6(ip1,ip2,if1,if2,iga)
     &  + 2.d0*(tm7(ip1,ip2,if1,if2,iga) + tm8(ip1,ip2,if1,if2,iga))
*
       if1 = 2
       if2 = 2       
        A22 = tm1(ip1,ip2,if1,if2,iga) + tm2(ip1,ip2,if1,if2,iga)
     &      + tm3(ip1,ip2,if1,if2,iga) + tm4(ip1,ip2,if1,if2,iga)
     &      + tm5(ip1,ip2,if1,if2,iga) + tm6(ip1,ip2,if1,if2,iga)

        B22 = tm1(ip1,ip2,if1,if2,iga) + tm2(ip1,ip2,if1,if2,iga)
     &      + tm3(ip1,ip2,if1,if2,iga) 
     &      - tm4(ip1,ip2,if1,if2,iga) - tm5(ip1,ip2,if1,if2,iga) 
     &      - tm6(ip1,ip2,if1,if2,iga)
     &  + 2.d0*(tm7(ip1,ip2,if1,if2,iga) + tm8(ip1,ip2,if1,if2,iga))
*
* e1_x e2_x  
        u0 = a11 + a21 - a12 - a22
        UT = b11 + b21 - b12 - b22
        cch = cs * u0*conjg(u0) + ca * ut*conjg(ut)
        hh(1,1) = hh(1,1) + cch
* e1_x e2_y  
        u0 = a11 + a21 - ei * (a12 + a22)
        ut = b11 + b21 - ei * (b12 + b22)
        cch = cs * u0*conjg(u0) + ca * ut*conjg(ut)
        hh(1,2) = hh(1,2) + cch
* e1_x e2_z  
        u0 = a12 + a22
        ut = b12 + b22
        cch = cs * u0*conjg(u0) + ca * ut*conjg(ut)
        hh(1,3) = hh(1,3) + 2.d0*cch
***
* e1_y e2_x  
        u0 = a11 - a12 - ei * (a21 - a22)
        ut = b11 - b12 - ei * (b21 - b22)
        cch = cs * u0*conjg(u0) + ca * ut*conjg(ut)
        hh(2,1) = hh(2,1) + cch
* e1_y e2_y  
        u0 = a11 - ei*(a12+a21) - a22
        u0 = b11 - ei*(b12+b21) - b22
        cch = cs * u0*conjg(u0) + ca * ut*conjg(ut)
        hh(2,2) = hh(2,2) + cch
* e1_y e2_z  
        u0 = a12 - ei*a22
        ut = b12 - ei*b22
        cch = cs * u0*conjg(u0) + ca * ut*conjg(ut)
        hh(2,3) = hh(2,3) + 2.d0*cch

* e1_z e2_x  
        u0 = a11 - a12
        ut = b11 - b12
        cch = cs * u0*conjg(u0) + ca * ut*conjg(ut)
        hh(3,1) = hh(3,1) + 2.d0 * cch
* e1_z e2_y  
        u0 = a11 - ei*a12
        ut = b11 - ei*b12
        cch = cs * u0*conjg(u0) + ca * ut*conjg(ut)
        hh(3,2) = hh(3,2) + 2.0 * cch
* e1_z e2_z  
        cch = cs * a12*conjg(a12) + ca * b12*conjg(b12)
        hh(3,3) = hh(3,3) + 4.d0 * cch
 997   continue 
      do ip1 = 1,3
      do ip2 = 1,3
       hh(ip1,ip2) = (hh(ip1,ip2) - TS) / TS
      enddo
      enddo

      ves = coef * rpar(16)**2 * TS 
      return
      end
*----------------------------------------------------------------------------*
*  reading and evaluation of the top-quark anomalous couplings               *
*----------------------------------------------------------------------------*
      subroutine FCNC_READ
*     -------------------                                                    *
* anomalous couplings are from "Top quark physics", hep-ph/0003033, M.Beneke *
*............................................................................*

      implicit none
      include "txpar.inc" 
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision mq,       mq2
      common  /massql/ mq(0:20), mq2(0:20)
      integer I 
* parameterization is : (par_L P_L + par_R P_R)                              *
* definition of other terms is determined by interaction                     *
*----------------------------                                                *
* input:                                                                     *
* ------                                                                     *
* three types of parameterizations (determined by IRtyp                      *
*  Irtyp(int) = 1 : ReA and ImA                                              *
*  Irtyp(int) = 2 : !A! and phase in radian, i.e. cos(phase)                 *
*  Irtyp(int) = 3 : |A| and phase in PI,     i.e. cos(PI*phase)              *
*  Irtyp(int) = 4 : |A| and phase , Rui&Pedro parameterization               *
*  Irtyp(int) = -1 : supress completely interaction                          *
*  Irtyp(int) = 10 + 1 (2, 3, 4) are the same as 1,2,3,4 but for f + h gamma5*
*   i.e. A_L = f - h,  A_R = f + h
* cH(i)  are divided by Rpar(50) (Lambda New Physics)                        *
* CX and CY are divided by Rpar(50)**2 (Lambda New Physics)                  *
* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .*
      double precision x0, CX_MD, A 
      integer Irtyp, JK 
      double precision an_FL,an_FR,an_HL,an_HR,an_XL,an_XR,an_YL,an_YR
      common /CTOPINI/Irtyp(20), an_FL(2,20), an_FR(2,20),
     &   an_HL(2,20), an_HR(2,20), an_XL(2,20), an_XR(2,20), 
     &   an_YL(2,20), an_YR(2,20) 
      double complex   CR,  CL
      double complex   FL,     FR,      HL,    HR,
     &                 XL,     XR,      YL,    YR
      common /ANOMCPL/FL(20), FR(20), HL(20), HR(20), 
     &                XL(20), XR(20), YL(20), YR(20) 

      character *9 nam(20)
      data nam
     &/'d W+- t  ','s W+- t  ','b W+- t  ','not used ',
     & 'b H+- t  ','b H+- T* ','not used ','not used ',
     & 'not used ','not used ','U gluon T','C gluon T',
     & 'U gamma T','C gamma T','U Z T    ','C Z T    ',
     & 'not used ','not used ','not used ','not used '/
***
      data Irtyp/20*1/
      data an_FL/
*      Re_FL  Im_FL         MID channel
     & 1.d0,  0.0d0,     ! 1   d W t SM 
     & 1.d0,  0.0d0,     ! 2   s W t SM 
     & 1.d0,  0.0d0,     ! 3   b W t SM 
     & 2*0.d0,           ! not used
     & 2*0.d0,           ! 5   b H+- 
     & 2*0.d0,           ! 6   b H+- T* 
     & 8*0.d0,           ! 7:10   not used
     & 0.d0,  0.d0,      ! 11 U_Gluon_T  
     & 0.d0,  1.d0,      ! 12 C_Gluon_T  
     & 0.d0,  0.d0,      ! 13 U_photon_T
     & 0.d0,  0.d0,      ! 14 U_photon_T  
     & 1.d0,  0.d0,      ! 15 U_Z_T  
     & 1.d0,  0.d0,      ! 16 C_Z_T  
     & 8*0.d0 /          ! 17:20 not used
      data an_FR/
*      Re_FR  Im_FR          MID channel
     & 0.d0,  0.d0,       ! 1   d W t SM 
     & 0.d0,  0.d0,       ! 2   s W t SM 
     & 0.d0,  0.d0,       ! 3   b W t SM 
     & 2*0.d0,            ! not used
     & 2*0.d0,            ! 5   b H+- 
     & 2*0.d0,            ! 6   b H+- T* 
     & 8*0.d0,            ! 7:10   not used
     & 0.d0,   0.d0,      ! 11 U_Gluon_T  
     & 0.d0,   0.d0,      ! 12 C_Gluon_T  
     & 0.d0,   0.d0,      ! 13 U_photon_T
     & 0.d0,   0.d0,      ! 14 U_photon_T  
     & 1.d0,   0.d0,      ! 15 U_Z_T  
     & 1.d0,   0.d0,      ! 16 C_Z_T  
     & 8*0.d0 /                         ! 17:20 not used
*****
      data an_HL/
*      Re_HL  Im_HL       MID channel
     & 0.d0,  0.0d0,    ! 1   d W t SM 
     & 0.d0,  0.0d0,    ! 2   s W t SM 
     & 0.d0,  0.0d0,    ! 3   b W t SM 
     & 2*0.d0,          ! not used
     & 2*0.d0,          ! 5   b H+- 
     & 2*0.d0,          ! 6   b H+- T* 
     & 8*0.d0,          ! 7:10   not used
     & 1.d0,  0.d0,     ! 11 U_Gluon_T  
     & 1.d0,  0.d0,     ! 12 C_Gluon_T  
     & 1.d0,  0.d0,     ! 13 U_photon_T
     & 1.d0,  0.d0,     ! 14 U_photon_T  
     & 1.d0,  0.d0,     ! 15 U_Z_T  
     & 1.d0,  0.d0,     ! 16 C_Z_T  
     & 8*0.d0 /                         ! 17:20 not used
      data an_HR/
*      Re_HR  Im_HR      MID channel
     & 0.d0,  0.d0,     ! 1   d W t SM 
     & 0.d0,  0.d0,     ! 2   s W t SM 
     & 0.d0,  0.d0,     ! 3   b W t SM 
     & 2*0.d0,          ! not used
     & 2*0.d0,          ! 5   b H+- 
     & 2*0.d0,          ! 6   b H+- T* 
     & 8*0.d0,          ! 7:10   not used
     & 1.d0,   0.d0,    ! 11 U_Gluon_T  
     & 1.d0,   0.d0,    ! 12 C_Gluon_T  
     & 1.d0,   0.d0,    ! 13 U_photon_T
     & 1.d0,   0.d0,    ! 14 U_photon_T  
     & 1.d0,   0.d0,    ! 15 U_Z_T  
     & 1.d0,   0.d0,    ! 16 C_Z_T  
     & 8*0.d0 /         ! 17:20 not used
******
      data an_XL/
*      Re_XL  Im_XL       MID channel
     & 0.d0,  0.0d0,    ! 1   d W t SM 
     & 0.d0,  0.0d0,    ! 2   s W t SM 
     & 0.d0,  0.0d0,    ! 3   b W t SM 
     & 2*0.d0,          ! not used
     & 2*0.d0,          ! 5   b H+- 
     & 2*0.d0,          ! 6   b H+- T* 
     & 8*0.d0,          ! 7:10   not used
     & 0.d0,  0.d0,     ! 11 U_Gluon_T  
     & 0.d0,  0.d0,     ! 12 C_Gluon_T  
     & 0.d0,  0.d0,     ! 13 U_photon_T
     & 0.d0,  0.d0,     ! 14 U_photon_T  
     & 0.d0,  0.d0,     ! 15 U_Z_T  
     & 0.d0,  0.d0,     ! 16 C_Z_T  
     & 8*0.d0 /         ! 17:20 not used

      data an_XR/
*      Re_XR  Im_XR       MID channel
     & 0.d0,  0.d0,     ! 1   d W t SM 
     & 0.d0,  0.d0,     ! 2   s W t SM 
     & 0.d0,  0.d0,     ! 3   b W t SM 
     & 2*0.d0,          ! not used
     & 2*0.d0,          ! 5   b H+- 
     & 2*0.d0,          ! 6   b H+- T* 
     & 8*0.d0,          ! 7:10   not used
     & 0.d0,   0.d0,    ! 11 U_Gluon_T  
     & 0.d0,   0.d0,    ! 12 C_Gluon_T  
     & 0.d0,   0.d0,    ! 13 U_photon_T
     & 0.d0,   0.d0,    ! 14 U_photon_T  
     & 0.d0,   0.d0,    ! 15 U_Z_T  
     & 0.d0,   0.d0,    ! 16 C_Z_T  
     & 8*0.d0 /         ! 17:20 not used
****
      data an_YL/
*      Re_YL  Im_YL        MID channel
     & 0.d0,  0.0d0,    ! 1   d W t SM 
     & 0.d0,  0.0d0,    ! 2   s W t SM 
     & 0.d0,  0.0d0,    ! 3   b W t SM 
     & 2*0.d0,          ! not used
     & 2*0.d0,          ! 5   b H+- 
     & 2*0.d0,          ! 6   b H+- T* 
     & 8*0.d0,          ! 7:10   not used
     & 0.d0,  0.d0,     ! 11 U_Gluon_T  
     & 0.d0,  0.d0,     ! 12 C_Gluon_T  
     & 0.d0,  0.d0,     ! 13 U_photon_T
     & 0.d0,  0.d0,     ! 14 U_photon_T  
     & 0.d0,  0.d0,     ! 15 U_Z_T  
     & 0.d0,  0.d0,     ! 16 C_Z_T  
     & 8*0.d0 /         ! 17:20 not used
      data an_YR/
*      Re_YR  Im_YR       MID channel
     & 0.d0,  0.d0,     ! 1   d W t SM 
     & 0.d0,  0.d0,     ! 2   s W t SM 
     & 0.d0,  0.d0,     ! 3   b W t SM 
     & 2*0.d0,          ! not used
     & 2*0.d0,          ! 5   b H+- 
     & 2*0.d0,          ! 6   b H+- T* 
     & 8*0.d0,          ! 7:10   not used
     & 0.d0,   0.d0,    ! 11 U_Gluon_T  
     & 0.d0,   0.d0,    ! 12 C_Gluon_T  
     & 0.d0,   0.d0,    ! 13 U_photon_T
     & 0.d0,   0.d0,    ! 14 U_photon_T  
     & 0.d0,   0.d0,    ! 15 U_Z_T  
     & 0.d0,   0.d0,    ! 16 C_Z_T  
     & 8*0.d0 /         ! 17:20 not used
**
       integer itwb
* 
       do jk = 1,20
         FR(jk) = (0.d0, 0.0d0)
         FL(jk) = (0.d0, 0.0d0)
         HR(jk) = (0.d0, 0.0d0)
         HL(jk) = (0.d0, 0.0d0)
         XR(jk) = (0.d0, 0.0d0)
         XL(jk) = (0.d0, 0.0d0)
         YR(jk) = (0.d0, 0.0d0)
         YL(jk) = (0.d0, 0.0d0)
       enddo
* read anomalous couplings 
      do I = 1,16
      if(I.le.3.and.mid(i,1).eq.-1) mid(I,1) = 0
       call TRANS_CPL(Irtyp(I),I, an_FL, an_FR, CR,CL)
        FR(I) = CR
        FL(I) = CL
       call TRANS_CPL(Irtyp(I),I, an_HL, an_HR, CR,CL)
        HR(I) = CR
        HL(I) = CL
       call TRANS_CPL(Irtyp(I),I, an_XL, an_XR, CR,CL)
        XR(I) = CR
        XL(I) = CL
       call TRANS_CPL(Irtyp(I),I, an_YL, an_YR, CR,CL)
        YR(I) = CR
        YL(I) = CL
*   set for FCNC: gluon + gamma FL = FR = 0
      if(I.ge.11.AND.mid(i,1).eq.-1) then 
       FL(i) = (0.d0, 0.d0)
       FR(i) = (0.d0, 0.d0)
       HL(i) = (0.d0, 0.d0)
       HR(i) = (0.d0, 0.d0)
       XL(i) = (0.d0, 0.d0)
       XR(i) = (0.d0, 0.d0)
       YL(i) = (0.d0, 0.d0)
       YR(i) = (0.d0, 0.d0)
      endif
       if(i.ge.11.and.I.le.14) then
        FR(I) = (0.d0, 0.d0)
        FL(I) = (0.d0, 0.d0)
       endif
      enddo
*
      do I = 11,16
       A = cx_md(HL(i)) + cx_md(HR(i)) 
     &   + cx_md(XL(i)) + cx_md(XR(i)) 
     &   + cx_md(YL(i)) + cx_md(YR(i)) 
      if(A.le.0.d0) mid(i,1) = -1
      enddo
**

      itwb = 0
      If( FL(1).eq.(1.d0,0.d0).and.FR(1).eq.(0.d0,0.d0).
     &AND.FL(2).eq.(1.d0,0.d0).and.FR(2).eq.(0.d0,0.d0).
     &AND.FL(3).eq.(1.d0,0.d0).and.FR(3).eq.(0.d0,0.d0)) then
       itwb = 0
      Else
       itwb = 1
      EndIf  
*
      write(*,*) 
     &'***********************************************'
      If(itwb.eq.0) then
        write(*,*) 
     &'* SM couplings for t W d/s/b verticex         *'
      else
       write(*,*) 
     &'* new parameterization of Anomalous couplings *'
      write(*,*) 
     &'* for t W d/s/b vertex                        *'
      endif
      write(*,*) 
     &'***********************************************'
      write(*,*)
     &'*  gamma^mu * (FL P_L + FR P_R) '
      do I = 1,3
       x0 = FL(I)*conjg(FL(i))+FR(i)*conjg(FR(i))
       write(*,*) ' ',I,' : ',nam(I),' sqrt(FL2+FR2)',dsqrt(X0),
     & ' FL',FL(i),'  FR',FR(i)
      enddo
      write(*,*) 
     &'*                                             *'

      if( mid(11,1).ge.0.OR.mid(12,1).ge.0.
     & OR.mid(13,1).ge.0.OR.mid(14,1).eq.0.
     & OR.mid(15,1).ge.0.OR.mid(16,1).ge.0) then     
      write(*,*) 
     &'* FCNC top quark anomalous couplings          *'
      write(*,*) 
     &'*                                             *'
      write(*,*)
     &'*  gamma^mu * (FL P_L + FR P_R) '

      do I = 15,16
       x0 = FL(I)*conjg(FL(i))+FR(i)*conjg(FR(i))
       if(mid(I,1).ge.0) write(*,*) 
     & ' ',I,' : ',nam(I),' sqrt(FL2+FR2) ',dsqrt(X0),
     & ' FL',FL(i),' FR',FR(i)
      enddo
      endif

      IF(itwb.eq.1.OR.mid(11,1).ge.0.OR.mid(12,1).ge.0.
     & OR.mid(13,1).ge.0.OR.mid(14,1).eq.0.
     & OR.mid(15,1).ge.0.OR.mid(16,1).ge.0) THEN 
      write(*,*) 
     &'*                                             *'
      write(*,*) 
     &'***********************************************'
       write(*,*) 
     &'* new parameterization of Anomalous couplings *'
      write(*,*) 
     &'***********************************************'
      If(itwb.eq.1) then
      do I = 1,3
       A = cx_md(HL(i)) + cx_md(HR(i)) 
      if(A.gt.0.d0) then
      write(*,*) '',I,': ',nam(I),' HL',HL(I),' HR',HR(I)
*      write(*,*) '    XL',XL(i),' XR',XR(i),'  YL',YL(i),' YR',YR(i)
      endif
      enddo
      EndIf
      do I = 11,16
       A = cx_md(HL(i)) + cx_md(HR(i)) 
     &   + cx_md(XL(i)) + cx_md(XR(i)) 
     &   + cx_md(YL(i)) + cx_md(YR(i)) 
      if(A.gt.0.d0) then
       write(*,*) '',I,': ',nam(I),' HL',HL(I),' HR',HR(I)
       write(*,*) '    XL',XL(i),' XR',XR(i),'  YL',YL(i),' YR',YR(i)
      endif
      enddo
      ENDIF

      do I = 1,16
        HL(i) = HL(i) / rpar(50)
        HR(i) = HR(i) / rpar(50)
       if((i.eq.11.or.i.eq.12).AND.irtyp(i).eq.4) then
        HR(i)=HR(i)*rpar(28)/Rpar(50)
        HL(i)=HL(i)*rpar(28)/Rpar(50)
        YR(i) = -YR(i)
        YL(i) = -YL(i)
        XR(i) = XR(i) - YR(i) 
        XL(i) = XL(i) - YL(i) 
       endif

       XL(i) = XL(i) / rpar(50)**2
       XR(i) = XR(i) / rpar(50)**2
       YL(i) = YL(i) / rpar(50)**2 
       YR(i) = YR(i) / rpar(50)**2
      enddo
*      return
*
* 2222 call RP_FCNC_READ  ! read parameters in Rui&Pedro format
      return
      end  
*----------------------------------------------------------------------------*
      subroutine TRANS_CPL(IT, IQ, ANL, ANR, CR, CL) 
      implicit none
      include "txpar.inc" 
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision ANL(2,20), ANR(2, 20)
      double complex   CR, CL, U
      double complex  ei   
      data ei/(0.d0, 1.d0)/
      integer IT, IQ
*
      CR = (0.d0, 0.d0)
      CL = (0.d0, 0.d0)
      If    (it.eq.1.or.it.eq.11) then
        CL = ANL(1,iq) + ei*ANL(2,iq)  ! Left or  'f'
        CR = ANR(1,iq) + ei*ANR(2,iq)  ! right or 'h'
      ElseIf(it.eq.2.or.it.eq.4) then
        CL = 
     & dabs(ANL(1,iq))*(dcos(ANL(2,iq)) + ei*dsin(ANL(2,iq)))
        CR = 
     & dabs(ANR(1,iq))*(dcos(ANR(2,iq)) + ei*dsin(ANR(2,iq)))
      ElseIf(it.eq.3) then !  phase in PI
        CL = dabs(ANL(1,iq))*dcos(pi*ANL(2,iq))
     &  + ei*dabs(ANL(1,iq))*dsin(pi*ANL(2,iq))
        CR = dabs(ANR(1,iq))*dcos(pi*ANR(2,iq))
     &  + ei*dabs(ANR(1,iq))*dsin(pi*ANR(2,iq))
      EndIf
*
        If(it.eq.11.or.it.eq.12.or.it.eq.13.
     &  or.it.eq.4) then
           U = CL
           CL = U - CR ! f - h
           CR = U + CR ! f + h
        EndIf
      return
      end     
*----------------------------------------------------------------------------*
*... Authors  : Serge Slabospitsky                                           *
* direct top production due to FCNC  2 -> 1                                  *
*............................................................................*

      subroutine gejzer_29(NFP)
      implicit None
      include "txpar.inc" 
      Integer NFP          ! number of particles in hard process 
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision  pn(5), PL(5)
      double precision  q1(5), q2(5), qq(5) 
      double precision            sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      Integer I,  L, iq, j8,j9 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision  x1, x2, sg, sgs

      double precision  ves
      dimension ves(-6:6,-6:6)
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision pdfbt(-5:5, -5:5)
      double precision veslum, ves1, sqhat_min, sqhat_max, parl(3) 
      save   sqhat_max, sqhat_min 
*
      double precision PARR(4), PT, wr(2), pb(5), vesGU, vesUG
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
*      integer        PID(20) 
*      common /TXtopcpl/ PID      ! 1/0 = ON/OFF top interaction 
*      save   /TXtopcpl/
      integer imatch
      common /wmtch/imatch 
*..............
      if(first) THEN
      first=.FALSE.
        if(mid(11,1).eq.0.AND.mid(12,1).eq.0.and.Ipar(26).eq.2) then 
         print*,' '
         print*,'TopReX  FCNC process  ',ipar(1)
         print*,' FCNC (top -> !UP+CHARM! gluon) is switched OFF'
         print*,' stop TopReX run '
          STOP 
         return
        endif 
*..RPAR(101)    : sqrt(Shat_MIN) for hard process                          
*..RPAR(102)    : sqrt(Shat_MAX) for hard process                            
       imatch = 1  ! for TopReX matching
       sqhat_min = rpar(101)
       sqhat_max = rpar(102)
      write(*,7051) sqhat_min, sqhat_max 
 7051 format(/,' sqrt(Shat) from ',f8.2,' to ',f8.2)
         if(sqhat_min.ge.sqhat_max) then
          write(*,7053) 
 7053    format(/,' Shat_min greater than Shat_max  stop running')
          STOP 
         endif
*
       imatch = 1  ! for TopReX matching

        ParR(1) = Rpar(41) 
        ParR(2) = Rpar(44) 
        ParR(3) = sqhat_min
        ParR(4) = sqhat_max
         pn(5) = 0.d0 
         PL(5) = 0.d0
      ENDIF
      
       imatch = 1  ! for TopReX matching
      do j8 = -6,6
      do j9 = -6,6
       XCS(j8,j9) = 0.d0
      enddo
      enddo
      call zer5mom(q1) 
      call zer5mom(q2) 
      
        q1(5) = 0.d0
        q2(5) = 0.d0

        pb(5) = mq(5)
       parL(1) = rpar(103) + dsqrt(sqhat_min**2+rpar(103)**2) 
       ParL(2) = rpar(102)      ! M(W*)_max for production
       parL(3) = Rpar(1)
       WR(1) = mq(6) 
       WR(2) = Rpar(36)   ! M(W) * Width(W) 


 100   continue
      if(Ipar(26).eq.2) then 
         call X1X2RES( ParL, WR, X1, X2, Veslum, q1, q2, QQ)
      else
       call X1X2GEN(parl, X1, X2, Veslum, q1, q2, QQ)
      endif
**
       q1(4) = dabs(q1(3))
       q2(4) = dabs(q2(3))
      call mass2(q1, q2, sg, sgs)

      Rpar(5) = mq(6) ! PH(5)   ! mass(H* or W*) ==> Q-scale for PDF
      call TXQscale  ! setting Q-scale for PDF( Rpar(3)) and for alpha_s    
      call pdf_BT(x1, x2, pdfbt)

      pb(5) = mq(5)
      pl(5) = 0.d0
      pn(5) = 0.d0
      call LIPS_Res_Wff(QQ, pb, pl, pn, Ves1)
      if(pt(pb).lt.rpar(103)) goto 100

      veslum = veslum * ves1 * pi2_4 / (2.*sg)
      do j8 = -6,6
      do j9 = -6,6
       VES(j8,j9) = 0.d0
      enddo
      enddo
      do i = 1,5
        pus(1,i) = q1(i)
        pus(2,i) = q2(i)
        pus(3,i) = pb(i) 
      enddo  
*

      iq = 2 ! up
      call tfcnc_SM(iq, q1, q2, pb, pl, pn, vesGU)
      call tfcnc_SM(iq, q2, q1, pb, pl, pn, vesUG)
      Xcs( 0, iq)=Veslum*vesGU*pdfBT( 0, iq)*BRS(1,2) ! BRS is W branching
      Xcs( 0,-iq)=Veslum*vesGU*pdfBT( 0,-iq)*BRS(2,2) 
      Xcs( iq, 0)=Veslum*vesUG*pdfBT( iq, 0)*BRS(1,2) 
      Xcs(-iq, 0)=Veslum*vesUG*pdfBT(-iq, 0)*BRS(2,2) 

      iq = 4 ! up
      call tfcnc_SM(iq, q1, q2, pb, pl, pn, vesGU)
      call tfcnc_SM(iq, q2, q1, pb, pl, pn, vesUG)
      Xcs( 0, iq)=Veslum*vesGU*pdfBT( 0, iq)*BRS(1,2) ! BRS is W branching
      Xcs( 0,-iq)=Veslum*vesGU*pdfBT( 0,-iq)*BRS(2,2) 
      Xcs( iq, 0)=Veslum*vesUG*pdfBT( iq, 0)*BRS(1,2) 
      Xcs(-iq, 0)=Veslum*vesUG*pdfBT(-iq, 0)*BRS(2,2) 


      sigrx=0.d0
      do i= -5 ,5
        do l= -5, 5 
          sigrx = sigrx + xcs(i,l)
        enddo
      enddo

 444  continue
       nfp = 6 ! 7 was in previous version 03.05.2006
       do i = 1, 5
        pus(1,i) = q1(i)
        pus(2,i) = q2(i)
*        pus(3,i) = QQ(i)        !  top 
        pus(3,i) = pb(i)         !  b-quark
        pus(4,i) = pl(i) + pn(i) !  W-quark
        pus(5,i) = pn(i)         !  nu  !  NEUTRINO is the first
        pus(6,i) = pl(i)         !  L+-
       enddo
        pus(4,5) = dsqrt(pus(4,4)**2-pus(4,1)**2
     &                 - pus(4,2)**2-pus(4,3)**2)
      return
      end
*----------------------------------------------------------------------------*
*... Authors  : Serge Slabospitsky                                           *
* direct top production due to FCNC  2 -> 1                                  *
*............................................................................*
      subroutine gejzer_30(NFP)
      implicit None
      include "txpar.inc" 
      Integer NFP          ! number of particles in hard process 
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision  q1(5), q2(5), ptop(5) 
      double precision            sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      Integer I,  L, iq, j8,j9 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision  x1, x2
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision pdfbt(-5:5, -5:5)
      double precision veslum, sqhat_min, sqhat_max, parl(3) 
      save   sqhat_max, sqhat_min 
*
      double precision wr(2), vesGU, vesUG
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
      integer imatch
      common /wmtch/imatch 
      double precision hrgu   ,hrug   , hrgc   , hrcg   
      common /fcncpol/ hrgu(4),hrug(4), hrgc(4), hrcg(4)
*..............
      if(first) THEN
      first=.FALSE.
        if(mid(11,1).eq.-1.AND.mid(12,1).eq.-1) then 
         print*,' '
         print*,'TopReX  FCNC process  ',ipar(1)
         print*,' FCNC (top -> !UP+CHARM! gluon) is switched OFF'
         print*,' stop TopReX run '
         stop ! STOP
         return
        endif 
*
*..RPAR(101)    : sqrt(Shat_MIN) for hard process                          
*..RPAR(102)    : sqrt(Shat_MAX) for hard process                            
       sqhat_min = mq(6) - 25.d0*rpar(34)
       sqhat_max = mq(6) + 25.d0*rpar(34)
      if(abs(sqhat_min-mq(6)).ge.60.d0) sqhat_min = mq(6) - 60.d0
      if(abs(sqhat_max-mq(6)).ge.60.d0) sqhat_max = mq(6) + 60.d0

      write(*,7051) sqhat_min, sqhat_max 
 7051 format(/,' sqrt(Shat) from ',f8.2,' to ',f8.2)
         if(sqhat_min.ge.sqhat_max) then
          write(*,7053) 
 7053    format(/,' Shat_min greater than Shat_max  stop running')
          STOP 
         endif
      

       parL(1) = sqhat_min 
       ParL(2) = sqhat_max
       parL(3) = Rpar(1)
       WR(1) = mq(6) 
       WR(2) = Rpar(36)   ! M(W) * Width(W) 
      ENDIF
      
      imatch = 1  ! for TopReX matching
      do j8 = -6,6
      do j9 = -6,6
       XCS(j8,j9) = 0.d0
      enddo
      enddo
      call zer5mom(q1) 
      call zer5mom(q2) 

        q1(5) = 0.d0
        q2(5) = 0.d0
         call X1X2delf( ParL, WR, X1, X2, Veslum, q1, q2, ptop)
**
      Rpar(5) = mq(6) ! PH(5)   ! mass(H* or W*) ==> Q-scale for PDF
      call TXQscale  ! setting Q-scale for PDF( Rpar(3)) and for alpha_s    
      call pdf_BT(x1, x2, pdfbt)

      veslum = veslum * pi / ptop(5)**2
*
      iq = 2 ! up
      call tfcnc_00(iq, q1, ptop, vesGU, hrGU)
      call tfcnc_00(iq, q2, ptop, vesUG, hrUG)
      Xcs( 0, iq)=Veslum*vesGU*pdfBT( 0, iq)*BRS(1,2) ! BRS is W branching
      Xcs( 0,-iq)=Veslum*vesGU*pdfBT( 0,-iq)*BRS(2,2) 
      Xcs( iq, 0)=Veslum*vesUG*pdfBT( iq, 0)*BRS(1,2) 
      Xcs(-iq, 0)=Veslum*vesUG*pdfBT(-iq, 0)*BRS(2,2) 

      iq = 4 ! up
      call tfcnc_00(iq, q1, ptop, vesGU, hrGC)
      call tfcnc_00(iq, q2, ptop, vesUG, hrCG)
      Xcs( 0, iq)=Veslum*vesGU*pdfBT( 0, iq)*BRS(1,2) ! BRS is W branching
      Xcs( 0,-iq)=Veslum*vesGU*pdfBT( 0,-iq)*BRS(2,2) 
      Xcs( iq, 0)=Veslum*vesUG*pdfBT( iq, 0)*BRS(1,2) 
      Xcs(-iq, 0)=Veslum*vesUG*pdfBT(-iq, 0)*BRS(2,2) 


      sigrx=0.d0
      do i= -5 ,5
        do l= -5, 5 
          sigrx = sigrx + xcs(i,l)
        enddo
      enddo

 444  continue
       nfp = 3 
       do i = 1, 5
        pus(1,i) = q1(i)
        pus(2,i) = q2(i)
        pus(3,i) = ptop(i)          !  top 
       enddo
      return
      end
*----------------------------------------------------------------------------*
*... Authors  : Serge Slabospitsky                                           *
*... testing new process                                                     *
*............................................................................*

      subroutine gejzer_test(NFP)
      implicit None
      include "txpar.inc" 
      Integer NFP          
      double precision Pus
      common /user_mom/Pus(20,5)

      double precision Ves, q1(5), b1(5), qq2(5), pq2(5), qq(5) 
      double precision q2(5), b2(5), pl(5), pn(5) 

      double precision            sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)

      integer I, J, j8,j9 
      double precision  x1, x2, sg, sgs
      double precision  pdfBT(-5:5, -5:5)
      double precision  Veslum, vesQB, vesBQ, ParL(3) ! , TopMV
* 
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
      double precision fqwq
      common /sng1fc/ fqwq(4)   !  is factor for weight  
      integer imatch
      common /wmtch/imatch 
*..............
      if(first) THEN
       I = 1
       J = 1
       call qflqw(I, J)
      first=.FALSE.
      ENDIF

      imatch = 1
      sigrx=0.d0
      do j8 = -6,6
      do j9 = -6,6
       XCS(j8,j9) = 0.d0
      enddo
      enddo
      call zer5mom(q1) 
      call zer5mom(q2) 
      PARL(1) = rpar(41)+10.d0 ! p1(5) + 1.d0 ! min sqrt(S_hat) 
      PARL(2) = Rpar(1)      ! max sqrt(S_hat) 
      PARL(3) = Rpar(1)      ! sqrt(S) 

 199  call X1X2GEN(ParL, X1, X2, Veslum, q1, qq2, QQ)
      
      if(qq2(4).lt.mq(5)) goto 199 

      call kinsng1(QQ, q1, qq2, -1)
      sg  = QQ(5)**2
      sgs = QQ(5)
      if(sgs.lt.Parl(1)) return

      b1(5)  = mq(5)
      call Rlip432(QQ, pq2, b1, pl, pn, Ves)
* setting Q-scale for PDF( Rpar(3)) and for alpha_s 
      call TXQscale     
      call pdf_BT(x1, x2, pdfBT) 

       veslum = 2.d0 * veslum * ves  * pi2_4 / (2.*sg)  ! 2 due to QB choice
*
      do j = 1,4
       b2(j) = -qq2(j)
       q2(j) = -pq2(j)
      enddo
        call mwqq(q1, q2, b1, b2, pl, pn, vesqb)
        VesBQ = 0.d0

      VesQB = -VesQB * Veslum 
      VesBQ = -VesBQ * Veslum 

*  top production
      do I = 1,4
       J = I
       if(I.eq.1.or.I.eq.3) J = -I
       Xcs( J, 5) = VesQB * pdfBT( J, 5) * fqwq(I) * BRS(1,1)  ! T
       Xcs(-J,-5) = VesQB * pdfBT(-J,-5) * fqwq(I) * BRS(2,1)  ! Tbar 
       Xcs( 5, J) = VesBQ * pdfBT( 5, J) * fqwq(I) * BRS(1,1)  ! T 
       Xcs(-5,-J) = VesBQ * pdfBT(-5,-J) * fqwq(I) * BRS(2,1)  ! Tbar
      enddo

      sigrx=0.d0
      do i=-5,5
        do j=-5,5
          sigrx = sigrx + xcs(i,j)
        enddo
      enddo

* fill momenta array 
       nfp = 4
      return
      end
*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky, date   : 22.06.2006                         *
*.. matrix element squared for t -> b (W*) l2(nu) l1(l+-) decay, including   *
*.. virtual W-boson exchange                                                 *
*.. WITHOUT calculation of the final lepton polarisation                     *
*.. WITH anomalous couplings                                                 *
      subroutine tbwff(iniq, p,k,l1,l2, VES, ps)
*     -------------------------------------------------                      *
      implicit none
      include "txpar.inc" 
      double precision p(5),k(5), l1(5), l2(5), ps(5) 
      double precision scalp, ves, mt, mu, coef 
      double precision PL1,pl2, l1k,L2K, Q2 
      integer J, iniq, kqw, iq 
      double complex fl2(3), fr2(3), hl2(3), hr2(3),
     & Sflhl(3), Aflhl(3), Sfrhr(3), Afrhr(3),
     & Sflhr(3), SfRhL(3), Sflfr(3), Shlhr(3),
     & Aflfr(3), Ahlhr(3)
      double precision NN1(4), NN2(4), WW(4), epsl(5)
      double precision T1, T2, T3 
      double complex   FL,     FR,      HL,    HR,
     &                 XL,     XR,      YL,    YR
      common /ANOMCPL/FL(20), FR(20), HL(20), HR(20), 
     &                XL(20), XR(20), YL(20), YR(20) 
      double complex ei
      data ei/(0.d0, 1.d0)/
      LOGICAL first
      SAVE first, coef
      DATA first /.TRUE./
*
* all couplings correspond to top tWq interaction: 1 -d, 2 - s, 3 - 6
* kqw function tronsform iniq ==> iq
      IF(first) THEN        ! initializing
      first=.FALSE.
       coef = (rpar(26)/dsqrt(2.d0))**4
       coef = coef * 9.d0 / 2.d0

      do J = 1,3
       fl(j) = (1.d0, 0.d0)
       fl2(j) = fl(j) * conjg(fl(j))
       fr2(j) = fr(j) * conjg(fr(j))
       hl2(j) = hl(j) * conjg(hl(j))
       hr2(j) = hr(j) * conjg(hr(j))
        Sflhl(j) = fl(j)*conjg(hl(j)) + hl(j)*conjg(fl(j))
        Aflhl(j) = fl(j)*conjg(hl(j)) - hl(j)*conjg(fl(j))
       Aflhl(j) = ei * Aflhl(j) 
        Sfrhr(j) = fr(j)*conjg(hr(j)) + hr(j)*conjg(fr(j))
        Afrhr(j) = fr(j)*conjg(hr(j)) - hr(j)*conjg(fr(j))
       Afrhr(j) = ei * Afrhr(j) 
*
       Sflhr(j) = fl(j)*conjg(hr(j)) + hr(j)*conjg(fl(j))
       SfRhL(j) = fr(j)*conjg(hl(j)) + hl(j)*conjg(fr(j))

       Sflfr(j) = fl(j)*conjg(fr(j)) + fr(j)*conjg(fl(j))
       Shlhr(j) = hl(j)*conjg(hr(j)) + hl(j)*conjg(hr(j))

         Aflfr(j) = fl(j)*conjg(fr(j)) - fr(j)*conjg(fl(j))
       Aflfr(j) = ei * Aflfr(j) 
         Ahlhr(j) = hl(j)*conjg(hr(j)) - hr(j)*conjg(hl(j))
       Ahlhr(j) = ei * Ahlhr(j) 

      enddo
       ENDIF
**
      iq = kqw(iniq)
      call epsil3(l1, l2, k, epsl)
      call zer5mom(ps,  2*5)
      mt  = p(5)
      mu  = k(5)

      PL1 = scalp(L1, P)
      PL2 = scalp(L2, P)
      L1K = scalp(L1, K)
      L2K = scalp(L2, K)
      Q2 = 2.d0 * scalp(L1, L2) 
**
      T1= fl2(iq)*pl1 + 4.d0*hl2(iq)*q2*pl2 - mt*q2*sflhl(iq)
      T1 = 16.d0 * T1 * l2k

      T2= fr2(iq)*pl2 + 4.d0*hr2(iq)*q2*pl1 - mt*q2*sfrhr(iq)
      T2 = 16.d0 * T2 * l1k

      T3=2.d0*q2*(sflhr(iq)*pl1 + sfrhl(iq)*pl2) 
     & - mt*q2*(sflfr(iq) + 4.d0*q2*shlhr(iq))
      T3 = 8.d0 * T3 * mu
      ves = coef * (T1 + T2 + T3)

      do J = 1,3
       NN1(J) = -mt*l1(j)
       nn2(j) =  mt*l2(j)
       ww(j) = pl1 * l2(j) - pl2 * l1(j)
     
       ps(J) = 16.d0*l2k *
     & (fl2(iq)*nn1(j) + 4.d0*q2*hl2(iq)*nn2(j)
     & - 2.d0*sflhl(iq)*ww(j) + 2.d0*Aflhl(iq)*epsl(j) )
     &
     &       + 16.d0*l1k *
     & (fr2(iq)*nn2(j) + 4.d0*q2*hr2(iq)*nn1(j)
     & - 2.d0*sfrhr(iq)*ww(j) - 2.d0*Afrhr(iq)*epsl(j) )
     &
     &       +  8.d0*mu*
     & (2.d0*q2*(sflhr(iq)*nn1(j) + sfrhl(iq)*nn2(j)) 
     & - (sflfr(iq) + 4.d0*q2*shlhr(iq))*ww(j)
     & + (Aflfr(iq) - 4.d0*Ahlhr(iq))*epsl(j) )

      ps(j) = ps(j) / (T1 + T2 + T3)
*      ps(j) = -ps(j) ! transit to 3-space 
*      ps(j) = ps(j) ! transit to 3-space 
      enddo
      ps(4) = 0.d0
      ps(5) = 0.d0
c      print*,'*****************  '
c      print*,' ps(x y z) ',(ps(j),j=1,3) 
c      print*,' l1/l0     ',( (l1(j)/l1(4)),j=1,3)
      return
      end
c----------------------------------------------------------------------------c
      integer function kqw(iq)
* transform quark number for d/dbar, s/sbar, b/bbar into numer of tWq        *
* d/dbar : 1, s/sbar : 2, b/bbar : 3     
c----------------------------------------------------------------------------c
      implicit none
      integer iq, ks(-5:5)
*            -5 -4 -3 -2 -1  0  1  2  3  4  5
      data ks/3, 0, 2, 0, 1, 0, 1, 0, 2, 0, 3/
*
      kqw = ks(iq)
      return
      end
c----------------------------------------------------------------------------c
*  author : Serge Slabospitsky   30.05.2006                                  *
*  matrix element for FCNC top production:  2 -> 1                           *
*  g(p1)  U/C(p2) --> t* -> b W* -> b(p3) L+(p5) nu(p4)                      *
*  averaged on initial spins and colors                                      *
*............................................................................*

      subroutine tfcnc_SM(iu, p1, p2, p3, p5, p4, ves)
      implicit none
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision  p1(5), p2(5)     ! momenta of initial gluon and u-quark
      double precision  p3(5), p5(5), p4(5)   ! momenta of b, L+, nu 
      double precision Ves, coef, ckm 
      integer iu, iqf ! initial quark (u or c)
      integer isu  ! = -1 for q2 < 0
*
      LOGICAL first
      SAVE first, coef
      DATA first /.TRUE./
      double precision VCKM
      common  /CKMD/ VCKM(-6:6,-6:6) ! CKM**2
*......... 
      double precision eg(5),x1(5),x2(5),x3(5)
      double complex ux1, ux2, ux3, veg(4,4),
     & UP2(2,4), UBP3(2,4), WB(4,4), PR1(4,4),PR2(4,4),PR3(4,4),
     & UG1(4,4), ug2(4,4), ug3(4,4), um1(4,4), um2(4,4)
      integer I,ig,i2,i3
*..RPAR(10)     : 0.38939d0     transformation 1/GeV**2 to mb                *
*..RPAR(26)     : g = g_weak  = e / sin(theta_W)                             *
*..Rpar(36)     : M(top) * width(total top)                                  *
*............................................................................*
      IF(first) THEN        ! initializing
       coef = rpar(10) * rpar(26)**4       ! W-exchange
       coef = coef / (3.d0 * 8.d0 * 4.d0) 
       coef = coef * 9.d0     ! 9.d0 is due to sum over leptons and quarks
      first=.FALSE.
      print*,'Vub Vcb ',dsqrt(vckm(2,5)), dsqrt(vckm(4,5))

      ENDIF
       ckm = dsqrt(vckm(iu,5))
        iqf = 0
        if(iu.eq.2) iqf = 1
        if(iu.eq.4) iqf = 2
      do I=1,4
       x1(i) =  p3(i) - p1(i)
       x2(i) =  p1(i) + p2(i)
       x3(i) =  x2(i)
      enddo
       x1(5) = p3(5)
       x2(5) = p2(5)
       x3(5) = mq(6)
       call PropF(x1, PR1)
       call PropF(x2, PR2)
       call PropF2(rpar(36), x3, PR3)

       call VbosMX(p4, p5, WB)

      call Dirs2_Ubar(p3, UBP3)
      call Dirs2_U   (p2, UP2)

*
      ves = 0.d0
      do ig = 1,2
       call VpolGAM(IG, isu,  p1, eg)
       call phat(eg, Veg)
       call prod_2(veg, PR1, UM1)
       call prod_2(UM1, WB, UG1)   ! t1
       call prod_2(PR2, Veg, UM1)
       call prod_2(WB,  UM1, UG2)  ! t2
* t3
       call Q_GLU_T(iqf, x2, p1, eg, UM2)
       call prod_2(WB, PR3, UM1)
       call prod_2(UM1, UM2, UG3) 
*
      do i2 = 1,2
      do i3 = 1,2
        call Ubar_m_U(i3, i2, UBP3, UP2, UG1, UX1)
        call Ubar_m_U(i3, i2, UBP3, UP2, UG2, UX2)
        call Ubar_m_U(i3, i2, UBP3, UP2, UG3, UX3)
        UX1 = ux1 * ckm
        UX2 = ux2 * ckm
       if(Ipar(26).eq.0) then 
          ves = ves + (ux1+ux2+ux3) * conjg(ux1+ux2+ux3)
       elseif(Ipar(26).eq.1) then 
          ves = ves + (ux1+ux2) * conjg(ux1+ux2)
       elseif(Ipar(26).eq.2) then 
          ves = ves + ux3 * conjg(ux3)
       endif
      enddo
      enddo
      enddo
***
 999   ves = ves * coef * rpar(16)  ! * dn3
      if(ves.le.0.d0) then
        print*,'========================'
      endif

      return
      end
*----------------------------------------------------------------------------*
*  author : Serge Slabospitsky   30.05.2006                                  *
*  matrix element for FCNC top production:  2 -> 1                           *
*  g(p1)  U/C(p2) --> t* -> b W* -> b(p3) L+(p5) nu(p4)                      *
*  averaged on initial spins and colors                                      *
*............................................................................*

      subroutine tfcnc_00(iu, pg, ptop, ves, hv)
      implicit none
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision  pg(5), ptop(5)   ! momenta of initial gluon and u-quark
      double precision  mt 
      double precision Ves, coef 
      integer iu, iqf, j
*
      LOGICAL first
      SAVE first, coef
      DATA first /.TRUE./
*......... 
      double precision hv(4), sp(4), sq, vh(3,4)
      double precision H0(2), X0(2), B0(2), AH(2), AX(2), AB(2)
      double complex   FL,     FR,      HL,    HR,
     &                 XL,     XR,      YL,    YR
      common /ANOMCPL/FL(20), FR(20), HL(20), HR(20), 
     &                XL(20), XR(20), YL(20), YR(20) 
*..RPAR(10)     : 0.38939d0     transformation 1/GeV**2 to mb                *
*............................................................................*
      IF(first) THEN        ! initializing
       coef = rpar(10) 
       coef = coef / (3.d0 * 8.d0 * 2.d0) 
       first=.FALSE.
       do j = 11,12
        iqf = j - 10
        H0(iqf) = HR(j)*conjg(HR(j)) + HL(j)*conjg(HL(j))
        X0(iqf) = XR(j)*conjg(XR(j)) + XL(j)*conjg(XL(j))
        B0(iqf) = HL(j)*conjg(XL(j)) + XL(j)*conjg(HL(j))
     &          + HR(j)*conjg(XR(j)) + XR(j)*conjg(HR(j))
*
        AH(iqf) = HL(j)*conjg(HL(j)) - HR(j)*conjg(HR(j))
        AX(iqf) = XL(j)*conjg(XL(j)) - XR(j)*conjg(XR(j))
        AB(iqf) = HL(j)*conjg(XL(j)) + XL(j)*conjg(HL(j))
     &          - HR(j)*conjg(XR(j)) - XR(j)*conjg(HR(j))
       enddo
      ENDIF
        iqf = 0
        if(iu.eq.2) iqf = 1
        if(iu.eq.4) iqf = 2
      mt = ptop(5)
      ves = 16.d0 * H0(iqf) + mt**2 * X0(iqf) - 4.d0*mt*B0(iqf)

       sq = 16.d0 * AH(iqf) + mt**2 * AX(iqf) - 4.d0*mt*AB(iqf)
      do j=1,4
       sp(j) = sq * 2.*pg(j) / mt / ves
      enddo

      call vortas(ptop, vh)
       do j = 1,3
        hv(j) = -(sp(4)*vh(j,4) - sp(1)*vh(j,1) - sp(2)*vh(j,2) 
     &                          - sp(3)*vh(j,3))
       enddo
*
      ves = ves * coef * mt**4 * rpar(16)
      return
      end
*----------------------------------------------------------------------------*
* FCNC vertex  :  q - gluon - top                                            *
* iu FCNC-q-type (1-u, 2-t), q - gluon momentum (ON and OFF shell), k - quark* 
* FINAL TOP quark,    return three complex matrices M1, M2, M3               *
* vertex is parametrize as follows V^mu = gamma^mu.M1 + k^mu.M2 + q^mu.M3    *
* eg is gluon polarization vector, veg = (gamma_nu . eg_nu)                  *
* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .*
      subroutine Q_GLU_T(iuu, p, q, eg, VRT)
*     ----------------------------------------------
      implicit none
      double precision q(5), p(5), scalp, pq, q2, eg(5), egq, egp
      double complex   FL,     FR,      HL,    HR,
     &                 XL,     XR,      YL,    YR
      common /ANOMCPL/FL(20), FR(20), HL(20), HR(20), 
     &                XL(20), XR(20), YL(20), YR(20) 
      integer IU, i1, i2, iuu
      double complex M1(4,4),M2(4,4),M3(4,4), VRT(4,4),VEG(4,4),hq(4,4)
      integer jk1,jk2
*
      do jk1 = 1,4
      do jk2 = 1,4
        M1(jk1,jk2) = (0.d0, 0.d0)
        M2(jk1,jk2) = (0.d0, 0.d0)
        M3(jk1,jk2) = (0.d0, 0.d0)
        VRT(jk1,jk2) = (0.d0, 0.d0)
      enddo
      enddo
*
      call phat(q, hq)
      call phat(eg, Veg)
      iu = 10 + iuu
*
*  M1
       q2  = scalp(q, q)
       pq =  scalp(q, p)
       do i1 = 1,2
         M1(i1,i1)         = -pq * XR(iu) - q2 * YR(iu)
         M1((i1+2),(i1+2)) = -pq * XL(iu) - q2 * YL(iu)
        do i2 = 3,4
         M1(i1,i2) = -2.d0*HL(iu) * hq(i1, i2)
         M1(i2,i1) = -2.d0*HR(iu) * hq(i2, i1)
        enddo
       enddo
* M2
       do i1 = 1,2
        do i2 = 3,4
         M2(i1,i2) = XL(iu) * hq(i1, i2)
         M2(i2,i1) = XR(iu) * hq(i2, i1)
        enddo
       enddo
* M3
       do i1 = 1,2
         M3(i1,i1)         = 2.d0 * HR(iu) 
         M3((i1+2),(i1+2)) = 2.d0 * HL(iu) 
        do i2 = 3,4
         M3(i1,i2) = YL(iu) * hq(i1, i2)
         M3(i2,i1) = YR(iu) * hq(i2, i1)
        enddo
       enddo

      call prod_2(veg, M1, VRT)
      egp = scalp(eg, p)
      egq = scalp(eg, q)
       do i1 = 1,4
       do i2 = 1,4
         VRT(i1,i2) = VRT(i1, i2) + egp * M2(i1,i2) + egq * M3(i1,i2)
       enddo
       enddo
      return
      end
*----------------------------------------------------------------------------*
* FCNC vertex  :  q - gluon gamma - top                                      *
* iu FCNC-q-type (1-u, 2-t), q - gluon momentum (ON and OFF shell), k - quark* 
* FINAL TOP quark,                                                           *
* PG and EG are incoming gluon  momentum and polarization vector             *
* PF and EF are incoming photon momentum and polarization vector             *
* 2/3 in NOT included                                                        *
* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .*
      subroutine Q_GLU_GAM_T(iu, pg, pf, eg, ef, VRT)
*     ----------------------------------------------
      implicit none
      double precision pg(5), pf(5), eg(5), ef(5), scalp, u1, u2
      double complex   C_HR,   C_HL,   C_XR,   C_TR,   C_XL,   C_TL
      common /ruiped2/ C_HR(2),C_HL(2),C_XR(2),C_TR(2),C_XL(2),C_TL(2)
      integer IU, j8,j9 
      double complex VRT(4,4), M1(4,4), hpg(4,4), hef(4,4)
*
      do j8 = 1,4
      do j9 = 1,4
        VRT(j8,j9) = (0.d0, 0.d0)
      enddo
      enddo
*
      call phat(pg, hpg)
      call phat(ef, hef)
*
      u1 = -scalp(eg, ef)
      u2 = +scalp(pg, ef)
*
      call matr_add_RR(u1, hpg, u2, hef, m1)
      call matr_A_FRL(C_XR(iu), C_XL(iu), m1, VRT) 
*
      return
      end
*----------------------------------------------------------------------------*
* V = A * (FR.R + FL.L)
      subroutine matr_A_FRL(FR, FL, A, V)
*     ------------------------------------------------------------
      double complex FR, FL, A(4,4), V(4,4)
      integer i1, i2
*
      do i1 = 1,4
       do i2 = 1,2
        V(i1,  i2)    = FR * A(i1,  i2)
        V(i1, (i2+2)) = FL * A(i1, (i2+2)) 
       enddo
      enddo
      return
      end
*----------------------------------------------------------------------------*
*  author : Serge Slabospitsky   06.06.2006                                  *
*  FCNC_02 process: g   g   -> g    top                                      *
*     momenta:      p1  p2     p3   p4                                       *
*     spinors:                 DS3  DS4                                      * 
*  for T only, not for Tbar. However, IT = -6 is used for T-polar. evaluation*
* => iq1 should be POSITIVE                                                  *
*  averaged on initial spins and colors                                      *
*............................................................................*

      subroutine tfcnc_02(iq3, idia, p1, p2, p3, p4, ves, hv)
      implicit none
      include "txpar.inc" 
      double precision p1(5), p2(5)       ! momenta of initial quarks
      double precision p3(5), p4(5)       ! momenta of Y and top 
      double precision Ves,coef, hv(4),x3,
     & s,s2,s3,s4, t,t2, t3,t4,ZZ, 
     & mt,mt2,mt4,mt6,mt8,mt10,mt12, 
     & y1, y2, sp(4), vh(3,4), aran,pyr,uu

      LOGICAL first
      SAVE first, coef
      DATA first /.TRUE./
      double complex   FL,     FR,      HL,    HR,
     &                 XL,     XR,      YL,    YR
      common /ANOMCPL/FL(20), FR(20), HL(20), HR(20), 
     &                XL(20), XR(20), YL(20), YR(20) 
      double complex AR, AL, U0(2), UP(2)
      save U0, UP
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer iq3,idia,iqf, j

*............................................................................*
      IF(first) THEN        ! initializing
        coef = rpar(10) ! transformation 1/GeV**2 to mb 
        coef = coef / 4.d0 ! due to lambda_a
*        coef = coef / (2.d0*2.d0 * 8.d0*8.d0) included 
        mt = mq(6)
        mt2 = mt**2
        mt4 = mt**4
        mt6 = mt**6
        mt8 = mt**8
       mt10 = mt**10
       mt12 = mt**12
        iqf = 11
       AR = mt*XR(iqf) - 4.d0*HR(iqf)
       AR = AR * conjg(AR)
       AL = mt*XL(iqf) - 4.d0*HL(iqf)
       AL = AL * conjg(AL)

       U0(1) = AR + AL
       UP(1) = AR - AL
        iqf = 12
       AR = mt*XR(iqf) - 4.d0*HR(iqf)
       AR = AR * conjg(AR)
       AL = mt*XL(iqf) - 4.d0*HL(iqf)
       AL = AL * conjg(AL)

       U0(2) = AR + AL
       UP(2) = AR - AL

       print*,'  Contributed code:   '
       print*,'  Rui Santos and Pedro Ferreira --> '
       print*,'  FCNC top-gluon-quark interaction '
       print*,'                     '
 
       first=.FALSE.
      ENDIF
      ves = 0.d0

        if(abs(iq3).eq.2) iqf = 1
        if(abs(iq3).eq.4) iqf = 2
*
********************

       s = (p1(4) + p2(4))**2 - (p1(1) + p2(1))**2
     &   - (p1(2) + p2(2))**2 - (p1(3) + p2(3))**2
       t = (p1(4) - p4(4))**2 - (p1(1) - p4(1))**2
     &   - (p1(2) - p4(2))**2 - (p1(3) - p4(3))**2
 
       s2 = s**2
       s3 = s**3
       s4 = s**4
       t2 = t**2
       t3 = t**3
       t4 = t**4

      ZZ = s*(mt2 - t)**2*t*(s+t)**2 * (s + t - mt2) 


      X3 =  2.d0*(4.d0*s2 + 9.d0*t*s + 9.d0*t2)* mt12
     &  - 4.d0*(s + 2*t)*(4*s2 + 9*t*s + 9*t2)*mt10
     & + 4*(s + 2*t)*(3*s3 + 14*t*s2 + 27*t2*s
     & + 18*t3)*mt8
     &-(s+t)*(4*s4 + 45*t*s3 + 157*t2*s2
     &+ 270*t3*s + 180*t4)* mt6
     & + t*(s+t)*(19*s4 + 104*t*s3 + 233*t2*s2
     &  + 288*t3*s + 144*t4)*mt4
     &-3*t2*(s+t)**2*(10*s3 + 27*t*s2 + 36*t2*s + 24*t3)*mt2
     &+3.d0*t3*(s+t)**3*(5.d0*s2 + 6.d0*t*s + 6.d0*t2)

      X3 = X3 * U0(iqf) 

      do J = 1,4
       y1 = p1(j)
       y2 = p2(j)

      sp(j) = 
     &- 2.d0*(2.d0*Y1 + Y2)*(4.d0*s2 + 9.d0*t*s + 9.d0*t2)*mt10 
     &+ ( (24.d0*Y1 + 7.d0*Y2)*s3 + (110.d0*Y1+23.d0*Y2)*t*s2 
     &+ 36.d0*(5.d0*Y1+Y2)*t2*s + 18.d0*(7.d0*Y1+2.d0*Y2)*t3)*mt8 
     &- ( 17.d0*Y1*s4 + 3.d0*(40.d0*Y1-3.d0*Y2)*t*s3 
     &   +(317.d0*Y1-19.d0*Y2)*t2*s2 
     &   +396.d0*Y1*t3*s + 18.d0*(11.d0*Y1+Y2)*t4)*mt6 
     &+ (s+t)*(8.d0*Y1*s4 + (68.d0*Y1-21*Y2)*t*s3 
     &   + 4.d0*(53.d0*Y1 - 11.d0*Y2)*t2*s2 
     &  + 18.d0*(17.d0*Y1-2.d0*Y2)*t3*s 
     & + 18.d0*(10.d0*Y1-Y2)*t4)*mt4 
     &- t*(s + t)*( 23.d0*Y1*s4 
     & + (107.d0*Y1-20.d0*Y2)*t*s3 + 15.d0*(14.d0*Y1-3.d0*Y2)*t2*s2 
     & + 54.d0*(4.d0*Y1-Y2)*t3*s + 18.d0*(5.d0*Y1-2.d0*Y2)*t4)*mt2
     &+ 3.d0*t2*
     & (s + t)**2*(s*Y1+(Y1-Y2)*t)*(5.d0*s2+6.d0*t*s+6.d0*t2)

      sp(j) = UP(iqf) * mt * sp(j) / x3 
      enddo

      call vortas(p4, vh)
       do j = 1,3
        hv(j) = -(sp(4)*vh(j,4) - sp(1)*vh(j,1) - sp(2)*vh(j,2) 
     &                            - sp(3)*vh(j,3))
       enddo

      ves = X3 * coef * rpar(16)**2  / 48.d0 / ZZ

      UU = abs(mt2 - s - t)
      idia = 1
      aran = pyr(0)*(abs(t) + UU)
       if(aran.le.uu) then
        idia = 1
       else
        idia = 2
       endif


      if(iq3.gt.0) ves = -ves
*
      if(ves.le.0.d0) then
       print*,'NEGATIVE  ves x3 ',ves,x3
*      else 
*       print*,'positive  ves x3 ',ves,x3
      endif
      return
      end
*----------------------------------------------------------------------------*
*  author : Serge Slabospitsky   06.06.2006                                  *
*  FCNC_02 process: g   g   -> g    top                                      *
*     momenta:      p1  p2     p3   p4                                       *
*     spinors:                 DS3  DS4                                      * 
*  for T only, not for Tbar. However, IT = -6 is used for T-polar. evaluation*
* => iq1 should be POSITIVE                                                  *
*  averaged on initial spins and colors                                      *
*............................................................................*

      subroutine tfcnc_03(iq3, idia, p1, p2, p3, p4, ves, hvv)
      implicit none
      include "txpar.inc" 
      double precision p1(5), p2(5)       ! momenta of initial quarks
      double precision p3(5), p4(5)       ! momenta of Y and top 
      double precision Ves,coef, hvv(4),x3, 
     & s,s2,s3,s4,s5, t,t2, t3,t4,t5,ZZ, 
     & mt,mt2,mt3,mt4,mt6,mt7,mt8,mt9,mt10,mt12, mt14, 
     & y1, y2, sp(4), vh(3,4), aran,pyr,uu

      LOGICAL first
      SAVE first, coef
      DATA first /.TRUE./
      double complex   FL,     FR,      HL,    HR,
     &                 XL,     XR,      YL,    YR
      common /ANOMCPL/FL(20), FR(20), HL(20), HR(20), 
     &                XL(20), XR(20), YL(20), YR(20) 
      double complex U0(2), UP(2), AR, AL

      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer iq3,idia,iqf, j

*............................................................................*
      IF(first) THEN        ! initializing
        coef = rpar(10) ! transformation 1/GeV**2 to mb 
        coef = coef / 4.d0 ! due to lambda_a
        coef = coef * 8.d0 / 3.d0
*        coef = coef / (2.d0*2.d0 * 8.d0*3.d0) included 
        mt = mq(6)
        mt2 = mt**2
        mt3 = mt**3
        mt4 = mt**4
        mt6 = mt**6
        mt7 = mt**7
        mt8 = mt**8
        mt9 = mt**9
       mt10 = mt**10
       mt12 = mt**12
       mt14 = mt**14

        iqf = 11
       AR = mt*XR(iqf) - 4.d0*HR(iqf)
       AR = AR * conjg(AR)
       AL = mt*XL(iqf) - 4.d0*HL(iqf)
       AL = AL * conjg(AL)
        U0(1) = AR + AL
        UP(1) = AR - AL
*
        iqf = 12
       AR = mt*XR(iqf) - 4.d0*HR(iqf)
       AR = AR * conjg(AR)
       AL = mt*XL(iqf) - 4.d0*HL(iqf)
       AL = AL * conjg(AL)
        U0(2) = AR + AL
        UP(2) = AR - AL
 
       print*,'  Contributed code:   '
       print*,'  Rui Santos and Pedro Ferreira --> '
       print*,'  FCNC top-gluon-quark interaction '
       print*,'                     '

       first=.FALSE.
      ENDIF
      ves = 0.d0

        if(abs(iq3).eq.2) iqf = 1
        if(abs(iq3).eq.4) iqf = 2
*

       s = (p1(4) + p2(4))**2 - (p1(1) + p2(1))**2
     &   - (p1(2) + p2(2))**2 - (p1(3) + p2(3))**2
       t = (p1(4) - p4(4))**2 - (p1(1) - p4(1))**2
     &   - (p1(2) - p4(2))**2 - (p1(3) - p4(3))**2
 
       s2 = s**2
       s3 = s**3
       s4 = s**4
       s5 = s**5
       t2 = t**2
       t3 = t**3
       t4 = t**4
       t5 = t**5
       ZZ = (mt2-s)**2*s*(mt2-t)**2*t*(s+t-mt2)


       X3 = 4*(s+t)*mt14 - (8*s2 + 37*t*s + 8*t2)*mt12 
     & + 4*(s+t)*(2*s2 + 21*t*s + 2*t2)*mt10 
     & - 2*(4*s4 + 53*t*s3 + 109*t2*s2 + 53*t3*s + 4*t4)*mt8 
     & + 2*(s+t)*(2*s4 + 31*t*s3 + 86*t2*s2 + 31*t3*s + 2*t4)*mt6 
     & - s*t*(19*s4 + 122*t*s3 + 221*t2*s2 + 122*t3*s + 19*t4)*mt4 
     & + 6*s2*t2*(s+t)*(5*s2 + 9*t*s + 5*t2)*mt2 
     & - 3*s3*t3*(5*s2 + 4*t*s + 5*t2)
       X3 = X3 * U0(iqf)

      do J = 1,4
       y1 = p1(j)
       y2 = p2(j)
       sp(j) = (8.d0*mt2 - 15*s)*(mt2 -s)*(Y1 +Y2)*t5 
     & - ( 23*(Y1+Y2)*mt6 -s*(58*Y1 + 79*Y2)*mt4 
     &     +20*s2*(2*Y1+3*Y2)*mt2 + 3*s3*(Y1-4*Y2))*t4 
     & + ((29*Y1 + 36*Y2)*mt8 - 3*s*(21*Y1 + 46*Y2)*mt6 
     & + s2*(47*Y1 + 146*Y2)*mt4-75*s3*Y2*mt2 + 3*s4*(Y1+ 5*Y2))*t3 
     &- ((21*Y1+34*Y2)*mt10 -s*(35*Y1 + 132*Y2)*mt8 + 169*s2*Y2*mt6 
     &+ s3*(47*Y1-99*Y2)*mt4 + 20*s4*(Y2-2*Y1)*mt2 + 15*s5*Y1)*t2 
     & + mt2*(mt2-s)*((7*Y1+12*Y2)*mt8 + s*(7*Y1-43*Y2)*mt6 
     & + 2*s2*(27*Y2-14*Y1)*mt4 + 7*s3*(5*Y1-3*Y2)*mt2 - 23*s4*Y1)*t 
     & + mt4*(mt2-s)**2*(Y2*mt6 + 7.d0*s*(Y2 -Y1)*mt4+7*s2*Y1*mt2
     & -8.d0*s3*Y1)

      sp(j) = UP(iqf) * mt * sp(j) / x3 
      enddo

      call vortas(p4, vh)
       do j = 1,3
        hvv(j) = -(sp(4)*vh(j,4) - sp(1)*vh(j,1) - sp(2)*vh(j,2) 
     &                          - sp(3)*vh(j,3))
       enddo

      ves = X3 * coef * rpar(16)**2  / 48.d0 / ZZ

      UU = abs(mt2 - s)
      idia = 1
      aran = pyr(0)*(abs(t) + UU)
       if(aran.le.uu) then
        idia = 2
       else
        idia = 1
       endif


      if(iq3.gt.0) ves = -ves
*
      if(ves.le.0.d0) then
       print*,'NEGATIVE  ves x3 ',ves,x3
*      else 
*       print*,'positive  ves x3 ',ves,x3
      endif
      return
      end
*----------------------------------------------------------------------------*
*  author : Serge Slabospitsky   07.06.2006                                  *
*  FCNC_04 process: g   q   -> gamma  top                                    *
*     momenta:      p1  p2     p3     p4                                     *
*     spinors:          DS2           DS4                                    * 
*  for T only, not for Tbar. However, IT = -6 is used for T-polar. evaluation*
* => iq1 should be POSITIVE                                                  *
*  averaged on initial spins and colors                                      *
*............................................................................*

      subroutine tfcnc_04(iq2, idia, p1, p2, p3, p4, ves, hr)
      implicit none
      include "txpar.inc" 
      double precision p1(5), p2(5)       ! momenta of initial gluon and quark 
      double precision p3(5), p4(5)       ! momenta of photon  and top 
      double precision x1(5), x2(5), km(5)  
      double precision Ves,coef,eg(5),ef(5),
     & hr(4), xt1, xt2,  pyr, aran
      integer iq2, iqf, i1,i2,i3,i4, idia, is1       ! top mother
      integer j5,j6,j7,j8
      double complex T1(2,2,2,2), T2(2,2,2,2), T3(2,2,2,2) 

      double complex veg(4,4), vef(4,4), 
     & PR1(4,4), PR2(4,4), DS2(2,4), DS4(2,4), 
     & VRT(4,4), UU1(4,4), UU2(4,4), UM1(4,4), UM2(4,4), U0,U1,U2
      LOGICAL first
      SAVE first, coef
      DATA first /.TRUE./
      double complex ei 
      data ei/(0.d0, 1.d0)/
*............................................................................*
      IF(first) THEN        ! initializing
        coef = rpar(10) ! transformation 1/GeV**2 to mb 
        coef = coef / (2.d0*2.d0 * 8.d0*3.d0) 
        coef = 4.d0 * coef * (Rpar(13)*2.d0/3.d0)**2
       first=.FALSE.
      ENDIF
      ves = 0.d0
       if(iq2.lt.0) return
        if(abs(iq2).eq.2) iqf = 1
        if(abs(iq2).eq.4) iqf = 2
*
      do j5 = 1,4
       do j6 = 1,4
        PR1(j5, j6) = (0.d0, 0.d0)
        PR2(j5, j6) = (0.d0, 0.d0)
       enddo
      enddo
*
      do 123 j5 = 1,2
      do 123 j6 = 1,2
      do 123 j7 = 1,2
      do 123 j8 = 1,2
       T1(j5,j6,j7,j8) = (0.d0, 0.d0)
       T2(j5,j6,j7,j8) = (0.d0, 0.d0)
 123   T3(j5,j6,j7,j8) = (0.d0, 0.d0)
        do i1 = 1,4
         x1(i1) = p2(i1) - p3(i1)
         x2(i1) = p1(i1) + p2(i1)
         km(i1) = -p3(i1) ! for vertex evaluation
        enddo
*
       call Dirs2_Ubar(p4, DS4) ! top 
       call Dirs2_V   (p2, DS2)
*
       x1(5) = p2(5)        !  up
        call Propf(x1, PR1)
       x2(5) = p4(5)        ! top
        call Propf(x2, PR2) ! top
      
       do 11 i1 = 1,2
        call VpolGAM(I1, is1, p1, eg)
        call phat(eg, Veg)
*
        call Q_GLU_T(iqf, p4, p1, eg, VRT)
        call prod_2(vrt, pr1, UU1)
*
        call Q_GLU_T(iqf, x2, p1, eg, VRT)
        call prod_2(PR2, vrt, UU2)
       do 11 i3 = 1,2
        call VpolGAM(I3, is1, p3, ef)
        call phat(ef, Vef)
         call prod_2(UU1, VeF, UM1)
         call prod_2(vef, UU2, UM2)
        call Q_GLU_GAM_T(iqf, p1, km, eg, ef, VRT)
       do 11 i2 = 1,2
       do 11 i4 = 1,2
        call Ubar_m_U(i4, i2, DS4, DS2, UM1, U0)
         T1(i1,i2,i3,i4) = T1(i1,i2,i3,i4) + U0
        call Ubar_m_U(i4, i2, DS4, DS2, UM2, U0)
         T2(i1,i2,i3,i4) = T2(i1,i2,i3,i4) + U0
        call Ubar_m_U(i4, i2, DS4, DS2, VRT, U0)
         T3(i1,i2,i3,i4) = T3(i1,i2,i3,i4) + U0
 11   continue
*
       ves = 0.d0
       xt1 = 0.d0
       xt2 = 0.d0
      do 12 i1 = 1,2
      do 12 i2 = 1,2
      do 12 i3 = 1,2
      do 12 i4 = 1,2
       U1 = T1(i1,i2,i3,i4)+T2(i1,i2,i3,i4)+T3(i1,i2,i3,i4)
       ves = ves + U1 * conjg(u1)
       xt1 = xt1 + T1(i1,i2,i3,i4)*conjg(T1(i1,i2,i3,i4))
       xt2 = xt2 + T2(i1,i2,i3,i4)*conjg(T2(i1,i2,i3,i4))
 12   continue
      aran = pyr(0)*(xt1+xt2) 
       idia = 1 
       if(aran.gt.xt1) idia = 2
* polarization
      do i1 = 1,4
       hr(i1) = 0.d0
      enddo
      do 14 i1 = 1,2
      do 14 i2 = 1,2
      do 14 i3 = 1,2
       U1 = T1(i1,i2,i3,1)+T2(i1,i2,i3,1)+T3(i1,i2,i3,1)
       U2 = T1(i1,i2,i3,2)+T2(i1,i2,i3,2)+T3(i1,i2,i3,2)
       hr(1) = hr(1) + (U1+U2) * conjg((U1+U2))
**
       hr(2) = hr(2) + (U1-ei*U2) * conjg((U1-ei*U2))
**
       hr(3) = hr(3) + 2.d0 * U1 * conjg(U1)
 14   continue
      do i1 = 1,3
       hr(i1) = (ves - hr(i1)) / ves
      enddo

* Top or TOPbar will be considered in top decay routines
      ves = ves * coef * rpar(16) 
      return
      end
*----------------------------------------------------------------------------*
      subroutine tfcnc_01dd(iq1, iq2, iq3, imt, p1, p2, p3, p4,ves,hv)
      implicit none
      include "txpar.inc" 
      double precision  p1(5), p2(5)       ! momenta of initial quarks
      double precision  p3(5), p4(5)       ! momenta of Y and top 
      double precision s,t,mt,mt2,mt4,mt6,  epsl(5)
      double complex   FL,     FR,      HL,    HR,
     &                 XL,     XR,      YL,    YR
      common /ANOMCPL/FL(20), FR(20), HL(20), HR(20), 
     &                XL(20), XR(20), YL(20), YR(20) 
      double complex alctCR, alctR, altcR, altcCR, alctCL, alctL,
     &  altcL, altcCL, betc, betcC, bectC, bect
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer iq1, iq2, iq3, imt, iqf, J
      double complex U0, U1, a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,
     & a11,a12,a13,a14,
     & b1,b2,b3,b4,b5,b6,b7,b8,b9,b10,
     & b11,b12,b13,b14,b15,b16,b17,b0, egr
      double precision ves, coef, s2,t2, sat, mt2sm,
     & sp(4), vh(3,4), hv(4)
      double complex ei 
      data ei/(0.d0, 1.d0)/
      LOGICAL first
      SAVE first, coef, mt,mt2,mt4,mt6
      DATA first /.TRUE./
*******
      IF(first) THEN        ! initializing
        coef = rpar(10) ! transformation 1/GeV**2 to mb 
        coef = coef / (2.d0*2.d0 * 3.d0*3.d0) 
        mt = mq(6)
        mt2 = mt**2
        mt4 = mt**4
        mt6 = mt**6
       print*,'  Contributed code:   '
       print*,'  Rui Santos and Pedro Ferreira --> '
       print*,'  FCNC top-gluon-quark interaction '
       print*,'                     '
       first=.FALSE.
      ENDIF
*
           if(abs(iq3).eq.2) iqf = 11
           if(abs(iq3).eq.4) iqf = 12
*
       s = (p1(4) + p2(4))**2 - (p1(1) + p2(1))**2
     &   - (p1(2) + p2(2))**2 - (p1(3) + p2(3))**2
       s2 = s * s
  
       t = (p1(4) - p4(4))**2 - (p1(1) - p4(1))**2
     &   - (p1(2) - p4(2))**2 - (p1(3) - p4(3))**2
       t2 = t * t
       sat = s + t
       mt2sm = mt2 - S
*
*      print*,'iqf ',iqf
*      print*,'HR HL ',HR(iqf),HL(iqf)
*      print*,'XR XL ',XR(iqf),XL(iqf)
*      print*,'YR YL ',YR(iqf),YL(iqf)



       alctCR = XR(iqf) + YR(iqf) ! C_TR(iqf)
       alctR  = conjg(alctCR)

       altcR  = - YR(iqf)         ! C_XR(iqf) - C_TR(iqf)
       altcCR = conjg(altcR)

       alctCL =  XL(iqf) + YL(iqf) ! C_TL(iqf)
       alctL  = conjg(alctCL)

       altcL  = - YL(iqf)          ! C_XL(iqf) - C_TL(iqf)
       altcCL = conjg(altcL)

       betc   = -ei*HR(iqf)        ! C_HR(iqf)
       betcC  = conjg(betc)
       bectC  = -ei*HL(iqf)        ! C_HL(iqf)
       bect   = conjg(bectC)

********************

      U1 =  mt4 - 2.d0*sat*mt2 + s2 + 2.d0*t2 + 2*s*t
      A1 = -2.d0*alctCR*altcCR * (mt2+s)* U1 

      A2 = -2.d0*alctCR*alctR *
     &mt2sm*((mt2 + s)**2 + 2.d0*t2 - 2.d0*(mt2 - s)*t)

      A3 = -8.d0*ei*alctCR*betcC * mt*(mt4-2.d0*t*mt2-s2+2.d0*t*sat) 
      A4 = -2.d0*altcCR*altcR*mt2sm* U1

      A5 =  8.d0*ei*altcCR*betc * mt      * U1
      A6 = -2.d0*alctR*altcR    * (mt2+s) * U1
      A7 = -8.d0*ei*altcR*betcC * mt      * U1
      A8 =  8.d0*ei*alctR *betc * mt*(mt4-2.d0*t*mt2-s2+2.d0*t*sat)
      A9 = -2.d0*alctCL*altcCL   * (mt2+s) * U1 

      A10 = -2.d0*alctCL*alctL*mt2sm*((mt2+s)**2+2.d0*t2
     & -2.d0*mt2sm*t)

      A11 = -8.d0*ei*alctCL*bect*mt*(mt4-2.d0*t*mt2-s2+2.d0*t*(s + t))
      A12 = (-2.d0*altcCL*altcL*(mt2 - s) 
     &    +   8.d0*ei*altcCL*bectC* mt 
     &    -   2.d0*alctL*altcL*(mt2+s)
     &    -   8.d0*ei*altcL*bect* mt    ) * U1

      A13 =  8.d0*ei*alctL*bectC*mt*(mt4-2.d0*t*mt2-s2 + 2.d0*t*sat)
      A14 = -32.d0*(bect*bectC + betc*betcC) *
     & (mt4-(s+2.d0*t)*mt2 + 2.d0*t*sat)

      U0 = a1+a2+a3+a4+a5+a6+a7+a8+a9+a10+a11+a12+a13+a14 

*** polarization
      
      call epsil3(p4, p1, p2, EPSL)

      do J = 1,4
      EGR =  -2.d0*ei*(mt2 - s - 2.d0*t)*EPSL(j)
      B1 = 4.d0 * alctCR * altcCR * mt *
     & ((mt2-s)*(P1(J)*mt2-P1(J)*t + P2(J)*(s+t)) + EGR)

      B2 = 4.d0 * alctCR * alctR * mt *
     & (4.d0*P2(J)*t*mt2 - 2.d0*(P1(J)+P2(J))*t2 
     &  + (mt4-s2)*(P1(J)-P2(J)) - 4.d0*s*P1(J)*t)

      B3 = 8.d0 * ei * alctCR * betcC * 
     &( (2.d0*P1(J)-P2(J))*mt4 
     & + (-s*P1(J) - t*P1(J) + s*P2(J) + 5.d0*P2(J)*t)*mt2
     & -  (s + 2.d0*t)*(s*P1(J) + (P1(J) + P2(J))*t) + EGR )

      B4 = 4.d0 * altcCR * altcR * mt *
     & (P1(J) + P2(J))*(mt4 - 2.d0*(s+t)*mt2 + s2 + 2.d0*t2 + 2.d0*s*t)

      B5 = - 8.d0 * ei * altcCR * betc * 
     & ((2.d0*P1(J) + P2(J))*mt4 - (3.d0*P1(J) + P2(J))*(s+t)*mt2 
     & + (s + 2.d0*t)*(s*P1(J) + (P1(J) + P2(J))*t) + EGR)

      B6 = 4.d0 * alctR * altcR * mt *
     & ((mt2 - s)*(P1(J)*mt2 - P1(J)*t + P2(J)*(s + t)) - EGR)

      B7 = 8.d0*ei * altcR * betcC * 
     & ((2.d0*P1(J) + P2(J))*mt4 - (3.d0*P1(J) + P2(J))*(s+t)*mt2 
     & + (s + 2.d0*t)*(s*P1(J) + (P1(J) + P2(J))*t) - EGR)

      B8 = 8.d0*ei* alctR * betc * 
     & (EGR - ((2.d0*P1(J) - P2(J))*mt4 
     &  + (-s*P1(J) - t*P1(J) + s*P2(J) + 5.d0*P2(J)*t)*mt2
     &  - (s + 2.d0*t)*(s*P1(J) + (P1(J) + P2(J))*t)))

      B9 = 4.d0 * alctCL * altcCL * mt *
     & ( EGR - (mt2 - s)*(P1(J)*mt2 - P1(J)*t + P2(J)*(s+t)))

      B10 = - 4.d0 * alctCL * alctL * mt *
     & (4.d0*P2(J)*t*mt2 - 2.d0*(P1(J) + P2(J))*t2 
     & + (mt4 - s2)*(P1(J) - P2(J)) - 4.d0*s*P1(J)*t)

      B11 = 8.d0 * ei * alctCL * bect * 
     & ( EGR - ((2.d0*P1(J) - P2(J))*mt4 
     & + (-s*P1(J) - t*P1(J) + s*P2(J) + 5.d0*P2(J)*t)*mt2 
     & - (s + 2.d0*t)*(s*P1(J) + (P1(J) + P2(J))*t)))

      B12 = -4.d0 * altcCL * altcL * mt *
     & (P1(J) + P2(J))*(mt4 - 2.d0*(s+t)*mt2 + s2 + 2.d0*t2 + 2.d0*s*t)

      B13 = 8.d0*ei* altcCL * bectC *
     & ((2.d0*P1(J) + P2(J))*mt4 - (3.d0*P1(J) + P2(J))*(s+t)*mt2 
     & + (s + 2.d0*t)*(s*P1(J) + (P1(J) + P2(J))*t) - EGR )

      B14 = - 4.d0 * alctL * altcL * mt *
     & ((mt2 - s)*(P1(J)*mt2 - P1(J)*t + P2(J)*(s+t)) + EGR )

      B15 = - 8.d0 * ei * altcL * bect * 
     & ((2.d0*P1(J) + P2(J))*mt4 - (3.d0*P1(J) + P2(J))*(s+t)*mt2
     & + (s + 2.d0*t)*(s*P1(J) + (P1(J) + P2(J))*t) + EGR )

      B16 = 8.d0*ei * alctL * bectC * 
     & ((2.d0*P1(J) - P2(J))*mt4 
     & + (-s*P1(J) - t*P1(J) + s*P2(J) + 5.d0*P2(J)*t)*mt2 
     & - (s + 2.d0*t)*(s*P1(J) + (P1(J) + P2(J))*t) + EGR )

      B17 = 64.d0 * (-bect * bectC + betc * betcC) * mt *
     & (P1(J)*mt2 - s*P1(J) + (P2(J) - P1(J))*t)


      b0 =  b1 +  b2 +  b3 +  b4 +  b5 +  b6 +  b7 + b8 + b9 + b10 
     &   + b11 + b12 + b13 + b14 + b15 + b16 + b17
      sp(j) = dble(b0 / u0)
      enddo

      call vortas(p4, vh)
       do j = 1,3
        hv(j) = -(sp(4)*vh(j,4) - sp(1)*vh(j,1) - sp(2)*vh(j,2) 
     &                          - sp(3)*vh(j,3))
       enddo

      ves = (u0 / S) * coef * rpar(16)**2
      return
      end

*----------------------------------------------------------------------------*
      subroutine tfcnc_01uu(iq1, iq2, iq3, imt, p1, p2, p3, p4,ves,hv)
      implicit none
      include "txpar.inc" 
      double precision  p1(5), p2(5)       ! momenta of initial quarks
      double precision  p3(5), p4(5)       ! momenta of Y and top 
      double precision s,t,mt,mt2,mt4,mt6,  epsl(5)
      double complex   FL,     FR,      HL,    HR,
     &                 XL,     XR,      YL,    YR
      common /ANOMCPL/FL(20), FR(20), HL(20), HR(20), 
     &                XL(20), XR(20), YL(20), YR(20) 
      double complex alctCR, alctR, altcR, altcCR, alctCL, alctL,
     &  altcL, altcCL, betc, betcC, bectC, bect
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer iq1, iq2, iq3, imt, iqf, J
      double complex U0, a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,
     & a11,a12,a13,a14,a15,a16,a17,a18,
     & b1,b2,b3,b4,b5,b6,b7,b8,b9,b10,
     & b11,b12,b13,b14,b15,b16,b17,b18,b0, egr
      double precision ves, coef, s2,s3, t2,t3,
     & sp(4), vh(3,4), hv(4), lq1, lq2 
      double complex ei 
      data ei/(0.d0, 1.d0)/
      LOGICAL first
      SAVE first, coef, mt,mt2,mt4,mt6
      DATA first /.TRUE./
*******
      IF(first) THEN        ! initializing
        coef = rpar(10) ! transformation 1/GeV**2 to mb 
        coef = coef / (2.d0*2.d0 * 3.d0*3.d0) 
        mt = mq(6)
        mt2 = mt**2
        mt4 = mt**4
        mt6 = mt**6
       print*,'  Contributed code:   '
       print*,'  Rui Santos and Pedro Ferreira --> '
       print*,'  FCNC top-gluon-quark interaction '
       print*,'                     '
       first=.FALSE.
      ENDIF
*
           if(abs(iq3).eq.2) iqf = 11
           if(abs(iq3).eq.4) iqf = 12
*
       s = (p1(4) + p2(4))**2 - (p1(1) + p2(1))**2
     &   - (p1(2) + p2(2))**2 - (p1(3) + p2(3))**2
       s2 = s * s
       s3 = s2 * s  
       t = (p1(4) - p4(4))**2 - (p1(1) - p4(1))**2
     &   - (p1(2) - p4(2))**2 - (p1(3) - p4(3))**2
       t2 = t * t
       t3 = t2 * t

*
*      print*,'iqf ',iqf
*      print*,'HR HL ',HR(iqf),HL(iqf)
*      print*,'XR XL ',XR(iqf),XL(iqf)
*      print*,'YR YL ',YR(iqf),YL(iqf)



       alctCR = XR(iqf) + YR(iqf) ! C_TR(iqf)
       alctR  = conjg(alctCR)

       altcR  = - YR(iqf)         ! C_XR(iqf) - C_TR(iqf)
       altcCR = conjg(altcR)

       alctCL =  XL(iqf) + YL(iqf) ! C_TL(iqf)
       alctL  = conjg(alctCL)

       altcL  = - YL(iqf)          ! C_XL(iqf) - C_TL(iqf)
       altcCL = conjg(altcL)

       betc   = -ei*HR(iqf)        ! C_HR(iqf)
       betcC  = conjg(betc)
       bectC  = -ei*HL(iqf)        ! C_HL(iqf)
       bect   = conjg(bectC)

********************

      a1 = 2*alctCR*altcCR*(3*(s + t)*mt6 - 2*(s2 + 2*t*s + 3*t2)*mt4 
     & + (2*s-3*t)*(3*s - 2*t)*(s+t)*mt2 + s*t*(11*s2 + 16*t*s + 11*t2))

      a2 = 2*alctCR*alctR*(3*(s + t)*mt6 - 6*(s - t)**2*mt4
     & + (s + t)*(6*s2 - t*s + 6*t2)*mt2 - s*t*(11*s2 + 16*t*s + 11*t2))

      a3 = 8*alctCR*betcC*mt*(3*(s + t)*mt4 + (-6*s2 + 4*t*s - 6*t2)*mt2
     &  + (s + t)*(6*s2 - 7*t*s + 6*t2)) 

      a4 = 2*altcCR*altcR*(-3*(s + t)*mt6 + 2*(3*s + t)*(s + 3*t)*mt4
     &  - (s+t)*(6*s2+ 19*t*s + 6*t2)*mt2 +s*t*(11*s2 + 16*t*s + 11*t2))

      a5 = 8*altcCR*betc*mt*(s+t)*(mt4-2*(s + t)*mt2 + 2*s2 + 2*t2+s*t)

      a6 = 2*alctR*altcR  *(3*(s +t)*mt6 - 2*(3*s2 + 2*t*s + 3*t2)*mt4 
     & + (2*s - 3*t)*(3*s-2*t)*(s+t)*mt2 +s*t*(11*s2 + 16*t*s + 11*t2))

      a9 = 2*alctCL*altcCL*(3*(s +t)*mt6 - 2*(3*s2 + 2*t*s + 3*t2)*mt4 
     & + (2*s-3*t)*(3*s - 2*t)*(s +t)*mt2 +s*t*(11*s2 + 16*t*s + 11*t2))

      a7 = 8*altcR*betcC*mt*(s+t)*(mt4-2*(s+t)*mt2 + 2*s2 + 2*t2 +s*t) 

      a8 = 8*alctR*betc*mt*(3*(s +t)*mt4 
     & + (-6*s2 + 4*t*s - 6*t2)*mt2 +(s +t)*(6*s2 - 7*t*s + 6*t2)) 

      a10 = 2*alctCL*alctL*(3*(s +t)*mt6 - 6*(s - t)**2*mt4 
     & + (s +t)*(6*s2 - t*s + 6*t2)*mt2 - s*t*(11*s2 + 16*t*s + 11*t2))

      a11 = 8*alctCL*bect*mt*(3*(s +t)*mt4 +(-6*s2 + 4*t*s - 6*t2)*mt2 
     & + (s +t)*(6*s2 - 7*t*s + 6*t2))

      a12 = 2*altcCL*altcL*(-3*(s +t)*mt6 + 2*(3*s +t)*(s + 3*t)*mt4 
     & - (s+t)*(6*s2+19*t*s + 6*t2)*mt2 +s*t*(11*s2 + 16*t*s + 11*t2))

      a13 = 8*altcCL*bectC*mt*(s+t)*(mt4-2*(s+t)*mt2 + 2*s2 +2*t2 +s*t) 

      a14 = 2*alctL*altcL*(3*(s +t)*mt6 - 2*(3*s2 + 2*t*s + 3*t2)*mt4 
     & + (2*s - 3*t)*(3*s - 2*t)*(s+t)*mt2 +s*t*(11*s2+16*t*s + 11*t2))

      a15 = 8*altcL*bect*mt*(s+t)*(mt4-2*(s+t)*mt2 + 2*s2+2*t2 +s*t)

      a16 = 8*alctL*bectC*mt*(3*(s +t)*mt4 +(-6*s2 + 4*t*s-6*t2)*mt2 
     & + (s +t)*(6*s2 - 7*t*s + 6*t2))

      a17 = 32*bect*bectC*(3*(s +t)*mt4 
     & - 2*(3*s2 + 2*t*s + 3*t2)*mt2 + 2*(s +t)*(3*s2 - t*s + 3*t2)) 

      a18 = 32*betc*betcC*(3*(s +t)*mt4 
     & - 2*(3*s2 + 2*t*s + 3*t2)*mt2 + 2*(s +t)*(3*s2 - t*s + 3*t2))

      U0 = -a1 - a2 -a3 + a4 + 3.d0*ei*a5 - a6 - 3.d0*ei*a7 
     & + ei*a8 - a9 -  a10 -ei*a11 + a12 + 3.d0*ei*a13 
     & - a14 - 3.d0* ei*a15 + ei*a16-a17-a18



* SPIN
      
      call epsil3(p4, p1, p2, EPSL)

      do J = 1,4
      EGR =  2.d0*ei*(4.d0*mt2 - 7*(s-t))*EPSL(j)
      LQ1 = P1(j)
      LQ2 = P2(j)

      b1 = 4*alctCR*altcCR*mt*(LQ2*mt6 + 2*(2*LQ1 +LQ2)*(s - t)*mt4 
     & - 2*((2*LQ1 + 3*LQ2)*s2 + 5*LQ2*t*s +(LQ2 - 2*LQ1)*t2)*mt2 
     & + s*t*(3*s*LQ1 - 3*t*LQ1 + 11*s*LQ2 + 8*LQ2*t) + EGR)

      b2 = 4*alctCR*alctR*mt
     & *(LQ2*mt6 + 2*(2*s*LQ1 - 2*t*LQ1 + 3*s*LQ2 +LQ2*t)*mt4 
     & + LQ2*(-13*s2 + 2*t*s - 13*t2)*mt2 + 7*(LQ1 +LQ2)*t3 
     & + 2*s*(5*LQ1-4*LQ2)*t2 - 7*s3*LQ1 - 2*s2*(5*LQ1 + 9*LQ2)*t)

      b3 = 8*alctCR*betcC* (2*LQ2*mt6 + 8*(s*(LQ1 +LQ2) - LQ1*t)*mt4 
     & - ((4*LQ1 + 19*LQ2)*s2 + 8*LQ2*t*s +(15*LQ2 - 4*LQ1)*t2)*mt2 
     &- 7*(s - t)*(s +t)*(s*LQ1 +(LQ1 +LQ2)*t) + EGR)

      b4 = 4*altcCR*altcR*mt*
     & (LQ2*mt6 +(4*s*LQ1 - 4*t*LQ1 - 2*s*LQ2 - 6*LQ2*t)*mt4 
     & - (s +t)*(8*s*LQ1 - 8*t*LQ1 - s*LQ2 - 9*LQ2*t)*mt2 
     & - 7*(LQ1 +LQ2)*t3 
     & - 4*s*(LQ1 + 2*LQ2)*t2 + 7*s3*LQ1 + 4*s2*(LQ1 - LQ2)*t)

      b5 = 8*altcCR*betc* (2*LQ2*mt6 + 8*(s*LQ1 - (LQ1 +LQ2)*t)*mt4 
     & + ((12*LQ1 + 7*LQ2)*t2 - s2*(12*LQ1 + 5*LQ2))*mt2 
     & + 7*(s - t)*(s +t)*(s*LQ1 +(LQ1 +LQ2)*t) 
     & + EGR)

      b6 = 4*alctR*altcR*mt*(LQ2*mt6 + 2*(2*LQ1 +LQ2)*(s - t)*mt4 
     & - 2*((2*LQ1 + 3*LQ2)*s2 + 5*LQ2*t*s +(LQ2 - 2*LQ1)*t2)*mt2 
     & + s*t*(3*s*LQ1 - 3*t*LQ1 + 11*s*LQ2 + 8*LQ2*t) 
     & - EGR)

      b7 = 8*altcR*betcC*(2*LQ2*mt6 + 8*(s*LQ1 - (LQ1 +LQ2)*t)*mt4 
     & + ((12*LQ1 + 7*LQ2)*t2 - s2*(12*LQ1 + 5*LQ2))*mt2 
     & + 7*(s - t)*(s +t)*(s*LQ1 +(LQ1 +LQ2)*t) 
     & - EGR)

      b8 = 8*alctR*betc*(2*LQ2*mt6 + 8*(s*(LQ1 +LQ2) - LQ1*t)*mt4 
     & - ((4*LQ1 + 19*LQ2)*s2 + 8*LQ2*t*s +(15*LQ2 - 4*LQ1)*t2)*mt2 
     & - 7*(s - t)*(s +t)*(s*LQ1 +(LQ1 +LQ2)*t) 
     &- EGR)

      b9 = 4*alctCL*altcCL*mt*(LQ2*mt6 + 2*(2*LQ1 +LQ2)*(s - t)*mt4 
     & - 2*((2*LQ1 + 3*LQ2)*s2 + 5*LQ2*t*s +(LQ2 - 2*LQ1)*t2)*mt2 
     & + s*t*(3*s*LQ1 - 3*t*LQ1 + 11*s*LQ2 + 8*LQ2*t) 
     & - EGR)

      b10 = 4*alctCL*alctL*mt*(LQ2*mt6 
     & + 2*(2*s*LQ1 - 2*t*LQ1 + 3*s*LQ2 +LQ2*t)*mt4 
     & + LQ2*(-13*s2 + 2*t*s - 13*t2)*mt2 + 7*(LQ1 +LQ2)*t3 
     & + 2*s*(5*LQ1-4*LQ2)*t2-7*s3*LQ1-2*s2*(5*LQ1 + 9*LQ2)*t)

      b11 = 8*alctCL*bect* (2*LQ2*mt6 + 8*(s*(LQ1 +LQ2) - LQ1*t)*mt4 
     & - ((4*LQ1 + 19*LQ2)*s2 + 8*LQ2*t*s +(15*LQ2 - 4*LQ1)*t2)*mt2 
     & - 7*(s - t)*(s +t)*(s*LQ1 +(LQ1 +LQ2)*t) 
     & - EGR)

      b12 = 4*altcCL*altcL*mt*(LQ2*mt6 +(4*s*LQ1 - 4*t*LQ1 - 2*s*LQ2 
     & - 6*LQ2*t)*mt4 
     & - (s +t)*(8*s*LQ1 - 8*t*LQ1 - s*LQ2 - 9*LQ2*t)*mt2 
     & - 7*(LQ1 +LQ2)*t3 
     & - 4*s*(LQ1 + 2*LQ2)*t2 + 7*s3*LQ1 + 4*s2*(LQ1 - LQ2)*t)

      b13= 8*altcCL*bectC* (2*LQ2*mt6 + 8*(s*LQ1 - (LQ1 +LQ2)*t)*mt4 
     & + ((12*LQ1 + 7*LQ2)*t2 - s2*(12*LQ1 + 5*LQ2))*mt2 
     & + 7*(s - t)*(s +t)*(s*LQ1 +(LQ1 +LQ2)*t) 
     & - EGR)

      b14 = 4*alctL*altcL*mt*(LQ2*mt6 + 2*(2*LQ1 +LQ2)*(s - t)*mt4 
     & - 2*((2*LQ1 + 3*LQ2)*s2 + 5*LQ2*t*s +(LQ2 - 2*LQ1)*t2)*mt2 
     & + s*t*(3*s*LQ1 - 3*t*LQ1 + 11*s*LQ2 + 8*LQ2*t) 
     & + EGR)


      b15 = 8*altcL*bect* (2*LQ2*mt6 + 8*(s*LQ1 - (LQ1 +LQ2)*t)*mt4 
     & + ((12*LQ1 + 7*LQ2)*t2 - s2*(12*LQ1 + 5*LQ2))*mt2 
     & + 7*(s - t)*(s +t)*(s*LQ1 +(LQ1 +LQ2)*t) 
     & + EGR)

      b16 = 8*alctL*bectC* (2*LQ2*mt6 + 8*(s*(LQ1 +LQ2) - LQ1*t)*mt4 
     & - ((4*LQ1 + 19*LQ2)*s2 + 8*LQ2*t*s +(15*LQ2 - 4*LQ1)*t2)*mt2 
     & - 7*(s - t)*(s +t)*(s*LQ1 +(LQ1 +LQ2)*t) 
     & + EGR)

      b17 = 64*bect*bectC*mt*(LQ2*mt4 + 2*(2*LQ1 +LQ2)*(s -t)*mt2 
     & - 2*((2*LQ1 + 3*LQ2)*s2 +LQ2*t*s +(LQ2 - 2*LQ1)*t2)) 

      b18 = 64*betc*betcC*mt*(LQ2*mt4 + 2*(2*LQ1 +LQ2)*(s-t)*mt2 
     & - 2*((2*LQ1 + 3*LQ2)*s2 +LQ2*t*s +(LQ2 - 2*LQ1)*t2))


      b0 = -b1 - b2 - ei*b3 - b4 + ei*b5 - b6 - ei*b7 + ei*b8 + b9 + b10 
     &   + ei*b11 - b12 - ei*b13 + b14 + ei*b15 - ei*b16 + b17 - b18
      sp(j) = dble(b0 / u0)
      enddo

      call vortas(p4, vh)
       do j = 1,3
        hv(j) = -(sp(4)*vh(j,4) - sp(1)*vh(j,1) - sp(2)*vh(j,2) 
     &                          - sp(3)*vh(j,3))
       enddo

*      ves = (u0 / 27.d0 /S/T) * coef * rpar(16)**2
      ves = (u0 / 3.d0 / S / T) * coef * rpar(16)**2
      return
      end

*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  30.05.2006                                  *
*  Ubar(p) gamma_nu (1/2)(1-gamma5) V(k), p^2 = k^2 = 0                      *
* return 4x4 matrix
      subroutine VbosMX(p, k, V)
*     ---------------------                                                  *
      implicit none
      double precision p(5), k(5), pp, pm, kp, km 
      double complex p1, p2,  k1, k2, Z
      double complex V(4,4), VP, VM, V1, V2
      double complex ei 
      data ei/(0.d0, 1.d0)/
      integer i1,i2
*
      do 123 i1 = 1,4
      do 123 i2 = 1,4
 123    V(i1,i2) = (0.d0, 0.d0)
       Pp = p(4) + p(3)   
       Pm = p(4) - p(3)   
       P1 = p(1) + ei * p(2)
       P2 = p(1) - ei * p(2)
*
       kp = k(4) + k(3)   
       km = k(4) - k(3)   
       k1 = k(1) + ei * k(2)
       k2 = k(1) - ei * k(2)
*
      If(    PP.ge.PM.AND.KP.ge.KM) then
        Z = 2.d0 / dsqrt(PP * KP)
       VP = pp * kp * Z
       VM = p1 * k2 * Z
       V1 = p1 * kp * Z
       V2 = pp * k2 * Z
      ElseIf(PP.ge.PM.AND.KP.lt.KM) then
        Z = 2.d0 / dsqrt(PP * KM)
       VP = -pp * k1 * Z
       VM = -p1 * km * Z
       V1 = -p1 * k1 * Z
       V2 = -pp * km * Z
      ElseIf(PP.lt.PM.AND.KP.ge.KM) then
        Z = 2.d0 / dsqrt(PM * KP)
       VP = -p2 * kp * Z
       VM = -pm * k2 * Z
       V1 = -p2 * k2 * Z
       V2 = -pp * km * Z
      ElseIf(PP.lt.PM.AND.KP.lt.KM) then
        Z = 2.d0 / dsqrt(PM * KM)
       VP = p2 * k1 * Z
       VM = pm * km * Z
       V1 = pm * k1 * Z
       V2 = p2 * km * Z
      EndIF
*
      v(1,3) = VP
      v(1,4) = V2
 
      v(2,3) = V1
      v(2,4) = VM
      RETURN
      END
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  01/06/2006                                  *
* TopReX code = 14,  q q -> T q, fcnc, gluon                                 *
*............................................................................*
      subroutine gejzer_31(NFP) 
      Implicit None
      include "txpar.inc" 
      include "txpro.inc" 
      Integer NFP          ! number of particles in hard process 
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision p1(5),p2(5), p3(5), p4(5), pft(5),pfq(5),qq(5)
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision x1, x2, sg, sgs, PT
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst / pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision           sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      double precision Ves, vlum, du1, dc1, uu1, uu2, cc1, cc2
      double precision pq1(5), pq2(5), pq3(5)
      integer ID1, i, j
      double precision pdfBT(-5:5, -5:5)
      integer iq1, iq2, iq3, ncl, j8,j9
      double precision HR(4), pyr 
      integer       idum,     idf 
      double precision                 ved,     HRD 
      common /tplFC/idum(16), idf(16), ved(16), HRD(16,4)
      save /tplfc/
      integer imatch
      common /wmtch/imatch 
*.......
      double precision Parl(3) !, TopMV
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
*..........................      
      if(first) THEN
       first=.FALSE.
        if(mid(11,1).eq.-1.AND.mid(12,1).eq.-1) then 
         print*,' '
         print*,'TopReX  FCNC process  ',ipar(1)
         print*,' FCNC (top -> !UP+CHARM! gluon) is switched OFF'
         print*,' stop TopReX run '
         STOP
         return
        endif 
        If(txsel.eq.2)  then
            Rpar(81) = Rpar(68) ! PTmin for q
        Else
            Rpar(81) = Rpar(103) ! PTmin for q
        EndIf 
         if(rpar(81).le.1.d0) rpar(81) = 1.d0
         print*,'TopReX process ',Ipar(1),' PTmin ',Rpar(81)
      ENDIF

      imatch = 2
      sigrx=0.d0
      do j8 = -6,6
      do j9 = -6,6
       XCS(j8,j9) = 0.d0
      enddo
      enddo
      call zer5mom(p1) 
      call zer5mom(p2) 

*
       p4(5) = mq(6)
       p3(5) = 0.d0
       Parl(1) = p3(5) + p4(5) 
       Parl(2) = Rpar(1)
       Parl(3) = Rpar(1)
 100   call X1X2GEN( Parl, X1, X2, Vlum, p1, p2, QQ)
      
      call mass2(p1, p2, sg, sgs)
      Call LIPS2(QQ, P3, P4, ves)
       if(PT(p3).lt.Rpar(81)) then
          NXev(Ipar(1)) = NXev(ipar(1)) + 1
          goto 100
       endif
      Ves = Vlum * Ves * pi2_4 / (2.* sg)
      Rpar(76) = p4(1)**2 + p4(2)**2     ! pt(top)
      Rpar(75) = dsqrt(Rpar(76))   

      call TXQscale  ! setting Q-scale for PDF( Rpar(3)) and for alpha_s 
      call pdf_BT(x1, x2, pdfbt)

*
****  Q Qbar and Q .NE. UP or CHARM 
       DU1 = 0.d0
       DC1 = 0.d0
*
       iq1 =  1  
       iq2 = -1
      if(mid(11,1).ge.0) then  !  t -> UP gluon
        iq3 = -2 
        ncl = 1
        call tfcnc_01dd(iq1, iq2, iq3, id1, p1, p2, p3, p4, DU1, HR)
        idf(ncl) = 3 ! id1
        ved(ncl) = du1
         do J = 1,4
          hrd(ncl,J) = hr(j)
         enddo
      endif 
      if(mid(12,1).ge.0) then 
        iq3 = -4
        ncl = 2
        call tfcnc_01dd(iq1, iq2, iq3, id1, p1, p2, p3, p4, DC1, hr)
         idf(ncl) = 3 ! id1
         ved(ncl) = DC1
          do J = 1,4
           hrd(ncl,J) = hr(j)
          enddo
      endif
*
      do I = 1, 3
        J = 2*I - 1
        xcs( j,-j) = (DU1 + DC1) * (BRS(1,1) + BRS(2,1)) ! T + Tbar
        xcs(-j, j) = (DU1 + DC1) * (BRS(1,1) + BRS(2,1)) ! T + Tbar
       enddo
*      goto 99
*** U Ubar or C Cbar
      uu1 = 0.d0
      uu2 = 0.d0
      CC1 = 0.d0
      cc2 = 0.d0
      if(mid(11,1).ge.0) then 
       iq1 =  2
       iq2 = -2
       iq3 = -2 
       ncl = 3
       call   tfcnc_01uu(iq1, iq2, iq3, id1, p1, p2, p3, p4, UU1, hr)
           if(pyr(0).ge.0.5d0) then
            idf(ncl) = 3 
           else
            idf(ncl) = 1
           endif  
         ved(ncl) = UU1
          do J = 1,4
           hrd(ncl,J) = hr(j)
          enddo
*
        ncl = 4
        call  tfcnc_01uu  (iq1, iq2, iq3, id1, p2, p1, p3, p4, UU2, hr)
           if(pyr(0).ge.0.5d0) then
            idf(ncl) = 3 
           else
            idf(ncl) = 1
           endif  

         ved(ncl) = UU2
          do J = 1,4
           hrd(ncl,J) = hr(j)
          enddo
      EndIf
      If(mid(12,1).ge.0) then  
       iq1 =  4
       iq2 = -4
       iq3 = -4 
        ncl = 5
        call tfcnc_01uu(iq1,iq2,iq3, id1, p1, p2, p3,p4, CC1, hr) 
           if(pyr(0).ge.0.5d0) then
            idf(ncl) = 3 
           else
            idf(ncl) = 1
           endif  
         ved(ncl) = CC1
          do J = 1,4
           hrd(ncl,J) = hr(j)
          enddo
        ncl = 6
        call tfcnc_01uu(iq1,iq2,iq3, id1, p2, p1, p3,p4, CC2, hr) 
           if(pyr(0).ge.0.5d0) then
            idf(ncl) = 3 
           else
            idf(ncl) = 1
           endif  

         ved(ncl) = CC2
          do J = 1,4
           hrd(ncl,J) = hr(j)
          enddo
      endif
* (U/C)1  (U/C)2bar -> TOP 
        xcs( 2,-2) = (UU1 + DC1) * BRS(1,1)    ! T       U U~ -> T
     &             + (UU2 + DC1) * BRS(2,1)    ! Tbar    U U~ -> Tbar
*
        xcs( 4,-4) = (CC1 + DU1) * BRS(1,1)    ! T 
     &             + (CC2 + DU1) * BRS(2,1)    ! Tbar
* U1bar U2
        xcs(-2, 2) = (UU2 + DC1) * BRS(1,1)    ! T 
     &             + (UU1 + DC1) * BRS(2,1)    ! Tbar
*
        xcs(-4, 4) = (CC2 + DU1) * BRS(1,1)    ! T 
     &             + (CC1 + DU1) * BRS(2,1)    ! Tbar

****  U U 
      UU1 = 0.d0
      CC1 = 0.d0
        do j = 1,4
         pq1(j) =  p2(j)
         pq2(j) = -p3(j)
         pq3(j) = -p1(j) 
        enddo
         pq2(5) = p3(5)
         pq3(5) = p1(5)
      if(mid(11,1).ge.0) then  !  t -> UP gluon
      iq1 =  2
      iq2 =  2
      iq3 =  2 
       ncl = 7
       call tfcnc_01uu(iq1, iq2, iq3, id1, pq1, pq2, pq3, p4, UU1, hr)
           if(pyr(0).ge.0.5d0) then
            idf(ncl) = 1 
           else
            idf(ncl) = 2
           endif  
         ved(ncl) = UU1
          do J = 1,4
           hrd(ncl,J) = hr(j)
          enddo
       xcs( 2, 2) = UU1 * BRS(1,1) ! T
       xcs(-2,-2) = UU1 * BRS(2,1) ! Tbar
      endif
      if(mid(12,1).ge.0) then  !  t -> CHARM gluon
      iq1 =  4
      iq2 =  4
      iq3 =  4 
       ncl = 8
       call tfcnc_01uu(iq1, iq2, iq3, id1, pq1, pq2, pq3, p4, UU1, hr)
           if(pyr(0).ge.0.5d0) then
            idf(ncl) = 1
           else
            idf(ncl) = 2
           endif  
         ved(ncl) = UU1
          do J = 1,4
           hrd(ncl,J) = hr(j)
          enddo
       xcs( 4, 4) = UU1 * BRS(1,1) ! T
       xcs(-4,-4) = UU1 * BRS(2,1) ! Tbar
      endif
**** U Sbar
      uu1 = 0.d0
      uu2 = 0.d0
      CC1 = 0.d0
      CC2 = 0.d0

        do j = 1,4
         pq1(j) = -p3(j)
         pq2(j) =  p2(j)
         pq3(j) = -p1(j) 
        enddo
      If(mid(11,1).ge.0) then  !  t -> UP gluon
      iq1 =  2  
      iq2 = -1
      iq3 = -1 
        ncl = 9

        call tfcnc_01dd(iq1, iq2, iq3, id1, pq1, pq2, pq3, p4, UU1, hr)
         idf(ncl) = 1 ! id1
         ved(ncl) = UU1
          do J = 1,4
           hrd(ncl,J) = hr(j)
          enddo
        ncl = 10
        call tfcnc_01dd(iq1, iq2, iq3, id1, pq2, pq1, pq3, p4, UU2, hr)
         idf(ncl) = 2 ! id1
         ved(ncl) = UU2
          do J = 1,4
           hrd(ncl,J) = hr(j)
          enddo
      EndIf
      If(mid(12,1).ge.0) then
        iq1 = 4
        ncl = 11
        call tfcnc_01dd(iq1, iq2, iq3, id1, pq1, pq2, pq3, p4, CC1, hr)
         idf(ncl) = 1 ! id1
         ved(ncl) = CC1
          do J = 1,4
           hrd(ncl,J) = hr(j)
          enddo
        ncl = 12
        call tfcnc_01dd(iq1, iq2, iq3, id1, pq2, pq1, pq3, p4, CC2, hr)
         idf(ncl) = 2 ! id1
         ved(ncl) = CC2
          do J = 1,4
           hrd(ncl,J) = hr(j)
          enddo
      EndIf
*
       xcs( 2,-4) = UU1* BRS(1,1) + CC2 * BRS(2,1) ! T + Tbar
       xcs(-2, 4) = UU1* BRS(2,1) + CC2 * BRS(1,1) ! T + Tbar
*
       xcs( 4,-2) = UU2* BRS(2,1) + CC1 * BRS(1,1) ! T + Tbar
       xcs(-4, 2) = UU2* BRS(1,1) + CC1 * BRS(2,1) ! T + Tbar
**** U/C d, s, b
      do I = 1,3
        J = 2*I - 1
           xcs( 2,-J) = UU1 * BRS(1,1) ! T
           xcs(-2, J) = UU1 * BRS(2,1) ! Tbar
           xcs(-J, 2) = UU2 * BRS(1,1) ! T
           xcs( J,-2) = UU2 * BRS(2,1) ! Tbar
*
           xcs( 4,-J) = CC1 * BRS(1,1) ! T
           xcs(-4, J) = CC1 * BRS(2,1) ! Tbar
           xcs(-J, 4) = CC2 * BRS(1,1) ! T
           xcs( J,-4) = CC2 * BRS(2,1) ! Tbar
      enddo
*
**** U S
      uu1 = 0.d0
      uu2 = 0.d0
      CC1 = 0.d0
      CC2 = 0.d0

        do j = 1,4
         pq1(j) =  p2(j)
         pq2(j) = -p3(j)
         pq3(j) = -p1(j) 
        enddo
      If(mid(11,1).ge.0) then  !  t -> UP gluon
      iq1 =  2  
      iq2 =  1
      iq3 =  1 
        ncl = 13
        call tfcnc_01dd(iq1, iq2, iq3, id1, pq1, pq2, pq3, p4, UU1, hr)
         idf(ncl) = 1 ! id1
         ved(ncl) = UU1
          do J = 1,4
           hrd(ncl,J) = hr(j)
          enddo
        ncl = 14
        call tfcnc_01dd(iq1, iq2, iq3, id1, pq2, pq1, pq3, p4, UU2, hr)
         idf(ncl) = 2 ! id1
         ved(ncl) = UU2
          do J = 1,4
           hrd(ncl,J) = hr(j)
          enddo
      EndIf
      If(mid(12,1).ge.0) then
        iq1 = 4
        ncl = 15
        call tfcnc_01dd(iq1, iq2, iq3, id1, pq1, pq2, pq3, p4, CC1, hr)
         idf(ncl) = 1 ! id1
         ved(ncl) = CC1
          do J = 1,4
           hrd(ncl,J) = hr(j)
          enddo
        ncl = 16
        call tfcnc_01dd(iq1, iq2, iq3, id1, pq2, pq1, pq3, p4, CC2, hr)
         idf(ncl) = 2 ! id1
         ved(ncl) = CC2
          do J = 1,4
           hrd(ncl,J) = hr(j)
          enddo
      EndIf
*
       xcs( 2, 4) = (UU1 + CC2) * BRS(1,1) ! T
       xcs(-2,-4) = (UU1 + CC2) * BRS(2,1) ! T
*
       xcs( 4, 2) = (UU2 + CC1) * BRS(1,1) ! T
       xcs(-4,-2) = (UU2 + CC1) * BRS(2,1) ! T
*
**** U/C d, s, b
       do I = 1,3
        J = 2*I - 1
           xcs( 2, J) = UU1 * BRS(1,1) ! T
           xcs(-2,-J) = UU1 * BRS(2,1) ! Tbar
           xcs( J, 2) = UU2 * BRS(1,1) ! T
           xcs(-J,-2) = UU2 * BRS(2,1) ! Tbar
*
           xcs( 4, J) = CC1 * BRS(1,1) ! T
           xcs(-4,-J) = CC1 * BRS(2,1) ! Tbar
           xcs( J, 4) = CC2 * BRS(1,1) ! T
           xcs(-J,-4) = CC2 * BRS(2,1) ! Tbar
       enddo
*
*       do I = -5,5
*       do j = -5,5
*        if((i.eq.2.and.j.eq.2).or.(i.eq.-2.and.j.eq.-2)) then
*         xcs(i,j) = xcs(i,j)
*        else
*         xcs(i,j) = 0.d0
*        endif
*       enddo
*       enddo
       
***
 99   continue
      do i = -5,5
        do j=-5,5
         xcs(i,j) = xcs(i,j) * ves * pdfBT(i,j)
        enddo
      enddo
****
       nfp = 4
        call TXTQ1SMR(QQ, p4, p3, pft, pfq)
       do i = 1, 5
        pus(1,i) =  p1(i)
        pus(2,i) =  p2(i)
        pus(3,i) =  pfq(i) ! final quark
        pus(4,i) =  pft(i) ! final T/Tbar
       enddo
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  06.06.2006                                  *
* TopReX code = 15,  g g -> T q, fcnc, gluon                                 *
*............................................................................*
      subroutine gejzer_32(NFP) 
      Implicit None
      include "txpar.inc" 
      include "txpro.inc" 
      Integer NFP          ! number of particles in hard process 
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision p1(5),p2(5), p3(5), p4(5), pft(5),pfq(5),qq(5)
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision x1, x2, sg, sgs, PT
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst / pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision           sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      double precision Ves, vlum, VUG, VCG 
      double precision pdfBT(-5:5, -5:5)
      integer i, j, iq3, id1, id2,j8,j9 
      double precision HR1(4), hr2(4), aran, pyr
      integer           kft, kfq, idia
      common /tplFC_GG/ kft, kfq, idia
      double precision hv
      common /topol1/  hV(4)    ! TOP polarisation vector
      save /tplfc_GG/, /topol1/
*.......
      double precision Parl(3) !, TopMV
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
      integer imatch
      common /wmtch/imatch 
*
      if(first) THEN
       first=.FALSE.
        if(mid(11,1).eq.-1.AND.mid(12,1).eq.-1) then 
         print*,' '
         print*,'TopReX  FCNC process  ',ipar(1)
         print*,' FCNC (top -> !UP+CHARM! gluon) is switched OFF'
         print*,' stop TopReX run '
         STOP
         return
        endif 
        If(txsel.eq.2)  then
            Rpar(81) = Rpar(68) ! PTmin for q
        Else
            Rpar(81) = Rpar(103) ! PTmin for q
        EndIf 
         if(rpar(81).le.1.d0) rpar(81) = 1.d0
         print*,'TopReX process ',Ipar(1),' PTmin ',Rpar(81)
      ENDIF
*
      imatch = 2

      sigrx=0.d0
      do j8 = -6,6
      do j9 = -6,6
       XCS(j8,j9) = 0.d0
      enddo
      enddo
      call zer5mom(p1) 
      call zer5mom(p2) 

*
       p4(5) = mq(6)
       p3(5) = 0.d0
       Parl(1) = p3(5) + p4(5) 
       Parl(2) = Rpar(1)
       Parl(3) = Rpar(1)
 100   call X1X2GEN( Parl, X1, X2, Vlum, p1, p2, QQ)
      
      call mass2(p1, p2, sg, sgs)
      Call LIPS2(QQ, P3, P4, ves)
       if(PT(p3).lt.Rpar(81)) then
          NXev(Ipar(1)) = NXev(ipar(1)) + 1
          goto 100
       endif

      Ves = Vlum * Ves * pi2_4 / (2.* sg)
      Rpar(76) = p4(1)**2 + p4(2)**2     ! pt(top)
      Rpar(75) = dsqrt(Rpar(76))   

      call TXQscale  ! setting Q-scale for PDF( Rpar(3)) and for alpha_s 
      call pdf_BT(x1, x2, pdfbt)
*
      if(mid(11,1).ge.0) then  !  t -> UP gluon
        iq3 = -2 
        call tfcnc_02( iq3, id1, p1, p2, p3, p4, VUG, hr1)
      endif
      if(mid(12,1).ge.0) then
        iq3 = -4
        call tfcnc_02(iq3, id2, p1, p2, p3, p4, VCG, hr2)
      endif
*
      xcs(0,0) =            VUG * (BRS(1,1) + BRS(2,1))
      xcs(0,0) = xcs(0,0) + VCG * (BRS(1,1) + BRS(2,1)) ! T + Tbar
      xcs(0,0) = xcs(0,0) * ves * pdfBT(0,0)

      aran = pyr(0)*(BRS(1,1) + BRS(2,1))
      kft = -1
      if(aran.le.BRS(1,1)) kft = +1

      If(mid(11,1).ge.0.AND.mid(12,1).ge.0) then  ! UP * CHARM
       aran = pyr(0)*(VUG + VCG) 
        if(aran.le.VUG) then ! UP
         kfq = kft * (-2) 
         idia = id1            
           do J = 1,4
            hv(J) = hr1(j)
           enddo
        else
         kfq = kft * (-4) 
         idia = id2   
          do J = 1,4
           hv(J) = hr2(j)
          enddo
        endif
      ElseIf(mid(11,1).ge.0.AND.mid(12,1).eq.-1) then  ! UP 
         kfq = kft * (-2) 
         idia = id1            
           do J = 1,4
            hv(J) = hr1(j)
           enddo
      ElseIf(mid(11,1).eq.-1.AND.mid(12,1).ge.0) then  ! CHARM
         kfq = kft * (-4) 
         idia = id2        
           do J = 1,4
            hv(J) = hr2(j)
           enddo
      EndIf
****
*      if(pt(p3).le.10.d0) then
*       print*,'****** second'
*       print*,'PT P3 ',pt(p3),(p3(i),i=1,5)
*      endif

      if(abs(kft).eq.1) kft = kft * 6
       nfp = 4
        call TXTQ1SMR(QQ, p4, p3, pft, pfq)
       do i = 1, 5
        pus(1,i) =  p1(i)
        pus(2,i) =  p2(i)
        pus(3,i) =  pfq(i) ! final quark
        pus(4,i) =  pft(i) ! final T/Tbar
       enddo
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  06.06.2006                                  *
* TopReX code = 16,  g q -> g T, fcnc, gluon                                 *
*............................................................................*
      subroutine gejzer_33(NFP) 
      Implicit None
      include "txpar.inc" 
      include "txpro.inc" 
      Integer NFP          ! number of particles in hard process 
      double precision Pus
      common /user_mom/Pus(20,5)
      double precision p1(5),p2(5), p3(5), p4(5), pft(5),pfq(5),qq(5)
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      double precision x1, x2, sg, sgs, PT
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst / pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision           sigrx, xcs
      common/xsecs/sigrx,xcs(-6:6,-6:6)
      double precision Ves, vlum, VU1, VU2, VC1, VC2, hr(4) 
      double precision pdfBT(-5:5, -5:5)
      integer i, j, iq2, id1, j8,j9 
      integer           idia(4)
      double precision        hrd(5,4)
      common /tplFC_GQ/ idia, hrd
      save /tplfc_GQ/ 
*.......
      double precision Parl(3) !, TopMV
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
      integer imatch
      common /wmtch/imatch 
*..........................      
      if(first) THEN
       first=.FALSE.
        if(mid(11,1).eq.-1.AND.mid(12,1).eq.-1) then 
         print*,' '
         print*,'TopReX  FCNC process  ',ipar(1)
         print*,' FCNC (top -> !UP+CHARM! gluon) is switched OFF'
         print*,' stop TopReX run '
         STOP
         return
        endif 
        If(txsel.eq.2)  then
            Rpar(81) = Rpar(68) ! PTmin for q
        Else
            Rpar(81) = Rpar(103) ! PTmin for q
        EndIf 
         if(rpar(81).le.1.d0) rpar(81) = 1.d0
         print*,'TopReX process ',Ipar(1),' PTmin ',Rpar(81)
      ENDIF
***
      imatch = 2
      sigrx=0.d0
      do j8 = -6,6
      do j9 = -6,6
       XCS(j8,j9) = 0.d0
      enddo
      enddo
      call zer5mom(p1) 
      call zer5mom(p2) 

*
       p4(5) = mq(6)
       p3(5) = 0.d0
       Parl(1) = p3(5) + p4(5) 
       Parl(2) = Rpar(1)
       Parl(3) = Rpar(1)
 100   call X1X2GEN( Parl, X1, X2, Vlum, p1, p2, QQ)
      
      call mass2(p1, p2, sg, sgs)
      Call LIPS2(QQ, P3, P4, ves)
         if(PT(p3).lt.Rpar(81)) then
           NXev(Ipar(1)) = NXev(ipar(1)) + 1
           goto 100
         endif
      Ves = Vlum * Ves * pi2_4 / (2.* sg)
      Rpar(76) = p4(1)**2 + p4(2)**2     ! pt(top)
      Rpar(75) = dsqrt(Rpar(76))   

      call TXQscale  ! setting Q-scale for PDF( Rpar(3)) and for alpha_s 
      call pdf_BT(x1, x2, pdfbt)
*
      if(mid(11,1).ge.0) then  !  t -> UP gluon
        iq2 = 2 
        call  tfcnc_03(iq2, id1, p1, p2, p3, p4, VU1, hr)
         idia(1) = id1
          do j = 1,4
           hrd(1,j) = hr(j)
          enddo


*        call  tfcnc_03(iq2, id1, p2, p1, p3, p4, VU2, hr11)
*        call tfcnc_03r(iq2, id1, p1, p2, p3, p4, Vc1, hr2)
*        call tfcnc_03r(iq2, id1, p2, p1, p3, p4, Vc2, hr21)
c      print*,'****************' 
c      print*,' srs ',vu1,vu2
c      print*,' rui ',vc1,vc2
c      print*,'RUI/SRS 1 2 ', (vc1/vu1), (vc2/vu2)
c      sp1 = dsqrt(hr(1)**2+hr(2)**2+hr(3)**2)
c      sp11 = dsqrt(hr11(1)**2+hr11(2)**2+hr11(3)**2)
c      sp2  = dsqrt(hr2(1)**2+hr2(2)**2+hr2(3)**2)
c      sp22 = dsqrt(hr21(1)**2+hr21(2)**2+hr21(3)**2)
*      print*,'SRS 1 ', sp1,' ! ', (hr(j),j=1,4)
*      print*,'SRS 2 ', sp11, ' ! ',(hr11(j),j=1,4)
*      print*,'RUI 1 ', sp2,' ! ',(hr2(j),j=1,4)
*      print*,'RUI 2 ', sp22, ' ! ',(hr21(j),j=1,4)
c      print*,'RUI/srs 1 2 ', (sp2/sp1), (sp22/sp11)
c      print*,'RUI/srs 1 ', ((hr(j)/hr2(j)),j=1,3)
c      print*,'RUI/srs 2 ', ((hr11(j)/hr21(j)),j=1,3)


        call tfcnc_03(iq2, id1, p2, p1, p3, p4, VU2, hr)
         idia(2) = id1
          do j = 1,4
           hrd(2,j) = hr(j)
          enddo
      endif
      if(mid(12,1).ge.0) then
        iq2 = 4
        call tfcnc_03(iq2, id1, p1, p2, p3, p4, VC1, hr)
         idia(3) = id1
          do j = 1,4
           hrd(3,j) = hr(j)
          enddo
       call tfcnc_03(iq2, id1, p2, p1, p3, p4, VC2, hr)
        idia(4) = id1
         do j = 1,4
          hrd(4,j) = hr(j)
         enddo
      endif
*
      xcs( 0, 2) = pdfBT( 0, 2) * VES * VU1 * BRS(1,1)
      xcs( 2, 0) = pdfBT( 2, 0) * VES * VU2 * BRS(1,1)
      xcs( 0,-2) = pdfBT( 0,-2) * VES * VU1 * BRS(2,1)
      xcs(-2, 0) = pdfBT(-2, 0) * VES * VU2 * BRS(2,1)

      xcs( 0, 4) = pdfBT( 0, 4) * VES * VC1 * BRS(1,1)
      xcs( 4, 0) = pdfBT( 4, 0) * VES * VC2 * BRS(1,1)
      xcs( 0,-4) = pdfBT( 0,-4) * VES * VC1 * BRS(2,1)
      xcs(-4, 0) = pdfBT(-4, 0) * VES * VC2 * BRS(2,1)

       nfp = 4
      call TXTQ1SMR(QQ, p4, p3, pft, pfq)
       do i = 1, 5
        pus(1,i) =  p1(i)
        pus(2,i) =  p2(i)
        pus(3,i) =  pfq(i) ! final quark
        pus(4,i) =  pft(i) ! final T/Tbar
       enddo
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  06.0?.2006                                  *
* TopReX code 34,  g+q -> gamma T, fcnc, gluon                               *
*

      subroutine gejzer_34(NFP) 
      implicit none
      include "txpar.inc" 
      integer nfp
      STOP

      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  01/06/2006                                  *
* TopReX code = 14,  q q -> T q, fcnc, gluon                                 *
*............................................................................*
      subroutine razbor_14(ip1, ip2, kft, kfm, kf3) 
      Implicit None
      include "txpar.inc" 
      double precision aran, PYR, S1,s2
      integer j, ip1, ip2, kft, kf3, kcl, kfm
      integer       idum,     idf 
      double precision                 ved,     HRD 
      common /tplFC/idum(16), idf(16), ved(16), HRD(16,4)
      double precision hv 
      common /topol1/ hv(4)    ! TOP lepton polarisation vector
*.......
*      integer        PID(20) 
*      common /TXtopcpl/ PID      ! 1/0 = ON/OFF top interaction 
*****************
      kft = 0
      kfm = 0
      kcl = 0
      kf3 = 0
*
*      print*,'**********************'
*      do J = 1,16
*       print*,' J ves ',j,ved(j)
*      enddo
      IF(ip1.eq.(-ip2).AND.abs(ip1).ne.2.AND.abs(ip1).ne.4) then
****  Q Qbar and Q .NE. UP or CHARM 
*
* DU1 = VED(1),  DC1 = VED(2)
* KF top, position of top, KF of final quark, polarization number in HRD array
* kft     kfm              kf3                kcl
*
        KFT = +1
        aran = pyr(0)*(BRS(1,1) + BRS(2,1)) 
        if(aran.gt.BRS(1,1)) KFT = -1  ! KF top
      if(mid(11,1).ge.0.AND.mid(12,1).ge.0) then  !  both UP and CHARM
          KF3 = kft * (-2)
          KCL = 1  ! number of top polarization in HRD array
         aran = pyr(0)*(ved(1) + ved(2)) ! DU1 = VED(1),  DC1 = VED(2) 
         if(aran.gt.ved(1)) then
          KF3 = kft * (-4)
          KCL = 2
         endif
      elseif(mid(11,1).ge.0.AND.mid(12,1).eq.-1) then  ! only UP
         KF3 = kft * (-2)
         KCL = 1
      elseif(mid(11,1).eq.-1.AND.mid(12,1).ge.0) then  ! only CHARM
         KF3 = kft * (-4)
         KCL = 2
      endif
         kfm = 3     ! position of top mother     
*** U Ubar or C Cbar
      ELSEIF(ip1.eq.2.AND.ip2.eq.-2) then
* ved(1) = DU1, ved(2) = DC1 
* ved(3) = UU1, ved(4) = UU2, ved(5) = CC1, ved(6) = CC2
* idf(3)= iuu1, idf(4)= iuu2, idf(5)= icc1, idf(6)= icc2
* (U/C)1  (U/C)2bar -> TOP
        s1 = (ved(3) + ved(2)) * BRS(1,1) ! T       U U~ -> T
        s2 = (ved(4) + ved(2)) * BRS(2,1) ! Tbar    U U~ -> Tbar
*  xcs( 2,-2) = s1 + s2        ! T + Tbar
         If((pyr(0)*(s1+s2)).le.s1) then
          kft = +6
           if((pyr(0)*(ved(3)+ved(2))).le.ved(3)) then
             kf3 = -2
             kfm = idf(3)
             kcl = 3
           else
             kf3 = -4
             kfm = 3
             kcl = 2
           endif
         Else
          kft = -6
           if((pyr(0)*(ved(4)+ved(2))).le.ved(4)) then
             kf3 = 2
             kfm = idf(4)
             kcl = 4 
             if(kfm.le.2) kfm = 3 - kfm ! 
           else
             kf3 = 4
             kfm = 3
             kcl = 2 
           endif
         EndIf 
      ELSEIF(ip1.eq.4.AND.ip2.eq.-4) then
* ved(1) = DU1, ved(2) = DC1 
* ved(3) = UU1, ved(4) = UU2, ved(5) = CC1, ved(6) = CC2
* idf(3)= iuu1, idf(4)= iuu2, idf(5)= icc1, idf(6)= icc2
** (U/C)1  (U/C)2bar -> TOP

        s1 = (ved(5) + ved(1)) * BRS(1,1) ! T 
        s2 = (ved(6) + ved(1)) * BRS(2,1) ! Tbar
*  xcs( 4,-4) = s1 + s2 ! T + Tbar
         If((pyr(0)*(s1+s2)).le.s1) then
          kft = +6
           if((pyr(0)*(ved(5) +ved(1))).le.ved(5)) then
             kf3 = -4
             kfm = idf(5) 
             kcl = 5
           else
             kf3 = -2
             kfm = 3
             kcl = 1
           endif
         Else
          kft = -6
           if((pyr(0)*(ved(6) + ved(1))).le.ved(6)) then
             kf3 = 4
             kfm = idf(6) 
             if(kfm.le.2) kfm = 3 - kfm ! 
             kcl = 6
           else
             kf3 = 2
             kfm = 3
             kcl = 1
           endif
         EndIf 
      ELSEIF(ip1.eq.-2.AND.ip2.eq.+2) then
* ved(1) = DU1, ved(2) = DC1 
* ved(3) = UU1, ved(4) = UU2, ved(5) = CC1, ved(6) = CC2
* idf(3)= iuu1, idf(4)= iuu2, idf(5)= icc1, idf(6)= icc2
* U1bar U2
        s1 = (ved(4) + ved(2)) * BRS(1,1) ! T 
        s2 = (ved(3) + ved(2)) * BRS(2,1) ! Tbar
*  xcs(-2, 2) = s1 + s2        ! T + Tbar
         If((pyr(0)*(s1+s2)).le.s1) then
          kft = +6
           if((pyr(0)*(ved(4) + ved(2))).le.ved(4)) then
            kf3 = -2
            kfm = idf(4) 
            if(kfm.le.2) kfm = 3 - kfm ! 
            kcl = 4
           else
            kf3 = -4
            kfm = 3
            kcl = 2
           endif
         Else
          kft = -6
           if((pyr(0)*(ved(3) + ved(2))).le.ved(3)) then
            kf3 = 2
            kfm = idf(3)
            kcl = 3
           else
            kf3 = 4
            kfm = 3
            kcl = 2
           endif
         EndIf
****
      ELSEIF(ip1.eq.-4.AND.ip2.eq.+4) then
* ved(1) = DU1, ved(2) = DC1 
* ved(3) = UU1, ved(4) = UU2, ved(5) = CC1, ved(6) = CC2
* idf(3)= iuu1, idf(4)= iuu2, idf(5)= icc1, idf(6)= icc2
* U1bar U2
        s1 = (ved(6) + ved(1)) * BRS(1,1) ! T 
        s2 = (ved(5) + ved(1)) * BRS(2,1) ! Tbar
*  xcs(-4, 4) = s1 + s2 ! T + Tbar
         If((pyr(0)*(s1+s2)).le.s1) then
          kft = +6
           if((pyr(0)*(ved(6) + ved(1))).le.ved(5)) then
            kf3 = -4
            kfm = idf(6) 
            if(kfm.le.2) kfm = 3 - kfm 
            kcl = 6
           else
            kf3 = -2
            kfm = 3
            kcl = 1
           endif
         Else
          kft = -6
           if((pyr(0)*(ved(5) + ved(1))).le.ved(5)) then
            kf3 = 4
            kfm = idf(5)
            kcl = 5
           else
            kf3 = 2
            kfm = 3
            kcl = 1
           endif
         EndIf 
*************
      ELSEIF(ip1.eq.ip2.AND.ABS(ip1).eq.+2) then
* ved(7) = UU1, idf(7) = iuu1 
        kfm = idf(7)
        kcl = 7
        kf3 = ip1
         if(ip1.gt.0) kft = +6      ! KF top
         if(ip1.lt.0) kft = -6      ! KF Tbar
******
      ELSEIF(ip1.eq.ip2.AND.abs(ip1).eq.+4) then
* ved(8) = CC1, idf(8)= id1 
        kfm = idf(8)  ! position of m.t.c
        kcl = 8       ! polarization number 
        kf3 = ip1
        if(ip1.gt.0) kft = +6 
        if(ip1.lt.0) kft = -6      ! KF top
*************
      ELSEIF(ip1.eq.+2.AND.ip2.eq.-4) then
* ved(9) = UU1, ved(10) = UU2, ved(11) = CC1, ved(12) = CC2
* idf(9)= iuu1, idf(10)= iuu2, idf(11)= icc1, idf(12)= icc2
*  xcs( 2,-4) = UU1* BRS(1,1) + CC2 * BRS(2,1) ! T + Tbar
        s1 =  ved(9)*BRS(1,1)
        s2 = ved(12)*BRS(2,1)
        aran = pyr(0) * (s1 + s2)
       if(aran.le.s1) then
         kft = +6  ! Top
         kfm =  1  ! position of m.t.c
         kf3 = ip2 ! KF code of final 3
         kcl =  9  ! polarization 
       else
         kft = -6
         kfm =  2  ! position of m.t.c
         kf3 = ip1 ! KF code of final 3
         kcl =  12 ! KF code of final 3
       endif
*************
      ELSEIF(ip1.eq.-2.AND.ip2.eq.+4) then
* ved(9) = UU1, ved(10) = UU2, ved(11) = CC1, ved(12) = CC2
* idf(9)= iuu1, idf(10)= iuu2, idf(11)= icc1, idf(12)= icc2
*  xcs(-2, 4) = UU1* BRS(2,1) + CC2 * BRS(1,1) ! T + Tbar
        s1 =  ved(9)*BRS(2,1)
        s2 = ved(12)*BRS(1,1)
       aran = pyr(0) * (s1 + s2)
       if(aran.le.s1) then
         kft = -6
         kfm =  1  ! position of m.t.c
         kf3 = ip2 ! KF code of final 3
         kcl =  9  ! polarization 
       else
         kft = +6
         kfm =  2  ! position of m.t.c
         kf3 = ip1 ! KF code of final 3
         kcl =  12 ! KF code of final 3
       endif
*************
      ELSEIF(ip1.eq.+4.AND.ip2.eq.-2) then
* ved(9) = UU1, ved(10) = UU2, ved(11) = CC1, ved(12) = CC2
* idf(9)= iuu1, idf(10)= iuu2, idf(11)= icc1, idf(12)= icc2
*  xcs( 4,-2) = UU2* BRS(2,1) + CC1 * BRS(1,1) ! T + Tbar
        s1 = ved(10)*BRS(2,1)
        s2 = ved(11)*BRS(1,1)
       aran = pyr(0) * (s1 + s2)
       if(aran.le.s1) then
         kft = -6
         kfm =  2  ! position of m.t.c
         kf3 = ip1 ! KF code of final 3
         kcl =  10 ! polarization 
       else
         kft =  6
         kfm =  1  ! position of m.t.c
         kf3 = ip2 ! KF code of final 3
         kcl =  11 ! KF code of final 3
       endif
*************
      ELSEIF(ip1.eq.-4.AND.ip2.eq.+2) then
* ved(9) = UU1, ved(10) = UU2, ved(11) = CC1, ved(12) = CC2
* idf(9)= iuu1, idf(10)= iuu2, idf(11)= icc1, idf(12)= icc2
*  xcs(-4, 2) = UU2* BRS(1,1) + CC1 * BRS(2,1) ! T + Tbar
        s1 = ved(10)*BRS(1,1)
        s2 = ved(11)*BRS(2,1)
       aran = pyr(0) * (s1 + s2)
       if(aran.le.s1) then
         kft =  6
         kfm =  2  ! position of m.t.c
         kf3 = ip1 ! KF code of final 3
         kcl =  10 ! polarization 
       else
         kft = -6
         kfm =  1  ! position of m.t.c
         kf3 = ip2 ! KF code of final 3
         kcl =  11 ! KF code of final 3
       endif
*****************
      ELSEIF((ip1.eq.+2.or.ip1.eq.+4).AND.
     & (ip2.eq.-1.OR.ip2.eq.-3.or.ip2.eq.-5)) then
        kft =  6  ! KF top
        kfm =  1  ! position of m.t.c
        kf3 = ip2 ! KF code of final 3
        kcl =  9  ! KF code of final 3
*****************
      ELSEIF((ip1.eq.-2.or.ip1.eq.-4).AND.
     & (ip2.eq.+1.OR.ip2.eq.+3.or.ip2.eq.+5)) then
*   xcs(-2, J) = UU1 * BRS(2,1) ! Tbar
        kft = -6  ! KF top
        kfm =  1  ! position of m.t.c
        kf3 = ip2 ! KF code of final 3
        kcl =  9 ! KF code of final 3
*****************
      ELSEIF((ip2.eq.+2.or.ip2.eq.+4).AND.
     & (ip1.eq.-1.OR.ip1.eq.-3.or.ip1.eq.-5)) then
*  xcs(-J, 2) = UU2 * BRS(1,1) ! T
        kft =  6  ! KF top
        kfm =  2  ! position of m.t.c
        kf3 = ip1 ! KF code of final 3
        kcl = 10  ! KF code of final 3
*****************
      ELSEIF((ip2.eq.-2.or.ip2.eq.-4).AND.
     & (ip1.eq.+1.OR.ip1.eq.+3.or.ip1.eq.+5)) then
*  xcs( J,-2) = UU2 * BRS(2,1) ! Tbar
        kft = -6  ! KF top
        kfm =  2  ! position of m.t.c
        kf3 = ip1 ! KF code of final 3
        kcl = 10  ! KF code of final 3
*********


*****************
      ELSEIF( (ip1.eq.+2.AND.ip2.eq.+4).
     &     or.(ip1.eq.-2.AND.ip2.eq.-4)) then
* ved(13) = UU1, ved(14) = UU2, ved(15) = CC1, ved(16) = CC2
*   xcs( 2, 4) = (UU1 + CC2) * BRS(1,1) ! T
*   xcs(-2,-4) = (UU1 + CC2) * BRS(2,1) ! T
        if(ip1.gt.0) kft = +6
        if(ip1.lt.0) kft = -6
       aran = pyr(0) * (ved(13) + ved(16))
       if(aran.le.ved(13)) then
         kfm =  1  ! position of m.t.c
         kf3 = ip2 ! KF code of final 3
         kcl =  13 ! polarization 
       else
         kfm =  2  ! position of m.t.c
         kf3 = ip1 ! KF code of final 3
         kcl =  16 !
       endif
*****************
      ELSEIF( (ip1.eq.+4.AND.ip2.eq.+2).
     &     or.(ip1.eq.-4.AND.ip2.eq.-2)) then
* ved(13) = UU1, ved(14) = UU2, ved(15) = CC1, ved(16) = CC2
*   xcs( 4, 2) = (UU2 + CC1) * BRS(1,1) ! T
*   xcs(-4,-2) = (UU2 + CC1) * BRS(2,1) ! T
        if(ip1.gt.0) kft = +6
        if(ip1.lt.0) kft = -6
       aran = pyr(0) * (ved(14) + ved(15))
       if(aran.le.ved(14)) then
         kfm =  2  ! position of m.t.c
         kf3 = ip1 ! KF code of final 3
         kcl =  14 ! polarization 
       else
         kfm =  1  ! position of m.t.c
         kf3 = ip2 ! KF code of final 3
         kcl =  15 !
       endif
**********
      ELSEIF( 
     &(ip1.eq.+2.and.(ip2.eq.+1.OR.ip2.eq.+3.or.ip2.eq.+5))
     & .OR.
     &(ip1.eq.-2.and.(ip2.eq.-1.OR.ip2.eq.-3.or.ip2.eq.-5)) 
     &    ) then
* ved(13) = UU1, ved(14) = UU2, ved(15) = CC1, ved(16) = CC2
*    xcs( 2, J) = UU1 * BRS(1,1) ! T
*    xcs(-2,-J) = UU1 * BRS(2,1) ! Tbar
        if(ip1.gt.0) kft = +6
        if(ip1.lt.0) kft = -6
         kfm =  1  ! position of m.t.c
         kf3 = ip2 ! KF code of final 3
         kcl =  13 ! polarization 
**********
      ELSEIF( 
     &(ip2.eq.+2.and.(ip1.eq.+1.OR.ip1.eq.+3.or.ip1.eq.+5))
     & .OR.
     &(ip2.eq.-2.and.(ip1.eq.-1.OR.ip1.eq.-3.or.ip1.eq.-5)) 
     &    ) then
* ved(13) = UU1, ved(14) = UU2, ved(15) = CC1, ved(16) = CC2
* xcs( J, 2) = UU2 * BRS(1,1) ! T
* xcs(-J,-2) = UU2 * BRS(2,1) ! Tbar
        if(ip2.gt.0) kft = +6
        if(ip2.lt.0) kft = -6
         kfm =  2  ! position of m.t.c
         kf3 = ip1 ! KF code of final 3
         kcl =  14 ! polarization 
**********
      ELSEIF( 
     &(ip1.eq.+4.and.(ip2.eq.+1.OR.ip2.eq.+3.or.ip2.eq.+5))
     & .OR.
     &(ip1.eq.-4.and.(ip2.eq.-1.OR.ip2.eq.-3.or.ip2.eq.-5)) 
     &    ) then
* ved(13) = UU1, ved(14) = UU2, ved(15) = CC1, ved(16) = CC2
* xcs( 4, J) = CC1 * BRS(1,1) ! T
* xcs(-4,-J) = CC1 * BRS(2,1) ! Tbar
        if(ip1.gt.0) kft = +6
        if(ip1.lt.0) kft = -6
         kfm =  1  ! position of m.t.c
         kf3 = ip2 ! KF code of final 3
         kcl =  15 ! polarization 
**********
      ELSEIF( 
     &(ip2.eq.+4.and.(ip1.eq.+1.OR.ip1.eq.+3.or.ip1.eq.+5))
     & .OR.
     &(ip2.eq.-4.and.(ip1.eq.-1.OR.ip1.eq.-3.or.ip1.eq.-5)) 
     &    ) then
* ved(13) = UU1, ved(14) = UU2, ved(15) = CC1, ved(16) = CC2
* xcs( J, 4) = CC2 * BRS(1,1) ! T
* xcs(-J,-4) = CC2 * BRS(2,1) ! Tbar
        if(ip2.gt.0) kft = +6
        if(ip2.lt.0) kft = -6
         kfm =  2  ! position of m.t.c
         kf3 = ip1 ! KF code of final 3
         kcl =  16 ! polarization 
****
      ENDIF

      If(abs(kft).eq.1) kft = 6 * kft 
*
*      if(kft.eq.0.or.kfm.eq.0.or.kf3.eq.0.or.kcl.eq.0) then
*      print*,'********************'
*       print*,' ip1 ip2 kft kfm kf3 kcl ', ip1,ip2,kft,kfm,kf3,kcl
*      endif
      do J = 1,4
       HV(J) = HRD(kcl, J)
      enddo
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  01.06.2006                                  *
* FCNC : 2 -> 2                                                              *
*   TopReX code = 31                                                         *
      subroutine COLORF_31(ip1, ip2)
*     ------------------------------                                         *
*............................................................................*
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer I, ip1, ip2, ntop, kpp(2), kftop(2), JJ 
      integer kft, kfm, kf3 
*....... FCNC q q -> t q ....................................................*
*     q   [1] ---------O----------  q[3]                                     *
*                      <                                                     *
*                      <                                                     * 
*     q   [2] ---------O==========  T [4]                                    *
*............................................................................*

* HEPEUP :        1     2       3     4 
*       nup = 4 
* how PYTHIA will be treated
        istup(4) =  2 ! final top 
        istup(3) =  1 ! final q
* parent's lines
          mothup(1,3)=1  ! final q
          mothup(2,3)=2  !
           mothup(1,4)=1  ! final top
           mothup(2,4)=2  !
*
       call Razbor_14(ip1, ip2, kft, kfm, kf3) 

          idup(3) = kf3
          idup(4) = kft
* color's flow
        ipar(50) = 300
         if(idup(4).eq.6) then
          JJ = 1
           I = 0
         else
          JJ = 0
           I = 1
         endif
          icolup(1,4) = JJ*ipar(50) ! color 
          icolup(2,4) =  I*ipar(50) ! anticolor 
       
         if(idup(kfm).gt.0) then
          JJ = 1
           I = 0
         else
          JJ = 0
           I = 1
         endif
          icolup(1, kfm) = JJ*ipar(50) ! color 
          icolup(2, kfm) =  I*ipar(50) ! anticolor 
        ipar(50) = ipar(50) + 1
*
      If(kfm.eq.3) then
       if(ip1.gt.0) then
         icolup(1,1) = ipar(50)     !q1 color 
         icolup(2,1) = 0            !q1 anti color 
         icolup(1,2) = 0            !q2 color 
         icolup(2,2) = ipar(50)     !q2 anti color 
       else 
         icolup(1,1) = 0            !q1 color 
         icolup(2,1) = ipar(50)     !q1 anti color 
         icolup(1,2) = ipar(50)     !q2 color 
         icolup(2,2) = 0            !q2 anti color 
       endif
      Else
       JJ = 3 - kfm
       if(idup(3).gt.0) then
         icolup(1,JJ) = ipar(50)     !q1 color 
         icolup(2,JJ) = 0            !q1 anti color 
         icolup(1,3)  = ipar(50)     !q2 color 
         icolup(2,3)  = 0            !q2 anti color 
       else 
         icolup(1,JJ) = 0            !q1 color 
         icolup(2,JJ) = ipar(50)     !q1 anti color 
         icolup(1,3)  = 0            !q2 color 
         icolup(2,3)  = ipar(50)     !q2 anti color 
       endif
      EndIf
*
      
*      call hardinfo

 


      ntop = 0
      do I = 3, Nup
       if(abs(idup(I)).eq.6) then
        ntop = ntop + 1
        kpp(ntop) = I
        kftop(ntop) = idup(i)
       endif 
      enddo
       if(ntop.ge.1) then
        call top_decay(ntop, kpp, kftop) 
       else 
        STOP ! no top quark
       endif
      return
      end
c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky  06.06.2006                                  *
      subroutine hardinfo
      implicit none
      include "hepeup.inc"
      integer I

      print*,'**********************'
      do I = 1, Nup
       write(*,10) I, idup(i),mothup(1,i),mothup(2,i),
     & icolup(1,I),icolup(2,i)
      enddo
 10   format('N = ',i2,' KF ',i10,' MOT ',2(i3,1x),' COL ',2(i4,1x))
      return
      end


c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky  06.06.2006                                  *
* FCNC : G G -> T q                                                          *
*   TopReX code = 32                                                         *
      subroutine COLORF_32(ip1, ip2)
*     ------------------------------                                         *
*............................................................................*
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer I, ip1, ip2, ntop, kpp(2), kftop(2), 
     & icl1, icl2, icl3 
      integer           kft, kfq, idia
      common /tplFC_GG/ kft, kfq, idia
*....... FCNC g g -> t q ....................................................*
*     q   [1] ---------O----------  q[3]                                     *
*                      <                                                     *
*                      <                                                     * 
*     q   [2] ---------O==========  T [4]                                    *
*............................................................................*
* HEPEUP :        1     2       3     4 
*       nup = 4 
* how PYTHIA will be treated
        istup(4) =  2 ! final top 
        istup(3) =  1 ! final q
*
      idup(1) = ip1 
       if(idup(1).eq.0) idup(1) = 21
      idup(2) = ip2
       if(idup(2).eq.0) idup(2) = 21
* parent's lines
          mothup(1,3)=1  ! final q
          mothup(2,3)=2  !
           mothup(1,4)=1  ! final top
           mothup(2,4)=2  !
*
          idup(3) = kfq
          idup(4) = kft
*  color flow 
       ipar(50) = 301
       icl1 = 301
       icl2 = 302
       icl3 = 303
* 
      IF(kft.eq.+6) then ! Top
       if(idia.eq.1) then ! t-channel
          icolup(1,1) = icl1 !  color first  gluon
          icolup(2,1) = icl2 ! Acolor first  gluon
          icolup(1,2) = icl2 !  color second gluon
          icolup(2,2) = icl3 ! Acolor second gluon

          icolup(1,3) = 0
          icolup(2,3) = icl3 ! Acol from second gluon
          icolup(1,4) = icl1 ! col  from first  gluon
          icolup(2,4) = 0
       elseif(idia.eq.2) then ! u-channel
          icolup(1,1) = icl1 !  color first  gluon
          icolup(2,1) = icl2 ! Acolor first  gluon
          icolup(1,2) = icl3 !  color second gluon
          icolup(2,2) = icl1 ! Acolor second gluon

          icolup(1,3) = 0
          icolup(2,3) = icl2 ! Acol from first  gluon
          icolup(1,4) = icl3 ! col  from second gluon
          icolup(2,4) = 0
       endif 
      ELSEIF(kft.eq.-6) then ! Tbar
       if(idia.eq.1) then ! t-channel
          icolup(1,1) = icl1 !  color first  gluon
          icolup(2,1) = icl2 ! Acolor first  gluon
          icolup(1,2) = icl3 !  color second gluon
          icolup(2,2) = icl1 ! Acolor second gluon

          icolup(1,3) = icl3 ! col  from second gluon
          icolup(2,3) = 0
          icolup(1,4) = 0
          icolup(2,4) = icl2 ! Acol  from first  gluon

       elseif(idia.eq.2) then ! u-channel
          icolup(1,1) = icl1 !  color first  gluon
          icolup(2,1) = icl2 ! Acolor first  gluon
          icolup(1,2) = icl2 !  color second gluon
          icolup(2,2) = icl3 ! Acolor second gluon

          icolup(1,3) = icl1 !  col from first  gluon
          icolup(2,3) = 0
          icolup(1,4) = 0
          icolup(2,4) = icl3 ! Acol  from second gluon
       endif 
      ENDIF
**
*      print*,'**********************'
*      do I = 1, Nup
*       print*,'I ',I,' is KF',idup(i),' MOT ',
*     & mothup(1,i),mothup(2,i),' COL ',icolup(1,I),icolup(2,i)
*      enddo
 
      ntop = 0
      do I = 3, Nup
       if(abs(idup(I)).eq.6) then
        ntop = ntop + 1
        kpp(ntop) = I
        kftop(ntop) = idup(i)
       endif 
      enddo
       if(ntop.ge.1) then
        call top_decay(ntop, kpp, kftop) 
       else 
        print*,' NO top is found. Stop run'
        STOP ! no top quark
       endif
      return
      end
c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky  06.06.2006                                  *
* FCNC : G q -> q T                                                          *
*   TopReX code = 33                                                         *
      subroutine COLORF_33(ip1, ip2)
*     ------------------------------                                         *
*............................................................................*
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer I, ip1, ip2, ntop, kpp(2), kftop(2), 
     & icl1, icl2, icl3 
      integer idia, ig1, ig2, iq
      integer           idig(4)
      double precision        hrd(5,4)
      common /tplFC_GQ/ idig, hrd
      double precision hv 
      common /topol1/ hv(4)    ! TOP lepton polarisation vector
*....... FCNC g q -> g t ....................................................*
*     q   [1] ---------O----------  q[3]                                     *
*                      <                                                     *
*                      <                                                     * 
*     q   [2] ---------O==========  T [4]                                    *
*............................................................................*
* HEPEUP :        1     2       3     4 
*       nup = 4 
* how PYTHIA will be treated
        istup(4) =  2 ! final top 
        istup(3) =  1 ! final q
*
      idup(1) = ip1 
       if(idup(1).eq.0) idup(1) = 21
      idup(2) = ip2
       if(idup(2).eq.0) idup(2) = 21
* parent's lines
          mothup(1,3)=1  ! final gluon
          mothup(2,3)=2  !
           mothup(1,4)=1  ! final top
           mothup(2,4)=2  !
*
       idup(3) = 21 ! always
       ig2 = 3
      If(ip1.eq.0) then
        ig1 = 1
        iq  = 2 
                    idup(4) = +6
       if(ip2.lt.0) idup(4) = -6
        if(abs(ip2).eq.2) then
         idia = idig(1) 
           do i = 1,4
            hv(i) = hrd(1,i)
           enddo
        endif
        if(abs(ip2).eq.4) then
         idia = idig(3) 
           do i = 1,4
            hv(i) = hrd(3,i)
          enddo
        endif
      ElseIf(ip2.eq.0) then
        ig1 = 2
        iq  = 1 
                    idup(4) = +6
       if(ip1.lt.0) idup(4) = -6
        if(abs(ip1).eq.2) then
         idia = idig(2) 
           do i = 1,4
            hv(i) = hrd(2,i)
           enddo
        endif
        if(abs(ip1).eq.4) then
         idia = idig(4) 
           do i = 1,4
            hv(i) = hrd(4,i) 
           enddo
        endif
      EndIf
*  color flow 
       ipar(50) = 301
       icl1 = 301
       icl2 = 302
       icl3 = 303
* 
      IF(idup(4).eq.+6) then ! Top
       if(idia.eq.1) then ! t-channel
          icolup(1,ig1) = icl1 !  color first  gluon
          icolup(2,ig1) = icl3 ! Acolor first  gluon
          icolup(1,ig2) = icl2 !  color second gluon
          icolup(2,ig2) = icl3 ! Acolor second gluon

          icolup(1,iq) = icl2  !  col from second gluon
          icolup(2,iq) = 0     ! 
          icolup(1,4)  = icl1  ! col  from first  gluon
          icolup(2,4)  = 0
       elseif(idia.eq.2) then ! u-channel
          icolup(1,ig1) = icl3 !  color first  gluon
          icolup(2,ig1) = icl1 ! Acolor first  gluon
          icolup(1,ig2) = icl3 !  color second gluon
          icolup(2,ig2) = icl2 ! Acolor second gluon

          icolup(1,iq) = icl1  ! col from first gluon 
          icolup(2,iq) = 0     ! 
          icolup(1,4) =  icl2  ! col  from second gluon
          icolup(2,4) = 0
       endif 
      ELSEIF(idup(4).eq.-6) then ! Tbar
       if(idia.eq.1) then ! t-channel
          icolup(1,ig1) = icl3 !  color first  gluon
          icolup(2,ig1) = icl1 ! Acolor first  gluon
          icolup(1,ig2) = icl3 !  color second gluon
          icolup(2,ig2) = icl2 ! Acolor second gluon

          icolup(1,iq) = 0     ! 
          icolup(2,iq) = icl2  ! Acol from second gluon
          icolup(1,4)  = 0
          icolup(2,4)  = icl1  ! Acol from first  gluon
       elseif(idia.eq.2) then ! u-channel
          icolup(1,ig1) = icl1 !  color first  gluon
          icolup(2,ig1) = icl3 ! Acolor first  gluon
          icolup(1,ig2) = icl2 !  color second gluon
          icolup(2,ig2) = icl3 ! Acolor second gluon

          icolup(1,iq) = 0     ! 
          icolup(2,iq) = icl1  ! Acol from first gluon 
          icolup(1,4 ) = 0     ! 
          icolup(2,4) =  icl2  ! Acol  from second gluon
       endif 

      ENDIF
**
*      print*,'**********************'
*      do I = 1, Nup
*       print*,'I ',I,' is KF',idup(i),' MOT ',
*     & mothup(1,i),mothup(2,i),' COL ',icolup(1,I),icolup(2,i)
*      enddo
 
      ntop = 0
      do I = 3, Nup
       if(abs(idup(I)).eq.6) then
        ntop = ntop + 1
        kpp(ntop) = I
        kftop(ntop) = idup(i)
       endif 
      enddo
       if(ntop.ge.1) then
        call top_decay(ntop, kpp, kftop) 
       else 
        print*,' NO top is found. Stop run'
        STOP ! no top quark
       endif
      return
      end
c----------------------------------------------------------------------------c
*.. author:  Serge Slabospitsky  06.06.2006                                  *
* FCNC : G q -> gamma T                                                      *
*   TopReX code = 34                                                         *
      subroutine COLORF_34(ip1, ip2)
*     ------------------------------                                         *
*............................................................................*
      implicit none
* PYTHIA6.2 common block for external user's process 
      include "hepeup.inc"
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer I, ip1, ip2, ntop, kpp(2), kftop(2), icl1, icl2 
      integer idia, ig1, ig2, iq
      integer           idig(4)
      double precision        hrd(5,4)
      common /tplFC_GQ/ idig, hrd
      double precision hv 
      common /topol1/ hv(4)    ! TOP lepton polarisation vector
*....... FCNC g q -> g t ....................................................*
*     q   [1] ---------O----------  q[3]                                     *
*                      <                                                     *
*                      <                                                     * 
*     q   [2] ---------O==========  T [4]                                    *
*............................................................................*
* HEPEUP :        1     2       3     4 
*       nup = 4 
* how PYTHIA will be treated
        istup(4) =  2 ! final top 
        istup(3) =  1 ! final photon
*
      idup(1) = ip1 
       if(idup(1).eq.0) idup(1) = 21
      idup(2) = ip2
       if(idup(2).eq.0) idup(2) = 21
* parent's lines
          mothup(1,3)=1  ! final gluon
          mothup(2,3)=2  !
           mothup(1,4)=1  ! final top
           mothup(2,4)=2  !
*
       idup(3) = 22 ! always
       ig2 = 3
      If(ip1.eq.0) then
        ig1 = 1
        iq  = 2 
                    idup(4) = +6
       if(ip2.lt.0) idup(4) = -6
        if(abs(ip2).eq.2) then
         idia = idig(1) 
           do i = 1,4
            hv(i) = hrd(1,i)
           enddo
        endif
        if(abs(ip2).eq.4) then
         idia = idig(3) 
           do i = 1,4
            hv(i) = hrd(3,i)
          enddo
        endif
      ElseIf(ip2.eq.0) then
        ig1 = 2
        iq  = 1 
                    idup(4) = +6
       if(ip1.lt.0) idup(4) = -6
        if(abs(ip1).eq.2) then
         idia = idig(2) 
           do i = 1,4
            hv(i) = hrd(2,i)
           enddo
        endif
        if(abs(ip1).eq.4) then
         idia = idig(4) 
           do i = 1,4
            hv(i) = hrd(4,i) 
           enddo
        endif
      EndIf
*  color flow 
       ipar(50) = 301
       icl1 = 301
       icl2 = 302
* 
      IF(idup(4).eq.+6) then ! Top
          icolup(1,ig1) = icl1 !  color gluon
          icolup(2,ig1) = icl2 ! Acolor gluon

          icolup(1,iq) = icl2  !  col from gluon
          icolup(2,iq) = 0     ! 
          icolup(1,4)  = icl1  ! col  from first  gluon
          icolup(2,4)  = 0
      ELSEIF(idup(4).eq.-6) then ! Tbar
          icolup(1,ig1) = icl1 !  color gluon
          icolup(2,ig1) = icl2 ! Acolor gluon

          icolup(1,iq) = 0     ! 
          icolup(2,iq) = icl1  ! Acol from gluon
          icolup(1,4)  = 0
          icolup(2,4)  = icl2  ! Acol from gluon
      ENDIF
**
      print*,'**********************'
      do I = 1, Nup
       print*,'I ',I,' is KF',idup(i),' MOT ',
     & mothup(1,i),mothup(2,i),' COL ',icolup(1,I),icolup(2,i)
      enddo
 
      ntop = 0
      do I = 3, Nup
       if(abs(idup(I)).eq.6) then
        ntop = ntop + 1
        kpp(ntop) = I
        kftop(ntop) = idup(i)
       endif 
      enddo
       if(ntop.ge.1) then
        call top_decay(ntop, kpp, kftop) 
       else 
        print*,' NO top is found. Stop run'
        STOP ! no top quark
       endif
      return
      end

*----------------------------------------------------------------------------*
*----------------------------------------------------------------------------*
*...Author : Serge Slabospitsky                                              *
*...                                                                         *
      subroutine LIPS2(Q, p1, p2, Wt)
*     -------------------------------                                        *
*...                                                                         *
*...calculate 2-body Lorentz Invariant Phase Space                           *
*    Q --> p1 p2                                                             *
*...input  : Q is 5-vector of initial system                                 *
*...output : p1 and p2 are 5-momenta of final particles                      *
*   the LIPS2 return WT, which is the weight                                 *
*       WT = 4*pi* / p-vect/ (4 sqrt(s)) / (2*pi)**6                         *
* ...(5) are masses of the momenta                                           *
*............................................................................*

      implicit None
      double precision Q(5), p1(5), p2(5), pp(5)
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision PYR
      double precision Wt, delta, rp, cte, ste, fi
      Integer l
*
      Wt = 0.d0
      DELTA = Q(5)**4 + p1(5)**4 + p2(5)**4 
     &-2.d0*((Q(5)*p1(5))**2+(Q(5)*p2(5))**2+(p1(5)*p2(5))**2)
       if(delta.ge.0.0d0) then
        delta = dsqrt(delta)
       else
        delta = 0.d0
       endif
      rp = delta / (2.d0 * Q(5)) 
c  calculation of p1 and p2  in the rest frame of pin
      cte = 1.d0 - 2.d0*PYR(0) 
      ste = DSQRT(1.d0 - cte*cte)
      fi = 2.d0*pi*PYR(0) 
      pp(4) = (Q(5)**2 + p1(5)**2 - p2(5)**2) / (2.d0 * Q(5)) 
      pp(3) = rp*cte
      pp(2) = rp*ste*DSIN(fi)
      pp(1) = rp*ste*DCOS(fi)
      pp(5) = p1(5)
       if(pp(5).GT.pp(4)) return
* now PP is momentum of 1-particle in the rest frame of Q 
      call lorenb_s(Q, pp, p1) ! Lorentz transformation into initial frame
        if(p1(5).gt.p1(4)) return
       do l = 1,4
        p2(l) = Q(l) - p1(l)
       end do
        if(p2(5).gt.p2(4)) return
      Wt = pi * rp / (Q(5) * pi2_6 )
      return
      end
c----------------------------------------------------------------------------c
*.. author : Serge Slabospitsky                  09.01.2001                  *
      subroutine LIPS3(Q, p1, p2, p3, Wt)                                   
*     -----------------------------------                                    *
*                                                                            *
*   calculate  Lorentz invariant phase space  of 3 particles                 *
*   input  : Q -> p1 p2 p3                                                   *
*   output : p1, p2, p3 are momenta of final particle                        *
*............................................................................*

      implicit none
      double precision Q(5), p1(5),p2(5),p3(5), pc(5)
      double precision WT, WC, m0, del, PYR
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
* 
      m0 = p1(5) + p2(5) + p3(5)
      del = (Q(5) - m0)*(Q(5) + m0 - 2.d0 * p3(5))
      pc(5) = dsqrt( (m0-p3(5))**2 + del * pyr(0))   
      call LIPS2(Q,  p3, pc, WT)
      call LIPS2(pc, p1, p2, WC) 
      WT = WT * WC * pi2_3 * del 
      return
      end
c----------------------------------------------------------------------------c
*...Author : Serge Slabospitsky     08.01.2001                               *
*...                                                                         *
      subroutine LIPSN(Q, Npp, p, Wt)
*     -----------------------------                                          *
*...                                                                         *
*...calculate N-body (N >=2) Lorentz Invariant Phase Space                   *
*    Q --> p1 p2 ... pn                                                      *
*...input  : Q is 5-vector of initial system                                 *
*            P(Np,5) masses of partricles                                    *
*...output : P(Np,5) are 5-momenta of final particles                        *
*............................................................................*
      implicit None
      double precision Q(5)
      integer NP, Npp
      double precision P(20,5), pn(5), pr(5), QR(5) 
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision PYR, Wt, del, M0, ves2
      Integer I
*
      Wt = 0.d0
      NP = npp
      if(np.le.1) return 
      Wt = 1.d0
       do i = 1,5
        QR(i) = Q(i)
       enddo
      if(np.eq.2) goto 300 
*  three or more particles
       m0 = 0.d0
      do i = 1, np
       m0 = m0 + p(i,5)
      enddo 
 100  pn(5) = p(np,5)
      del = (QR(5) - M0)*(QR(5) + M0 - 2*pn(5)) 
      pr(5) = dsqrt( (m0-pn(5))**2 + del * PYR(0))
       call LIPS2(QR, pn, pr, ves2)
      wt = wt * ves2 * pi2_3 * del
       do i=1,5
        p(np,i) = pn(i)
       enddo 
       np = np - 1
        m0 = m0 - pn(5)
         do i = 1,5
          QR(i) = PR(I)
         enddo
      if(np.ge.3) goto 100
 300  continue
          pn(5) = p(2,5)
          pr(5) = p(1,5)
         call LIPS2(QR, pn, pr, ves2)
         wt = wt * ves2  
        do i=1,5
         p(2,i) = pn(i)
         p(1,i) = pr(i)
        enddo
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  14.06.2004                                  *
*  calculates dLIPS4 with denominator                                        *
*  R -> pZ(f1, f2) f3 f4                                                     *
*  ONE denominator is  included                                              *
*  the denominator is (pZ^2-M_Z^2)^2 + (M_Z * Width_Z)^2  due to Z-boson     *
*............................................................................*
      subroutine Rlip42(R, k1, k2, k3, k4, pz, wtR)
*     -------------------------------------------                            *
      implicit none
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision R(5), k1(5), k2(5), k3(5), k4(5), pz(5), pqq(5)
      include "txpar.inc" 
      double precision plim(2), ves, p2s, wtR, del, pyr 

      plim(1) = rpar(79) 
        if(plim(1).lt.(k1(5)+k2(5))) then
           plim(1) = k1(5)+k2(5)
        endif          
        plim(2) = min(rpar(80), ( R(5) - rpar(77))) 
       wtR = 0.d0
       if(plim(1).ge.plim(2)) return
      call brtwig(plim, rpar(45), rpar(48), ves, p2s)
      wtR = ves 
       pz(5) = p2s
      del = min(rpar(78), (R(5) - p2s)) / Rpar(77)
      pqq(5) = rpar(77) * del ** pyr(0)
      call Lips2(R,  pz, pqq, ves)
      wtR = wtR * ves * 4.d0 * pqq(5)**2 * dlog(del)
      call Lips2(pz, k1, k2, ves)
      wtR = wtR * ves 
      call Lips2(pqq, k3, k4, ves)
      wtR = pi2_3 * pi2_3 * wtR * ves 
      wtR = wtR * ( (rpar(46) - p2s**2)**2 + Rpar(48)**2)
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  14.06.2004                                  *
*  calculates dLIPS4 with denominator                                        *
*  R -> pZ(f1, f2) f3 f4                                                     *
*  ONE denominator is  included                                              *
*  the denominator is (pZ^2-M_Z^2)^2 + (M_Z * Width_Z)^2  due to Z-boson     *
*............................................................................*
      subroutine Rlip423(R, k1, k2, k3, k4, pz, wtR)
*     -------------------------------------------                            *
      implicit none
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision R(5), k1(5), k2(5), k3(5), k4(5), pz(5) 
      include "txpar.inc" 
      double precision ves1, ves2,wtr

      pz(5) = rpar(45)
      call Lips3(R,  k3, k4, pz, ves1)
      call Lips2(pz, k1, k2, ves2)
      wtR = ves1 * ves2
      return
      end
*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky                  09.01.2001                  *
      subroutine LIPS3_TTG(Q, PT0, p1, p2, p3, Wt)                             
*     -----------------------------------                                    *
*                                                                            *
*   calculate  Lorentz invariant phase space  of 3 particles                 *
*   input  : Q -> p1 p2 p3                                                   *
*   output : p1, p2, p3 are momenta of final particle                        *
*............................................................................*

      implicit none
      double precision Q(5), p1(5),p2(5),p3(5), pc(5)
      double precision WT, WC, m0, del 
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision PYR, fi, delta,x0,xx, pp(5), pt0,
     & c3te, s3te, rp, ptt 
      integer i
* 
      wt = 0.d0
      m0 = p1(5) + p2(5) + p3(5)
      del = (Q(5) - m0)*(Q(5) + m0 - 2.d0 * p3(5))
 100  pc(5) = dsqrt( (m0-p3(5))**2 + del * pyr(0))   
*
*      call LIPS2(Q,  p3, pc, WT)

      DELTA = Q(5)**4 + p3(5)**4 + pc(5)**4 
     &-2.d0*((Q(5)*p3(5))**2+(Q(5)*pc(5))**2+(p3(5)*pc(5))**2)
       if(delta.ge.0.0d0) then
        delta = dsqrt(delta)
       else
        delta = 0.d0
       endif
      rp = delta / (2.d0 * Q(5)) 

c  calculation of p1 and p2  in the rest frame of pin
      x0 = (rp**2 - pt0**2)/pt0**2
      if(x0.le.0.d0) return
      x0 = dsqrt(x0)
      xx = pyr(0) * x0
      PTT = rp / dsqrt(1.d0 + xx**2)
      c3te = xx / dsqrt(1.d0 + xx**2)
      fi = pyr(0) 
       if(fi.ge.0.5d0) c3te = -c3te
      s3te = DSQRT(1.d0 - c3te*c3te)
      fi = 2.d0*pi*pyr(0) 
      pp(4) = (Q(5)**2 + p3(5)**2 - pc(5)**2) / (2.d0 * Q(5)) 
      pp(3) = rp*c3te
      pp(2) = rp*s3te*DSIN(fi)
      pp(1) = rp*s3te*DCOS(fi)
      pp(5) = p3(5)
       if(pp(5).GT.pp(4)) return
* now PP is momentum of 1-particle in the rest frame of Q 
      wt = 0.d0
      call lorenb_s(Q, pp, p3) ! Lorentz transformation into initial frame
        if(p3(5).gt.p3(4)) return
       do i = 1,4
        pc(i) = Q(i) - p3(i)
       end do
        if(pc(5).gt.pc(4)) return
      Wt = pi * rp / (Q(5) * pi2_6 )
      Wt = Wt * x0 * PTT**3/rp**3
*      WT = Wt * 2.d0 ! due to +/- cosTHETA
*
      call LIPS2(pc, p1, p2, WC) 
      WT = WT * WC * pi2_3 * del 
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  06.03.2005                                  *
* rotate 5-dim vector in 3-dim  space                                        *
* rotate X-vector (defined in P frame) into Y (in Q-frame)                   *
      subroutine rot3(p, q, x, y)
*     ---------------------------                                            *
      implicit none
      double precision p(5), q(5), x(5), y(5), pv, qv, pp(3), qq(3)
      double precision px, zn
      integer J
*
       Y(5) = X(5)
       Y(4) = X(4)
      pv = dsqrt(p(1)**2+p(2)**2+p(3)**2)
      qv = dsqrt(q(1)**2+q(2)**2+q(3)**2)
      if(pv.le.0.000001d0.or.qv.le.0.000001d0) then
       Y(1) = X(1)    ! too small vector
       Y(2) = X(2)    ! nothing rotate
       Y(3) = X(3)
       return
      endif
       do J = 1,3
        pp(J) = p(j)/pv
        qq(J) = q(j)/qv
       enddo 
      px = pp(1)*x(1) + pp(2)*x(2) + pp(3)*x(3)
      zn = 1 + pp(1)*qq(1) + pp(2)*qq(2) + pp(3)*qq(3)
      if(dabs(zn).le.0.000001d0) then
        do J = 1,3
         Y(J) = X(J) - 2.d0*px*pp(j)
        enddo 
        return
      else
       zn = (px + qq(1)*x(1)+qq(2)*x(2)+qq(3)*x(3))/zn
        do J = 1,3
         Y(J) = X(J) + 2.d0*px*qq(j) - zn*(pp(J)+qq(j))
        enddo 
      endif
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  09.07.2001                                  *
      subroutine Rlip43(R, b1, b2, pl, pn, wtR)
*     -------------------------------------------                            *
*  calculates dLIPS with denominator                                         *
*  R -> pw( el nu) q (-> B1 B2)                                              *
*  two denominators are included                                             *
*  one is    (q**2)      due to gluon splitting into q1 q2                   *
*  second is (pw^2-M_W^2)^2 + (M_W * Width_W)^2  due to W-boson              *
*............................................................................*
      implicit none
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision R(5), pq(5), b1(5), b2(5), PL(5), PN(5), pw(5)
      include "txpar.inc" 
*  rpar(70) = MW_min  is  min (e+ nu) mass
      double precision amel, amnu 
      data amel /0./, amnu /0./     !  e+ and nu masses
      double precision t0, wtR, dew, deq, ves 
      double precision PYR
      double precision q0, qt0
*
      q0 = rpar(77) 
      t0 = datan(  (rpar(70)**2 - Rpar(42))/ Rpar(44))
      dew = datan(((R(5) - q0 )**2 - Rpar(42))/ Rpar(44)) - t0 
       pw(5) = dsqrt(Rpar(42) + Rpar(44)*dtan(t0 + dew * PYR(0))) 
      qt0 = min( rpar(78), (R(5) - pw(5)) ) / q0
      deq = 2.d0 * dlog(qt0) 
       pq(5) = q0 * (qt0)**(PYR(0)) 
      call Lips2(R,  pw, pq, wtR)
      call Lips2(pq, b1, b2, ves)
      wtR = pi2_3 *  deq * wtR * ves * pi2_3 * (dew / Rpar(44) ) 
       PL(5) = amel
       PN(5) = amnu
      call Lips2(pw,  Pl, Pn, ves)
      wtR = wtR * ves
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  09.07.2001                                  *
      subroutine Rlip432(R, pq, pb, pl, pn, wtR)
*     -------------------------------------------                            *
*  calculates dLIPS with denominator                                         *
*  R -> pw( el nu) q (-> B1 B2)                                              *
*  denominator: (pw^2-M_W^2)^2 + (M_W * Width_W)^2  due to W-boson           *
*............................................................................*
      implicit none
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision R(5), pq(5), pb(5), PL(5), PN(5), pw(5)
      include "txpar.inc" 
*  rpar(70) = MW_min  is  min (e+ nu) mass
      double precision amel, amnu 
      data amel /0./, amnu /0./     !  e+ and nu masses
      double precision t0, wtR, dew, ves, PYR, q0

*
      t0 = datan(  (rpar(70)**2 - Rpar(42))/ Rpar(44))
      dew = datan(((R(5) - q0 )**2 - Rpar(42))/ Rpar(44)) - t0 
      pw(5) = dsqrt(Rpar(42) + Rpar(44)*dtan(t0 + dew * PYR(0))) 
       pq(5) = 0.d0   
       call LIPS3(R,  pw, pq, pb, wtr)                                   
       PL(5) = amel
       PN(5) = amnu
       call Lips2(pw, Pl, Pn, ves)
      wtR = wtR * ves * pi2_3 * (dew / Rpar(44) ) 
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  25.06.2004                                  *
      subroutine Rlip44(R, k1, k2, k3, wtR)
*     -------------------------------------------                            *
*  calculates dLIPS3 with denominator                                        *
*  R -> pZ(f1, f2) f3                                                        *
*  ONE denominator is  included                                              *
*  the denominator is (pZ^2-M_Z^2)^2 + (M_Z * Width_Z)^2  due to Z-boson     *
*............................................................................*
      implicit none
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision R(5), k1(5), k2(5), k3(5), pz(5)
      include "txpar.inc" 
      double precision plim(2), ves, p2s, wtR
      plim(1) = rpar(70)
      plim(2) = R(5)-2.*k1(5)
      call brtwig(plim, rpar(45), rpar(48), ves, p2s)
       pz(5) = p2s
      call Lips2(R,  pz, k3, wtR)
      wtR = wtR * ves
      call Lips2(pz, k1, k2, ves)
      wtR = pi2_3 * wtR * ves 
      wtR = wtR * ( (rpar(46) - p2s**2)**2 + Rpar(48)**2)
      return
      end
*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   15.11.99                                   *
*....                                                                        *
      subroutine LIPS_QG(Q, b, PS, P0, Ves)      
*     -------------------------------------                                  *
*                                                                            *
* calculation of the LIPS with ONE system and one on-shell particle          *
* in the final state with inclusion of denominator from system               *
* the denominator corresponds to B-exchane in the t-channel                  *
*   R -> P1 (-> X1)  PS                                                      *
*                                                                            *
*    4 * R2(R -> b Ps)                                                       *
*    -----------------                                                       *
*    [(m(b)**2 - t)                                                          *
*                                                                            *
*... input :                                                                 *
*  Q   is  5-momentum of initial system                                      *
*  P0  is min. invariant mass of the system (PS)                             *
*  P0 is positive(negative) for q along-side(counter-side) Z-axis            *
*                                                                            *
*    q ------O------ b                                                       *
*            |          t = (q - b)**2                                       *
*            |                                                               *
*    --------O====== Ps                                                      *
*                                                                            *
*... output :                                                                *
*  B  is 5-momentum of the on-shell particle                                 *
*  PS is 5-momentum of the system                                            *
*  ves is the weight                                                         * 
*............................................................................*

      implicit none
      double precision PYR, aran
      double precision Q(5), B(5), PS(5), P0, bv, p2, al 
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision fi, del, cte, ste
      double precision ves
      integer j
c  calculation of Ps**2 and ps in the rest frame of pin
      del = (Q(5) - b(5))**2 - p0**2
      p2  = p0**2 + del*PYR(0)
*      ps(5) = p2
      b(4) = (q(5)**2 + b(5)**2 - p2) / 2.d0 / q(5)
      bv = dsqrt(b(4)**2 - b(5)**2)
      aran = pyr(0)
      al = b(4) / bv
       cte = al - (al-1.d0)*((al+1.d0)/(al-1.d0))**(pyr(0))
       if(p0.lt.0.d0) cte = - cte
       ste = dsqrt(1. - cte*cte)
       fi = pi2 * PYR(0) 
      b(3) = bv * cte
      b(2) = bv * ste * dsin(fi)
      b(1) = bv * ste * dcos(fi)
* now B is momentum of 1-particle in the rest frame of Q
      call lorenb_s(q, b, Ps)     ! Lorentz trasformation into
                                  ! initial frame
       ps(5) = dsqrt(p2)
      do j = 1,4
       b(j) = ps(j)
       PS(j) = Q(j) - B(j)
      end do
      ves = del * dlog((b(4)+bv)/b(5)) / (4.d0 * pi**2 * Q(5)**2)
      return
      end
c----------------------------------------------------------------------------c
*.. author : Serge Slabospitsky   30.01.2001                                 *
*....                                                                        *
      subroutine LIPS_RES_ONE(Q, Par, R, P, Ves)      
*     ------------------------------------------                             *
* LIPS with ONE resonance and one on-shell particle in the final state       *
* denominator from resonance is included                                     *
*                                                                            *
*   Q -> R (-> X1)  P                                                        *
*                                                                            *
*         R2(Q -> R P)                                                       *
*  ----------------------------                                              *
*  [(Q**2 - MR**2)**2 + g1**2]                                               *
*                                                                            *
*  LIPS(P1 -> X1) is not included                                            *
*... input :                                                                 *
*  Q   is  5-momentum of initial system                                      *
*  Par(1) mass of the resonance                                              *
*  Par(2) = g1 = width(R) * Par(1)                                           *
*  Par(3) is minimal invariant mass of the resonace                          *
*  Par(4) is maximal invariant mass of the resonace                          *
*                                                                            *
*... output :                                                                *
*  R  is 5-momentum of resonance, P is  5-momentum of on-shell particle      *
*  ves is the weight                                                         * 
*............................................................................*

      implicit none
      double precision Q(5), Par(4), R(5), P(5)
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision ves, Qlim
      double precision plim(2), jacb, r5
*
       Qlim = min(Q(5), Par(4))
        if(Qlim.le.Par(3)) then
         VES = 0.d0
         return
        endif
       plim(1) = par(3)
       plim(2) = Qlim - p(5) 
       call brtwig(plim, par(1), par(2), jacb, r5)
      r(5) = r5
      call LIPS2 (Q, R, P, Ves)
      VES = pi2_3 * ves * jacb 
      return
      end

*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   24.10.99                                   *
*....                                                                        *
      subroutine LIPS_RES_TWO(R, Par1, Par2, P1, P2, Ves)      
*     ---------------------------------------------------                    *
*                                                                            *
*  calculation of the LIPS with TWO resonances in the final state            *
*  with inclusion of denominators                                            *
*                                                                            *
*   R -> P1 (-> X1)  P2 (-> X2)                                              *
*                                                                            *
*                    R2(R -> P1 P2)                                          *
*  ---------------------------------------------------------                 *
*  [(P1**2 - m1**2)**2 + g1**2] [(P2**2 - m2**2)**2 + g2**2]                 *
*                                                                            *
*  LIPS(P1 -> X1) and LIPS(P2 -> X2)   are not included                      *
*                                                                            *
*... input :                                                                 *
*  R   is  5-momentum of initial system                                      *
*  Par1(1) is pole mass of the first resonance                               *
*  Par1(2) = width(R1) * Par1(1)                                             *
*  Par1(3) is the minimal invariant mass    of the first resonace            *
*  Par2(1:3) have the same meaning, but for the second resonance             *
*                                                                            *
*... output :                                                                *
*  P1 and P2 are 5-momenta of final resonances                               *
*  ves is the weight                                                         * 
*............................................................................*

      implicit none
      double precision R(5), Par1(3), Par2(3), P1(5), P2(5)
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common  /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision ves
      double precision p2s, plim(2), wgt1, wgt2, ves12
*
      plim(1) = par1(3)
      plim(2) = r(5) - par1(3)
      call brtwig(plim, par1(1), par1(2), wgt1, p2s)
      P1(5) = p2s

      plim(1) = par2(3)
      plim(2) = r(5) - p1(5)
      call brtwig(plim, par2(1), par2(2), wgt2, p2s)
      p2(5) = p2s !  dsqrt(par2(1)**2 + par2(2) * tan(q0 + dq*PYR(0))) 
      call LIPS2 (R, P1, P2, Ves12)
       VES = pi2_3 * pi2_3 * ves12 * wgt1 * wgt2 
      return
      end
c----------------------------------------------------------------------------c

*.. author : Serge Slabospitsky   24.10.99                                   *
*....                                                                        * 
      subroutine LIPS_Res_Wff(R, pq, pl, pn, Ves)
*     -------------------------------------------                            *
*                                                                            *
*  calculation of the dLIPS_3 with denominator due to W-boson                *
*                                                                            *
*                R3(R, Pq, Pl, Pn)                                           *
*    --------------------------------------------                            *
*    [ (p_w**2 - m_W**2)**2 + (Gamma_W * m_W)**2]                            *
*                                                                            *
*     R -> q   W (-> el nu)                                                  *
*     R    Pq  Pw    Pl Pn                                                   *
*... input :                                                                 *
*  R   is  5-momentum of initial system                                      *
*    lepton and neutrino denoted the two final fermions resulted from        *
*    from W-boson decay                                                      *
*... output :                                                                *
*  Pq, Pl, and Pn are 5-momenta of final quark, lepton, and neutrino         *
*  ves is the weight                                                         * 
*............................................................................*

      implicit none
      double precision R(5), Pq(5), Pl(5), Pn(5)
      include "txpar.inc" 
      double precision et0, Dew
      double precision ves, Ves21, Ves22
      double precision Pw(5), PYR
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
*
      et0 = atan((rpar(70)**2 - Rpar(42) ) / Rpar(44)) 
      Dew = atan( ((R(5) - Pq(5))**2 - Rpar(42))/ Rpar(44)) - et0
      pw(5) = dsqrt(Rpar(42) + Rpar(44)*tan(et0 + Dew * PYR(0))) 
      ves = pi2_3 * Dew / Rpar(44) 
      call LIPS2 (R,  Pq, Pw, ves21)
      call LIPS2 (pw, Pl, Pn, ves22)
       VES = ves * ves21 * ves22
      return
      end
*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   09.08.2001                                 *
*....                                                                        *
      subroutine brtwig(plim, mp, gam, wgt, p2s)
*     ------------------------------------------------                       *
*                                                                            *
*  calculate           d p2                                                  *
*              -----------------------,   (pmin)**2  =< p2  =< (pmax)**2     *
*              [(p2 - m2)**2 + gam**2]                                       *
* plim(1) = pmin, plim(2) = pmax are min and max values of sqrt(p**2)        *
* mp is the resonance mass,  gam = m(r) * Gamma(R)_tot                       *
* return :   WGT is total weight(jacobian) and P2S = sqrt(p**2) generated    *
*............................................................................*
      Implicit None
      double precision plim(2), mp, m2, gam, wgt, p2s, t0, del
      double precision pyr
*    plim(1) = pmin     Plim(2) = pmax
*
      m2 = mp**2
      if(plim(1).ge.plim(2)) then 
       p2s = -100.d0
       wgt = 0.d0
       return
      endif
*
      t0  = datan((plim(1)**2 - m2) / gam) 
      del = datan((plim(2)**2 - m2) / gam) - t0
      p2s = dsqrt(m2 + gam * dtan(t0 + del * pyr(0)))
      wgt = del / gam
      return
      end
*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   09.08.2001                                 *
*....                                                                        *
      subroutine brtwig_2(plim, mp, gam, wgt, p2s)
*     ------------------------------------------------                       *
*                                                                            *
*  calculate           d p2                                                  *
*              -----------------------,   (pmin)**2  =< p2  =< (pmax)**2     *
*              [(p2 - m2)**2 + gam**2]                                       *
* plim(1) = pmin, plim(2) = pmax are min and max values of sqrt(p**2)        *
* mp is the resonance mass,  gam = m(r) * Gamma(R)_tot                       *
* return :   WGT is total weight(jacobian) and P2S = sqrt(p**2) generated    *
* for Ipar(32) = 1 zero width approximation is used                          *
*............................................................................*
      Implicit None
      include "txpar.inc" 
      double precision plim(2), mp, m2, gam, wgt, p2s, t0, del
      double precision pyr
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst / pi, pi2, pi4, pi2_3, pi2_4, pi2_6
*      double precision p1(5), p2(5), phiang 
      LOGICAL first
      DATA first /.TRUE./
      SAVE first
*
      if(first) THEN
       print*,'******************************************'
       print*,'*'
        if(ipar(32).eq.1) print*,
     &'* Breit-Wigner shape is used for resonanse decay chain'
        if(ipar(32).eq.0) print*,
     &'* ZERO width approximation is used for resonanse decay chain'
       print*,'*'
       print*,'******************************************'
       first=.FALSE.
      ENDIF
      wgt = 0.d0
      m2 = mp**2
      if(plim(1).ge.plim(2)) then 
       p2s = -100.d0
       wgt = 0.d0
       return
      endif
*
      
      if(Ipar(32).eq.1) then 
       t0  = datan((plim(1)**2 - m2) / gam) 
       del = datan((plim(2)**2 - m2) / gam) - t0
       p2s = dsqrt(m2 + gam * dtan(t0 + del * pyr(0)))
       wgt = del / gam
      elseif(Ipar(32).eq.0) then
       if(mp.lt.plim(1).OR.mp.gt.plim(2)) then
         print*,'Mass of the resonance is out of ranges',
     &    'in BRTWIG_2'
         print*,'null weight is used. Check the limits'
       endif
       p2s = mp
       wgt = pi / gam
*      print*,' MW gamW ',rpar(41),rpar(43),rpar(44)
      endif       
      
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  24/06/2000                                  *
      subroutine mass2(p1,p2,sm2,sm)
*     -------------------------------                                        *
*                                                                            *
*    invariant mass of two 4-vectors                                         *
*    input : p1 and p2                                                       *
*    sm2 - mass**2                                                           *
*    sm  - mass, if SM2 < 0, then SM = 0                                     *
*............................................................................*

      Implicit none
      double precision p1(5), p2(5), SM2, SM 
*
      sm2 = (p1(4) + p2(4))*(p1(4) + p2(4))
     &    - (p1(1) + p2(1))*(p1(1) + p2(1))
     &    - (p1(2) + p2(2))*(p1(2) + p2(2))
     &    - (p1(3) + p2(3))*(p1(3) + p2(3))
      if(sm2.lt.0d0) then
       SM = 0d0
      else
       SM = DSQRT(SM2)
      endif
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  23.01.2006                                  *
      double precision FUNCTION massONE(p) 
*     ------------------------------------                                   *
*                                                                            *
*    invariant mass of 4-vector p                                            *
*    massONE = sqrt(p**2), if P**2 < 0, then massONE = -sqrt(-p**2)          *
*............................................................................*

      Implicit none
      double precision p(5)
*
      massone = p(4)**2 - p(1)**2 - p(2)**2 - p(3)**2
      if(massone.ge.0d0) then
        massone =  DSQRT(massone)
      else
        massone = -DSQRT(-massone)
      endif
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  25.11.2003                                  *
      double precision FUNCTION massTWO(p1, p2) 
*     -------------------------------                                        *
*                                                                            *
*    invariant mass of two 4-vectors                                         *
*    input : p1 and p2                                                       *
*    sm  - mass, if SM2 < 0, then SM = -sqrt(-sm2)                           *
*............................................................................*

      Implicit none
      double precision p1(5), p2(5) 
*
      masstwo = (p1(4) + p2(4))**2
     &   - (p1(1) + p2(1))**2
     &   - (p1(2) + p2(2))**2
     &   - (p1(3) + p2(3))**2
      if(masstwo.ge.0d0) then
        masstwo =  DSQRT(masstwo)
      else
        masstwo = -DSQRT(-masstwo)
      endif
      return
      end
*----------------------------------------------------------------------------*
      subroutine delt(a,b,c,aout,aouts)
*     ---------------------------------                                      *
*                                                                            *
*    kinematical function                                                    *
*    aout usial delta                                                        *
*    aouts = sqrt(aout)                                                      *
*............................................................................*
      implicit none 
      double precision a,b,c,aout,aouts 
      aout = a*a + b*b + c*c - 2*(a*b + a*c + b*c)
      aouts = 0.0d0
      if(aout.le.0.0d0) return
      aouts = DSQRT(aout)
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  24/06/2000                                  *
*----------------------------------------------------------------------------*
*... Author  :  Serge Slabospitsky                                           *
*... 25/04/2000                                                              *
*... return cos(theta*), where theta* is the angle between b-momentum        *
*..  direction of first p-momentum in P rest frame                           *
*............................................................................*

*
      Subroutine costhet_s (P, B, cost)

      Implicit None
      double precision P(5), B(5), cost, v(5)
      double precision scalp, mt, eb, pb, pp
      Integer I
*
      mt = sqrt( scalp(p, p) )
      Eb = scalp(p, b) / mt
      pb = sqrt(Eb*Eb - scalp(b,b))
      pp = sqrt(p(1)**2 + p(2)**2 + p(3)**2)
       do i = 1,3
        v(i) = (p(4)/mt) * p(i) / pp
       enddo
       v(4) = pp / mt
      cost = -scalp(v,b) / pb
      return
      end

*----------------------------------------------------------------------------*
*... Author  :  Serge Slabospitsky                                           *
*... 22/11/99                                                                *
*... modified 15.08.2005                                                     *
*... abs(pnu1(3)) <= abs(pnu2(3))                                            *
c----------------------------------------------------------------------------*

      Subroutine NeutZ(iv, nut, pl, pnu1, pnu2, pw1, pw2)

      implicit none
      include "txpar.inc" 
      double precision MV, MV2 ! m**2 of V-boson
      double precision nut(5), pl(5), pnu1(5), pnu2(5), pw1(5), pw2(5)
      double precision mt2, lt2, nt2, d, z1, z2
      double precision xx1, xx2, xx3
      integer i, iv
*
      if(iv.eq.23) then
       mv  = Rpar(45)
       mv2 = Rpar(46) ! Z-boson
      elseif(iv.eq.24) then
       mv  = Rpar(41)
       mv2 = Rpar(42) ! W-boson
      else
       print*,'Neutz: wrong IV = ',iv,' should be 23 or 24 '
       pnu1(4) = -10.d0
       pnu2(4) = -10.d0
      endif
      mt2 = mv2 / 2. + nut(1)*pl(1) + nut(2)*pl(2) 
      lt2 = pl(1)*pl(1) + pl(2) *pl(2)
      nt2 = nut(1)**2 + nut(2)**2

      d = mt2*mt2 - lt2*nt2
       if(d.lt.0.0) then
         xx1 = (pl(4)+nut(4))**2 - (pl(1)+nut(1))**2 
     &       - (pl(2)+nut(2))**2 - (pl(3)+nut(3))**2
         xx2 = dsqrt(xx1)
         xx3 = dsqrt(2.d0*(dsqrt(lt2*nt2)-nut(1)*pl(1)-nut(2)*pl(2)))
         
        pnu1(4) = -10.
        return
       else
        d = sqrt(mt2*mt2 - lt2*nt2)
       endif
      z1 = (mt2*pl(3) + pl(4)*d)/lt2
      z2 = (mt2*pl(3) - pl(4)*d)/lt2
        if(abs(z1).lt.abs(z2)) then
         pnu1(3) = z1
         pnu2(3) = z2
        else
         pnu1(3) = z2
         pnu2(3) = z1
        endif

       pnu1(4) = sqrt(nt2 + pnu1(3)**2)
       pnu2(4) = sqrt(nt2 + pnu2(3)**2)
      do i = 1,2
       pnu1(i) = nut(i)
       pnu2(i) = nut(i)
      enddo                  
       pnu1(5) = 0.d0
       pnu2(5) = 0.d0
       do i = 1,4
        pw1(i) = pnu1(i) + pl(i)
        pw2(i) = pnu2(i) + pl(i)
       enddo
        pw1(5) = mv
        pw2(5) = mv
      return
      end
*----------------------------------------------------------------------------*
*... Author  :  Serge Slabospitsky                                           *
*... 22/11/99                                                                *
*... modified 15.08.2005                                                     *
*... abs(pnu1(3)) <= abs(pnu2(3))                                            *
c----------------------------------------------------------------------------*

      Subroutine NeutZ0(iv, nut, pl, pnu1, pnu2, pw1, pw2)

      implicit none
      include "txpar.inc" 
      double precision MV, MV2 ! m**2 of V-boson
      double precision nut(5), pl(5), pnu1(5), pnu2(5), pw1(5), pw2(5)
      double precision mt2, lt2, nt2, d, z1, z2
      integer i, iv
*
      if(iv.eq.23) then
       mv  = Rpar(45)
       mv2 = Rpar(46) ! Z-boson
      elseif(iv.eq.24) then
       mv  = Rpar(41)
       mv2 = Rpar(42) ! W-boson
      else
       print*,'Neutz: wrong IV = ',iv,' should be 23 or 24 '
       pnu1(4) = -10.d0
       pnu2(4) = -10.d0
      endif
      mt2 = mv2 / 2. + nut(1)*pl(1) + nut(2)*pl(2) 
      lt2 = pl(1)*pl(1) + pl(2) *pl(2)
      nt2 = nut(1)**2 + nut(2)**2

      d = mt2*mt2 - lt2*nt2
       if(d.lt.0.0) then
*         no solutions. May be too high P_T of neutrino
        pnu1(4) = -10.
        return
       else
        d = sqrt(mt2*mt2 - lt2*nt2)
       endif
      z1 = (mt2*pl(3) + pl(4)*d)/lt2
      z2 = (mt2*pl(3) - pl(4)*d)/lt2
        if(abs(z1).lt.abs(z2)) then
         pnu1(3) = z1
         pnu2(3) = z2
        else
         pnu1(3) = z2
         pnu2(3) = z1
        endif

       pnu1(4) = sqrt(nt2 + pnu1(3)**2)
       pnu2(4) = sqrt(nt2 + pnu2(3)**2)
      do i = 1,2
       pnu1(i) = nut(i)
       pnu2(i) = nut(i)
      enddo                  
       pnu1(5) = 0.d0
       pnu2(5) = 0.d0
       do i = 1,4
        pw1(i) = pnu1(i) + pl(i)
        pw2(i) = pnu2(i) + pl(i)
       enddo
        pw1(5) = mv
        pw2(5) = mv
      return
      end
*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   21/11/2000                                 *
*....                                                                        *
      double precision FUNCTION ETARAP(P)
*     -----------------------------------                                    *
*...pseudorapidity(ETA)  CALCULATION                                         *
*............................................................................* 
      IMPLICIT NONE

      double precision P(5), COST
 
       COST = P(3) / DSQRT(P(1)**2 + P(2)**2 + P(3)**2)
       IF(dABS(COST).LT.0.999999) THEN
          ETARAP = 0.5 * dLOG((1.+ COST)/(1.- COST))
        ELSE
          ETARAP = 10000.
       ENDIF
      return 
      END
*----------------------------------------------------------------------------*
*-- Author :    S. Slabospitsky                                              *
*...CALC. THE DISTANCE IN Delta R = sqrt(dPHI**2 + dETARAP**2)               *
*............................................................................*
      double precision FUNCTION DELTAR(P1,P2)
      IMPLICIT NONE
      double precision  TX_PHIDIS, ETARAP, p1(5), p2(5) 
*
      DELTAR = dsqrt( tx_phidis(p1,p2)**2 + (etarap(p1)-etarap(p2))**2)
      END

c----------------------------------------------------------------------------c
*-- Author :    N.Stepanov                                                   *
*...CALC. THE DISTANCE IN PHI                                                *
* modified by S.Slabospitsky                                                 *
*............................................................................*
      double precision FUNCTION TX_PHIDIS(P1,P2)
      IMPLICIT NONE
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst / pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision p1(5), p2(5), phiang 
*
      TX_PHIDIS = DABS( PHIANG(P1) - PHIANG(p2) )
      if(TX_PHIDIS.gt.pi) TX_PHIDIS = PI2 - TX_PHIDIS
      END

c----------------------------------------------------------------------------c
*-- Author :    N.Stepanov,       modified by S.Abdullin                     *
* modified by S.Slabospitsky                                                 *
*............................................................................*
      double precision FUNCTION TX_PHIFUN(P)
*...PHI  CALCULATIONS
      IMPLICIT NONE
      double precision EPSSQ 
      data epssq /0.000000000001d0/
      double precision P(5), PX, PY 
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst / pi, pi2, pi4, pi2_3, pi2_4, pi2_6
 
      IF(DABS(P(1)).LT.EPSSQ.AND.DABS(P(2)).LT.EPSSQ) THEN
         PRINT '(''PHIFUN : anomalous input : '',2(1PE13.5))',P(1),p(2) 
         IF(PY.GE.0.) THEN
            TX_PHIFUN = 0.5 * PI
          ELSE
            TX_PHIFUN = 1.5 * PI
         ENDIF
       ELSE
         Px = p(1)
         py = p(2)
         TX_PHIFUN = DATAN2(PY,PX)
      ENDIF
      IF(TX_PHIFUN.LT.0.) TX_PHIFUN = TX_PHIFUN + PI2
      END
c----------------------------------------------------------------------------c
*-- T. Sjostrandt, ajusted for TopReX S.Slabospitsky, 05/05/2006             *
*   PYTHIA's name is PYANGL                                                  *
*............................................................................*
      double precision FUNCTION PHIANG(P)
*...PHI  CALCULATIONS
      IMPLICIT NONE
      double precision P(5), X, Y, R 
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common /piconst / pi, pi2, pi4, pi2_3, pi2_4, pi2_6
 
      PHIANG = 0.d0
       x = p(1)
       y = p(2) 
      R = dsqrt(X**2+Y**2)
      IF(R.LT.1D-20) RETURN
      IF(dABS(X)/R.LT.0.8D0) THEN
        PHIANG = SIGN(dACOS(X/R),Y)
      ELSE
        PHIANG = dASIN(Y/R)
        IF(X.LT.0D0.AND.PHIANG.GE.0D0) THEN
          PHIANG = pi - PHIANG
        ELSEIF(X.LT.0D0) THEN
          PHIANG=-pi - PHIANG
        ENDIF
      ENDIF

      return
      END
c----------------------------------------------------------------------------c
* modified by  Serge Slabospitsky                                            *
      subroutine lorenf_s (ps, pi, pf)
*     -------------------------------                                        *
*                                                                            *
*  Lorentz boost pi into pf.  pi is defined in ps CURENTt frame              *
*                             pf is defined in ps REST    frame              *
*  ...(5) are the masses of the particles                                    *
*............................................................................*
c
c cern proglib u102    lorenf          .version kernfor  4.04  821124
c orig. 20/08/75 l.pape
c
      implicit None
      double precision ps(5), pi(5), pf(5)
      double precision pf4, fn
*...
      if (ps(4).eq.ps(5)) go to 17
      pf4  = (pi(4)*ps(4)-pi(3)*ps(3)-pi(2)*ps(2)-pi(1)*ps(1)) / ps(5)
      fn   = (pf4+pi(4)) / (ps(4)+ps(5))
      pf(1)= pi(1) - fn*ps(1)
      pf(2)= pi(2) - fn*ps(2)
      pf(3)= pi(3) - fn*ps(3)
      pf(4)= pf4
      go to 18
c
   17 pf(1)= pi(1)
      pf(2)= pi(2)
      pf(3)= pi(3)
      pf(4)= pi(4)
c
   18 pf(5) = pi(5) 
      return
      end

*............................................................................*
* modified by  Serge Slabospitsky                                            *
      subroutine lorenb_s (ps, pi, pf)
*     -------------------------------                                        *
*                                                                            *
*  Lorentz boost pi into pf.  pi is defined in ps REST    frame              *
*                             pf is defined in ps CURRENT frame              *
*  ...(5) are the masses of the particles                                    *
*............................................................................*
*                                                                            *
* cern proglib u102    lorenb          .version kernfor  4.04  821124       *
* orig. 20/08/75 l.pape                                                      *
*............................................................................*
      
      implicit none
      double precision ps(5), pi(5), pf(5), pf4, fn

      if (ps(4).eq.ps(5)) go to 17
      pf4  = (pi(4)*ps(4)+pi(3)*ps(3)+pi(2)*ps(2)+pi(1)*ps(1)) / ps(5)
      fn   = (pf4+pi(4)) / (ps(4)+ps(5))
      pf(1)= pi(1) + fn*ps(1)
      pf(2)= pi(2) + fn*ps(2)
      pf(3)= pi(3) + fn*ps(3)
      pf(4)= pf4
      go to 18
c
   17 pf(1)= pi(1)
      pf(2)= pi(2)
      pf(3)= pi(3)
      pf(4)= pi(4)
c
   18 pf(5) = pi(5)
      return
      end

*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   06.11.99                                   *
*....                                                                        *
      Function PT(A)
*     --------------                                                         *
*                                                                            *
*  transverse momentum of 4-vector                                           *
*............................................................................*
      Implicit None
      double precision A(5)
      double precision PT
      double precision Pmin
      data Pmin /0.000001/   ! min P_x or P_y
*
      if(abs(A(1)).ge.Pmin.or.abs(A(2)).ge.Pmin) then
       PT = dsqrt( A(1)*A(1) + A(2)*A(2) )
      else
       PT = 0d0
      endif
      return
      end
*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   24/11/2000                                 *
*....                                                                        *
      double precision function SCALP (A, B)
*     --------------------------------------                                 *
*                                                                            *
*  calculate of the scalar product of two vectors                            *
*............................................................................*
      Implicit None
      double precision A(5), B(5)
*
      SCALP = A(4)*B(4) - A(1)*B(1) - A(2)*B(2) - A(3)*B(3)
      return
      end

*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   20/11/2000                                 *
*....                                                                        *
      subroutine EPSPR(A, B, C, V)
*     ------------------------------                                         *
*                                                                            *
*  V(nu) = epsilon(nu, al, bl, cl) A(al) B(bl) C(cl)                         *
* A, B, C are vectors                                                        *
*............................................................................*
      implicit None
      double precision A(5), B(5), C(5), V(4)
*
      V(4) =   A(1) * (B(2)*C(3) - B(3)*C(2))
     &       - A(2) * (B(1)*C(3) - B(3)*C(1))
     &       + A(3) * (B(1)*C(2) - B(2)*C(1))
      V(1) = - A(4) * (B(2)*C(3) - B(3)*C(2))
     &       + A(2) * (B(4)*C(3) - B(3)*C(4))
     &       - A(3) * (B(4)*C(2) - B(2)*C(4))
      V(2) =   A(4) * (B(1)*C(3) - B(3)*C(1))
     &       - A(1) * (B(4)*C(3) - B(3)*C(4))
     &       + A(3) * (B(4)*C(1) - B(1)*C(4))
      V(3) = - A(4) * (B(1)*C(2) - B(2)*C(1))
     &       + A(1) * (B(4)*C(2) - B(2)*C(4))
     &       - A(2) * (B(4)*C(1) - B(1)*C(4))
      return
      end
*----------------------------------------------------------------------------*
* routines for matrix evaluations                                            *
*----------------------------------------------------------------------------*
* M*I + p^hat, P(5) = M is the mass of fermion
* denominator (m**2 - p**2) in inculded
      subroutine PropF(p, V)
*     -------------------------------------------                            *
      implicit none
      double precision p(5), zn, scalp
      double complex V(4,4), PP, PM, P1, P2, p5
      double complex ei 
      data ei/(0.d0, 1.d0)/
      integer i,j
*
       do i=1,4
        do j = 1,4
         v(i,j) = (0.d0, 0.d0)
        enddo
       enddo
*
        zn = p(5)**2 - scalp(p, p)

       P5 =  p(5)              / zn
       Pp = (p(4) + p(3)     ) / zn 
       Pm = (p(4) - p(3)     ) / zn 
       p1 = (p(1) + ei * p(2)) / zn 
       p2 = (p(1) - ei * p(2)) / zn 
      v(1,1) = p5
      v(1,3) = PP
      v(1,4) = p2
 
      v(2,2) = p5
      v(2,3) = p1
      v(2,4) = Pm

      v(3,1) =  Pm
      v(3,2) = -p2
      v(3,3) =  p5

      v(4,1) = -p1
      v(4,2) =  Pp
      v(4,4) =  p5
      RETURN
      END
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  30.05.2006                                  *
* the fermion propagator, M*I + p^hat, P(5) = M is the mass of ON-SHELL ferm *
* denominator (m**2 - p**2 - i epsilon) in incserulded                          *
      subroutine PropF2(eps, p, V)
*     ----------------------------                                           *
      implicit none
      double precision p(5), eps, scalp
      double complex V(4,4), PP, PM, P1, P2, p5, zn
      double complex ei 
      data ei/(0.d0, 1.d0)/
      integer i,j
*
       do i=1,4
        do j = 1,4
         v(i,j) = (0.d0, 0.d0)
        enddo
       enddo
*
        zn = p(5)**2 - scalp(p, p) - ei*eps
       P5 =  p(5)              / zn
       Pp = (p(4) + p(3)     ) / zn 
       Pm = (p(4) - p(3)     ) / zn 
       p1 = (p(1) + ei * p(2)) / zn 
       p2 = (p(1) - ei * p(2)) / zn 
      v(1,1) = p5
      v(1,3) = PP
      v(1,4) = p2
 
      v(2,2) = p5
      v(2,3) = p1
      v(2,4) = Pm

      v(3,1) =  Pm
      v(3,2) = -p2
      v(3,3) =  p5

      v(4,1) = -p1
      v(4,2) =  Pp
      v(4,4) =  p5
      RETURN
      END
*----------------------------------------------------------------------------*
* p^hat, 
      subroutine Phat(p, V)
*     ---------------------                                                  *
      implicit none
      double precision p(5) 
      double complex V(4,4), PP, PM, P1, P2
      double complex ei 
      data ei/(0.d0, 1.d0)/
      integer i,j
*
       do i=1,4
        do j = 1,4
         v(i,j) = (0.d0, 0.d0)
        enddo
       enddo
*
       Pp = p(4) + p(3)   
       Pm = p(4) - p(3)   
       p1 = p(1) + ei * p(2)
       p2 = p(1) - ei * p(2)
      v(1,3) = PP
      v(1,4) = p2
 
      v(2,3) = p1
      v(2,4) = Pm

      v(3,1) =  Pm
      v(3,2) = -p2

      v(4,1) = -p1
      v(4,2) =  Pp
      RETURN
      END
*----------------------------------------------------------------------------*
* return modulo of complex A
      double precision FUNCTION CX_MD(A) 
      implicit none 
      double complex A 
*
      CX_md = A*conjg(A)
      CX_md = dsqrt(CX_MD)
      return
      end
*----------------------------------------------------------------------------*
* Real part of complex A
      double precision FUNCTION CX_Re(A) 
      implicit none 
      double complex A 
*
      CX_Re = A
      return
      end
*----------------------------------------------------------------------------*
* Imaginary part of complex A
      double precision FUNCTION CX_Im(A) 
      implicit none 
      double complex A 
      double complex   ei
      data ei/(0.d0, 1.d0)/
*
      CX_Im= -ei * A 
      return
      end
*----------------------------------------------------------------------------*
* spinors are the solutions of Dirac equation                                *
*----------------------------------------------------------------------------*
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  16.08.2004                                  *
      Subroutine Dirs2_Ubar(P, V) 
*     --------------------------                                             *
*  two solutions of Dirac equations, Ubar-spinors (rows)                     *
*... input                                                                   *
*  P(5) is fermion's momentum                                                *
*... Output : U-spinors (rows),   V(2,4)  are two solutions                  *
*... Output : V(2,4)  is two solutions                                       *
*   (gamma^5 gamma^3) V(1, ..) = +V(1, ..)                                   *
*   (gamma^5 gamma^3) V(2, ..) = -V(1, ..)                                   *
*............................................................................*

      implicit None
      double complex ei 
      data ei/(0.d0, 1.d0)/
      double complex V(2,4), PP, PM, P1, P2
      double precision P(5), NR 
      integer i,j
*
       do i=1,2
        do j = 1,4
         v(i,j) = (0.d0, 0.d0)
        enddo
       enddo
*
      NR = dsqrt(2.d0 * (p(5) + p(4)))
       Pp = (p(5) + p(4) + p(3)) / nr
       Pm = (p(5) + p(4) - p(3)) / nr
       p1 = (p(1) + ei * p(2)  ) / nr
       p2 = (p(1) - ei * p(2)  ) / nr
*   Ubar-spinors, rows
       V(1,1) =  pm
       V(1,2) = -p2
       V(1,3) =  pp
       V(1,4) =  p2 
        V(2,1) = -p1
        V(2,2) =  pp
        V(2,3) =  p1 
        V(2,4) =  pm
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  16.08.2004                                  *
      Subroutine Dirs2_U(P, V) 
*     -----------------------                                                *
*  two solutions of Dirac equations, U-spinors (columns)                     *
*... input                                                                   *
*  P(5) is fermion's momentum                                                *
*... Output : U-spinors (column),   V(2,4)  are two solutions                *
*   (gamma^5 gamma^3) V(1, ..) = +V(1, ..)                                   *
*   (gamma^5 gamma^3) V(2, ..) = -V(1, ..)                                   *
*............................................................................*

      implicit None

      double complex ei 
      data ei/(0.d0, 1.d0)/
      double complex V(2,4), PP, PM, P1, P2
      double precision P(5), NR 
      integer i,j
*
       do i=1,2
        do j = 1,4
         v(i,j) = (0.d0, 0.d0)
        enddo
       enddo

      NR = dsqrt(2.d0 * (p(5) + p(4)))
       Pp = (p(5) + p(4) + p(3)) / nr
       Pm = (p(5) + p(4) - p(3)) / nr
       p1 = (p(1) + ei * p(2)  ) / nr
       p2 = (p(1) - ei * p(2)  ) / nr
*   U-spinors, column
       V(1,1) =  pp
       V(1,2) =  p1
       V(1,3) =  pm
       V(1,4) = -p1
        V(2,1) =  p2
        V(2,2) =  pm
        V(2,3) = -p2 
        V(2,4) =  pp
      RETURN
      END
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  16.08.2004                                  *
      Subroutine Dirs2_Vbar(P, V) 
*     --------------------------                                             *
*  two solutions of Dirac equations, Vbar-spinors (rows)                     *
*... input                                                                   *
*  P(5) is fermion's momentum                                                *
*... Output : V-spinors (column),   V(2,4)  are two solutions                *
*............................................................................*

      implicit None
      double complex ei 
      data ei/(0.d0, 1.d0)/
      double complex V(2,4), PP, PM, P1, P2
      double precision P(5), NR 
      integer i,j
*
       do i=1,2
        do j = 1,4
         v(i,j) = (0.d0, 0.d0)
        enddo
       enddo
* 
      NR = dsqrt(2.d0 * (p(5) + p(4)))
       Pp = (p(5) + p(4) + p(3)) / nr
       Pm = (p(5) + p(4) - p(3)) / nr
       p1 = (p(1) + ei * p(2)  ) / nr
       p2 = (p(1) - ei * p(2)  ) / nr
*  Vbar-spinors, rows
       V(1,1) = -pm
       V(1,2) =  p2 
       V(1,3) =  pp
       V(1,4) =  p2 
        V(2,1) =  p1
        V(2,2) = -pp
        V(2,3) =  p1 
        V(2,4) =  pm
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  16.08.2004                                  *
      Subroutine Dirs2_V(P, V) 
*     -----------------------                                                *
*  two solutions of Dirac equations, V-spinors (columns)                     *
*... input                                                                   *
*  P(5) is fermion's momentum                                                *
*... Output : V-spinors (column),   V(2,4)  are two solutions                *
*............................................................................*

      implicit None
      double complex ei 
      data ei/(0.d0, 1.d0)/
      double complex V(2,4), PP, PM, P1, P2
      double precision P(5), NR 
      integer i,j
*
       do i=1,2
        do j = 1,4
         v(i,j) = (0.d0, 0.d0)
        enddo
       enddo
*
      NR = dsqrt(2.d0 * (p(5) + p(4)))
       Pp = (p(5) + p(4) + p(3)) / nr
       Pm = (p(5) + p(4) - p(3)) / nr
       p1 = (p(1) + ei * p(2)  ) / nr
       p2 = (p(1) - ei * p(2)  ) / nr
*   V-spinors, columns
       V(1,1) =  pp 
       V(1,2) =  p1
       V(1,3) = -pm
       V(1,4) =  p1 
        V(2,1) =  p2
        V(2,2) =  pm
        V(2,3) =  p2 
        V(2,4) = -pp
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  25.12.2003                                  *
      Subroutine Dirs_Ubar(P, V) 
*     --------------------------                                             *
*  two solutions of Dirac equations, Ubar-spinors (rows)                     *
*... input                                                                   *
*  P(5) is fermion's momentum                                                *
*... Output : U-spinors (rows),   V(2,4)  are two solutions                  *
*  P(5) is fermion's momentum                                                *
*... Output : V(2,4)  is two solutions                                       *
*   (gamma^5 gamma^3) V(1, ..) = +V(1, ..)                                   *
*   (gamma^5 gamma^3) V(2, ..) = -V(1, ..)                                   *
*............................................................................*

      implicit None
      double complex ei 
      data ei/(0.d0, 1.d0)/
      double complex V(2,4), PP, PM, P1, P2
      double precision P(5), NR 
      integer i,j
*
       do i = 1,2
        do j = 1,4
         V(i,j) = (0.d0, 0.d0)
        enddo
       enddo
      NR = dsqrt(2.d0 * (p(5) + p(4)))
       Pp = (p(5) + p(4) + p(3)) / nr
       Pm = (p(5) + p(4) - p(3)) / nr
       p1 = (p(1) + ei * p(2)  ) / nr
       p2 = (p(1) - ei * p(2)  ) / nr
*   Ubar-spinors, rows
       V(1,1) =  pm
       V(1,2) = -p2
       V(1,3) =  pp
       V(1,4) =  p2 
        V(2,1) = -p1
        V(2,2) =  pp
        V(2,3) =  p1 
        V(2,4) =  pm
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  25.12.2003                                  *
      Subroutine Dirs_U(P, V) 
*     -----------------------                                                *
*  two solutions of Dirac equations, U-spinors (columns)                     *
*... input                                                                   *
*  P(5) is fermion's momentum                                                *
*... Output : U-spinors (column),   V(2,4)  are two solutions                *
*   (gamma^5 gamma^3) V(1, ..) = +V(1, ..)                                   *
*   (gamma^5 gamma^3) V(2, ..) = -V(1, ..)                                   *
*............................................................................*

      implicit None
      double complex ei 
      data ei/(0.d0, 1.d0)/
      double complex V(2,4), PP, PM, P1, P2
      double precision P(5), NR 
      integer i,j
*
       do i = 1,2
        do j = 1,4
         V(i,j) = (0.d0, 0.d0)
        enddo
       enddo
      NR = dsqrt(2.d0 * (p(5) + p(4)))
       Pp = (p(5) + p(4) + p(3)) / nr
       Pm = (p(5) + p(4) - p(3)) / nr
       p1 = (p(1) + ei * p(2)  ) / nr
       p2 = (p(1) - ei * p(2)  ) / nr
*   U-spinors, column
       V(1,1) =  pp
       V(1,2) =  p1
       V(1,3) =  pm
       V(1,4) = -p1
        V(2,1) =  p2
        V(2,2) =  pm
        V(2,3) = -p2 
        V(2,4) =  pp
      RETURN
      END
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  25.12.2003                                  *
      Subroutine Dirs_Vbar(P, V) 
*     --------------------------                                             *
*  two solutions of Dirac equations, Vbar-spinors (rows)                     *
*... input                                                                   *
*  P(5) is fermion's momentum                                                *
*... Output : V-spinors (column),   V(2,4)  are two solutions                *
*............................................................................*

      implicit None
      double complex ei 
      data ei/(0.d0, 1.d0)/
      double complex V(2,4), PP, PM, P1, P2
      double precision P(5), NR 
      integer i,j
*
       do i = 1,2
        do j = 1,4
         V(i,j) = (0.d0, 0.d0)
        enddo
       enddo
      NR = dsqrt(2.d0 * (p(5) + p(4)))
       Pp = (p(5) + p(4) + p(3)) / nr
       Pm = (p(5) + p(4) - p(3)) / nr
       p1 = (p(1) + ei * p(2)  ) / nr
       p2 = (p(1) - ei * p(2)  ) / nr
*  Vbar-spinors, rows
       V(1,1) = -p1
       V(1,2) =  pp 
       V(1,3) = -p1
       V(1,4) = -pm 
        V(2,1) = -pm
        V(2,2) =  p2
        V(2,3) =  pp 
        V(2,4) =  p2
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  25.12.2003                                  *
      Subroutine Dirs_V(P, V) 
*     -----------------------                                                *
*  two solutions of Dirac equations, V-spinors (columns)                      *
*... input                                                                   *
*  P(5) is fermion's momentum                                                *
*... Output : V-spinors (column),   V(2,4)  are two solutions                *
*............................................................................*

      implicit None
      double complex ei 
      data ei/(0.d0, 1.d0)/
      double complex V(2,4), PP, PM, P1, P2
      double precision P(5), NR 
      integer i,j
*
       do i = 1,2
        do j = 1,4
         V(i,j) = (0.d0, 0.d0)
        enddo
       enddo
      NR = dsqrt(2.d0 * (p(5) + p(4)))
       Pp = (p(5) + p(4) + p(3)) / nr
       Pm = (p(5) + p(4) - p(3)) / nr
       p1 = (p(1) + ei * p(2)  ) / nr
       p2 = (p(1) - ei * p(2)  ) / nr
*   V-spinors, columns
       V(1,1) = -p2 
       V(1,2) = -pm
       V(1,3) = -p2
       V(1,4) =  pp 
        V(2,1) =  pp
        V(2,2) =  p1
        V(2,3) = -pm 
        V(2,4) =  p1
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  23.11.2005                                  *
* Ubar(Vbar)[ix] V(matrix) U(V)[iy] is product of spinor matrix spinor
* ix and iy are the number of solutions
*............................................................................*
      subroutine UBAR_M_U(ix, iy, X, Y, V, A)
      implicit None
      integer ix, iy, i1, i2
      double complex X(2,4), Y(2,4), V(4,4), A
*
      A = (0.d0, 0.d0)
      do i1 = 1,4
      do i2 = 1,4
       A = A + X(ix,i1)*V(i1,i2)*y(iy,i2)
      enddo
      enddo
      return
      end 
*----------------------------------------------------------------------------*
* SpinorString * Matrix * SpinonColumn 
      subroutine Us_M_Uc(I1, I2, U1, V, U2, UU) 
*     -------------------------------------------                            *
      implicit none
      double complex V(4,4), U1(2,4), U2(2,4), UU
      integer I1, I2, j, k 
*
      UU = (0.d0, 0.d0) 
       do j = 1,4
        do k = 1,4
         UU = UU + U1(I1,j) * V(j,k) * U2(I2,k)
        enddo
       enddo
      RETURN
      END
*----------------------------------------------------------------------------*
* V1(4, 4) = A(real) * V(4,4) 
      subroutine mscale_real(A, V)
*     -----------------------------
      implicit none
      double precision A
      double complex V(4,4)
      integer j, k 
       do j=1,4
        do k = 1,4 
         V(j, k) = A * V(j,k)
        enddo
       enddo
      RETURN
      END 
*----------------------------------------------------------------------------*
* V1(4, 4) = A(complex) * V(4,4) 
      subroutine mscale_cplx(A, V)
*     -----------------------------
      implicit none
      double complex A, V(4,4)
      integer j, k 
       do j=1,4
        do k = 1,4 
         V(j, k) = A * V(j,k)
        enddo
       enddo
      RETURN
      END 
*----------------------------------------------------------------------------*
* a*V1(4, 4) + b*V2(4,4) ==> U(4,4)
* Real A, Real B
      subroutine matr_add_RR(A, V1, B, V2, U)
*     -----------------------------
      implicit none
      double precision A, B
      double complex V1(4,4), V2(4,4), U(4,4)
      integer j, k 
       do j=1,4
        do k = 1,4 
         U(j,k) = A * V1(j, k) + B * V2(j,k)
        enddo
       enddo
      RETURN
      END 
*----------------------------------------------------------------------------*
* a*V1(4, 4) + b*V2(4,4) ==> U(4,4)
* Complex A, Complex B
      subroutine matr_add_CC(A, V1, B, V2, U)
*     -----------------------------
      implicit none
      double complex A, B, V1(4,4), V2(4,4), U(4,4)
      integer j, k 
       do j=1,4
        do k = 1,4 
         U(j,k) = A * V1(j, k) + B * V2(j,k)
        enddo
       enddo
      RETURN
      END 
*----------------------------------------------------------------------------*
* V1(4, 4) + V2(4,4) ==> U(4,4)
      subroutine matr_add_2(V1, V2, U)
*     -----------------------------
      implicit none
      double complex V1(4,4), V2(4,4), U(4,4)
      integer j, k 
       do j=1,4
        do k = 1,4 
         U(j,k) = V1(j, k) + V2(j,k)
        enddo
       enddo
      RETURN
      END 
*----------------------------------------------------------------------------*
* product of two complex matrices,  V = A1 * A2
      subroutine PROD_2(A1, A2, v) 
*     ------------------------------                                         *
      implicit none
      double complex A1(4,4), A2(4,4), v(4,4) 
      integer i1, i2 
*
      do i1 = 1,4
       do i2 = 1,4
         v(i1,i2) = A1(i1,1) * A2(1,i2) + A1(i1,2) * A2(2,i2)
     &            + A1(i1,3) * A2(3,i2) + A1(i1,4) * A2(4,i2)
       enddo
      enddo
      RETURN
      END
*----------------------------------------------------------------------------*
* product of three complex matrices,  V = A1 * A2 * A3
      subroutine PROD_3(A1, A2, A3, v) 
*     ------------------------------                                         *
      implicit none
      double complex A1(4,4), A2(4,4), A3(4,4), u(4,4), v(4,4) 
      integer i1, i2, k 
*
      do i1 = 1,4
       do i2 = 1,4
        u(i1,i2) = (0.d0, 0.d0)
         do k=1,4
          u(i1,i2) = u(i1,i2) + A1(i1,k) * A2(k,i2)
         enddo
       enddo
      enddo

      do i1 = 1,4
       do i2 = 1,4
        v(i1,i2) = (0.d0,0.d0)
          do k = 1,4
           v(i1,i2) = v(i1,i2) + U(i1,k)*A3(k,i2)
          enddo
       enddo
      enddo
      RETURN
      END
*----------------------------------------------------------------------------*
* V^mu = SpinorString * GAMMA^mu(gamma^5) * SpinonColumn 
* GV = gamma^nu * V^nu
*  
      subroutine MATR_ZbA(cg, cv, ca, Gf, Gz, GV) 
*     -------------------------------------------                            *
      implicit none
      double complex cg, cv, ca
      double complex Gf(2,2,4), Gz(2,2,4)
      double complex GV(2,2,4,4)
      integer I, J, K
*
       do i = 1,2
        do j = 1,2
         do k = 1,4
          GF(i,j, k) = (0.d0, 0.d0)
          GZ(i,j, k) = (0.d0, 0.d0)
         enddo
        enddo
       enddo
*
      do I = 1,2
      do j = 1,2    
       GV(I,J,1,3) =  cg*Gf(I,J,4) + (cv-ca)*Gz(I,J,4) 
       GV(I,J,1,4) =  cg*Gf(I,J,2) + (cv-ca)*Gz(I,J,2) 
       GV(I,J,2,3) =  cg*Gf(I,J,1) + (cv-ca)*Gz(I,J,1) 
       GV(I,J,2,4) =  cg*Gf(I,J,3) + (cv-ca)*Gz(I,J,3) 

       GV(I,J,3,1) =  cg*Gf(I,J,3) + (cv+ca)*Gz(I,J,3) 
       GV(I,J,3,2) = -cg*Gf(I,J,2) - (cv+ca)*Gz(I,J,2)
       GV(I,J,4,1) = -cg*Gf(I,J,1) - (cv+ca)*Gz(I,J,1) 
       GV(I,J,4,2) =  cg*Gf(I,J,4) + (cv+ca)*Gz(I,J,4)
      enddo 
      enddo 
      return
      end
*----------------------------------------------------------------------------*
* V^mu = SpinorString * GAMMA^mu(gamma^5) * SpinonColumn 
* GV = gamma^nu * V^nu
* cg = e(f) / Q^2(photon)
* cv(ca) = gv(ga) / (Q^2(Z-boson) - MZ^2 + ei*MZ*Gamma(Z)) 
      subroutine Us_ZbA_Uc(PZ, cg, cv, ca, X, Y, Gf, Gz) 
*     -------------------------------------------                            *
      implicit none
      include "txpar.inc"
      double complex X(2,4), Y(2,4)
      double complex cg, cv, ca
      double complex VP, VM, V1, V2, AP, AM, A1, A2
      double complex Gf(2,2,4), Gz(2,2,4)
      double complex zP, zM, z1, z2, SPV, SPA
      double precision PZ(5) 
      double complex ei 
      data ei/(0.d0, 1.d0)/
      integer I, J, k
*
       do i = 1,2
        do j = 1,2
         do k = 1,4 
          gf(i,j,k) = (0.d0, 0.d0)
          gz(i,j,k) = (0.d0, 0.d0)
         enddo
        enddo
       enddo
*
       zP = pz(4) + pz(3)
       zM = pz(4) - pz(3)
       z1 = pz(1) + ei*pz(2)
       z2 = pz(1) - ei*pz(2)

      do I = 1,2
      do j = 1,2    
       VP = 2.d0 * (X(i,3)*Y(j,1) + X(i,2)*Y(j,4))
       VM = 2.d0 * (X(i,4)*Y(j,2) + X(i,1)*Y(j,3)) 
       V1 = 2.d0 * (X(i,3)*Y(j,2) - X(i,1)*Y(j,4))
       V2 = 2.d0 * (X(i,4)*Y(j,1) - X(i,2)*Y(j,3))

       AP = 2.d0 * (X(i,3)*Y(j,1) - X(i,2)*Y(j,4))
       AM = 2.d0 * (X(i,4)*Y(j,2) - X(i,1)*Y(j,3)) 
       A1 = 2.d0 * (X(i,3)*Y(j,2) + X(i,1)*Y(j,4))
       A2 = 2.d0 * (X(i,4)*Y(j,1) + X(i,2)*Y(j,3))
*
      SPV = 0.5d0 * (vP*zM + vM*zP - v1*z2 - v2*z1)/Rpar(46)
      SPA = 0.5d0 * (aP*zM + aM*zP - a1*z2 - a2*z1)/Rpar(46)

       vP = vP - SPV * zP
       vM = vM - SPV * zM
       v1 = v1 - SPV * z1
       v2 = v2 - SPV * z2

       aP = aP - SPA * zP
       aM = aM - SPA * zM
       a1 = a1 - SPA * z1
       a2 = a2 - SPA * z2

        Gf(I,J,4) = cg * vP
        Gf(I,J,3) = cg * vM
        Gf(I,J,1) = cg * v1
        Gf(I,J,2) = cg * v2

        Gz(I,J,4) = cv * vP + ca * aP
        Gz(I,J,3) = cv * vM + ca * aM
        Gz(I,J,1) = cv * v1 + ca * a1
        Gz(I,J,2) = cv * v2 + ca * a2
      enddo
      enddo
      RETURN
      END
*----------------------------------------------------------------------------*
* V^mu = SpinorString * GAMMA^mu * SpinonColumn 
* GV = gamma^nu * V^nu gluon
      subroutine Us_gluon_Uc(P, N, gs, X, Y, GV) 
*     ------------------------------------------
      implicit none
      double complex gs, X(2,4), Y(2,4)
      double complex G(4), GV(2,2,4,4)
      double complex A, B, PP, PM, P1, P2, PG, NG 
      double complex kp, km, k1, k2, np, nm, n1, n2
      double complex kkp, kkm, kk1, kk2
      double precision P(5), N(6) 
      double complex ei 
      data ei/(0.d0, 1.d0)/
      integer I, J, j1,j2
*
       do 11 i = 1,2
       do 11 j = 1,2
       do 11 j1 = 1,4
       do 11 j2 = 1,4
 11      GV(i,j,j1,j2) = (0.d0, 0.d0)

      kp = (p(4) + p(3))     / n(6)
      km = (p(4) - p(3))     / n(6)
      k1 = (p(1) + ei * p(2))/ n(6)
      k2 = (p(1) - ei * p(2))/ n(6)
*
      kkp = n(5)*(p(4) + p(3))     / n(6) / n(6)
      kkm = n(5)*(p(4) - p(3))     / n(6) / n(6)
      kk1 = n(5)*(p(1) + ei * p(2))/ n(6) / n(6)
      kk2 = n(5)*(p(1) - ei * p(2))/ n(6) / n(6)
      np = (n(4) + n(3))     / n(6)
      nm = (n(4) - n(3))     / n(6)
      n1 = (n(1) + ei*n(2))  / n(6)
      n2 = (n(1) - ei*n(2))  / n(6)
*
      do I = 1,2
      do j = 1,2    
       A  = X(i,3)*Y(j,1) + X(i,4)*Y(j,2)
       B  = X(i,1)*Y(j,3) + X(i,2)*Y(j,4) 
        G(4)  = A + B 
       A =  X(i,3)*Y(j,1) - X(i,4)*Y(j,2)
       B = -X(i,1)*Y(j,3) + X(i,2)*Y(j,4) 
        G(3)  = A + B
       A = ei * ( X(i,4)*Y(j,1) - X(i,3)*Y(j,2))
       B = ei * (-X(i,2)*Y(j,3) + X(i,1)*Y(j,4))
        G(2)  = A + B
       A =        X(i,4)*Y(j,1) + X(i,3)*Y(j,2)
       B =       -X(i,2)*Y(j,3) - X(i,1)*Y(j,4) 
        G(1)  = A + B
*
      PG = P(4)*G(4) - P(1)*G(1) - P(2)*G(2) - P(3)*G(3)
      NG = N(4)*G(4) - N(1)*G(1) - N(2)*G(2) - N(3)*G(3)

       PP = G(4) + G(3) 
       PM = G(4) - G(3) 
       P1 = G(1) + ei*G(2) 
       P2 = G(1) - ei*G(2) 
       PP = PP  - kp * ng - np * pg + kkp * pg
       PM = PM  - km * ng - nm * pg + kkm * pg
       P1 = P1  - k1 * ng - n1 * pg + kk1 * pg
       P2 = P2  - k2 * ng - n2 * pg + kk2 * pg
        GV(I,J,1,3) =  gs * PP 
        GV(I,J,1,4) =  gs * P2 
        GV(I,J,2,3) =  gs * P1 
        GV(I,J,2,4) =  gs * PM 

        GV(I,J,3,1) =  gs * PM 
        GV(I,J,3,2) = -gs * P2 
        GV(I,J,4,1) = -gs * P1 
        GV(I,J,4,2) =  gs * PP 
      enddo
      enddo
      RETURN
      END
*----------------------------------------------------------------------------*
* V(i2, j2, 4, 4) ==> U(4,4)
      subroutine V4toU(I1, I2, V, U)
*     ------------------------------------      
      implicit none
      double complex V(2,2,4,4), U(4,4)
      integer i1, i2, j, k 
       do j=1,4
        do k = 1,4 
         U(j,k) = V(i1, i2, j, k)
        enddo
       enddo
      RETURN
      END 
*----------------------------------------------------------------------------*
* E_hat * A 
* v(1,...) = ex_hat * A,  v(2,...) = ex_hat * A          
      subroutine PROD_EhatA(I, A, v) 
*     ------------------------------                                         *
      implicit none
      double complex A(4,4), v(4,4) 
      double complex ei
      data ei /(0.d0, 1.d0)/
      integer I
*  ex
      if(I.eq.1) then
      v(1,1) = a(4,1)
      v(1,2) = a(4,2)
      v(1,3) = a(4,3)
      v(1,4) = a(4,4)
       v(2,1) = a(3,1)
       v(2,2) = a(3,2)
       v(2,3) = a(3,3)
       v(2,4) = a(3,4)
        v(3,1) = -a(2,1)
        v(3,2) = -a(2,2)
        v(3,3) = -a(2,3)
        v(3,4) = -a(2,4)
         v(4,1) = -a(1,1)
         v(4,2) = -a(1,2)
         v(4,3) = -a(1,3)
         v(4,4) = -a(1,4)
      elseif(I.eq.2) then
* ey
      v(1,1) = -ei*a(4,1)
      v(1,2) = -ei*a(4,2)
      v(1,3) = -ei*a(4,3)
      v(1,4) = -ei*a(4,4)
       v(2,1) = ei*a(3,1)
       v(2,2) = ei*a(3,2)
       v(2,3) = ei*a(3,3)
       v(2,4) = ei*a(3,4)
        v(3,1) = ei*a(2,1)
        v(3,2) = ei*a(2,2)
        v(3,3) = ei*a(2,3)
        v(3,4) = ei*a(2,4)
         v(4,1) = -ei*a(1,1)
         v(4,2) = -ei*a(1,2)
         v(4,3) = -ei*a(1,3)
         v(4,4) = -ei*a(1,4)
      endif
      RETURN
      END
*----------------------------------------------------------------------------*
* A * E_hat, v(1,...) = A * ex_hat,  v(2,...) = A * ex_hat 
      subroutine PROD_AEhat(I, A, v) 
*     ------------------------------                                         *
      implicit none
      double complex A(4,4), v(4,4) 
      double complex ei
      data ei /(0.d0, 1.d0)/
      integer I      
*  A * ex
      if(I.eq.1) then
      v(1,1) = -a(1,4)
      v(1,2) = -a(1,3)
      v(1,3) =  a(1,2)
      v(1,4) =  a(1,1)
       v(2,1) = -a(2,4)
       v(2,2) = -a(2,3)
       v(2,3) =  a(2,2)
       v(2,4) =  a(2,1)
        v(3,1) = -a(3,4)
        v(3,2) = -a(3,3)
        v(3,3) =  a(3,2)
        v(3,4) =  a(3,1)
         v(4,1) = -a(4,4)
         v(4,2) = -a(4,3)
         v(4,3) =  a(4,2)
         v(4,4) =  a(4,1)
* ey
      elseif(I.eq.2) then
      v(1,1) = -ei*a(1,4)
      v(1,2) =  ei*a(1,3)
      v(1,3) =  ei*a(1,2)
      v(1,4) = -ei*a(1,1)
       v(2,1) = -ei*a(2,4)
       v(2,2) =  ei*a(2,3)
       v(2,3) =  ei*a(2,2)
       v(2,4) = -ei*a(2,1)
        v(3,1) = -ei*a(3,4)
        v(3,2) =  ei*a(3,3)
        v(3,3) =  ei*a(3,2)
        v(3,4) = -ei*a(3,1)
         v(4,1) = -ei*a(4,4)
         v(4,2) =  ei*a(4,3)
         v(4,3) =  ei*a(4,2)
         v(4,4) = -ei*a(4,1)
      endif
      RETURN
      END
*----------------------------------------------------------------------------*
* product A_hat * (M + Phat) * Bhat
      subroutine PROD_3XPY(X, P, Y, v) 
*     ------------------------------                                         *
      implicit none
      double complex X(4,4), P(4,4), Y(4,4), u(4,4),v(4,4) 
*
      v(1,1) = p(1,1) *  (x(1,3)*y(3,1) + x(1,4)*y(4,1))
      v(1,2) = p(1,1) *  (x(1,3)*y(3,2) + x(1,4)*y(4,2))
       v(2,1) = p(1,1) * (x(2,3)*y(3,1) + x(2,4)*y(4,1))
       v(2,2) = p(1,1) * (x(2,3)*y(3,2) + x(2,4)*y(4,2))
      v(3,3) = p(1,1) *  (x(3,1)*y(1,3) + x(3,2)*y(2,3))
      v(3,4) = p(1,1) *  (x(3,1)*y(1,4) + x(3,2)*y(2,4))
       v(4,3) = p(1,1) * (x(4,1)*y(1,3) + x(4,2)*y(2,3))
       v(4,4) = p(1,1) * (x(4,1)*y(1,4) + x(4,2)*y(2,4))
*
      u(1,1) =  x(1,3)*p(3,1) + x(1,4)*p(4,1)
      u(1,2) =  x(1,3)*p(3,2) + x(1,4)*p(4,2)
       u(2,1) = x(2,3)*p(3,1) + x(2,4)*p(4,1)
       u(2,2) = x(2,3)*p(3,2) + x(2,4)*p(4,2)
      u(3,3) =  x(3,1)*p(1,3) + x(3,2)*p(2,3)
      u(3,4) =  x(3,1)*p(1,4) + x(3,2)*p(2,4)
       u(4,3) = x(4,1)*p(1,3) + x(4,2)*p(2,3)
       u(4,4) = x(4,1)*p(1,4) + x(4,2)*p(2,4)
*
      v(1,3) =  u(1,1)*y(1,3) + u(1,2)*y(2,3)
      v(1,4) =  u(1,1)*y(1,4) + u(1,2)*y(2,4)
       v(2,3) = u(2,1)*y(1,3) + u(2,2)*y(2,3)
       v(2,4) = u(2,1)*y(1,4) + u(2,2)*y(2,4)
      v(3,1) =  u(3,3)*y(3,1) + u(3,4)*y(4,1)
      v(3,2) =  u(3,3)*y(3,2) + u(3,4)*y(4,2)
       v(4,1) = u(4,3)*y(3,1) + u(4,4)*y(4,1)
       v(4,2) = u(4,3)*y(3,2) + u(4,4)*y(4,2)

      RETURN
      END
*----------------------------------------------------------------------------*
* product of three complex matrices,  V = A1 * A2 * A3
      subroutine PROD_3ZPGL(iq, A1, A2, v) 
*     ------------------------------                                         *
      implicit none
      double complex A1(4,4), A2(4,4), u(4,4), v(4,4) 
      integer i1, i2, k, iq 
*
     
      do i1 = 1,4
       do i2 = 1,4
        u(i1,i2) = (0.d0, 0.d0)
        v(i1,i2) = (0.d0, 0.d0)
         do k=1,4
          u(i1,i2) = u(i1,i2) + A1(i1,k) * A2(k,i2)
         enddo
       enddo
      enddo
      if(iq.eq.1) then
       v(1,2) =   u(1,3) 
       v(1,4) =  -u(1,1) 
       v(2,2) =   u(2,3) 
       v(2,4) =  -u(2,1) 
       v(3,2) =   u(3,3) 
       v(3,4) =  -u(3,1) 
       v(4,2) =   u(4,3) 
       v(4,4) =  -u(4,1) 
      elseif(iq.eq.2) then
       v(1,1) = -u(1,4)
       v(1,3) =  u(1,2) 
       v(2,1) = -u(2,4)
       v(2,3) =  u(2,2) 
       v(3,1) = -u(3,4)
       v(3,3) =  u(3,2) 
       v(4,1) = -u(4,4)
       v(4,3) =  u(4,2) 
      endif
      RETURN
      END
*----------------------------------------------------------------------------*
* product of three complex matrices,  V = A1 * A2 * A3
      subroutine PROD_3GLPZ(iq, A1, A2, v) 
*     ------------------------------                                         *
      implicit none
      double complex A1(4,4), A2(4,4), u(4,4), v(4,4) 
      integer i1, i2, k, iq 
*
     
      do i1 = 1,4
       do i2 = 1,4
        u(i1,i2) = (0.d0, 0.d0)
        v(i1,i2) = (0.d0, 0.d0)
         do k=1,4
          u(i1,i2) = u(i1,i2) + A1(i1,k) * A2(k,i2)
         enddo
       enddo
      enddo
      if(iq.eq.1) then
       v(1,1) = -u(4,1) 
       v(1,2) = -u(4,2) 
       v(1,3) = -u(4,3) 
       v(1,4) = -u(4,4) 
       v(3,1) =  u(2,1) 
       v(3,2) =  u(2,2) 
       v(3,3) =  u(2,3) 
       v(3,4) =  u(2,4) 
      elseif(iq.eq.2) then
       v(2,1) =  u(3,1) 
       v(2,2) =  u(3,2) 
       v(2,3) =  u(3,3) 
       v(2,4) =  u(3,4) 
       v(4,1) = -u(1,1) 
       v(4,2) = -u(1,2) 
       v(4,3) = -u(1,3) 
       v(4,4) = -u(1,4) 
      endif
      RETURN
      END
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  23.11.2005                                  *
*............................................................................*
      subroutine GUBARU(ix, iy, X, Y, V)
      implicit None
      integer ix, iy, i1,i2
      double complex X(2,4), Y(2,4), V(4,4), gp,gm,g1,g2
*
      do 11 i1 = 1,4
      do 11 i2 = 1,4
 11      v(i1,i2) = (0.d0, 0.d0)
       gp = 2.d0*( x(ix,2)*y(iy,4) + x(ix,3)*y(iy,1))
       gm = 2.d0*( x(ix,1)*y(iy,3) + x(ix,4)*y(iy,2))
       g1 = 2.d0*(-x(ix,1)*y(iy,4) + x(ix,3)*y(iy,2))
       g2 = 2.d0*(-x(ix,2)*y(iy,3) + x(ix,4)*y(iy,1))
*
      v(1,3) = gp
      v(1,4) = g2
       v(2,3) = g1
       v(2,4) = gm
      v(3,1) =  gm
      v(3,2) = -g2
       v(4,1) = -g1
       v(4,2) =  gp
      return
      end 
*----------------------------------------------------------------------------*
* gamma matrices 
      subroutine gamdir 
*     -------------------------------------------                            *
      implicit none
      double complex g4(4,4), g1(4,4), g2(4,4),g3(4,4),g5(4,4)
      common /gmatr/g4, g1, g2, g3, g5
      double complex ei 
      data ei/(0.d0, 1.d0)/
      double complex e1 
      data e1/(1.d0, 0.d0)/
      integer j,k
*
       do j = 1,4
        do k = 1,4
         g4(j,k) = (0.d0, 0.d0)
         g1(j,k) = (0.d0, 0.d0)
         g2(j,k) = (0.d0, 0.d0)
         g3(j,k) = (0.d0, 0.d0)
         g5(j,k) = (0.d0, 0.d0)
        enddo
       enddo
      g1(1,4) = -e1
      g1(2,3) = -e1
      g1(3,2) =  e1
      g1(4,1) =  e1

      g2(1,4) =  ei
      g2(2,3) = -ei
      g2(3,2) = -ei
      g2(4,1) =  ei

      RETURN
      END
*----------------------------------------------------------------------------*
* polarization vectors                                                       *
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  30.05.2006                                  *
* Massive Vector Boson Polarization vectors                                  *
* k is v-boson 4-momentum,  MV is mass, since very often k(5) = sqrt(k^2)    *
* output: ev(mu) - polarization vector                                       *
* WARNING: sum on forth vectors has                                          *
*  sign PLUS  for (k2 - m2)/k2 > 0 ==> return IP =  4                        *
*  sign MINUS for (k2 - m2)/k2 < 0 ==> return IP = -4                        *
*----------------------------------------------------------------------------*

      subroutine VpolBos(IP, mv, k, ev) 
*     -------------------------                                 
      implicit none
      double precision mv, k(5), ev(5), kt, kv, k2 
      integer IP, I ! number of polarization vector
      double precision deps ! minimal value 
      data deps /0.0000001d0/ ! e-7
*
      do i = 1,5
        ev(i) = 0.d0
      enddo
      kt = dsqrt(k(1)**2 + k(2)**2) 
      kv = dsqrt(k(1)**2 + k(2)**2 + k(3)**2) 
*
      If(    IP.eq.1) then
       if(kt.le.deps) then
          ev(1) = 1.d0  
       else
          ev(1) =  k(2) / kt    ! e1_x
          ev(2) = -k(1) / kt    ! e1_y
       endif
      ElseIf(IP.eq.2) then
       if(kt.le.deps) then
          ev(2) = 1.d0     
       else
          ev(1) =  k(3)*k(1) / kt / kv ! e2_x
          ev(2) =  k(3)*k(2) / kt / kv ! e2_y
          ev(3) =  -    kt   / kv      ! e2_z
       endif
      ElseIf(IP.eq.3) then
       if(kt.le.deps) then
          ev(4) = k(3) / mv   ! e3_0
          ev(3) = k(4) / mv   ! e3_z
       else
          ev(1) =  k(4)*k(1) / kv / mv ! e3_x
          ev(2) =  k(4)*k(2) / kv / mv ! e3_y
          ev(3) =  k(4)*k(3) / kv / mv ! e3_z
          ev(4) =       kv        / mv ! e3_0
       endif
      ElseIf(IP.eq.4) then  ! OFF-shell case
        k2 = k(4)**2 - kv**2
       if(dabs(k2).le.deps) return 
       kt = dsqrt(2.d0*dabs( (k2 - mv**2)/k2) ) / mv
          ev(1) =  kt * k(1)  ! e4_x
          ev(2) =  kt * k(2)  ! e4_y
          ev(3) =  kt * k(3)  ! e4_z
          ev(4) =  kt * k(4)  ! e4_0
        if( ((k2 - mv**2)/k2).le.0.d0) IP = - IP
      EndIf
      return
      end
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  30.05.2006                                  *
* Photon Polarization vectors                                                *
* output: ev(mu) - polarization vector                                       *
* WARNING: sum on third vectors has                                          *
* for IP = 1 and 2 : return IS = +1                                          *
* for IP = 3 : sign PLUS  for q2 > 0 ==> return IS = +1                      *
*              sign MINUS for q2 < 0 ==> return IS = -1                      *
* q(5) is evaluated here                                                     *
*............................................................................*
      subroutine VpolGAM(IP, IS,  q, V)
      implicit None
      double precision q(5), v(5), pt, qt, qn, q2
      integer IP, IS 
      double precision deps ! minimal value 
      data deps /0.0000001d0/ ! e-7
*
      call zer5mom(v)
      IS = +1
      If(    IP.eq.1) then
        if(pt(q).le.deps) then
          v(1) = 1.d0
        else 
          qt = pt(q)
          v(1) =  q(2) / qt
          v(2) = -q(1) / qt
        endif
      ElseIf(IP.eq.2) then
        if(pt(q).le.deps) then
          v(2) = 1.d0
        else
          qt = pt(q)
          qn = qt * dsqrt(qt*qt + q(3)**2)
          v(1) =  q(1)*q(3) / qn
          v(2) =  q(2)*q(3) / qn
          v(3) = -qt*qt     / qn
        endif
      ElseIf(IP.eq.3) then
          qt = dsqrt(q(1)**2 + q(2)**2) 
          qn = dsqrt(qt*qt + q(3)**2)
          q2 = q(4)**2 - qn**2
           if(q2.le.0.d0) IS = -1
         if(dabs(q2).le.deps) return 
          q2 = dsqrt(dabs(q2))
        if(qn.le.deps) then
          v(3) = 1.d0
        elseif(qt.le.deps) then
          v(4) = q(3) / q2
          v(3) = q(4) / q2
        else
          v(1) = q(4) * q(1) / qn / q2
          v(2) = q(4) * q(2) / qn / q2
          v(3) = q(4) * q(3) / qn / q2
          v(4) =        qn   / q2
        endif
      EndIf        
      return
      end 
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  30.05.2006                                  *
* Gluon Polarization vectors                                                 *
* q - gluon 4-vector, N - gauge fixing vector                                *
* output: ev(mu) - polarization vector                                       *
* WARNING: sum on third vectors has                                          *
* for IP = 1 and 2 : return IS = +1                                          *
* for IP = 3 : sign PLUS  for k2 > 0 ==> return IS = +1                      *
*              sign MINUS for k2 < 0 ==> return IS = -1                      *
*  k(5) = k2 is evaluated here                                               *
*............................................................................*
      subroutine VpolGLU(IP, IS, k, n, EV)
      implicit None
      double precision k(5), v(5), EV(5),n(5),pt, kt, kn, k2, scalp, ek
      integer IP, IS, J
      double precision deps ! minimal value 
      data deps /0.0000001d0/ !  e-7
*
      IS = +1
      call zer5mom(v,2*5)
      If(    IP.eq.1) then
        if(pt(k).le.deps) then
          v(1) = 1.d0
        else 
          kt = pt(k)
          v(1) =  k(2) / kt
          v(2) = -k(1) / kt
        endif
      ElseIf(IP.eq.2) then
        if(pt(k).le.deps) then
          v(2) = 1.d0
        else
          kt = pt(k)
          kn = kt * dsqrt(kt*kt + k(3)**2)
          v(1) =  k(1)*k(3) / kn
          v(2) =  k(2)*k(3) / kn
          v(3) = -kt*kt     / kn
        endif
      ElseIf(IP.eq.3) then
          kt = dsqrt(k(1)**2 + k(2)**2) 
          kn = dsqrt(kt*kt + k(3)**2)
          k2 = k(4)**2 - kn**2
           if(k2.le.0.d0) IS = -1
         if(dabs(k2).le.deps) return 
          k2 = dsqrt(dabs(k2))
        if(kn.le.deps) then
          v(3) = 1.d0
        elseif(kt.le.deps) then
          v(4) = k(3) / k2
          v(3) = k(4) / k2
        else
          v(1) = k(4) * k(1) / kn / k2
          v(2) = k(4) * k(2) / kn / k2
          v(3) = k(4) * k(3) / kn / k2
          v(4) =        kn   / k2
        endif
      EndIf
        call zer5mom(ev,2*5)
        ek = scalp(k, n)
       if(dabs(ek).le.deps) then
        print*,' scalar product (QN) is very small'
        print*,' polarization vector equals zero'        
        return
       endif
        ek = scalp(v, n) / ek
        do j = 1,4
         ev(j) = v(j) - ek * k(j)
        enddo
      return
      end 
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  26.10.2001                                  *
      Subroutine Vortas(P, V) 
*     ----------------------                                                 *
*  three orthogonal vectors                                                  *
*  in P rest frame : V(1,...) = e_x,  V(2,...) = e_y,  V(3,...) = e_z        *
*... input                                                                   *
*  P(5) is 5-momentum                                                        *
*... Output : V(3,4)                                                         *
*............................................................................*

      implicit None
      double precision P(5), Z, v(3,4) 
*
*  e_x (1)
      Z = p(1) / (p(5) * (p(5) + p(4)) )
       V(1,4) = p(1) / p(5) 
       V(1,1) = p(1) * z + 1.d0
       V(1,2) = p(2) * z
       V(1,3) = p(3) * z
*  e_y (2)
      Z = p(2) / (p(5) * (p(5) + p(4)) )
       V(2,4) = p(2) / p(5) 
       V(2,1) = p(1) * z 
       V(2,2) = p(2) * z + 1.d0
       V(2,3) = p(3) * z
*  e_z (3)
      Z = p(3) / (p(5) * (p(5) + p(4)) )
       V(3,4) = p(3) / p(5) 
       V(3,1) = p(1) * z 
       V(3,2) = p(2) * z
       V(3,3) = p(3) * z + 1.d0
      return
      end
*----------------------------------------------------------------------------*
      Subroutine zer5mom(P)
      implicit None
      double precision P(5)
      integer I
       do I = 1,5
        P(I) = 0.d0
       enddo
      return
      end
*----------------------------------------------------------------------------*

